:userdoc.
:docprof toc=123456.
:title.Harbour Reference Guide
.* HBDOC generated IPF Source File.
.* HBDOC Document Source Extractor, (c)1999-2000 Luiz Rafael Culik.
:h1 res=1.TFILEREAD()
:i1 id=TFILEREAD().TFILEREAD()
:p.TFILEREAD()
:p.:hp2.Read a file one line at a time
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oFile := TFileRead():New( <cFileName> [, <nReadSize> ] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileName>:ehp2.   is the required name of the file to be read.    

      :hp2. <nReadSize>:ehp2.   is the optional size to use when reading from the file. The default value is 4096 and the allowed range is 1 through 65535.  Any value outside of this range causes the default value to be used.        

:p.:hp2.Returns
:ehp2.
      An  instance of the File Reader class    

:p.:hp2.Description
:ehp2.
     TFileRead() is used to access a file one line at a time. You must  specify the name of the file when an instance of the class is created.        
     The class data should be considered private to the class.   

     The class methods are as follows&colon.   

        New()              Creates a new instance of the TFileRead class.   

        Open([<nFlags>])   Opens the file for reading. The optional nFlags  parameter can use any of the FOPEN() flags from  fileio.ch. The default is FO_READ + FO_SHARED.  Calling this method when the file is already  open causes the next ReadLine() to start over  from the beginning of the file.        

        Close()            Closes the file.   

        ReadLine()         Returns one line from the file&comma. stripping the  newline characters. The following sequences are  treated as one newline&colon. 1) CR CR LF; 2) CR LF;  3) LF; and 4) CR. Note&colon. LF CR is 2 newlines.        
        Name()             Returns the name of the file.   

        IsOpen()           Returns .T. if the file is open.   

        MoreToRead()       Returns .T. if there are more lines to be read  (think of it as an inverse EOF function).       

        Error()            Returns .T. if an error has occurred.   

        ErrorNo()          Returns the current error code.   

        ErrorMsg([<cPre>]) Returns a formatted error message.   

:p.:hp2.Examples
:ehp2.

      #ifdef __HARBOUR__
       #define NEW_LINE CHR( 10 )
      #else
       #define NEW_LINE CHR( 13 ) + CHR( 10 )
      #endif
      #include &cdq.fileio.ch&cdq.

      PROCEDURE Main( cFile )
      LOCAL oFile &colon.= TFileRead()&colon.New( cFile )

         oFile&colon.Open()
         IF oFile&colon.Error()
            QOUT( oFile&colon.ErrorMsg( &cdq.FileRead&colon. &cdq. ) )
         ELSE
            WHILE oFile&colon.MoreToRead()
               OUTSTD( oFile&colon.ReadLine() )
               OUTSTD( NEW_LINE )
            END WHILE
            oFile&colon.Close()
         END IF
      QUIT
  

:p.:hp2.Tests
:ehp2.

      See Examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is a new Harbour Tools class     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=2.TClass():elink.
.br
:h1 res=3.ISBIN()
:i1 id=ISBIN().ISBIN()
:p.ISBIN()
:p.:hp2.Check if the value is a Binary  Number
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISBIN(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   STRING TO BE CHECKED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.   .T. IF THE STRING IS BYNARY,otherwise .F.    

:p.:hp2.Description
:ehp2.
     check if the passed string is a bynary number or not     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=4.ISOCTAL():elink.
.br
:link reftype=hd res=5.ISDEC():elink.
.br
:link reftype=hd res=6.ISHEXA():elink.
.br
:h1 res=4.ISOCTAL()
:i1 id=ISOCTAL().ISOCTAL()
:p.ISOCTAL()
:p.:hp2.Check if the value is a Octal  Number
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISOCTAL(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   STRING TO BE CHECKED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.   .T. IF THE STRING IS OCTAL;otherwise .F.    

:p.:hp2.Description
:ehp2.
     check if the passed string is a octal number or not     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=3.ISBIN():elink.
.br
:link reftype=hd res=5.ISDEC():elink.
.br
:link reftype=hd res=6.ISHEXA():elink.
.br
:h1 res=5.ISDEC()
:i1 id=ISDEC().ISDEC()
:p.ISDEC()
:p.:hp2.Check if the value is a Decimal  Number
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISDEC(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   STRING TO BE CHECKED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.   .T. IF THE STRING IS DECIMAL;otherwise .F.    

:p.:hp2.Description
:ehp2.
     check if the passed string is a decimal number or not     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=4.ISOCTAL():elink.
.br
:link reftype=hd res=3.ISBIN():elink.
.br
:link reftype=hd res=6.ISHEXA():elink.
.br
:h1 res=6.ISHEXA()
:i1 id=ISHEXA().ISHEXA()
:p.ISHEXA()
:p.:hp2.Check if the value is a Hexal  Number
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISHEXA(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   STRING TO BE CHECKED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.   .T. IF THE STRING IS HEXA;otherwise .F.    

:p.:hp2.Description
:ehp2.
     check if the passed string is a hexa number or not     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=4.ISOCTAL():elink.
.br
:link reftype=hd res=5.ISDEC():elink.
.br
:link reftype=hd res=3.ISBIN():elink.
.br
:h1 res=7.DECTOBIN()
:i1 id=DECTOBIN().DECTOBIN()
:p.DECTOBIN()
:p.:hp2.Converts a Decimal Value to Binary
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DECTOBIN(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   NUMBER TO BE CONVERTED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.    NUMBER CONVERTED    

:p.:hp2.Description
:ehp2.
     This function converts a string <cN> from an decimal value  to an binary value.     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=8.Dectohexa():elink.
.br
:link reftype=hd res=9.dectooctal():elink.
.br
:h1 res=10.DECTOOCTAL()
:i1 id=DECTOOCTAL().DECTOOCTAL()
:p.DECTOOCTAL()
:p.:hp2.Converts a Decimal Value to Octal
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DECTOOCTAL(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   NUMBER TO BE CONVERTED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.    NUMBER CONVERTED    

:p.:hp2.Description
:ehp2.
     This function converts a string <cN> from an decimal value  to an octal value.     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=8.Dectohexa():elink.
.br
:link reftype=hd res=11.dectobin():elink.
.br
:h1 res=12.DECTOHEXA()
:i1 id=DECTOHEXA().DECTOHEXA()
:p.DECTOHEXA()
:p.:hp2.Converts a Decimal Value to Hexa
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DECTOHEXA(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   NUMBER TO BE CONVERTED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.    NUMBER CONVERTED    

:p.:hp2.Description
:ehp2.
     This function converts a string <cN> from an decimal value  to an hexadecimal value.     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=13.Dectobin():elink.
.br
:link reftype=hd res=9.dectooctal():elink.
.br
:h1 res=14.BINTODEC()
:i1 id=BINTODEC().BINTODEC()
:p.BINTODEC()
:p.:hp2.Converts a Binary Value to Decimal
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BIntODEC(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   NUMBER TO BE CONVERTED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.    NUMBER CONVERTED    

:p.:hp2.Description
:ehp2.
     This function converts a string <cN> from an binary value  to a numeric decimal value.     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=15.OctaltoDec():elink.
.br
:link reftype=hd res=16.HexatoDec():elink.
.br
:h1 res=17.OCTALTODEC()
:i1 id=OCTALTODEC().OCTALTODEC()
:p.OCTALTODEC()
:p.:hp2.Converts a Octal Value to Decimal
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.OCTALTODEC(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   NUMBER TO BE CONVERTED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.    NUMBER CONVERTED    

:p.:hp2.Description
:ehp2.
     This function converts a string <cN> from an octal value  to a numeric decimal value.     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=18.BintoDec():elink.
.br
:link reftype=hd res=16.HexatoDec():elink.
.br
:h1 res=19.HEXATODEC()
:i1 id=HEXATODEC().HEXATODEC()
:p.HEXATODEC()
:p.:hp2.Converts a Hexa Value to Decimal
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HEXATODEC(<cN>) -><cNr>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cN>:ehp2.   NUMBER TO BE CONVERTED    

:p.:hp2.Returns
:ehp2.
      :hp2. <cNr>:ehp2.    NUMBER CONVERTED    

:p.:hp2.Description
:ehp2.
     This function converts a string <cN> from an hexadecimal value  to a numeric decimal value.     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=15.OctaltoDec():elink.
.br
:link reftype=hd res=18.BintoDec():elink.
.br
:h1 res=20.FIELDTYPE()
:i1 id=FIELDTYPE().FIELDTYPE()
:p.FIELDTYPE()
:p.:hp2.Determines the type of a given field.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDTYPE(<nFieldNum>) --> cFieldType
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nFieldNum>:ehp2.   Data field , which type need to be determined.    

:p.:hp2.Returns
:ehp2.
      :hp2. FIELDTYPE():ehp2.   returns the character that designates the type of a given field:     

:cgraphic.
 
      'C'   character string;
      'N'   numeric;
      'L'   logical;
      'D'   date;
      'M'   memo.
 
:ecgraphic.


:p.:hp2.Description
:ehp2.
     This function determines the type of a field&comma. designated by its  number.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL i
      USE Tests NEW
      FOR i = 1 TO FCOUNT()
        ? FieldType( i )
      NEXT
      USE
      RETURN NIL
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-CLIPPER tools compatible     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=21.FIELDSIZE():elink.
.br
:link reftype=hd res=22.FIELDDECI():elink.
.br
:h1 res=21.FIELDSIZE()
:i1 id=FIELDSIZE().FIELDSIZE()
:p.FIELDSIZE()
:p.:hp2.Determines the size of a given field.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDSIZE(<nFieldNum>) --> nFieldSize
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nFieldNum>:ehp2.   Data field , which size need to be determined.    

:p.:hp2.Returns
:ehp2.
      :hp2. FIELDSIZE():ehp2.   returns the number that designates the size of a given field.     

:p.:hp2.Description
:ehp2.
     This function determines the size of a field&comma. designated by its number.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL i
      USE Tests NEW
      FOR i = 1 TO FCOUNT()
        ? FieldSize( i )
      NEXT
      USE
      RETURN NIL
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-CLIPPER tools compatible     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=20.FIELDTYPE():elink.
.br
:link reftype=hd res=22.FIELDDECI():elink.
.br
:h1 res=22.FIELDDECI()
:i1 id=FIELDDECI().FIELDDECI()
:p.FIELDDECI()
:p.:hp2.Determines the number of decimal places of a given numeric field.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDDECI(<nFieldNum>) --> nFieldDeci
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nFieldNum>:ehp2.   Numeric data field , for which number of decimal places need to be determined.     

:p.:hp2.Returns
:ehp2.
      :hp2. FIELDDECI():ehp2.   returns the numeric value that designates the number of decimal places of a given field.     

:p.:hp2.Description
:ehp2.
     This function determines the number of decimal places of a given numeric field.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL i
      USE Tests NEW
      FOR i = 1 TO FCOUNT()
        ? FieldDeci( i )
      NEXT
      USE
      RETURN NIL
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-CLIPPER tools compatible     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=20.FIELDTYPE():elink.
.br
:link reftype=hd res=21.FIELDSIZE():elink.
.br
:h1 res=23.THTML()
:i1 id=THTML().THTML()
:p.THTML()
:p.:hp2.Html Class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oHtml:=THtml():New(<cFile>) --> oHtm
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of the Html file to create    

:p.:hp2.Returns
:ehp2.
      :hp2. <oHtm>:ehp2.   An  instance of the THtml Class    

:p.:hp2.Description
:ehp2.
     THtml() is a class that creates an .html file of the same  name you pass to the constructor.        
     The class methods are as follows&colon.   
        New(<cFile>)         Create a new instance of the THtml class   
        Close()              Close the created file   
        WriteTitle(<cTitle>) Write the file title   
        WritePar(<cPar>)     Writes a paragraph   
        WriteParBold(<cPar>) Same as WritePar()&comma. but the text is bold   
        WriteLink(<cLink>&comma.<cName>)  Write a link to another topic   
        WriteText(<cText>)   Write any text   

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()

      LOCAL oHtm

      oHtm &colon.= THTML()&colon.New( &cdq.www\harbour.html&cdq. )
      oHtm&colon.WriteTitle( &cdq.Harbour Reference Guide&cdq. )
      oHtm&colon.WritePar( &cdq.HARBOUR&cdq. )
      oHtm&colon.WriteLink( &cdq.OverView&cdq. )
      oHtm&colon.WriteLink( &cdq.License&cdq. )
      oHtm&colon.WriteLink( &cdq.http&colon.//www.gnu.org/copyleft/gpl&cdq. )
      oHtm&colon.WritePar( &cdq.See the Links Above&cdq. )
      oHtm&colon.Close()
      RETURN Nil
  </par>
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is a new Harbour Tools class   

:p.:hp2.Platforms
:ehp2.
     ALL   
.br
See Also&colon.
:link reftype=hd res=24.TCLASS():elink.
.br
:h1 res=25.TOS2()
:i1 id=TOS2().TOS2()
:p.TOS2()
:p.:hp2.OS/2 Documentation Class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oNg:=TOs2():New(<cFile>) --> oOs2
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of the IPF Source file to create    

:p.:hp2.Returns
:ehp2.
      :hp2. <oOs2>:ehp2.   An instance of the TOs2 Class    

:p.:hp2.Description
:ehp2.
     TOs2() is a class that creates the OS/2 IPF Source  of the same name you pass to the constructor.        
     The class methods are as follows&colon.   
        New(<cFile>)          Create a new instance of the TOs2 class   
        Close()               Close the created file   
        WriteTitle(<cTopic>&comma.<cTitle>)  Write the file title   
        WritePar(<cPar>)      Write a paragraph   
        WriteParBold(<cPar>)  Same as WritePar()&comma. but the text is bold   
        WriteLink(<cLink>)    Write a link to another topic   
        ScanLink(<clink>)     Scan the aLinkRef array for a valid topic   
        DosToOs2Text(<cText>) Convert a Dos string to a OS/2 String   

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()

      LOCAL oNg

      oNg &colon.= TOs2()&colon.New( &cdq.ngi\harbour.ngi&cdq. )
      oNg&colon.WriteTitle( &cdq.Harbour Reference Guide&cdq. )
      oNg&colon.WritePar( &cdq.HARBOUR&cdq. )
      oNg&colon.WriteLink( &cdq.OverView&cdq. )
      oNg&colon.WriteLink( &cdq.License&cdq. )

      oNg&colon.WritePar( &cdq.See the Links Above&cdq. )
      oNg&colon.Close()
      RETURN Nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is a new Harbour Tools class   

:p.:hp2.Platforms
:ehp2.
     ALL   
.br
See Also&colon.
:link reftype=hd res=26.TNortonGuide():elink.
.br
:h1 res=27.TNORTONGUIDE()
:i1 id=TNORTONGUIDE().TNORTONGUIDE()
:p.TNORTONGUIDE()
:p.:hp2.Norton Guide Class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oNg:=TNortonGuide():New(<cFile>) --> oNg
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of the Ng Source file to create    

:p.:hp2.Returns
:ehp2.
      :hp2. <oNg>:ehp2.   An instance of the TNortonGuide Class    

:p.:hp2.Description
:ehp2.
     TNortonGuide() is a class that creates the Norton Guide Source  Code of the same name you pass to the constructor.        
     The class methods are as follows&colon.   
        New(<cFile>)         Create an instance of the TNortonGuide class   
        Close()              Close the created file   
        WriteTitle(<cTopic>&comma.<cTitle>)  Write the file title   
        WritePar(<cPar>)     Write a paragraph   
        WriteParBold(<cPar>) Same as WritePar()&comma. but the text is bold   
        WriteLink(<cLink>)   Write a link to another topic   

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()

      LOCAL oNg

      oNg &colon.= TNortonGuide()&colon.New( &cdq.ngi\harbour.ngi&cdq. )
      oNg&colon.WriteTitle( &cdq.Harbour Reference Guide&cdq. )
      oNg&colon.WritePar( &cdq.HARBOUR&cdq. )
      oNg&colon.WriteLink( &cdq.OverView&cdq. )
      oNg&colon.WriteLink( &cdq.License&cdq. )

      oNg&colon.WritePar( &cdq.See the Links Above&cdq. )
      oNg&colon.Close()
      RETURN Nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is a new Harbour Tools class   

:p.:hp2.Platforms
:ehp2.
     ALL   
.br
See Also&colon.
:link reftype=hd res=28.TTroff():elink.
.br
:link reftype=hd res=29.TRtf():elink.
.br
:link reftype=hd res=30.THtml():elink.
.br
:link reftype=hd res=31.TOs2():elink.
.br
:h1 res=32.TRTF()
:i1 id=TRTF().TRTF()
:p.TRTF()
:p.:hp2.Rtf Class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oNg:=TRtf():New(<cFile>) --> oRtf
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of the RTF file to create    

:p.:hp2.Returns
:ehp2.
      :hp2. <oRtf>:ehp2.   An  instance of the TRtf Class    

:p.:hp2.Description
:ehp2.
     TRtf() is a class that creates the RTF Documentation Source  Code of the same name you pass to the constructor.        
     The class methods are as follows&colon.   
        New(<cFile>)         Create a new instance of the TRtf class   
        Close()              Close the create file   
        WriteTitle(<cTopic>&comma.<cTitle>)  Write the file title   
        WritePar(<cPar>)     Write a paragraph   
        WriteParBold(<cPar>) Same as WritePar()&comma. but the text is bold   
        WriteLink(<cLink>)   Write a link to another topic   
        WriteHeader()        Write the RTF header   
        EndPar()             Write the end paragraph delimiter   

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()

      LOCAL oRtf

      oRtf &colon.= TRtf()&colon.New( &cdq.rtf\harbour.rtf&cdq. )
      oRtf&colon.WriteHeader()
      oRtf&colon.WriteTitle( &cdq.Harbour Reference Guide&cdq. )
      oRtf&colon.WritePar( &cdq.HARBOUR&cdq. )&colon.Endpar()
      oRtf&colon.WriteLink( &cdq.OverView&cdq. )
      oRtf&colon.WriteLink( &cdq.License&cdq. )

      oRtf&colon.WritePar( &cdq.See the Links Above&cdq. )&colon.EndPar()
      oRtf&colon.Close()
      RETURN Nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is a new Harbour Tools class   

:p.:hp2.Platforms
:ehp2.
     ALL   
.br
See Also&colon.
:link reftype=hd res=26.TNortonGuide():elink.
.br
:h1 res=33.TTROFF()
:i1 id=TTROFF().TTROFF()
:p.TTROFF()
:p.:hp2.Troff Class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oTroff:=TTrof():New(<cFile>) --> oTrf
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of the Troff file to create    

:p.:hp2.Returns
:ehp2.
      :hp2. <oTrf>:ehp2.    instance of the TTroff Class    

:p.:hp2.Description
:ehp2.
     TTroff() is a class that creates the TROFF Documentation Source  Code of the same name you pass to the constructor.        
     The class methods are as follows&colon.   
        New(<cFile>)         Create a new instance of the THtml class  Close()              Close the created file        
        WriteTitle(<cTopic>&comma.<cTitle>) Write the file title   
        WritePar(<cPar>)     Write a paragraph   
        WriteParBold(<cPar>) Same as WritePar()&comma. but the text is bold   
        WriteLink(<cLink>)   Write a link to another topic   
        WriteText()          Writes text without formating   

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()

      LOCAL oTroff
      oTroff &colon.= TTroff()&colon.New( &cdq.tr\harbour.ngi&cdq. )
      oTroff&colon.WriteTitle( &cdq.Harbour Reference Guide&cdq. )
      oTroff&colon.WritePar( &cdq.HARBOUR&cdq. )
      oTroff&colon.WriteLink( &cdq.OverView&cdq. )
      oTroff&colon.WriteLink( &cdq.License&cdq. )

      oTroff&colon.WritePar( &cdq.See the Links Above&cdq. )
      oTroff&colon.Close()

      RETURN Nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is a new Harbour Tools class   

:p.:hp2.Platforms
:ehp2.
     ALL   
.br
See Also&colon.
:link reftype=hd res=26.TNortonGuide():elink.
.br
:h1 res=34.CD()
:i1 id=CD().CD()
:p.CD()
:p.:hp2.Change the Current Directory
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CD(<cDir>) --> lSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDir>:ehp2.   DIR TO BE CHANGED    

:p.:hp2.Returns
:ehp2.
      :hp2. <lSucess>:ehp2.   .T. IF SUCESSFUL; otherwise .F.    

:p.:hp2.Description
:ehp2.
     CHANGE THE CURRENT DIRECTORY     

:p.:hp2.Examples
:ehp2.

      IF CD(&cdq.OLA&cdq.)
         RETURN(.T.)
      ELSE
         RETURN(.F.)
      ENDIF

:p.:hp2.Files
:ehp2.
     Header is Fileio.ch     
.br
See Also&colon.
:link reftype=hd res=35.MD():elink.
.br
:link reftype=hd res=36.RD():elink.
.br
:h1 res=35.MD()
:i1 id=MD().MD()
:p.MD()
:p.:hp2.Creates a Directory
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MD(<cDir>) -> <lSucess>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDir>:ehp2.   DIRECTORY TO BE CREATED    

:p.:hp2.Returns
:ehp2.
      :hp2. <lSucess>:ehp2.   .T. IF SUCESSFUL; otherwise .F.    

:p.:hp2.Description
:ehp2.
     CREATE A  DIRECTORY     

:p.:hp2.Examples
:ehp2.

      IF MD(&cdq.OLA&cdq.)
        RETURN(.T.)
      ELSE
        RETURN(.F.)
      ENDIF

:p.:hp2.Files
:ehp2.
     Header is Fileio.ch     
.br
See Also&colon.
:link reftype=hd res=34.CD():elink.
.br
:link reftype=hd res=35.MD():elink.
.br
:h1 res=36.RD()
:i1 id=RD().RD()
:p.RD()
:p.:hp2.Remove a Directory
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RD(<cDir>) --> <lSucess>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDir>:ehp2.   DIR TO BE DELETED    

:p.:hp2.Returns
:ehp2.
      :hp2. <lSucess>:ehp2.   .T. IF SUCESSFUL; otherwise .F.    

:p.:hp2.Description
:ehp2.
    REMOVE A  DIRECTORY     

:p.:hp2.Examples
:ehp2.

     IF RD(&cdq.OLA&cdq.)
       RETURN(.T.)
     ELSE
       RETURN(.F.)
     ENDIF

:p.:hp2.Files
:ehp2.
     Header is Fileio.ch     
.br
See Also&colon.
:link reftype=hd res=34.CD():elink.
.br
:link reftype=hd res=35.MD():elink.
.br
:h1 res=37.STRFORMAT()
:i1 id=STRFORMAT().STRFORMAT()
:p.STRFORMAT()
:p.:hp2.Format a string
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.StrFormat(<cMask>[, <cPar1>[, <cParn>[, ...]]) --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cMask>:ehp2.   Holds the mask for the resulting string    
      :hp2. <cParn>:ehp2.   Holds the strings to be inserted in the mask maximum 9 of them can be specified.        

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.   Return the mask with all the parameters inserted.    

:p.:hp2.Description
:ehp2.
     String replacment&comma. can be useful when writing international  apps. You can separate the constant strings from the variable ones.  Each %1 - %9 marks will be replaced with the appropriate parameter  from the parameter list.        
     Marks can be in any order&comma. and can be duplicated.   
     You can print &cdq.%&cdq. character with &cdq.%%&cdq..   

:p.:hp2.Examples
:ehp2.

      StrFormat(&cdq.Please insert disk %1 to drive %2&cdq.&comma. LTrim(Str(2))&comma. &cdq.A&colon.&cdq.)
      StrFormat(&cdq.This is %1 from %2&cdq.&comma. &cdq.Victor&cdq.&comma. &cdq.Hungary&cdq.)
      StrFormat(&cdq.%2 %1 %2&cdq.&comma. &cdq.Param1&cdq.&comma. &cdq.Param2&cdq.)
   

:p.:hp2.Tests
:ehp2.

      ? StrFormat(&cdq.Please insert disk %1 to drive %2&cdq.&comma. LTrim(Str(2))&comma. &cdq.A&colon.&cdq.)
      ? StrFormat(&cdq.This is %1 from %2&cdq.&comma. &cdq.Victor&cdq.&comma. &cdq.Hungary&cdq.)
      ? StrFormat(&cdq.%2 %1 %2&cdq.&comma. &cdq.Param1&cdq.&comma. &cdq.Param2&cdq.)
      ? StrFormat(&cdq.Hello&cdq.)
      ? StrFormat(&cdq.%1 - %2&cdq.&comma. &cdq.one&cdq.)
      ? StrFormat(&cdq.%1 - %2&cdq.&comma. &cdq.one&cdq.&comma. &cdq.two&cdq.)
      ? StrFormat(&cdq.%2 - %1&cdq.&comma. &cdq.one&cdq.&comma. &cdq.two&cdq.)
      ? StrFormat(&cdq.%2 - %&cdq.&comma. &cdq.one&cdq.&comma. &cdq.two&cdq.)
      ? StrFormat(&cdq.%% - %&cdq.&comma. &cdq.one&cdq.&comma. &cdq.two&cdq.)
      ? StrFormat(&cdq.%9 - %&cdq.&comma. &cdq.one&cdq.&comma. &cdq.two&cdq.)
  
:p.:hp2.Status
:ehp2.
      Done

:p.:hp2.Compliance
:ehp2.
     All platforms   

:p.:hp2.Files
:ehp2.
     Library is libmisc     
:h1 res=38.AMONTHS()
:i1 id=AMONTHS().AMONTHS()
:p.AMONTHS()
:p.:hp2.Returns an array with the months names.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AMONTHS()  --> aMonths
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <aMonths>:ehp2.   The array which holds the months names.    

:p.:hp2.Description
:ehp2.
     This function returns an array with all the months names in the  selected current language.     

:p.:hp2.Examples
:ehp2.

      aMonths &colon.= AMonths()
      ? aMonths[1] -> January
      ? aMonths[1] -> Enero (if the selected language is Spanish)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=39.ADAYS():elink.
.br
:h1 res=39.ADAYS()
:i1 id=ADAYS().ADAYS()
:p.ADAYS()
:p.:hp2.Returns an array with the days names.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ADAYS()  --> aDays
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <aDays>:ehp2.     The array which holds the days names.    

:p.:hp2.Description
:ehp2.
     This function returns an array with all the days names in the  selected current language.     

:p.:hp2.Examples
:ehp2.

      aDays &colon.= ADays()
      ? aDays[1] -> Sunday
      ? aDays[1] -> Domingo (if the selected language is Spanish)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=39.ADAYS():elink.
.br
:h1 res=40.ISLEAPYEAR()
:i1 id=ISLEAPYEAR().ISLEAPYEAR()
:p.ISLEAPYEAR()
:p.:hp2.Checks if the given date is a leap year.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISLEAPYEAR( <dDate> )  --> lTrueOrFalse
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <lTrueOrFalse>:ehp2.    A logical that indicates if the date year is leap    

:p.:hp2.Description
:ehp2.
     This function returns true if the given date is a leap year and  false if isn't.     

:p.:hp2.Examples
:ehp2.

      ? IsLeapYear( DToC( &cdq.01/01/2000&cdq. ) ) -> .t.
      ? IsLeapYear( DToC( &cdq.01/01/2001&cdq. ) ) -> .f.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=41.DAYSINMONTH():elink.
.br
:h1 res=41.DAYSINMONTH()
:i1 id=DAYSINMONTH().DAYSINMONTH()
:p.DAYSINMONTH()
:p.:hp2.Gets the days in a month.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DAYSINMONTH( <dDate> )  --> nDays
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nDays>:ehp2.     The number of days of the month.    

:p.:hp2.Description
:ehp2.
     This function returns the number of days of the given date month.     

:p.:hp2.Examples
:ehp2.

      ? DaysInMonth( DToC( &cdq.01/01/2000&cdq. ) ) -> 31
      ? DaysInMonth( DToC( &cdq.02/01/2000&cdq. ) ) -> 29
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=42.IsLeapYear():elink.
.br
:h1 res=43.EOM()
:i1 id=EOM().EOM()
:p.EOM()
:p.:hp2.Gets the last day in a month.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.EOM( <dDate> )  --> dEOM
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <dEOM>:ehp2.      The last day in the month.    

:p.:hp2.Description
:ehp2.
     This function returns the last day of a given month date.     

:p.:hp2.Examples
:ehp2.

      ? EOM( DToC( &cdq.01/01/2000&cdq. ) ) -> &cdq.01/31/2000&cdq.
      ? EOM( DToC( &cdq.02/01/2000&cdq. ) ) -> &cdq.01/29/2000&cdq.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=44.BOM():elink.
.br
:h1 res=44.BOM()
:i1 id=BOM().BOM()
:p.BOM()
:p.:hp2.Gets the first day in a month.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BOM( <dDate> )  --> dBOM
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <dBOM>:ehp2.      The first day in the month.    

:p.:hp2.Description
:ehp2.
     This function returns the first day of a given month date.     

:p.:hp2.Examples
:ehp2.

      ? BOM( DToC( &cdq.01/25/2000&cdq. ) ) -> &cdq.01/01/2000&cdq.
      ? BOM( DToC( &cdq.02/24/2000&cdq. ) ) -> &cdq.02/01/2000&cdq.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=43.EOM():elink.
.br
:h1 res=45.DOY()
:i1 id=DOY().DOY()
:p.DOY()
:p.:hp2.Gets the day number of the year.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DOY( <dDate> )  --> nDay
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nDay>:ehp2.      The day number    

:p.:hp2.Description
:ehp2.
     This function returns the day number of the year for a given date.     

:p.:hp2.Examples
:ehp2.

      ? DOY( DToC( &cdq.01/31/2000&cdq. ) ) -> 31
      ? DOY( DToC( &cdq.02/20/2000&cdq. ) ) -> 51
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=46.WOY():elink.
.br
:h1 res=46.WOY()
:i1 id=WOY().WOY()
:p.WOY()
:p.:hp2.Gets the week number of the year.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.WOY( <dDate>, <lIso> )  --> nWeek
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nWeek>:ehp2.     The week number <lIso>    Flag that indicates if <nWeek> is in ISO format.     

:p.:hp2.Description
:ehp2.
     This function returns the week number of the year for a given date.  It returns the week number in ISO format ( range 0 - 52&comma. by default  or passing TRUE as second parameter) or 1 - 52 if lIso is FALSE.     

:p.:hp2.Examples
:ehp2.

      ? WOY( DToC( &cdq.01/31/2000&cdq. ) ) -> 3
      ? WOY( DToC( &cdq.01/31/2000&cdq. )&comma. FALSE ) -> 4
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=45.DOY():elink.
.br
:h1 res=47.EOY()
:i1 id=EOY().EOY()
:p.EOY()
:p.:hp2.Gets the last date of the year.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.EOY( <dDate> )  --> dEOY
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <dEOY>:ehp2.      The last date of the year.    

:p.:hp2.Description
:ehp2.
     This function returns the last date of a given year date.     

:p.:hp2.Examples
:ehp2.

      ? EOY( DToC( &cdq.01/01/2000&cdq. ) ) -> &cdq.31/12/2000&cdq.
      ? EOY( DToC( &cdq.01/01/2001&cdq. ) ) -> &cdq.31/12/2001&cdq.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=48.BOY():elink.
.br
:h1 res=48.BOY()
:i1 id=BOY().BOY()
:p.BOY()
:p.:hp2.Gets the first date of the year.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BOY( <dDate> )  --> dBOY
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.     A valid date.    

:p.:hp2.Returns
:ehp2.
      :hp2. <dBOY>:ehp2.      The first day in the year.    

:p.:hp2.Description
:ehp2.
     This function returns the first date of a given year date.     

:p.:hp2.Examples
:ehp2.

      ? BOY( DToC( &cdq.01/25/2000&cdq. ) ) -> &cdq.01/01/2000&cdq.
      ? BOY( DToC( &cdq.02/24/2001&cdq. ) ) -> &cdq.01/01/2001&cdq.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is new in Harbour.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is libmisc     
.br
See Also&colon.
:link reftype=hd res=47.EOY():elink.
.br
:h1 res=49.HB_ZIPFILE()
:i1 id=HB_ZIPFILE().HB_ZIPFILE()
:p.HB_ZIPFILE()
:p.:hp2.Create a zip file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_ZIPFILE( <cFile> , <cFileToCompress> | <aFiles>, <nLevel> ,
:ehp2.
:p.:hp2.<bBlock>,<lOverWrite> ) ---> lCompress
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.     Name of the zip file      

      :hp2. <cFileToCompress>:ehp2.    Name of a file to Compress ,Drive and/or path can be used       

      :hp2. <aFiles>:ehp2.    An array containing files to compress,Drive and/or path can be used       

      :hp2. <nLevel>:ehp2.    Compression level ranging from 0 to 9      

      :hp2. <bBlock>:ehp2.    Code block to execute while compressing      

      :hp2. <lOverWrite>:ehp2.    Toggle to overwite the file if exists    

:p.:hp2.Returns
:ehp2.
      :hp2. <lCompress>:ehp2.    .T. if file was create,otherwise .f.    

:p.:hp2.Description
:ehp2.
     This function create a zip file named <cFile>. If the extension  is ommited &comma. .ZIP will be assumed. If the second parameter is a  character string&comma. this file will be added to the zip file.If the  second parameter is an array&comma.all files names contained in <aFiles>  will be compressed.       

     If <nLevel> is used&comma. it detemines the compression type where 0 means  No compression and 9 means best compression.       

     If <bBlock> is used&comma. every time the file is opened to compress it  will do the action specified.       

     If <lOverWrite> is used &comma. it toggles to overwrite or not the existing  file.Default is to overwrite the file.     

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()
      IF HB_ZIPFILE( &cdq.TEST.ZIP&cdq.&comma.&cdq.TEST.PRG&cdq.)
         qout(&cdq.File was successly create&cdq.)
      ENDIF
      IF HB_ZIPFILE( &cdq.TEST1.ZIP&cdq.&comma.{&cdq.TEST.PRG&cdq.&comma.&cdq.c&colon.\windows\win.ini&cdq.})
         qout(&cdq.File was successly create&cdq.)
      ENDIF
      IF HB_ZIPFILE( &cdq.TEST2.ZIP&cdq.&comma.{&cdq.TEST.PRG&cdq.&comma.&cdq.c&colon.\windows\win.ini&cdq.}&comma.8&comma.{|cFile|&comma.qout(cFile)})
         qout(&cdq.File was successly create&cdq.)
      ENDIF

      Return Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Platforms
:ehp2.
     Win32     

:p.:hp2.Files
:ehp2.
     Library is zlib.lib and zlib_bor.lib For Borland Compilers  Library is zlib.lib zlib_ms.lib for MSVC compilers     
:h1 res=50.HB_UNZIPFILE()
:i1 id=HB_UNZIPFILE().HB_UNZIPFILE()
:p.HB_UNZIPFILE()
:p.:hp2.Unzip a compressed file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_UNZIPFILE( <cFile> , <bBlock> ) ---> lCompress
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.     Name of the zip file      

      :hp2. <bBlock>:ehp2.    Code block to execute while compressing      

:p.:hp2.Returns
:ehp2.
      :hp2. <lCompress>:ehp2.    .T. if all file was successfuly restored,otherwise .f.    

:p.:hp2.Description
:ehp2.
     This function restores all files contained inside the <cFile>.  If the extension is ommited &comma..ZIP will be assumed. If a file already  exists&comma. it wlllbe overwriten.       

     If <bBlock> is used&comma. every time the file is opened to compress it  will do the action specified.     

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()
      IF HB_UNZIPFILE( &cdq.TEST.ZIP&cdq.)
         qout(&cdq.File was successly create&cdq.)
      ENDIF
      IF HB_ZIPFILE( &cdq.TEST2.ZIP&cdq.&comma.{|cFile|&comma.qout(cFile)})
         qout(&cdq.File was successly create&cdq.)
      ENDIF

      Return Nil
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Platforms
:ehp2.
     Win32     

:p.:hp2.Files
:ehp2.
     Library is zlib.lib and zlib_bor.lib For Borland Compilers  Library is zlib.lib zlib_ms.lib for MSVC compilers     
:euserdoc.
