:userdoc.
:docprof toc=123456.
:title.Harbour Reference Guide
.* HBDOC generated IPF Source File.
.* HBDOC Document Source Extractor, (c)1999-2000 Luiz Rafael Culik.
:h1 res=1.ARRAY()
:i1 id=ARRAY().ARRAY()
:p.ARRAY()
:p.:hp2.Create an uninitialized array of specified length
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ARRAY( <nElements> [, <nElements>...] ) --> aArray
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nElements>:ehp2.   is the number of elements in the specified dimension.    

:p.:hp2.Returns
:ehp2.
      :hp2. <aArray>:ehp2.   an array of specified dimensions.    

:p.:hp2.Description
:ehp2.
     This function returns an uninitialized array with the length of  <nElements>. Nested arrays are uninitialized within the same array  pointer reference if additional parameters are specified.  Establishing a memory variable with the same name as the array may  destroy the original array and release the entire contents of the  array. This depends&comma. of course&comma. on the data storage type of either  the array or the variable with the same name as the array.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
        LOCAL aArray&colon.=Array(10)
        LOCAL x&colon.=1
        FOR x&colon.=1 to LEN(aArray)
          aArray[x]&colon.=Array(x)
        NEXT
        Return Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-CLIPPER Compliant in all Cases&comma. except that  arrays in Harbour can have an unlimited number of dimensions&comma. while  Clipper has a limit of 4096 array elements.     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=2.AADD():elink.
.br
:link reftype=hd res=3.ADEL():elink.
.br
:link reftype=hd res=4.AFILL():elink.
.br
:link reftype=hd res=5.AINS():elink.
.br
:h1 res=2.AADD()
:i1 id=AADD().AADD()
:p.AADD()
:p.:hp2.Dynamically add an element to an array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AADD(<aArray>[, <xValue>]) --> Value
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   The name of an array      

      :hp2. <xValue>:ehp2.   Element to add to array <aArray>    

:p.:hp2.Returns
:ehp2.
      :hp2. <Value>:ehp2.   if specified <xValue>,<xValue> will return , otherwise this function  returns a NIL value.     

:p.:hp2.Description
:ehp2.
     This function dynamically increases the length of the array named  <aArray> by one element and stores the value of <xValue> to that  newly created element.       

     <xValue> may be an array reference pointer&comma. which in turn may be  stored to an array's subscript position.     

:p.:hp2.Examples
:ehp2.

      LOCAL aArray&colon.={}
      AADD(aArray&comma.10)
      FOR x&colon.=1 to 10
          AADD(aArray&comma.x)
      NEXT
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=5.AINS():elink.
.br
:link reftype=hd res=6.ASIZE():elink.
.br
:h1 res=6.ASIZE()
:i1 id=ASIZE().ASIZE()
:p.ASIZE()
:p.:hp2.Adjust the size of an array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ASIZE(<aArray>, <nLen>) --> aTarget
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   Name of array to be dynamically altered      

      :hp2. <nLen>:ehp2.   Numeric value representing the new size of <aArray>    

:p.:hp2.Returns
:ehp2.
      :hp2. <aTarget>:ehp2.   an array pointer reference to .    

:p.:hp2.Description
:ehp2.
     This function will dynamically increase or decrease the size of  <aArray> by adjusting the length of the array to <nLen> subscript  positions.       

     If the length of the array <aArray> is shortened&comma. those former  subscript positions are lost. If the length of the array is  lengthened a NIL value is assigned to the new subscript position.     

:p.:hp2.Examples
:ehp2.

      aArray &colon.= { 1 }          // Result&colon. aArray is { 1 }
      ASIZE(aArray&comma. 3)         // Result&colon. aArray is { 1&comma. NIL&comma. NIL }
      ASIZE(aArray&comma. 1)         // Result&colon. aArray is { 1 }
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     If HB_COMPAT_C53 is defined&comma. the function generates an Error&comma.  else it will return the array itself.     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=2.AADD():elink.
.br
:link reftype=hd res=3.ADEL():elink.
.br
:link reftype=hd res=4.AFILL():elink.
.br
:link reftype=hd res=5.AINS():elink.
.br
:h1 res=7.ATAIL()
:i1 id=ATAIL().ATAIL()
:p.ATAIL()
:p.:hp2.Returns the rightmost element of an array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ATAIL( <aArray> ) --> Element
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   is the array.    

:p.:hp2.Returns
:ehp2.
      :hp2. <Element>:ehp2.   the expression of the last element in the array.    

:p.:hp2.Description
:ehp2.
     This function return the value of the last element in the array  named <aArray>. This function does not alter the size of the  array or any of the subscript values.     

:p.:hp2.Examples
:ehp2.

      LOCAL array&colon.= {&cdq.Harbour&cdq.&comma. &cdq.is&cdq.&comma. &cdq.Supreme&cdq.&comma. &cdq.Power&cdq.}
      ? ATAIL(aArray)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=8.LEN():elink.
.br
:link reftype=hd res=1.ARRAY():elink.
.br
:link reftype=hd res=6.ASIZE():elink.
.br
:link reftype=hd res=2.AADD():elink.
.br
:h1 res=5.AINS()
:i1 id=AINS().AINS()
:p.AINS()
:p.:hp2.Insert a NIL value at an array subscript position.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AINS( <aArray>, <nPos> ) --> aTarget
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   Array name.      

      :hp2. <nPos>:ehp2.   Subscript position in <aArray>    

:p.:hp2.Returns
:ehp2.
      :hp2. <aTarget>:ehp2.   an array pointer reference.    

:p.:hp2.Description
:ehp2.
     This function inserts a NIL value in the array named <aArray>  at the <nPos>th position.       

     All array elements starting with the <nPos>th position will be  shifted down one subscript position in the array list and the  last item in the array will be removed completely. In other words&comma.  if an array element were to be inserted at the fifth subscript  position&comma. the element previously in the fifth position would now  be located at the sixth position. The length of the array <aArray>  will remain unchanged.     

:p.:hp2.Examples
:ehp2.

      LOCAL aArray&colon.={&cdq.Harbour&cdq.&comma.&cdq.is&cdq.&comma.&cdq.Power!&cdq.&comma.&cdq.!!!&cdq.}
      AINS(aArray&comma.4)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=2.AADD():elink.
.br
:link reftype=hd res=9.ACOPY():elink.
.br
:link reftype=hd res=3.ADEL():elink.
.br
:link reftype=hd res=10.AEVAL():elink.
.br
:link reftype=hd res=4.AFILL():elink.
.br
:link reftype=hd res=6.ASIZE():elink.
.br
:h1 res=3.ADEL()
:i1 id=ADEL().ADEL()
:p.ADEL()
:p.:hp2.Delete an element form an array.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ADEL(<aArray>, <nPos>) --> aTarget
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   Name of array from which an element is to be removed.      

      :hp2. <nPos>:ehp2.     Subscript of the element to be removed.    

:p.:hp2.Returns
:ehp2.
      :hp2. <aTarget>:ehp2.   an array pointer reference.    

:p.:hp2.Description
:ehp2.
     This function deletes the element found at <nPos> subscript position  in the array <aArray>. All elements in the array <aArray> below the  given subscript position <nPos> will move up one position in the  array. In other words&comma. what was formerly the sixth subscript position  will become the fifth subscript position. The length of the array  <aArray> will remain unchanged&comma.as the last element in the array will  become a NIL data type.     

:p.:hp2.Examples
:ehp2.

     LOCAL aArray
      aArray &colon.= { &cdq.Harbour&cdq.&comma.&cdq.is&cdq.&comma.&cdq.Power&cdq. }      // Result&colon. aArray is

      ADEL(aArray&comma. 2)            // Result&colon. aArray is
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=9.ACOPY():elink.
.br
:link reftype=hd res=5.AINS():elink.
.br
:link reftype=hd res=4.AFILL():elink.
.br
:h1 res=4.AFILL()
:i1 id=AFILL().AFILL()
:p.AFILL()
:p.:hp2.Fill an array with a specified value
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AFILL( <aArray>, <xValue>, [<nStart>], [<nCount>] ) --> aTarget
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   Name of array to be filled.      

      :hp2. <xValue>:ehp2.   Expression to be globally filled in <aArray>      

      :hp2. <nStart>:ehp2.   Subscript starting position      

      :hp2. <nCount>:ehp2.   Number of subscript to be filled    

:p.:hp2.Returns
:ehp2.
      :hp2. <aTarget>:ehp2.   an array pointer.    

:p.:hp2.Description
:ehp2.
     This function will fill each element of an array named <aArray> with  the value <xValue>. If specified&comma. <nStart> denotes the beginning  element to be filled and the array elements will continue to be  filled for <nCount> positions. If Not specified&comma. the value of  <nStart> will be 1&comma. and the value of <nCount> will be the value  of LEN(<aArray>); thus&comma. all subscript positions in the array  <aArray> will be filled with the value of <xValue>.       

     This function will work on only a single dimension of <aArray>.  If there are array pointer references within a subscript <aArray>&comma.  those values will be lost&comma. since this function will overwrite those  values with new values.     

:p.:hp2.Examples
:ehp2.

      LOCAL aTest&colon.={Nil&comma.0&comma.1&comma.2}
      Afill(aTest&comma.5)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=2.AADD():elink.
.br
:link reftype=hd res=10.AEVAL():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=12.DIRECTORY():elink.
.br
:h1 res=13.ASCAN()
:i1 id=ASCAN().ASCAN()
:p.ASCAN()
:p.:hp2.Scan array elements for a specified condition
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ASCAN( <aTarget>, <xSearch>, [<nStart>], [<nCount>] ) --> nStoppedAt
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aTarget>:ehp2.     Name of array to be scanned.      

      :hp2. <xSearch>:ehp2.     Expression to search for in <aTarget>      

      :hp2. <nStart>:ehp2.      Beginning subscript position at which to start the search.      

      :hp2. <nCount>:ehp2.      Number of elements to scan with <aTarget>.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nStoppedAt>:ehp2.   A numeric value of subscript position where <xSearch> was found.     

:p.:hp2.Description
:ehp2.
     This function scan the content of array named <aTarget> for the  value of <xSearch>. The return value is the position in the array  <aTarget> in which <xSearch> was found. If it was not found&comma. the  return value will be 0.       

     If specified&comma. the beginning subscript position at which to start  scanning may be set with the value passed as <nStart>. The default  is 1.       

     If specified&comma. the number of array elements to scan may be set with  the value passed as <nCount>. The default is the number of elements  in the array <aTarget>.       

     If <xSearch> is a code block&comma. the operation of the function is  slightly different. Each array subscript pointer reference is  passed to the code block to be evaluated. The scanning routine  will continue until the value obtained from the code block is a  logical true (.T.) or until the end of the array has been reached.     

:p.:hp2.Examples
:ehp2.

      aDir&colon.=Directory(&cdq.*.prg&cdq.)
      AScan(aDir&comma.&comma.&comma.{|x&comma.y| x[1]=&cdq.Test.prg&cdq.})
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is not CA-Clipper compatible. Clipper ASCAN() is affected by the SET EXACT ON/OFF Condition     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=10.AEVAL():elink.
.br
:h1 res=10.AEVAL()
:i1 id=AEVAL().AEVAL()
:p.AEVAL()
:p.:hp2.Evaluated the subscript element of an array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AEVAL(<aArray>, <bBlock>, [<nStart>], [<nCount>]) --> aArray
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   Is the array to be evaluated.      

      :hp2. <bBlock>:ehp2.   Is a code block to evaluate for each element processed.      

      :hp2. <nStart>:ehp2.   The beginning  array element to evaluate.      

      :hp2. <nCount>:ehp2.   The number of elements to process.    

:p.:hp2.Returns
:ehp2.
      :hp2. <aArray>:ehp2.   an array pointer reference.    

:p.:hp2.Description
:ehp2.
     This function will evaluate and process the subscript elements  in <aArray>. A code block passed as <bBlock> defines the operation  to be executed on each element of the array. All elements in <aArray>  will be evaluated unless specified by a beginning subscript position  in <nStart> for <nCount> elements.       

     Two parameters are passed to the code block <bBlock>. The individual  elements in an array are the first parameter and the subscript position  is the second.       

     AEVAL() does not replace a FOR...NEXT loop for processing arrays. If  an array is an autonomous unit&comma. AEVAL() is appropriate. If the array  is to be altered or if elements are to be reevaluated&comma. a FOR...NEXT  loop is more appropriate.     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=14.EVAL():elink.
.br
:link reftype=hd res=15.DBEVAL():elink.
.br
:h1 res=9.ACOPY()
:i1 id=ACOPY().ACOPY()
:p.ACOPY()
:p.:hp2.Copy elements from one array to another
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ACOPY( <aSource>, <aTarget>, [<nStart>], [<nCount>], [<nTargetPos>] )
:ehp2.
:p.:hp2.--> aTarget
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aSource>:ehp2.   is the array to copy elements from.      

      :hp2. <aTarget>:ehp2.   is the array to copy elements to.      

      :hp2. <nStart>:ehp2.    is the beginning subscript position to copy from <aSource>      

      :hp2. <nCount>:ehp2.    the number of subscript elements to copy from <aSource>.      

      :hp2. <nTargetPos>:ehp2.   the starting subscript position in <aTarget> to copy elements to.     

:p.:hp2.Returns
:ehp2.
      :hp2. <aTarget>:ehp2.   an array pointer reference    

:p.:hp2.Description
:ehp2.
     This function copies array elements from <aSource> to <aTarget>.  <nStart> is the beginning element to be copied from <aSource>;  the default is 1.       

     <nCount> is the number of elements to be copied from <aSource>;  the default is the entire array.       

     <nTargetPos> is the subscript number in the target array&comma.<aTarget>&comma.  to which array elements are to be copied; the default is 1       

     This function will copy all data types in <aSource> to <aTarget>.       

     If an array element in <aSource> is a pointer reference to another  array&comma. that array pointer will be copied to <aTarget>; not all  subdimensions will be copied from one array to the next. This must  be accomplished via the ACLONE() function.       

     Note  If array <aSource> is larger then <aTarget>&comma. array elements will  start copying at <nTargetPos> and continue copying until the end  of array <aTarget> is reached. The ACOPY() function doesn't append  subscript positions to the target array&comma. the size of the target  array <aTarget> remains constant.     

:p.:hp2.Examples
:ehp2.

      LOCAL nCount &colon.= 2&comma. nStart &colon.= 1&comma. aOne&comma. aTwo
      aOne &colon.= {&cdq.HABOUR&cdq.&comma.&cdq. is &cdq.&comma.&cdq.POWER&cdq.}
      aTwo &colon.= {&cdq.CLIPPER&cdq.&comma.&cdq. was &cdq.&comma.&cdq.POWER&cdq.}
      ACOPY(aOne&comma. aTwo&comma. nStart&comma. nCount)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=16.ACLONE():elink.
.br
:link reftype=hd res=3.ADEL():elink.
.br
:link reftype=hd res=10.AEVAL():elink.
.br
:link reftype=hd res=4.AFILL():elink.
.br
:link reftype=hd res=5.AINS():elink.
.br
:link reftype=hd res=17.ASORT():elink.
.br
:h1 res=16.ACLONE()
:i1 id=ACLONE().ACLONE()
:p.ACLONE()
:p.:hp2.Duplicate a  multidimensional array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ACLONE(<aSource>) --> aDuplicate
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aSource>:ehp2.   Name of the array to be cloned.    

:p.:hp2.Returns
:ehp2.
      :hp2. <aDuplicate>:ehp2.   A new array pointer reference complete with nested array values.     

:p.:hp2.Description
:ehp2.
     This function makes a complete copy of the array expressed as  <aSource> and return a cloned set of array values.This provides  a complete set of arrays values for all dimensions within the  original array <aSource>     

:p.:hp2.Examples
:ehp2.

      LOCAL aOne&comma. aTwo
      aOne &colon.= {&cdq.Harbour&cdq.&comma.&cdq. is &cdq.&comma.&cdq.POWER&cdq.}
      aTwo &colon.= ACLONE(aOne)       // Result&colon. aTwo is {1&comma. 2&comma. 3}
      aOne[1] &colon.= &cdq.The Harbour Compiler&cdq.              // Result&colon. aOne is {99&comma. 2&comma. 3}
                                 // aTwo is still {1&comma. 2&comma. 3}
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Clipper will return NIL if the parameter is not an array.     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=9.ACOPY():elink.
.br
:link reftype=hd res=3.ADEL():elink.
.br
:link reftype=hd res=5.AINS():elink.
.br
:link reftype=hd res=6.ASIZE():elink.
.br
:h1 res=17.ASORT()
:i1 id=ASORT().ASORT()
:p.ASORT()
:p.:hp2.Sort an array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ASORT( <aArray>, [<nStart>], [<nCount>], [<bSort>] ) --> aArray
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aArray>:ehp2.   Array to be sorted.      

      :hp2. <nStart>:ehp2.   The first element to start the sort from, default is 1.      

      :hp2. <nCount>:ehp2.   Number of elements starting from <nStart> to sort, default is all elements.       

      :hp2. <bSort>:ehp2.   Code block for sorting order, default is ascending order {| x, y | x < y }. The code block should accept two parameters and  must return .T. if the sort is in order, .F. if not.     

:p.:hp2.Returns
:ehp2.
      :hp2. <aArray>:ehp2.   reference to the now sorted  or NIL if the passed <aArray> is not an array.     

:p.:hp2.Description
:ehp2.
     ASORT() sort all or part of a given array. If <bSort> is omitted&comma.  the function expect <aArray> to be one dimensional array containing  single data type (one of&colon. Character&comma. Date&comma. Logical&comma. Numeric) and sort  this array in ascending order&colon. Character are sorted by their ASCII  value&comma. Dates are sorted chronologically&comma. Logical put .F. values before  .T.&comma. Numeric are sorted by their value.       

     If <bSort> is specified&comma. it is used to handle the sorting order. With  each time the block is evaluate&comma. two array elements are passed to the  code block&comma. and <bSort> must return a logical value that state if  those elements are in order (.T.) or not (.F.). Using this block you  can sort multidimensional array&comma. descending orders or even (but why  would you want to do that) sort array that contain different data  type.     

:p.:hp2.Examples
:ehp2.

      // sort numeric values in ascending order
      ASORT( { 3&comma. 1&comma. 4&comma. 42&comma. 5&comma. 9 } )     // result&colon. { 1&comma. 3&comma. 4&comma. 5&comma. 9&comma. 42 }

      // sort character strings in descending lexical order
      aKeys &colon.= { &cdq.Ctrl&cdq.&comma. &cdq.Alt&cdq.&comma. &cdq.Delete&cdq. }
      bSort &colon.= {| x&comma. y | UPPER( x ) > UPPER( y ) }
      ASORT( aKeys&comma.&comma.&comma. bSort )      // result&colon. { &cdq.Delete&cdq.&comma. &cdq.Ctrl&cdq.&comma. &cdq.Alt&cdq. }

      // sort two-dimensional array according to 2nd element of each pair
      aPair &colon.=   { {&cdq.Sun&cdq.&comma.8}&comma. {&cdq.Mon&cdq.&comma.1}&comma. {&cdq.Tue&cdq.&comma.57}&comma. {&cdq.Wed&cdq.&comma.-6} }
      ASORT( aPair&comma.&comma.&comma. {| x&comma. y | x[2] < y[2] } )
      // result&colon. { {&cdq.Wed&cdq.&comma.-6}&comma. {&cdq.Mon&cdq.&comma.1}&comma. {&cdq.Sun&cdq.&comma.8}&comma. {&cdq.Tue&cdq.&comma.57} }
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Codeblock calling frequency and order differs from Clipper&comma. since  Harbour uses a different (faster) sorting algorithm (quicksort).     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=13.ASCAN():elink.
.br
:link reftype=hd res=14.EVAL():elink.
.br
:link reftype=hd res=18.SORT:elink.
.br
:h1 res=19.BIN2W()
:i1 id=BIN2W().BIN2W()
:p.BIN2W()
:p.:hp2.Convert unsigned short encoded bytes into Harbour numeric
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BIN2W( <cBuffer> ) --> nNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cBuffer>:ehp2.   is a character string that contain 16 bit encoded unsigned short integer (least significant byte first). The first two bytes  are taken into account, the rest if any are ignored.     

:p.:hp2.Returns
:ehp2.
      :hp2. BIN2W():ehp2.   return numeric integer (or 0 if <cBuffer> is not a string).    

:p.:hp2.Description
:ehp2.
     BIN2W() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. BIN2W() take two bytes of encoded  16 bit unsigned short integer and convert it into standard Harbour  numeric value.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     BIN2W() is the opposite of W2BIN()     

:p.:hp2.Examples
:ehp2.

 
      // Show header length of a DBF
      FUNCTION main()
      LOCAL nHandle&comma. cBuffer &colon.= space( 2 )
      nHandle &colon.= fopen( &cdq.test.dbf&cdq. )
      IF nHandle > 0
         fseek( nHandle&comma. 8 )
         fread( nHandle&comma. @cBuffer&comma. 2 )
         ? &cdq.Length of DBF header in bytes&colon.&cdq.&comma. BIN2W( cBuffer )
         fclose( nHandle )
      ELSE
         ? &cdq.Can not open file&cdq.
      ENDIF
      RETURN NIL
 
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     BIN2W() works exactly like CA-Clipper's BIN2W()     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:h1 res=20.BIN2I()
:i1 id=BIN2I().BIN2I()
:p.BIN2I()
:p.:hp2.Convert signed short encoded bytes into Harbour numeric
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BIN2I( <cBuffer> ) --> nNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cBuffer>:ehp2.   is a character string that contain 16 bit encoded signed short integer (least significant byte first). The first two bytes  are taken into account, the rest if any are ignored.     

:p.:hp2.Returns
:ehp2.
      :hp2. BIN2I():ehp2.   return numeric integer (or 0 if <cBuffer> is not a string).    

:p.:hp2.Description
:ehp2.
     BIN2I() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. BIN2I() take two bytes of encoded  16 bit signed short integer and convert it into standard Harbour  numeric value.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     BIN2I() is the opposite of I2BIN()     

:p.:hp2.Examples
:ehp2.

 
      // Show DBF last update date
      FUNCTION main()
      LOCAL nHandle&comma. cYear&comma. cMonth&comma. cDay
      nHandle &colon.= fopen( &cdq.test.dbf&cdq. )
      IF nHandle > 0
         fseek( nHandle&comma. 1 )
         cYear &colon.= cMonth &colon.= cDay &colon.= &cdq. &cdq.
         fread( nHandle&comma. @cYear &comma. 1 )
         fread( nHandle&comma. @cMonth&comma. 1 )
         fread( nHandle&comma. @cDay  &comma. 1 )
         ? &cdq.Last update&colon.&cdq.&comma. BIN2I( cYear )&comma. BIN2I( cMonth )&comma. BIN2I( cDay )
         fclose( nHandle )
      ELSE
         ? &cdq.Can not open file&cdq.
      ENDIF
      RETURN NIL
 
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     BIN2I() works exactly like CA-Clipper's BIN2I()     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:h1 res=21.BIN2L()
:i1 id=BIN2L().BIN2L()
:p.BIN2L()
:p.:hp2.Convert signed long encoded bytes into Harbour numeric
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BIN2L( <cBuffer> ) --> nNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cBuffer>:ehp2.   is a character string that contain 32 bit encoded signed long integer (least significant byte first). The first four bytes  are taken into account, the rest if any are ignored.     

:p.:hp2.Returns
:ehp2.
      :hp2. BIN2L():ehp2.   return numeric integer (or 0 if <cBuffer> is not a string).    

:p.:hp2.Description
:ehp2.
     BIN2L() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. BIN2L() take four bytes of encoded  32 bit signed long integer and convert it into standard Harbour  numeric value.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     BIN2L() is the opposite of L2BIN()     

:p.:hp2.Examples
:ehp2.

 
      // Show number of records in DBF
      FUNCTION main()
      LOCAL nHandle&comma. cBuffer &colon.= space( 4 )
      nHandle &colon.= fopen( &cdq.test.dbf&cdq. )
      IF nHandle > 0
         fseek( nHandle&comma. 4 )
         fread( nHandle&comma. @cBuffer&comma. 4 )
         ? &cdq.Number of records in file&colon.&cdq.&comma. BIN2L( cBuffer )
         fclose( nHandle )
      ELSE
         ? &cdq.Can not open file&cdq.
      ENDIF
      RETURN NIL
 
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     BIN2L() works exactly like CA-Clipper's BIN2L()     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:h1 res=22.BIN2U()
:i1 id=BIN2U().BIN2U()
:p.BIN2U()
:p.:hp2.Convert unsigned long encoded bytes into Harbour numeric
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BIN2U( <cBuffer> ) --> nNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cBuffer>:ehp2.   is a character string that contain 32 bit encoded unsigned long integer (least significant byte first). The first four bytes  are taken into account, the rest if any are ignored.     

:p.:hp2.Returns
:ehp2.
      :hp2. BIN2U():ehp2.   return numeric integer (or 0 if <cBuffer> is not a string).    

:p.:hp2.Description
:ehp2.
     BIN2U() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. BIN2U() take four bytes of encoded  32 bit unsigned long integer and convert it into standard Harbour  numeric value.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     BIN2U() is the opposite of U2BIN()     

:p.:hp2.Examples
:ehp2.

 
      // Show number of records in DBF
      FUNCTION main()
      LOCAL nHandle&comma. cBuffer &colon.= space( 4 )
      nHandle &colon.= fopen( &cdq.test.dbf&cdq. )
      IF nHandle > 0
         fseek( nHandle&comma. 4 )
         fread( nHandle&comma. @cBuffer&comma. 4 )
         ? &cdq.Number of records in file&colon.&cdq.&comma. BIN2U( cBuffer )
         fclose( nHandle )
      ELSE
         ? &cdq.Can not open file&cdq.
      ENDIF
      RETURN NIL
 
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     BIN2U() is an XBase++ compatibility function and does not exist  as a standard CA-Clipper 5.x function.  This function is only visible if source/rtl/binnum.c was compiled  with the HB_COMPAT_XPP flag.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:h1 res=23.I2BIN()
:i1 id=I2BIN().I2BIN()
:p.I2BIN()
:p.:hp2.Convert Harbour numeric into signed short encoded bytes
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.I2BIN( <nNumber> ) --> cBuffer
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   is a numeric value to convert (decimal digits are ignored).    

:p.:hp2.Returns
:ehp2.
      :hp2. I2BIN():ehp2.   return two bytes character string that contain 16 bit encoded signed short integer (least significant byte first).     

:p.:hp2.Description
:ehp2.
     I2BIN() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. I2BIN() take a numeric integer  value and convert it into two bytes of encoded 16 bit signed short  integer.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     I2BIN() is the opposite of BIN2I()     

:p.:hp2.Examples
:ehp2.

 
      // Update DBF &cdq.last update&cdq. date
      #include &cdq.fileio.ch&cdq.
      FUNCTION main()
      LOCAL nHandle&comma. cYear&comma. cMonth&comma. cDay
      use test
      ? &cdq.Original update date is&colon.&cdq.&comma. lupdate()
      close
      nHandle &colon.= fopen( &cdq.test.dbf&cdq.&comma. FO_READWRITE )
      IF nHandle > 0
         fseek( nHandle&comma. 1&comma. )
         cYear  &colon.= I2BIN( 68 )
         cMonth &colon.= I2BIN(  8 )
         cDay   &colon.= I2BIN(  1 )
         fwrite( nHandle&comma. cYear &comma. 1 )   // write only the first byte
         fwrite( nHandle&comma. cMonth&comma. 1 )
         fwrite( nHandle&comma. cDay  &comma. 1 )
         fclose( nHandle )
         use test
         ? &cdq.New update date is&colon.&cdq.&comma. lupdate()
         close
      ELSE
         ? &cdq.Can not open file&cdq.
      ENDIF
      RETURN NIL
 
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     I2BIN() works exactly like CA-Clipper's I2BIN()     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=25.W2BIN()
:i1 id=W2BIN().W2BIN()
:p.W2BIN()
:p.:hp2.Convert Harbour numeric into unsigned short encoded bytes
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.W2BIN( <nNumber> ) --> cBuffer
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   is a numeric value to convert (decimal digits are ignored).    

:p.:hp2.Returns
:ehp2.
      :hp2. W2BIN():ehp2.   return two bytes character string that contain 16 bit encoded unsigned short integer (least significant byte first).     

:p.:hp2.Description
:ehp2.
     W2BIN() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. W2BIN() take a numeric integer  value and convert it into two bytes of encoded 16 bit unsigned short  integer.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     W2BIN() is the opposite of BIN2W()     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     W2BIN() is an XBase++ compatibility function and does not exist  as a standard CA-Clipper 5.x function.  This function is only visible if source/rtl/binnum.c was compiled  with the HB_COMPAT_XPP flag.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=24.L2BIN()
:i1 id=L2BIN().L2BIN()
:p.L2BIN()
:p.:hp2.Convert Harbour numeric into signed long encoded bytes
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.L2BIN( <nNumber> ) --> cBuffer
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   is a numeric value to convert (decimal digits are ignored).    

:p.:hp2.Returns
:ehp2.
      :hp2. L2BIN():ehp2.   return four bytes character string that contain 32 bit encoded signed long integer (least significant byte first).     

:p.:hp2.Description
:ehp2.
     L2BIN() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. L2BIN() take a numeric integer  value and convert it into four bytes of encoded 32 bit signed long  integer.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     L2BIN() is the opposite of BIN2L()     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     L2BIN() works exactly like CA-Clipper's L2BIN()     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=27.U2BIN():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=27.U2BIN()
:i1 id=U2BIN().U2BIN()
:p.U2BIN()
:p.:hp2.Convert Harbour numeric into unsigned long encoded bytes
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.U2BIN( <nNumber> ) --> cBuffer
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   is a numeric value to convert (decimal digits are ignored).    

:p.:hp2.Returns
:ehp2.
      :hp2. U2BIN():ehp2.   return four bytes character string that contain 32 bit encoded unsigned long integer (least significant byte first).     

:p.:hp2.Description
:ehp2.
     U2BIN() is one of the low level binary conversion functions&comma. those  functions convert between Harbour numeric and a character  representation of numeric value. U2BIN() take a numeric integer  value and convert it into four bytes of encoded 32 bit unsigned long  integer.       

     You might ask what is the need for such functions&comma. well&comma. first of  all it allow you to read/write information from/to a binary file  (like extracting information from DBF header)&comma. it is also a useful  way to share information from source other than Harbour (C for  instance).       

     U2BIN() is the opposite of BIN2U()     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     U2BIN() is an XBase++ compatibility function and does not exist  as a standard CA-Clipper 5.x function.  This function is only visible if source/rtl/binnum.c was compiled  with the HB_COMPAT_XPP flag.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=22.BIN2U():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:link reftype=hd res=25.W2BIN():elink.
.br
:link reftype=hd res=26.WORD():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=26.WORD()
:i1 id=WORD().WORD()
:p.WORD()
:p.:hp2.Converts double to integer values.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.WORD( <nDouble> ) --> <nInteger>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nDouble>:ehp2.   is a numeric double value.    

:p.:hp2.Returns
:ehp2.
      :hp2. WORD():ehp2.   return an integer in the range +-32767    

:p.:hp2.Description
:ehp2.
     This function converts double values to integers to use  within the CALL command     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     The Clipper NG states that WORD() will only work when used in CALL  commands parameter list&comma. otherwise it will return NIL&comma. in Harbour  it will work anywhere.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=30.CALL:elink.
.br
:h1 res=31.DBEDIT()*
:i1 id=DBEDIT()*.DBEDIT()*
:p.DBEDIT()*
:p.:hp2.Browse records in a table
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBEDIT( [<nTop>], [<nLeft>], [<nBottom>], [<nRight>], [<acColumns>], [<xUserFunc>], [<xColumnSayPictures>], [<xColumnHeaders>], [<xHeadingSeparators>], [<xColumnSeparators>], [<xFootingSeparators>], [<xColumnFootings>] ) --> lOk
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nTop>:ehp2.   coordinate for top row display.  could range from 0 to MAXROW(), default is 0.       

      :hp2. <nLeft>:ehp2.   coordinate for left column display.  could range from 0 to MAXCOL(), default is 0.       

      :hp2. <nBottom>:ehp2.   coordinate for bottom row display.  could range from 0 to MAXROW(), default is MAXROW().       

      :hp2. <nRight>:ehp2.   coordinate for right column display.  could range from 0 to MAXCOL(), default is MAXCOL().       

      :hp2. <acColumns>:ehp2.   is an array of character expressions that contain database fields names or expressions to display in each column.  If not specified, the default is to display all fields from the  database in the current work area.       

      :hp2. <xUserFunc>:ehp2.   is a name of a user defined function or a code block that would be called every time unrecognized key is been pressed or  when there are no keys waiting to be processed and DBEDIT() goes  into idle mode. If <xUserFunc> is a character string, it must  contain root name of a valid user define function without  parentheses. Both the user define function or the code block should  accept two parameters: nMode, nCurrentColumn. Both should return  a numeric value that correspond to one of the expected return codes  (see table below for a list of nMode and return codes).       

      :hp2. <xColumnSayPictures>:ehp2.   is an optional picture. If  is a character string, all columns would used this value as a  picture string. If <xColumnSayPictures> is an array, each element  should be a character string that correspond to a picture string  for the column with the same index. Look at the help for @...SAY  to get more information about picture values.       

      :hp2. <xColumnHeaders>:ehp2.   contain the header titles for each column, if this is a character string, all columns would have that same header, if  this is an array, each element is a character string that contain  the header title for one column. Header may be split to more than  one line by placing semicolon (;) in places where you want to break  line. If omitted, the default value for each column header is taken  from <acColumns> or field name if <acColumns> was not specified.       

      :hp2. <xHeadingSeparators>:ehp2.   is an array that contain characters that draw the lines separating the headers and the fields data. Instead of an  array you can use a character string that would be used to display  the same line for all fields. Default value is a double line.       

      :hp2. <xColumnSeparators>:ehp2.   is an array that contain characters that draw the lines separating displayed columns. Instead of an array you can  use a character string that would be used to display the same line  for all fields. Default value is a single line.       

      :hp2. <xFootingSeparators>:ehp2.   is an array that contain characters that draw the lines separating the fields data area and the footing area.  Instead of an array you can use a character string that would be  used to display the same line for all footers. Default is to have to  no footing separators.       

      :hp2. <xColumnFootings>:ehp2.   contain the footing to be displayed at the bottom of each column, if this is a character string, all columns would  have that same footer, if this is an array, each element is a  character string that contain the footer for one column. Footer may  be split to more than one line by placing semicolon (;) in places  where you want to break line. If omitted, no footer are displayed.     

:p.:hp2.Returns
:ehp2.
      :hp2. DBEDIT():ehp2.   return .F. if there is no database in use or if the number of columns to display is zero, else DBEDIT() return .T.     

:p.:hp2.Description
:ehp2.
     DBEDIT() display and edit records from one or more work areas in  a grid on screen. Each column is defined by element from <acColumns>  and is the equivalent of one field. Each row is equivalent of one  database record.       

     Following are active keys that handled by DBEDIT()&colon.       
     ---------------------------------------------------       


:cgraphic.
 
       Key              Meaning

       Left             Move one column to the left (previous field)
       Right            Move one column to the right (next field)
       Up               Move up one row (previous record)
       Down             Move down one row (next record)
       Page-Up          Move to the previous screen
       Page-Down        Move to the next screen
       Ctrl Page-Up     Move to the top of the file
       Ctrl Page-Down   Move to the end of the file
       Home             Move to the leftmost visible column
       End              Move to the rightmost visible column
       Ctrl Left        Pan one column to the left
       Ctrl Right       Pan one column to the right
       Ctrl Home        Move to the leftmost column
       Ctrl End         Move to the rightmost column
 
:ecgraphic.


     When <xUserFunc> is omitted&comma. two more keys are active&colon.       


:cgraphic.
 
       Key              Meaning

       Esc              Terminate BROWSE()
       Enter            Terminate BROWSE()
 
:ecgraphic.

     When DBEDIT() execute <xUserFunc> it pass the following arguments&colon.  nMode and the index of current record in <acColumns>. If <acColumns>  is omitted&comma. the index number is the FIELD() number of the open  database structure.       

     DBEDIT() nMode could be one of the following&colon.    
     ---------------------------------------------       


:cgraphic.
 
       Dbedit.ch      Meaning

       DE_IDLE        DBEDIT() is idle&comma. all movement keys have been handled.
       DE_HITTOP      Attempt to cursor past top of file.
       DE_HITBOTTOM   Attempt to cursor past bottom of file.
       DE_EMPTY       No records in work area&comma. database is empty.
       DE_EXCEPT      Key exception.
 
:ecgraphic.

     The user define function or code block must return a value that tell  DBEDIT() what to do next.       

     User function return codes&colon.    
     ---------------------------       


:cgraphic.
 
       Dbedit.ch    Value   Meaning

       DE_ABORT     0       Abort DBEDIT().
       DE_CONT      1       Continue DBEDIT() as is.
       DE_REFRESH   2       Force reread/redisplay of all data rows.
 
:ecgraphic.

     The user function is called once in each of the following cases&colon.  - The database is empty.  - The user try to move past top of file or past bottom file.  - Key exception&comma. the uses had pressed a key that is not handled by DBEDIT().  - The keyboard buffer is empty or a screen refresh had just occurred  DBEDIT() is a compatibility function&comma. it is superseded by the  TBrowse class and there for not recommended for new applications.     

:p.:hp2.Examples
:ehp2.

  
      // Browse a file using default values
      USE Test
      DBEDIT()
  
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     <xUserFunc> can take a code block value&comma. this is a Harbour  extension.       

     CA-Clipper will throw an error if there's no database open&comma. Harbour  would return .F.       

     CA-Clipper is buggy and will throw an error if the number of columns  zero&comma. Harbour would return .F.       

     The CA-Clipper 5.2 NG state that the return value is NIL&comma. this is  wrong and should be read logical.       

     There is an undocumented result code (3) from the user defined  function in Clipper (both 87 and 5.x). This is an Append Mode which&colon.  &cdq.split the screen to allow data to be appended in windowed area&cdq..  This mode is not supported by Harbour.     

:p.:hp2.Files
:ehp2.
     Header files are dbedit.ch&comma. inkey.ch  Library is rtl       

.br
See Also&colon.
:link reftype=hd res=32.@...SAY:elink.
.br
:link reftype=hd res=33.BROWSE():elink.
.br
:link reftype=hd res=34.TBrowse class:elink.
.br
:link reftype=hd res=35.TRANSFORM():elink.
.br
:h1 res=33.BROWSE()
:i1 id=BROWSE().BROWSE()
:p.BROWSE()
:p.:hp2.Browse a database file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BROWSE( [<nTop>, <nLeft>, <nBottom>, <nRight>] ) --> lOk
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nTop>:ehp2.   coordinate for top row display.      

      :hp2. <nLeft>:ehp2.   coordinate for left column display.      

      :hp2. <nBottom>:ehp2.   coordinate for bottom row display.      

      :hp2. <nRight>:ehp2.   coordinate for right column display.    

:p.:hp2.Returns
:ehp2.
      :hp2. BROWSE():ehp2.   return .F. if there is no database open in this work area, else it return .T.     

:p.:hp2.Description
:ehp2.
     BROWSE() is a general purpose database browser&comma. without any  thinking you can browse a file using the following keys&colon.       


:cgraphic.
 
       Key              Meaning

       Left             Move one column to the left (previous field)
       Right            Move one column to the right (next field)
       Up               Move up one row (previous record)
       Down             Move down one row (next record)
       Page-Up          Move to the previous screen
       Page-Down        Move to the next screen
       Ctrl Page-Up     Move to the top of the file
       Ctrl Page-Down   Move to the end of the file
       Home             Move to the leftmost visible column
       End              Move to the rightmost visible column
       Ctrl Left        Pan one column to the left
       Ctrl Right       Pan one column to the right
       Ctrl Home        Move to the leftmost column
       Ctrl End         Move to the rightmost column
       Esc              Terminate BROWSE()
 
:ecgraphic.

     On top of the screen you see a status line with the following  indication&colon.       


:cgraphic.
 
       Record ###/###   Current record number / Total number of records.
       <none>           There are no records&comma. the file is empty.
       <new>            You are in append mode at the bottom of file.
       <Deleted>        Current record is deleted.
       <bof>            You are at the top of file.
 
:ecgraphic.

     You should pass whole four valid coordinate&comma. if less than four  parameters are passed to BROWSE() the coordinate are default to&colon.  1&comma. 0&comma. MAXROW()&comma. MAXCOL().     

:p.:hp2.Examples
:ehp2.

  
      // this one shows you how to browse around
      USE Around
      BROWSE()
  
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=31.DBEDIT()*:elink.
.br
:link reftype=hd res=34.TBrowse class:elink.
.br
:h1 res=36.TBROWSEDB()
:i1 id=TBROWSEDB().TBROWSEDB()
:p.TBROWSEDB()
:p.:hp2.Create a new TBrowse object to be used with database file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.TBrowseDB( [<nTop>], [<nLeft>], [<nBottom>], [<nRight>] ) --> oBrowse
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nTop>:ehp2.   coordinate for top row display.      

      :hp2. <nLeft>:ehp2.   coordinate for left column display.      

      :hp2. <nBottom>:ehp2.   coordinate for bottom row display.      

      :hp2. <nRight>:ehp2.   coordinate for right column display.    

:p.:hp2.Returns
:ehp2.
      :hp2. TBrowseDB():ehp2.   return new TBrowse object with the specified coordinate and a default :SkipBlock, :GoTopBlock and :GoBottomBlock to browse  a database file.     

:p.:hp2.Description
:ehp2.
     TBrowseDB() is a quick way to create a TBrowse object along with  the minimal support needed to browse a database. Note that the  returned TBrowse object contain no TBColumn objects and you need  to add column for each field by your self.     

:p.:hp2.Examples
:ehp2.

      
      for a good example&comma. look at the source code for BROWSE() function
      at source/rtl/browse.prg
      
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     TBrowseDB() works exactly like CA-Clipper's TBrowseDB().     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=33.BROWSE():elink.
.br
:link reftype=hd res=37.TBColumn class:elink.
.br
:link reftype=hd res=34.TBrowse class:elink.
.br
:link reftype=hd res=38.TBrowseNew():elink.
.br
:h1 res=39.DBSKIPPER()
:i1 id=DBSKIPPER().DBSKIPPER()
:p.DBSKIPPER()
:p.:hp2.Helper function to skip a database
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.dbSkipper( <nRecs> ) --> nSkipped
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRecs>:ehp2.   is the number of records to skip relative to current record. Positive number would try to move the record pointer forward, while  a negative number would try to move the record pointer back <nRecs>  records.     

:p.:hp2.Returns
:ehp2.
      :hp2. dbSkipper():ehp2.   return the number of actual record skipped.    

:p.:hp2.Description
:ehp2.
     dbSkipper() is a helper function used in browse mechanism to skip  a number of records while giving the caller indication about the  actual records skipped.     

:p.:hp2.Examples
:ehp2.

  
      // open a file and find if we've got enough records in it
      USE MonthSales
      IF dbSkipper( 100 ) == 100
         ? &cdq.Good work! You can party now&cdq.
      ELSE
         ? &cdq.Too bad&comma. you should really work harder&cdq.
      ENDIF
      CLOSE
    
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     dbSkipper() is an XBase++ compatibility function and does not exist  as a standard CA-Clipper 5.x function.       

     This function is only visible if source/rtl/browdb.prg was compiled  with the HB_COMPAT_XPP flag.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=40.DBSKIP():elink.
.br
:link reftype=hd res=41.SKIP:elink.
.br
:h1 res=42.CDOW()
:i1 id=CDOW().CDOW()
:p.CDOW()
:p.:hp2.Converts a date to the day of week
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CDOW(<dDate>)  --> cDay
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.    Any date expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cDay>:ehp2.    The current day of week.    

:p.:hp2.Description
:ehp2.
     This function returns a character string of the day of the week&comma.  from a date expression <dDate> passed to it.  If a NULL date is passed to the function&comma. the value of the function  will be a NULL byte.     

:p.:hp2.Examples
:ehp2.

      ? CDOW(DATE())
      if CDOW(DATE()+10) ==&cdq.SUNDAY&cdq.
         ? &cdq.This is a sunny day.&cdq.
      Endif
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=43.DAY():elink.
.br
:link reftype=hd res=44.DOW():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=46.CMONTH():elink.
.br
:h1 res=46.CMONTH()
:i1 id=CMONTH().CMONTH()
:p.CMONTH()
:p.:hp2.Return the name of the month.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CMONTH(<dDate>)  --> cMonth
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.    Any date expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cMonth>:ehp2.    The current month name    

:p.:hp2.Description
:ehp2.
     This function returns the name of the month (January&comma.February&comma.etc.)  from a date expression <dDate> passed to it.  If a NULL date is passed to the function&comma. the value of the function  will be a NULL byte.     

:p.:hp2.Examples
:ehp2.

      ? CMONTH(DATE())
      if CMONTH(DATE()+10) ==&cdq.March&cdq.
         ? &cdq.Have you done your system BACKUP?&cdq.
      Endif
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=42.CDOW():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=47.MONTH():elink.
.br
:link reftype=hd res=48.YEAR():elink.
.br
:link reftype=hd res=44.DOW():elink.
.br
:link reftype=hd res=49.DTOC():elink.
.br
:h1 res=45.DATE()
:i1 id=DATE().DATE()
:p.DATE()
:p.:hp2.Return the Current OS Date
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DATE() --> dCurDate
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <dCurDate>:ehp2.    Current system date.    

:p.:hp2.Description
:ehp2.
     This function returns the current system date.     

:p.:hp2.Examples
:ehp2.

      ? Date()

:p.:hp2.Tests
:ehp2.

      ? &cdq.Today is &cdq.&comma.Day(date())&comma.&cdq. of &cdq.&comma.cMonth(date())&comma.&cdq. of &cdq.&comma.Year(date())
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper Compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=50.CTOD():elink.
.br
:link reftype=hd res=51.DTOS():elink.
.br
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=43.DAY():elink.
.br
:link reftype=hd res=47.MONTH():elink.
.br
:link reftype=hd res=46.CMONTH():elink.
.br
:h1 res=50.CTOD()
:i1 id=CTOD().CTOD()
:p.CTOD()
:p.:hp2.Converts a character string to a date expression
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CTOD(<cDateString>)  --> dDate
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDateString>:ehp2.   A character date in format 'mm/dd/yy'    

:p.:hp2.Returns
:ehp2.
      :hp2. <dDate>:ehp2.   A date expression    

:p.:hp2.Description
:ehp2.
     This function converts a date that has been entered as a character  expression to a date expression.The character expression will be in  the form &cdq.MM/DD/YY&cdq. (based on the default value in SET DATE) or in  the appropriate format specified by the SET DATE TO command. If an  improper character string is passed to the function&comma.an empty date  value will be returned.     

:p.:hp2.Examples
:ehp2.

      ? CTOD('12/21/00')
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=52.SET DATE:elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=51.DTOS():elink.
.br
:h1 res=43.DAY()
:i1 id=DAY().DAY()
:p.DAY()
:p.:hp2.Return the numeric day of the month.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DAY(<cDate>) --> nMonth
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDate>:ehp2.   Any valid date expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nMonth>:ehp2.   Numeric value of the day of month.    

:p.:hp2.Description
:ehp2.
     This function returns the numeric value of the day of month from a  date.     

:p.:hp2.Examples
:ehp2.

      ? Day(DATE())
      ? Day(DATE()+6325)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=50.CTOD():elink.
.br
:link reftype=hd res=51.DTOS():elink.
.br
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=47.MONTH():elink.
.br
:link reftype=hd res=46.CMONTH():elink.
.br
:h1 res=53.DAYS()
:i1 id=DAYS().DAYS()
:p.DAYS()
:p.:hp2.Convert elapsed seconds into days
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DAYS(<nSecs> ) --> nDay
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nSecs>:ehp2.   The number of seconds    

:p.:hp2.Returns
:ehp2.
      :hp2. <nDay>:ehp2.    The number of days    

:p.:hp2.Description
:ehp2.
     This function converts <nSecs> seconds to the equivalent number  of days; 86399 seconds represents one day&comma. 0 seconds being midnight.     

:p.:hp2.Examples
:ehp2.

      ? DAYS(2434234)
      ? &cdq.Has been passed &cdq.&comma.DAYS(63251)&comma.' since midnight'
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=54.SECONDS():elink.
.br
:link reftype=hd res=55.SECS():elink.
.br
:link reftype=hd res=56.ELAPTIME():elink.
.br
:h1 res=44.DOW()
:i1 id=DOW().DOW()
:p.DOW()
:p.:hp2.Value for the day of week.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DOW(<dDate>) --> nDay
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.    Any valid date expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <nDay>:ehp2.    The current day number    

:p.:hp2.Description
:ehp2.
     This function returns the number representing the day of the week  for the date expressed as <dDate>.     

:p.:hp2.Examples
:ehp2.

      ? DOW(DATE())
      ? DOW(DATE()-6584)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=42.CDOW():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=51.DTOS():elink.
.br
:link reftype=hd res=43.DAY():elink.
.br
:h1 res=49.DTOC()
:i1 id=DTOC().DTOC()
:p.DTOC()
:p.:hp2.Date to character conversion
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DTOC(<dDateString>)  --> cDate
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDateString>:ehp2.   Any date    

:p.:hp2.Returns
:ehp2.
      :hp2. <dDate>:ehp2.   Character represention of date    

:p.:hp2.Description
:ehp2.
     This function converts any date expression (a field or variable)  expressed as <dDateString> to a character expression in the default  format &cdq.MM/DD/YY&cdq.. The date format expressed by this function is  controled in part by the date format specified in the SET DATE  command     

:p.:hp2.Examples
:ehp2.

      ? DTOC(Date())
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=52.SET DATE:elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=51.DTOS():elink.
.br
:h1 res=51.DTOS()
:i1 id=DTOS().DTOS()
:p.DTOS()
:p.:hp2.Date to string conversion
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DTOS(<dDateString>)  --> cDate
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDateString>:ehp2.   Any date    

:p.:hp2.Returns
:ehp2.
      :hp2. <dDate>:ehp2.   String notation of the date    

:p.:hp2.Description
:ehp2.
     This function returns the value of <dDateString> as a character  string in the format of YYYYMMDD. If the value of <dDateString> is  an empty date&comma. this function will return eight blank spaces.     

:p.:hp2.Examples
:ehp2.

      ? DTOS(Date())
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=51.DTOS():elink.
.br
:h1 res=56.ELAPTIME()
:i1 id=ELAPTIME().ELAPTIME()
:p.ELAPTIME()
:p.:hp2.Calculates elapted time.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ELAPTIME(<cStartTime>,<cEndTime>) --> cDiference
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cStartTime>:ehp2.   Start in time as a string format <cEndTime>   End time as a string format     

:p.:hp2.Returns
:ehp2.
      :hp2. <cDiference>:ehp2.    Difference between the times    

:p.:hp2.Description
:ehp2.
     This function returns a string that shows the difference between  the starting time represented as <cStartTime> and the ending time  as <cEndTime>. If the stating time is greater then the ending  time&comma. the function will assume that the date changed once.     

:p.:hp2.Examples
:ehp2.

      Static cStartTime
      Init Proc Startup
      cStartTime&colon.=Time()

      Exit Proc StartExit
      ? &cdq.You used this program by&cdq.&comma.ELAPTIME(cStartTime&comma.Time())
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=55.SECS():elink.
.br
:link reftype=hd res=54.SECONDS():elink.
.br
:link reftype=hd res=57.TIME():elink.
.br
:link reftype=hd res=43.DAY():elink.
.br
:h1 res=47.MONTH()
:i1 id=MONTH().MONTH()
:p.MONTH()
:p.:hp2.Converts a date expression to a month value
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MONTH(<dDate>) --> nMonth
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.   Any valid date expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <nMonth>:ehp2.   Corresponding number of the month in the year, ranging from 0 to 12     

:p.:hp2.Description
:ehp2.
     This function returns a number that represents the month of a given  date expression <dDate>. If a NULL date (CTOD('')) is passed to the  function&comma. the value of the function will be 0.     

:p.:hp2.Examples
:ehp2.

      ? Month(DATE())
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=42.CDOW():elink.
.br
:link reftype=hd res=44.DOW():elink.
.br
:link reftype=hd res=48.YEAR():elink.
.br
:link reftype=hd res=46.CMONTH():elink.
.br
:h1 res=54.SECONDS()
:i1 id=SECONDS().SECONDS()
:p.SECONDS()
:p.:hp2.Returns the number of elapsed seconds past midnight.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SECONDS() --> nSeconds
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <nSeconds>:ehp2.   Number of seconds since midnight    

:p.:hp2.Description
:ehp2.
     This function returns a numeric value representing the number of  elapsed seconds based on the current system time.  The system time is considered to start at 0 (midnight);it continues  up to 86399 seconds.The value of the return expression is displayed  in both seconds and hundredths of seconds.     

:p.:hp2.Examples
:ehp2.

      ? Seconds()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=57.TIME():elink.
.br
:h1 res=55.SECS()
:i1 id=SECS().SECS()
:p.SECS()
:p.:hp2.Return the number of seconds from the system date.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SECS( <cTime> ) --> nSeconds
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cTime>:ehp2.   Character expression in a time string format    

:p.:hp2.Returns
:ehp2.
      :hp2. <nSeconds>:ehp2.   Number of seconds    

:p.:hp2.Description
:ehp2.
     This function returns a numeric value that is a number of elapsed  seconds from midnight based on a time string given as <cTime>.     

:p.:hp2.Examples
:ehp2.

      ? Secs(Time())
      ? Secs(time()-10)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=54.SECONDS():elink.
.br
:link reftype=hd res=56.ELAPTIME():elink.
.br
:link reftype=hd res=57.TIME():elink.
.br
:h1 res=57.TIME()
:i1 id=TIME().TIME()
:p.TIME()
:p.:hp2.Returns the system time as a string
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.TIME() --> cTime
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <cTime>:ehp2.   Character string representing time    

:p.:hp2.Description
:ehp2.
     This function returns the system time represented as a character  expression in the format of HH&colon.MM&colon.SS     

:p.:hp2.Examples
:ehp2.

      ? Time()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=54.SECONDS():elink.
.br
:h1 res=48.YEAR()
:i1 id=YEAR().YEAR()
:p.YEAR()
:p.:hp2.Converts the year portion of a date into a numeric value
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.YEAR(<cDate>) --> nYear
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <dDate>:ehp2.   Any valid date expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <nYear>:ehp2.   The year portion of the date.    

:p.:hp2.Description
:ehp2.
     This function returns the numeric value for the year in <dDate>.  This value will always be a four-digit number and is not affected  by the setting of the SET CENTURY and SET DATE commands. Addition  ally&comma. an empty date expression passed to this function will yield  a zero value.       

:p.:hp2.Examples
:ehp2.

      ? Year(date())
      ? year(CTOD(&cdq.01/25/3251&cdq.))
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=43.DAY():elink.
.br
:link reftype=hd res=47.MONTH():elink.
.br
:h1 res=58.__DBCOPYSTRUCT()
:i1 id=__DBCOPYSTRUCT().__DBCOPYSTRUCT()
:p.__DBCOPYSTRUCT()
:p.:hp2.Create a new database based on current database structure
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__dbCopyStruct( <cFileName>, [<aFieldList>] ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileName>:ehp2.   is the name of the new database file to create. (.dbf) is the default extension if none is given.       

      :hp2. <aFieldList>:ehp2.   is an array where each element is a field name. Names could be specified as uppercase or lowercase.     

:p.:hp2.Returns
:ehp2.
      :hp2. __dbCopyStruct():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __dbCopyStruct() create a new empty database file with a structure  that is based on the currently open database in this work-area. If  <aFieldList> is empty&comma. the newly created file would have the same  structure as the currently open database. Else&comma. the new file would  contain only fields that exactly match <aFieldList>.       

     __dbCopyStruct() can be use to create a sub-set of the currently  open database&comma. based on a given field list.       

     COPY STRUCTURE command is preprocessed into __dbCopyStruct()  function during compile time.     

:p.:hp2.Examples
:ehp2.

     // Create a new file that contain the same structure
      USE TEST
      __dbCopyStruct( &cdq.MyCopy.DBF&cdq. )

      // Create a new file that contain part of the original structure
      LOCAL aList
      USE TEST
      aList &colon.= { &cdq.NAME&cdq. }
      __dbCopyStruct( &cdq.OnlyName.DBF&cdq.&comma. aList )
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __dbCopyStruct() works exactly like CA-Clipper's __dbCopyStruct()     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=59.COPY STRUCTURE:elink.
.br
:link reftype=hd res=60.COPY STRUCTURE EXTENDED:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=62.__dbCopyXStruct():elink.
.br
:link reftype=hd res=63.__dbCreate():elink.
.br
:link reftype=hd res=64.__dbStructFilter():elink.
.br
:h1 res=59.COPY STRUCTURE
:i1 id=COPY STRUCTURE.COPY STRUCTURE
:p.COPY STRUCTURE
:p.:hp2.Create a new database based on current database structure
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.COPY STRUCTURE TO <xcFileName> [FIELDS <field,...>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. :hp2. TO:ehp2.   <xcFileName>:ehp2.  is the name of the new database file to create. (.dbf) is the default extension if none is given. It can be  specified as a literal file name or as a character expression  enclosed in parentheses.       

      :hp2. :hp2. FIELDS:ehp2.   <field,...>:ehp2.  is an optional list of field names to copy from the currently open database in the specified order, the default  is all fields. Names could be specified as uppercase or lowercase.     

:p.:hp2.Description
:ehp2.
     COPY STRUCTURE create a new empty database file with a structure  that is based on the currently open database in this work-area.       

     COPY STRUCTURE can be use to create a sub-set of the currently  open database&comma. based on a given field list.       

     COPY STRUCTURE command is preprocessed into __dbCopyStruct()  function during compile time.     

:p.:hp2.Examples
:ehp2.

     // Create a new file that contains the same structure
      USE TEST
      COPY STRUCTURE TO MyCopy

      // Create a new file that contains part of the original structure
      USE TEST
      COPY STRUCTURE TO SomePart FIELDS name&comma. address
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     COPY STRUCTURE works exactly as in CA-Clipper     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=60.COPY STRUCTURE EXTENDED:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=62.__dbCopyXStruct():elink.
.br
:link reftype=hd res=63.__dbCreate():elink.
.br
:link reftype=hd res=64.__dbStructFilter():elink.
.br
:h1 res=66.__DBCOPYXSTRUCT()
:i1 id=__DBCOPYXSTRUCT().__DBCOPYXSTRUCT()
:p.__DBCOPYXSTRUCT()
:p.:hp2.Copy current database structure into a definition file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__dbCopyXStruct( <cFileName> ) --> lSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileName>:ehp2.   is the name of target definition file to create. (.dbf) is the default extension if none is given.     

:p.:hp2.Returns
:ehp2.
      :hp2. __dbCopyXStruct():ehp2.   return (.F.) if no database is USED in the current work-area, (.T.) on success, or a run-time error if the file create  operation had failed.     

:p.:hp2.Description
:ehp2.
     __dbCopyXStruct() create a new database named <cFileName> with a  pre-defined structure (also called &cdq.structure extended file&cdq.)&colon.       


:cgraphic.
 
       Field name   Type   Length   Decimals

       FIELD_NAME   C      10       0
       FIELD_TYPE   C      1        0
       FIELD_LEN    N      3        0
       FIELD_DEC    N      3        0
 
:ecgraphic.


     Each record in the new file contains information about one field in  the original file. CREATE FROM could be used to create a database  from the structure extended file.       

     For prehistoric compatibility reasons&comma. Character fields which are  longer than 255 characters are treated in a special way by writing  part of the length in the FIELD_DEC according to the following  formula (this is done internally)&colon.       

      
      FIELD->FIELD_DEC &colon.= int( nLength / 256 )
      FIELD->FIELD_LEN &colon.= ( nLength % 256 )
      

     Later if you want to calculate the length of a field you can use  the following formula&colon.       

      
      nLength &colon.= IIF( FIELD->FIELD_TYPE == &cdq.C&cdq.&comma. ;
                      FIELD->FIELD_DEC * 256 + FIELD->FIELD_LEN&comma. ;
                      FIELD->FIELD_LEN )
      

     COPY STRUCTURE EXTENDED command is preprocessed into  __dbCopyXStruct() function during compile time.     

:p.:hp2.Examples
:ehp2.

      // Open a database&comma. then copy its structure to a new file&comma.
      // Open the new file and list all its records
      USE Test
      __dbCopyXStruct( &cdq.TestStru&cdq. )
      USE TestStru
      LIST

:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __dbCopyXStruct() works exactly like CA-Clipper's __dbCopyXStruct()     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=59.COPY STRUCTURE:elink.
.br
:link reftype=hd res=60.COPY STRUCTURE EXTENDED:elink.
.br
:link reftype=hd res=67.CREATE:elink.
.br
:link reftype=hd res=68.CREATE FROM:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=63.__dbCreate():elink.
.br
:h1 res=60.COPY STRUCTURE EXTENDED
:i1 id=COPY STRUCTURE EXTENDED.COPY STRUCTURE EXTENDED
:p.COPY STRUCTURE EXTENDED
:p.:hp2.Copy current database structure into a definition file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.COPY STRUCTURE EXTENDED TO <xcFileName>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. :hp2. TO:ehp2.   <xcFileName>:ehp2.   The name of the target definition file to create. (.dbf) is the default extension if none is given. It can be  specified as a literal file name or as a character expression  enclosed in parentheses.     

:p.:hp2.Description
:ehp2.
     COPY STRUCTURE EXTENDED create a new database named <cFileName> with  a pre-defined structure (also called &cdq.structure extended file&cdq.)&colon.       


:cgraphic.
 
       Field name   Type   Length   Decimals

       FIELD_NAME   C      10       0
       FIELD_TYPE   C      1        0
       FIELD_LEN    N      3        0
       FIELD_DEC    N      3        0
 
:ecgraphic.


     Each record in the new file contains information about one field in  the original file. CREATE FROM could be used to create a database  from the structure extended file.       

     For prehistoric compatibility reasons&comma. Character fields which are  longer than 255 characters are treated in a special way by writing  part of the length in the FIELD_DEC according to the following  formula (this is done internally)&colon.       

      
      FIELD->FIELD_DEC &colon.= int( nLength / 256 )
      FIELD->FIELD_LEN &colon.= ( nLength % 256 )
      

     Later if you want to calculate the length of a field you can use  the following formula&colon.       

      
      nLength &colon.= IIF( FIELD->FIELD_TYPE == &cdq.C&cdq.&comma. ;
                      FIELD->FIELD_DEC * 256 + FIELD->FIELD_LEN&comma. ;
                      FIELD->FIELD_LEN )
      

     COPY STRUCTURE EXTENDED command is preprocessed into  __dbCopyXStruct() function during compile time.     

:p.:hp2.Examples
:ehp2.

      // Open a database&comma. then copy its structure to a new file&comma.
      // Open the new file and list all its records
      USE Test
      COPY STRUCTURE EXTENDED TO TestStru
      USE TestStru
      LIST
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     COPY STRUCTURE EXTENDED works exactly as in CA-Clipper     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=59.COPY STRUCTURE:elink.
.br
:link reftype=hd res=67.CREATE:elink.
.br
:link reftype=hd res=68.CREATE FROM:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=62.__dbCopyXStruct():elink.
.br
:link reftype=hd res=63.__dbCreate():elink.
.br
:h1 res=69.__DBCREATE()
:i1 id=__DBCREATE().__DBCREATE()
:p.__DBCREATE()
:p.:hp2.Create structure extended file or use one to create new file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__dbCreate( <cFileName>, [<cFileFrom>], [<cRDDName>], [<lNew>],
:ehp2.
:p.:hp2.[<cAlias>] ) --> lUsed
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileName>:ehp2.   is the target file name to create and then open. (.dbf) is the default extension if none is given.       

      :hp2. <cFileFrom>:ehp2.   is an optional structure extended file name from which the target file <cFileName> is going to be built. If omitted, a new  empty structure extended file with the name <cFileName> is created  and opened in the current work-area.       

      :hp2. <cRDDName>:ehp2.   is RDD name to create target with. If omitted, the default RDD is used.       

      :hp2. <lNew>:ehp2.   is an optional logical expression, (.T.) opens the target file name <cFileName> in the next available unused work-area and makes  it the current work-area. (.F.) opens the target file in the current  work-area. Default value is (.F.). The value of <lNew> is ignored if  <cFileFrom> is not specified.       

      :hp2. <cAlias>:ehp2.   is an optional alias to USE the target file with. If not specified, alias is based on the root name of <cFileName>.     

:p.:hp2.Returns
:ehp2.
      :hp2. __dbCreate():ehp2.   returns (.T.) if there is database USED in the current work-area (this might be the newly selected work-area), or  (.F.) if there is no database USED. Note that on success a (.T.)  would be returned, but on failure you probably end up with a  run-time error and not a (.F.) value.     

:p.:hp2.Description
:ehp2.
     __dbCreate() works in two modes depending on the value of <cFileFrom>&colon.       

     &colon.hp2. 1)&colon.ehp2.  If <cFileFrom> is empty or not specified a new empty  structure extended file with the name <cFileName> is created and  then opened in the current work-area (<lNew> is ignored). The new  file has the following structure&colon.       


:cgraphic.
 
       Field name   Type   Length   Decimals

       FIELD_NAME   C      10       0
       FIELD_TYPE   C      1        0
       FIELD_LEN    N      3        0
       FIELD_DEC    N      3        0
 
:ecgraphic.


     The CREATE command is preprocessed into the __dbCopyStruct() function  during compile time and uses this mode.       

     &colon.hp2. 2)&colon.ehp2.  If <cFileFrom> is specified&comma. it is opened and assumed to  be a structure extended file where each record contains at least the  following fields (in no particular order)&colon. FIELD_NAME&comma. FIELD_TYPE&comma.  FIELD_LEN and FIELD_DEC. Any other field is ignored. From this  information the file <cFileName> is then created and opened in the  current or new work-area (according to <lNew>)&comma. if this is a new  work-area it becomes the current.       

     For prehistoric compatibility reasons&comma. structure extended file  Character fields which are longer than 255 characters should be  treated in a special way by writing part of the length in the  FIELD_DEC according to the following formula&colon.       

      
      FIELD->FIELD_DEC &colon.= int( nLength / 256 )
      FIELD->FIELD_LEN &colon.= ( nLength % 256 )
      

     CREATE FROM command is preprocessed into __dbCopyStruct() function  during compile time and use this mode.     

:p.:hp2.Examples
:ehp2.

      // CREATE a new structure extended file&comma. append some records and
      // then CREATE FROM this file a new database file

      __dbCreate( &cdq.template&cdq. )
      DBAPPEND()
      FIELD->FIELD_NAME &colon.= &cdq.CHANNEL&cdq.
      FIELD->FIELD_TYPE &colon.= &cdq.N&cdq.
      FIELD->FIELD_LEN  &colon.= 2
      FIELD->FIELD_DEC  &colon.= 0
      DBAPPEND()
      FIELD->FIELD_NAME &colon.= &cdq.PROGRAM&cdq.
      FIELD->FIELD_TYPE &colon.= &cdq.C&cdq.
      FIELD->FIELD_LEN  &colon.= 20
      FIELD->FIELD_DEC  &colon.= 0
      DBAPPEND()
      FIELD->FIELD_NAME &colon.= &cdq.REVIEW&cdq.
      FIELD->FIELD_TYPE &colon.= &cdq.C&cdq.      // this field is 1000 char long
      FIELD->FIELD_LEN  &colon.= 232      // 1000 % 256 = 232
      FIELD->FIELD_DEC  &colon.= 3        // 1000 / 256 = 3
      DBCLOSEAREA()
      __dbCreate( &cdq.TV_Guide&cdq.&comma. &cdq.template&cdq. )
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __dbCreate() works exactly as in CA-Clipper     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=59.COPY STRUCTURE:elink.
.br
:link reftype=hd res=60.COPY STRUCTURE EXTENDED:elink.
.br
:link reftype=hd res=67.CREATE:elink.
.br
:link reftype=hd res=68.CREATE FROM:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=62.__dbCopyXStruct():elink.
.br
:h1 res=67.CREATE
:i1 id=CREATE.CREATE
:p.CREATE
:p.:hp2.Create empty structure extended file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CREATE <xcFileName> [VIA <xcRDDName>] [ALIAS <xcAlias>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xcFileName>:ehp2.   is the target file name to create and then open. (.dbf) is the default extension if none is given. It can be specified as  literal file name or as a character expression enclosed in  parentheses.       

      :hp2. :hp2. VIA:ehp2.   <xcRDDName>:ehp2.  is RDD name to create target with. If omitted, the default RDD is used. It can be specified as literal name or as a  character expression enclosed in parentheses.       

      :hp2. :hp2. ALIAS:ehp2.   <xcAlias>:ehp2.  is an optional alias to USE the target file with. If not specified, alias is based on the root name of  <xcFileName>.     

:p.:hp2.Description
:ehp2.
     CREATE a new empty structure extended file with the name <cFileName>  and then open it in the current work-area. The new file has the  following structure&colon.       


:cgraphic.
 
       Field name   Type   Length   Decimals

       FIELD_NAME   C      10       0
       FIELD_TYPE   C      1        0
       FIELD_LEN    N      3        0
       FIELD_DEC    N      3        0
 
:ecgraphic.


     CREATE command is preprocessed into __dbCopyStruct() function during  compile time and use this mode.     

:p.:hp2.Examples
:ehp2.

      // CREATE a new structure extended file&comma. append some records and
      // then CREATE FROM this file a new database file

      CREATE template
      APPEND BLANK
      FIELD->FIELD_NAME &colon.= &cdq.CHANNEL&cdq.
      FIELD->FIELD_TYPE &colon.= &cdq.N&cdq.
      FIELD->FIELD_LEN  &colon.= 2
      FIELD->FIELD_DEC  &colon.= 0
      APPEND BLANK
      FIELD->FIELD_NAME &colon.= &cdq.PROGRAM&cdq.
      FIELD->FIELD_TYPE &colon.= &cdq.C&cdq.
      FIELD->FIELD_LEN  &colon.= 20
      FIELD->FIELD_DEC  &colon.= 0
      APPEND BLANK
      FIELD->FIELD_NAME &colon.= &cdq.REVIEW&cdq.
      FIELD->FIELD_TYPE &colon.= &cdq.C&cdq.      // this field is 1000 char long
      FIELD->FIELD_LEN  &colon.= 232      // 1000 % 256 = 232
      FIELD->FIELD_DEC  &colon.= 3        // 1000 / 256 = 3
      CLOSE
      CREATE TV_Guide FROM template
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CREATE works exactly as in CA-Clipper     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=59.COPY STRUCTURE:elink.
.br
:link reftype=hd res=60.COPY STRUCTURE EXTENDED:elink.
.br
:link reftype=hd res=68.CREATE FROM:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=62.__dbCopyXStruct():elink.
.br
:link reftype=hd res=63.__dbCreate():elink.
.br
:h1 res=68.CREATE FROM
:i1 id=CREATE FROM.CREATE FROM
:p.CREATE FROM
:p.:hp2.Create new database file from a structure extended file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CREATE <xcFileName> FROM <xcFileFrom> [VIA <xcRDDName>] [NEW]
:ehp2.
:p.:hp2.[ALIAS <xcAlias>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xcFileName>:ehp2.   is the target file name to create and then open. (.dbf) is the default extension if none is given. It can be specified as  literal file name or as a character expression enclosed in  parentheses.       

      :hp2. :hp2. FROM:ehp2.   <xcFileFrom>:ehp2.  is a structure extended file name from which the target file <xcFileName> is going to be built. It can be  specified as literal file name or as a character expression enclosed  in parentheses.       

      :hp2. :hp2. VIA:ehp2.   <xcRDDName>:ehp2.  is RDD name to create target with. If omitted, the default RDD is used. It can be specified as literal name or as a  character expression enclosed in parentheses.       

      :hp2. :hp2. NEW:ehp2. :ehp2.   open the target file name <xcFileName> in the next available unused work-area and making it the current work-area. If  omitted open the target file in current work-area.       

      :hp2. :hp2. ALIAS:ehp2.   <xcAlias>:ehp2.  is an optional alias to USE the target file with. If not specified, alias is based on the root name of  <xcFileName>.     

:p.:hp2.Description
:ehp2.
     CREATE FROM open a structure extended file <xcFileFrom> where each  record contain at least the following fields (in no particular  order)&colon. FIELD_NAME&comma. FIELD_TYPE&comma. FIELD_LEN and FIELD_DEC. Any other  field is ignored. From this information the file <xcFileName> is  then created and opened in the current or new work-area (according to  the NEW clause)&comma. if this is a new work-area it becomes the current.       

     For prehistoric compatibility reasons&comma. structure extended file  Character fields which are longer than 255 characters should be  treated in a special way by writing part of the length in the  FIELD_DEC according to the following formula&colon.       

      
      FIELD->FIELD_DEC &colon.= int( nLength / 256 )
      FIELD->FIELD_LEN &colon.= ( nLength % 256 )
      

     CREATE FROM command is preprocessed into __dbCopyStruct() function  during compile time and uses this mode.     

:p.:hp2.Examples
:ehp2.

      See example in the CREATE command
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CREATE FROM works exactly as in CA-Clipper     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=59.COPY STRUCTURE:elink.
.br
:link reftype=hd res=60.COPY STRUCTURE EXTENDED:elink.
.br
:link reftype=hd res=67.CREATE:elink.
.br
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=62.__dbCopyXStruct():elink.
.br
:link reftype=hd res=63.__dbCreate():elink.
.br
:h1 res=70.__FLEDIT()*
:i1 id=__FLEDIT()*.__FLEDIT()*
:p.__FLEDIT()*
:p.:hp2.Filter a database structure array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__FLEDIT( <aStruct>, [<aFieldList>] ) --> aStructFiltered
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aStruct>:ehp2.   is a multidimensional array with database fields structure, which is usually the output from DBSTRUCT(), where each  array element has the following structure:       


:cgraphic.
 
       Position   Description    dbstruct.ch

       1          cFieldName     DBS_NAME
       2          cFieldType     DBS_TYPE
       3          nFieldLength   DBS_LEN
       4          nDecimals      DBS_DEC
 
:ecgraphic.


      :hp2. <aFieldList>:ehp2.   is an array where each element is a field name. Names could be specified as uppercase or lowercase.     

:p.:hp2.Returns
:ehp2.
      :hp2. __FLEDIT():ehp2.   return a new multidimensional array where each element is in the same structure as the original <aStruct>, but the array is  built according to the list of fields in <aFieldList>. If  <aFieldList> is empty, __FLEDIT() return reference to the original  <aStruct> array.     

:p.:hp2.Description
:ehp2.
     __FLEDIT() can be use to create a sub-set of a database structure&comma.  based on a given field list.       

     Note that field names in <aStruct> MUST be specified in uppercase  or else no match would found.       

     SET EXACT has no effect on the return value.       

     __FLEDIT() is a compatibility function and it is synonym for  __dbStructFilter() which does exactly the same.     

:p.:hp2.Examples
:ehp2.

      LOCAL aStruct&comma. aList&comma. aRet
      aStruct &colon.= { { &cdq.CODE&cdq.&comma.  &cdq.N&cdq.&comma.  4&comma. 0 }&comma. ;
                   { &cdq.NAME&cdq.&comma.  &cdq.C&cdq.&comma. 10&comma. 0 }&comma. ;
                   { &cdq.PHONE&cdq.&comma. &cdq.C&cdq.&comma. 13&comma. 0 }&comma. ;
                   { &cdq.IQ&cdq.&comma.    &cdq.N&cdq.&comma.  3&comma. 0 } }
      aList &colon.= { &cdq.IQ&cdq.&comma. &cdq.NAME&cdq. }
      aRet &colon.= __FLEDIT( aStruct&comma. aList )
                        // { { &cdq.IQ&cdq.&comma. &cdq.N&cdq.&comma. 3&comma. 0 }&comma. { &cdq.NAME&cdq.&comma. &cdq.C&cdq.&comma. 10&comma. 0 } }

      aRet &colon.= __FLEDIT( aStruct&comma. {} )
      ? aRet == aStruct // .T.

      aList &colon.= { &cdq.iq&cdq.&comma. &cdq.NOTEXIST&cdq. }
      aRet &colon.= __FLEDIT( aStruct&comma. aList )
                        // { { &cdq.IQ&cdq.&comma. &cdq.N&cdq.&comma. 3&comma. 0 } }

      aList &colon.= { &cdq.NOTEXIST&cdq. }
      aRet &colon.= __FLEDIT( aStruct&comma. aList )   // {}


      // Create a new file that contain part of the original structure
      LOCAL aStruct&comma. aList&comma. aRet
      USE TEST
      aStruct &colon.= DBSTRUCT()
      aList &colon.= { &cdq.NAME&cdq. }
      DBCREATE( &cdq.OnlyName.DBF&cdq.&comma. __FLEDIT( aStruct&comma. aList ) )
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CA-Clipper has internal undocumented function named __FLEDIT()&comma.  in Harbour we name it __dbStructFilter(). The new name gives a better  description of what this function does. In Harbour __FLEDIT() simply  calls __dbStructFilter() and therefor the later is the recommended  function to use.       

     This function is only visible if source/rdd/dbstrux.prg was compiled  with the HB_C52_UNDOC flag.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Header file is dbstruct.ch  Library is rdd     
.br
See Also&colon.
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=64.__dbStructFilter():elink.
.br
:h1 res=71.__DBSTRUCTFILTER()
:i1 id=__DBSTRUCTFILTER().__DBSTRUCTFILTER()
:p.__DBSTRUCTFILTER()
:p.:hp2.Filter a database structure array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__dbStructFilter( <aStruct>, [<aFieldList>] ) --> aStructFiltered
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aStruct>:ehp2.   is a multidimensional array with database fields structure, which is usually the output from DBSTRUCT(), where each  array element has the following structure:       


:cgraphic.
 
       Position   Description    dbstruct.ch

       1          cFieldName     DBS_NAME
       2          cFieldType     DBS_TYPE
       3          nFieldLength   DBS_LEN
       4          nDecimals      DBS_DEC
 
:ecgraphic.


      :hp2. <aFieldList>:ehp2.   is an array where each element is a field name. Names could be specified as uppercase or lowercase.     

:p.:hp2.Returns
:ehp2.
      :hp2. __dbStructFilter():ehp2.   return a new multidimensional array where each element is in the same structure as the original <aStruct>, but the  array is built according to the list of fields in <aFieldList>. If  <aFieldList> is empty, __dbStructFilter() return reference to the  original <aStruct> array.     

:p.:hp2.Description
:ehp2.
     __dbStructFilter() can be use to create a sub-set of a database  structure&comma. based on a given field list.       

     Note that field names in <aStruct> MUST be specified in uppercase  or else no match would be found.       

     SET EXACT has no effect on the return value.     

:p.:hp2.Examples
:ehp2.

      LOCAL aStruct&comma. aList&comma. aRet
      aStruct &colon.= { { &cdq.CODE&cdq.&comma.  &cdq.N&cdq.&comma.  4&comma. 0 }&comma. ;
                   { &cdq.NAME&cdq.&comma.  &cdq.C&cdq.&comma. 10&comma. 0 }&comma. ;
                   { &cdq.PHONE&cdq.&comma. &cdq.C&cdq.&comma. 13&comma. 0 }&comma. ;
                   { &cdq.IQ&cdq.&comma.    &cdq.N&cdq.&comma.  3&comma. 0 } }
      aList &colon.= { &cdq.IQ&cdq.&comma. &cdq.NAME&cdq. }
      aRet &colon.= __dbStructFilter( aStruct&comma. aList )
                        // { { &cdq.IQ&cdq.&comma. &cdq.N&cdq.&comma. 3&comma. 0 }&comma. { &cdq.NAME&cdq.&comma. &cdq.C&cdq.&comma. 10&comma. 0 } }

      aRet &colon.= __dbStructFilter( aStruct&comma. {} )
      ? aRet == aStruct // .T.

      aList &colon.= { &cdq.iq&cdq.&comma. &cdq.NOTEXIST&cdq. }
      aRet &colon.= __dbStructFilter( aStruct&comma. aList )
                        // { { &cdq.IQ&cdq.&comma. &cdq.N&cdq.&comma. 3&comma. 0 } }

      aList &colon.= { &cdq.NOTEXIST&cdq. }
      aRet &colon.= __dbStructFilter( aStruct&comma. aList )   // {}


      // Create a new file that contain part of the original structure
      LOCAL aStruct&comma. aList&comma. aRet
      USE TEST
      aStruct &colon.= DBSTRUCT()
      aList &colon.= { &cdq.NAME&cdq. }
      DBCREATE( &cdq.OnlyName.DBF&cdq.&comma. __dbStructFilter( aStruct&comma. aList ) )
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __dbStructFilter() is a Harbour extension. CA-Clipper has an internal  undocumented function named __FLEDIT() that does exactly the same  thing. The new name gives a better description of what this function does.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Header file is dbstruct.ch  Library is rdd     
.br
See Also&colon.
:link reftype=hd res=61.DBCREATE():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=65.__dbCopyStruct():elink.
.br
:link reftype=hd res=70.__FLEDIT()*:elink.
.br
:h1 res=72.DISKSPACE()
:i1 id=DISKSPACE().DISKSPACE()
:p.DISKSPACE()
:p.:hp2.Get the amount of space available on a disk
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DISKSPACE( [<nDrive>] [, <nType>] ) --> nDiskbytes
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nDrive>:ehp2.   The number of the drive you are requesting info on where 1 = A, 2 = B, etc. For 0 or no parameter, DiskSpace will operate on the current  drive.  The default is 0       

      :hp2. <nType>:ehp2.   The type of space being requested.  The default is HB_DISK_AVAIL.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nDiskBytes>:ehp2.   The number of bytes on the requested disk that match the requested type.     

:p.:hp2.Description
:ehp2.
     By default&comma. this function will return the number of bytes of  free space on the current drive that is available to the user  requesting the information.       

     There are 4 types of information available&colon.       

      HB_FS_AVAIL    The amount of space available to the user making the  request.  This value could be less than HB_FS_FREE if  disk quotas are supported by the O/S in use at runtime&comma.  and disk quotas are in effect.  Otherwise&comma. the value  will be equal to that returned for HB_FS_FREE.       

      HB_FS_FREE     The actual amount of free diskspace on the drive.       

      HB_FS_USED     The number of bytes in use on the disk.       

      HB_FS_TOTAL    The total amount of space allocated for the user if  disk quotas are in effect&comma. otherwise&comma. the actual size  of the drive.       

     If information is requested on a disk that is not available&comma. a runtime  error 2018 will be raised.     

:p.:hp2.Examples
:ehp2.

      ? &cdq.You can use &colon. &cdq. +Str( DiskSpace() ) + &cdq. bytes &cdq. +;
        &cdq.Out of a total of &cdq. + Str( DiskSpace(0&comma.HB_FS_TOTAL) )

      Note&colon. See tests\tstdspac.prg for another example
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     CA-Clipper will return an integer value which limits it's usefulness to  drives less than 2 gigabytes.  The Harbour version will return a  floating point value with 0 decimals if the disk is > 2 gigabytes.  <nType> is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     Dos&comma.Win32&comma.OS/2&comma.Unix     

:p.:hp2.Files
:ehp2.
     Library is rtl  Header is fileio.ch     
:h1 res=73.__DIR()*
:i1 id=__DIR()*.__DIR()*
:p.__DIR()*
:p.:hp2.Display listings of files
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__Dir( [<cFileMask>] ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileMask>:ehp2.   File mask to include in the function return. It could contain path and standard wildcard characters as supported by your  OS (like * and ?). If <cFileMask> contains no path, then SET DEFAULT  path is used to display files in the mask.     

:p.:hp2.Returns
:ehp2.
      :hp2. __Dir():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     If no <cFileMask> is given&comma. __Dir() displays information about all  *.dbf in the SET DEFAULT path. This information contains&colon. file name&comma.  number of records&comma. last update date and the size of each file.       

     If <cFileMask> is given&comma. __Dir() list all files that match the mask  with the following details&colon. Name&comma. Extension&comma. Size&comma. Date.       

     DIR command is preprocessed into __Dir() function during compile  time.       

     __Dir() is a compatibility function&comma. it is superseded by DIRECTORY()  which return all the information in a multidimensional array.     

:p.:hp2.Examples
:ehp2.

  
      __Dir()      // information for all DBF files in current directory

      __Dir( &cdq.*.dbf&cdq. )         // list all DBF file in current directory

      // list all PRG files in Harbour Run-Time library
      // for DOS compatible operating systems
      __Dir( &cdq.c&colon.\harbour\source\rtl\*.prg&cdq. )

      // list all files in the public section on a Unix like machine
      __Dir( &cdq./pub&cdq. )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBF information&colon. CA-Clipper displays 8.3 file names&comma. Harbour displays  the first 15 characters of a long file name if available.       

     File listing&colon. To format file names displayed we use something like&colon.  PadR( Name&comma. 8 ) + &cdq. &cdq. + PadR( Ext&comma. 3 )  CA-Clipper use 8.3 file name&comma. with Harbour it would probably cut  long file names to feet this template.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=74.ADIR():elink.
.br
:link reftype=hd res=12.DIRECTORY():elink.
.br
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:link reftype=hd res=76.DIR:elink.
.br
:h1 res=76.DIR
:i1 id=DIR.DIR
:p.DIR
:p.:hp2.Display listings of files
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DIR [<cFileMask>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileMask>:ehp2.   File mask to include in the function return. It could contain path and standard wildcard characters as supported by your  OS (like * and ?). If <cFileMask> contains no path, then SET DEFAULT  path is used to display files in the mask.     

:p.:hp2.Description
:ehp2.
     If no <cFileMask> is given&comma. __Dir() display information about all  *.dbf in the SET DEFAULT path&comma. this information contain&colon. file name&comma.  number of records&comma. last update date and the size of each file.       

     If <cFileMask> is given&comma. __Dir() list all files that match the mask  with the following details&colon. Name&comma. Extension&comma. Size&comma. Date.       

     DIR command is preprocessed into __Dir() function during compile  time.       

     __Dir() is a compatibility function&comma. it is superseded by DIRECTORY()  which returns all the information in a multidimensional array.     

:p.:hp2.Examples
:ehp2.

  
      DIR          // information for all DBF files in current directory

      dir   &cdq.*.dbf&cdq.          // list all DBF file in current directory

      // list all PRG files in Harbour Run-Time library
      // for DOS compatible operating systems
        Dir  &cdq.c&colon.\harbour\source\rtl\*.prg&cdq.

      // list all files in the public section on a Unix like machine
        Dir  &cdq./pub&cdq.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBF information&colon. CA-Clipper displays 8.3 file names&comma. Harbour displays  the first 15 characters of a long file name if available.       

     File listing&colon. To format file names displayed we use something like&colon.  PadR( Name&comma. 8 ) + &cdq. &cdq. + PadR( Ext&comma. 3 )  CA-Clipper use 8.3 file name&comma. with Harbour it would probably cut  long file names to feet this template.     
.br
See Also&colon.
:link reftype=hd res=74.ADIR():elink.
.br
:link reftype=hd res=12.DIRECTORY():elink.
.br
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:link reftype=hd res=73.__DIR()*:elink.
.br
:h1 res=74.ADIR()
:i1 id=ADIR().ADIR()
:p.ADIR()
:p.:hp2.Fill pre-defined arrays with file/directory information
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ADIR( [<cFileMask>], [<aName>], [<aSize>], [<aDate>],
:ehp2.
:p.:hp2.[<aTime>], [<aAttr>] ) -> nDirEnries
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileMask>:ehp2.   File mask to include in the function return. It could contain path and standard wildcard characters as supported by your  OS (like * and ?). If you omit <cFileMask> or if <cFileMask> contains  no path, then the path from SET DEFAULT is used.       

      :hp2. <aName>:ehp2.   Array to fill with file name of files that meet <cFileMask>. Each element is a Character string and include the file name and  extension without the path. The name is the long file name as  reported by the OS and not necessarily the 8.3 uppercase name.       

      :hp2. <aSize>:ehp2.   Array to fill with file size of files that meet <cFileMask>. Each element is a Numeric integer for the file size in Bytes.  Directories are always zero in size.       

      :hp2. <aDate>:ehp2.   Array to fill with file last modification date of files that meet <cFileMask>. Each element is of type Date.       

      :hp2. <aTime>:ehp2.   Array to fill with file last modification time of files that meet <cFileMask>. Each element is a Character string in the format  HH:mm:ss.       

      :hp2. <aAttr>:ehp2.   Array to fill with attribute of files that meet <cFileMask>. Each element is a Character string, see DIRECTORY() for information  about attribute values. If you pass array to <aAttr>, the function  is going to return files with normal, hidden, system and directory  attributes. If <aAttr> is not specified or with type other than  Array, only files with normal attribute would return.     

:p.:hp2.Returns
:ehp2.
      :hp2. ADIR():ehp2.   return the number of file entries that meet <cFileMask>    

:p.:hp2.Description
:ehp2.
     ADIR() return the number of files and/or directories that match  a specified skeleton&comma. it also fill a series of given arrays with  the name&comma. size&comma. date&comma. time and attribute of those files. The passed  arrays should pre-initialized to the proper size&comma. see example below.  In order to include hidden&comma. system or directories <aAttr> must be  specified.       

     ADIR() is a compatibility function&comma. it is superseded by DIRECTORY()  which returns all the information in a multidimensional array.     

:p.:hp2.Examples
:ehp2.

  
      LOCAL aName&comma. aSize&comma. aDate&comma. aTime&comma. aAttr&comma. nLen&comma. i
      nLen &colon.= ADIR( &cdq.*.JPG&cdq. )     // Number of JPG files in this directory
      IF nLen > 0
         aName &colon.= Array( nLen )   // make room to store the information
         aSize &colon.= Array( nLen )
         aDate &colon.= Array( nLen )
         aTime &colon.= Array( nLen )
         aAttr &colon.= Array( nLen )
         FOR i = 1 TO nLen
             ? aName[i]&comma. aSize[i]&comma. aDate[i]&comma. aTime[i]&comma. aAttr[i]
         NEXT
      ELSE
         ? &cdq.This directory is clean from smut&cdq.
      ENDIF
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     <aName> is going to be fill with long file name and not necessarily  the 8.3 uppercase name.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=1.ARRAY():elink.
.br
:link reftype=hd res=12.DIRECTORY():elink.
.br
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:h1 res=77.ERRORSYS()
:i1 id=ERRORSYS().ERRORSYS()
:p.ERRORSYS()
:p.:hp2.Install default error handler
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ERRORSYS() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. ERRORSYS():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     ERRORSYS() is called upon startup by Harbour and install the default  error handler. Normally you should not call this function directly&comma.  instead use ERRORBLOCK() to install your own error handler.     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ERRORSYS() works exactly like CA-Clipper's ERRORSYS().     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=78.ERRORBLOCK():elink.
.br
:link reftype=hd res=79.Error class:elink.
.br
:h1 res=80.FOPEN()
:i1 id=FOPEN().FOPEN()
:p.FOPEN()
:p.:hp2.Open a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FOPEN( <cFile>, [<nMode>] ) --> nHandle
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of file to open.      

      :hp2. <nMode>:ehp2.   Dos file open mode.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nHandle>:ehp2.   A file handle.    

:p.:hp2.Description
:ehp2.
     This function opens a file expressed as <cFile> and returns a  file handle to be used with other low-level file functions. The  value of <nMode> represents the status of the file to be opened;  the default value is 0. The file open modes are as follows&colon.       


:cgraphic.
 
       nMode   fileio.ch      Meaning

       0       FO_READ        Read only
       1       FO_WRITE       Write only
       2       FO_READWRITE   Read/write
       16      FO_EXCLUSIVE   Exclusive read only
       32      FO_DENYWRITE   Prevent others from writing
       48      FO_DENYREAD    Deny read only
       64      FO_DENYNONE    Share read only
 
:ecgraphic.

     If there is an error in opening a file&comma. a -1 will be returned by  the function. Files handles may be in the range of 0 to 65535. The  status of the SET DEFAULT TO and SET PATH TO commands has no effect  on this function. Directory names and paths must be specified along  with the file that is to be opened.       

     If an error has occured&comma. see the returns values from FERROR() for  possible reasons for the error.     

:p.:hp2.Examples
:ehp2.



      IF (nH&colon.=FOPEN('X.TXT'&comma.66) < 0
         ? 'File can't be opened'
      ENDIF
  
:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rtl  Header  is fileio.ch     
.br
See Also&colon.
:link reftype=hd res=81.FCREATE():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=83.FCLOSE():elink.
.br
:h1 res=81.FCREATE()
:i1 id=FCREATE().FCREATE()
:p.FCREATE()
:p.:hp2.Creates a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FCREATE( <cFile>, [<nAttribute>] ) --> nHandle
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   is the name of the file to create.      

      :hp2. <nAttribute>:ehp2.   Numeric code for the file attributes.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nHandle>:ehp2.    Numeric file handle to be used in other operations.    

:p.:hp2.Description
:ehp2.
     This function creates a new file with a filename of <cFile>. The  default value of <nAttribute> is 0 and is used to set the  attribute byte for the file being created by this function.  The return value will be a file handle that is associated  with the new file. This number will be between zero to 65&comma.535&comma.  inclusive. If an error occurs&comma. the return value of this function  will be -1.       

     If the file <cFile> already exists&comma. the existing file will be  truncated to a file length of 0 bytes.       

     If specified&comma. the following table shows the value for <nAttribute>  and their related meaning to the file <cFile> being created by  this function.       


:cgraphic.
 
       <nAttribute>   fileio.ch     Attribute

       0              FC_NORMAL     Normal/Default&comma.Read/Write
       1              FC_READONLY   Read-only file attribute is set
       2              FC_HIDDEN     Hidden&comma.Excluded from normal DIR search
       4              FC_SYSTEM     Create&comma.Excluded from normal DIR search
 
:ecgraphic.


:p.:hp2.Examples
:ehp2.

      IF (nh&colon.=FCREATE(&cdq.TEST.TXT&cdq.) <0
          ? &cdq.Cannot create file&cdq.
      ENDIF
    
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl  Header is fileio.ch     
.br
See Also&colon.
:link reftype=hd res=83.FCLOSE():elink.
.br
:link reftype=hd res=80.FOPEN():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:h1 res=28.FREAD()
:i1 id=FREAD().FREAD()
:p.FREAD()
:p.:hp2.Reads a specified number of bytes from a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FREAD( <nHandle>, @<cBuffer>, <nBytes> ) --> nBytes
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nHandle>:ehp2.       Dos file handle      

      :hp2. <cBufferVar>:ehp2.    Character expression passed by reference.      

      :hp2. <nBytes>:ehp2.        Number of bytes to read.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nBytes>:ehp2.   the number of bytes successfully read from the file. <nHandle>     

:p.:hp2.Description
:ehp2.
     This function reads the characters from a file whose file handle  is <nHandle> into a character memory variable expressed as <cBuffer>.  The function returns the number of bytes successfully read into  <cBuffer>.       

     The value of <nHandle> is obtained from either a call to the FOPEN()  or the FCREATE() function.       

     The <cBuffer> expression is passed by reference and must be defined  before this function is called. It also must be at least the same  length as <nBytes>.       

     <nBytes> is the number of bytes to read&comma. starting at the current  file pointer position. If this function is successful in reading  the characters from the file&comma. the length of <cBuffer> or the number  of bytes specified in <nBytes> will be the value returned. The current  file pointer advances the number of bytes read with each successive  read. The return value is the number of bytes successfully read  from the file. If a 0 is returned&comma. or if the number of  bytes read matches neither the length of <cBuffer> nor the specified  value in <nBytes> an end-of-file condition has been reached.     

:p.:hp2.Examples
:ehp2.

      cBuffer&colon.=SPACE(500)
      IF (nH&colon.=FOPEN('X.TXT))>0
         FREAD(Hh&comma.@cBuffer&comma.500)
         ? cbuffer
      ENDIF
      FCLOSE(nH)
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    This function is CA-Clipper compliant&comma. but also extends the possible  buffer size to strings greater than 65K (depending on platform).     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=29.FWRITE()
:i1 id=FWRITE().FWRITE()
:p.FWRITE()
:p.:hp2.Writes characters to a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FWRITE( <nHandle>, <cBuffer>, [<nBytes>] ) --> nBytesWritten
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nHandle>:ehp2.    DOS file handle number.      

      :hp2. <cBuffer>:ehp2.    Character expression to be written.      

      :hp2. <nBytes>:ehp2.     The number of bytes to write.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nBytesWritten>:ehp2.   the number of bytes successfully written.    

:p.:hp2.Description
:ehp2.
     This function writes the contents of <cBuffer> to the file designated  by its file handle <nHandle>. If used&comma. <nBytes> is the number of  bytes in <cBuffer> to write.       

     The returned value is the number of bytes successfully written to the  DOS file. If the returned value is 0&comma. an error has occurred (unless  this is intended). A successful write occurs when the number returned  by FWRITE() is equal to either LEN( <cBuffer>) or <nBytes>.       

     The value of <cBuffer> is the string or variable to be written to the  open DOS file <nHandle>.       

     The value of <nBytes> is the number of bytes to write out to the file.  The disk write begins with the current file position in <nHandle>. If  this variable is not used&comma. the entire contents of <cBuffer> is written  to the file.  To truncate a file. a call of FWRITE( nHandle&comma. &cdq.&cdq.&comma. 0 ) is needed.     

:p.:hp2.Examples
:ehp2.

      nHandle&colon.=FCREATE('x.txt')
      FOR X&colon.=1 to 10
        FWRITE(nHandle&comma.STR(x))
      NEXT
      FCLOSE(nHandle)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is not CA-Clipper compatile since  it can writes strings greather the 64K     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=83.FCLOSE():elink.
.br
:link reftype=hd res=81.FCREATE():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=80.FOPEN():elink.
.br
:link reftype=hd res=23.I2BIN():elink.
.br
:link reftype=hd res=24.L2BIN():elink.
.br
:h1 res=82.FERROR()
:i1 id=FERROR().FERROR()
:p.FERROR()
:p.:hp2.Reports the error status of low-level file functions
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FERROR() --> <nErrorCode>
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <nErrorCode>:ehp2.   Value of the DOS error last encountered by a low-level file function.       

      :hp2. FERROR():ehp2.   Return Values      


:cgraphic.
 
       Error          Meaning

       0              Successful
       2              File not found
       3              Path not found
       4              Too many files open
       5              Access denied
       6              Invalid handle
       8              Insufficient memory
       15             Invalid drive specified
       19             Attempted to write to a write-protected disk
       21             Drive not ready
       23             Data CRC error
       29             Write fault
       30             Read fault
       32             Sharing violation
       33             Lock Violation
 
:ecgraphic.


:p.:hp2.Description
:ehp2.
     After every low-level file function&comma.this function will return  a value that provides additional informationon the status of  the last low-level file functions's performance.If the FERROR()  function returns a 0&comma. no error was detected.Below is a table  of possibles values returned by the FERROR() function.     

:p.:hp2.Examples
:ehp2.

      #include &cdq.Fileio.ch&cdq.
      //
      nHandle &colon.= FCREATE(&cdq.Temp.txt&cdq.&comma. FC_NORMAL)
      IF FERROR() != 0
         ? &cdq.Cannot create file&comma. DOS error &cdq.&comma. FERROR()
      ENDIF
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    This function is CA-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=83.FCLOSE():elink.
.br
:link reftype=hd res=84.FERASE():elink.
.br
:link reftype=hd res=80.FOPEN():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=83.FCLOSE()
:i1 id=FCLOSE().FCLOSE()
:p.FCLOSE()
:p.:hp2.Closes an open file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FCLOSE( <nHandle> ) --> <lSuccess>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nHandle>:ehp2.   DOS file handle    

:p.:hp2.Returns
:ehp2.
      :hp2. <lSuccess>:ehp2.    Logical TRUE (.T.) or FALSE (.F.)    

:p.:hp2.Description
:ehp2.
    This function closes an open file with a dos file handle  of <nHandle> and writes the associated DOS buffer to the  disk. The <nHandle> value is derived from the FCREATE()  or FOPEN() function.     

:p.:hp2.Examples
:ehp2.

     nHandle&colon.=FOPEN('x.txt')
     ? FSEEK(nHandle0&comma.2)
     FCLOSE(nHandle)
     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=80.FOPEN():elink.
.br
:link reftype=hd res=81.FCREATE():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:h1 res=84.FERASE()
:i1 id=FERASE().FERASE()
:p.FERASE()
:p.:hp2.Erase a file from disk
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FERASE( <cFile> ) --> nSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of file to erase.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nSuccess>:ehp2.   0 if successful, -1 if not    

:p.:hp2.Description
:ehp2.
     This function deletes the file specified in <cFile> from the disk.  No extensions are assumed. The drive and path my be included in  <cFile>; neither the SET DEFAULT not the SET PATH command controls  the performance of this function.If the drive or path is not used&comma.  the function will look for the file only on the currently selected  direcytory on the logged drive.       

     If the function is able to successfully delete the file from the  disk&comma. the value of the function will be 0; otherwise a -1 will  be returned.If not successfu&comma. aditional information may be  obtained by calling the FERROR() function.       

     Note&colon. Any file to be removed by FERASE() must still be closed.       

:p.:hp2.Examples
:ehp2.

      IF (FERASE(&cdq.TEST.TXT&cdq.)==0)
          ? &cdq.File successfully erased&cdq.
      ELSE
          ? &cdq.File can not be deleted&cdq.
      ENDIF
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    This function is CA-Clipper Compatible     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=85.FRENAME():elink.
.br
:h1 res=85.FRENAME()
:i1 id=FRENAME().FRENAME()
:p.FRENAME()
:p.:hp2.Renames a file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FRENAME( <cOldFile>, <cNewFile> ) --> nSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOldFile>:ehp2.   Old filenarne to he changed      

      :hp2. <cNewFile>:ehp2.   New filename    

:p.:hp2.Returns
:ehp2.
      :hp2. <nSuccess>:ehp2.   If sucessful, a 0 will he returned otherwise, a -1 will be returned.     

:p.:hp2.Description
:ehp2.
     This function renames the specified file <cOldFile> to <cNewFile>.  A filename and/or directory name may be specified for either para-  meter. However&comma. if a path is supplied as part of <cNewFile> and  this path is different from either the path specified in <cOldFile>  or (if none is used) the current drive and directory&comma. the function  will not execute successfully.       

     Neither parameter is subject to the control of the SET PATH TO or  SET DEFAULT TO commands. In attempting to locate the file to be  renamed&comma. this function will search the default drive and directory  or the drive and path specified in <cOldFile>. It will not search  directories named by the SET PATH TO and SET DEFAULT TO commands  or by the DOS PATH statement.       

     If the file specified in <cNewFile> exists or the file is open&comma.  the function will be unable to rename the file.If the function  is unable to complete its operation&comma.it will return a value of -1.  If it is able to rename the file&comma. the return value for the function  will be 0.A call to FERROR() function will give additional infor-  mation about any error found.     

:p.:hp2.Examples
:ehp2.

      nResult&colon.=FRENAME(&cdq.x.txt&cdq.&comma.&cdq.x1.txt&cdq.)
      IF nResult <0
         ? &cdq.File could not be renamed.&cdq.
      ENDIF
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=86.ERASE:elink.
.br
:link reftype=hd res=84.FERASE():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=87.FILE():elink.
.br
:link reftype=hd res=88.RENAME:elink.
.br
:h1 res=89.FSEEK()
:i1 id=FSEEK().FSEEK()
:p.FSEEK()
:p.:hp2.Positions the file pointer in a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FSEEK( <nHandle>, <nOffset>, [<nOrigin>] ) --> nPosition
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nHandle>:ehp2.   DOS file handle.      

      :hp2. <nOffset>:ehp2.   The number of bytes to move.      

      :hp2. <nOrigin>:ehp2.   The relative position in the file.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nPosition>:ehp2.   the current position relative to begin-of-file    

:p.:hp2.Description
:ehp2.
     This function sets the file pointer in the file whose DOS file  handle is <nHandle> and moves the file pointer by <expN2> bytes  from the file position designated by <nOrigin>. The returned value  is the relative position of the file pointer to the beginning-of-file  marker once the operation has been completed.       

     <nHandle> is the file handle number. It is obtained from the FOPEN()  or FCREATE() function.       

     The value of <nOffSet> is the number of bytes to move the file pointer  from the position determined by <nOrigin>.The value of <nOffset> may  be a negative number&comma. suggesting backward movement.       

     The value of <nOrigin> designates the starting point from which the  file pointer should he moved&comma. as shown in the following table&colon.       


:cgraphic.
 
       <nOrigin>   fileio.ch     File position

       0           FS_SET        Beginning of file
       1           FS_RELATIVE   Current file pointer position
       2           FS_END        End of file
 
:ecgraphic.

     If a value is not provided for <nOrigin>&comma. it defaults to 0 and  moves the file pointer from the beginning of the file.     

:p.:hp2.Examples
:ehp2.

      // here is a function that read one text line from an open file

      // nH = file handle obtained from FOPEN()
      // cB = a string buffer passed-by-reference to hold the result
      // nMaxLine = maximum number of bytes to read

      #define EOL HB_OSNEWLINE()
      FUNCTION FREADln( nH&comma. cB&comma. nMaxLine )
      LOCAL cLine&comma. nSavePos&comma. nEol&comma. nNumRead
      cLine &colon.= space( nMaxLine )
      cB &colon.= ''
      nSavePos &colon.= FSEEK( nH&comma. 0&comma. FS_RELATIVE )
      nNumRead &colon.= FREAD( nH&comma. @cLine&comma. nMaxLine )
      IF ( nEol &colon.= AT( EOL&comma. substr( cLine&comma. 1&comma. nNumRead ) ) ) == 0
        cB &colon.= cLine
      ELSE
        cB &colon.= SUBSTR( cLine&comma. 1&comma. nEol - 1 )
        FSEEK( nH&comma. nSavePos + nEol + 1&comma. FS_SET )
      ENDIF
      RETURN nNumRead != 0
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl  Header is fileio.ch     
.br
See Also&colon.
:link reftype=hd res=81.FCREATE():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=80.FOPEN():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:link reftype=hd res=90.FREADSTR():elink.
.br
:link reftype=hd res=29.FWRITE():elink.
.br
:h1 res=87.FILE()
:i1 id=FILE().FILE()
:p.FILE()
:p.:hp2.Tests for the existence of file(s)
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FILE( <cFileSpec> ) --> lExists
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFileSpec>:ehp2.   Dos Skeleton or file name to find.    

:p.:hp2.Returns
:ehp2.
      :hp2. <lExists>:ehp2.   a logical true (.T.) if the file exists or logical false (.F.).     

:p.:hp2.Description
:ehp2.
     This function return a logical true (.T.) if the given filename  <cFileSpec> exist.       

     Dos skeletons symbols may be used in the filename in <cFileSpec>&comma.  as may the drive and/or path name. If a drive are not explicity  specified&comma.FILE() will first search the current drive and directory&comma.  and will look for the file in the directories specified by SET PATH  TO and SET DEFAULT TO commands.However&comma. this command does not look  at the values in the DOS PATH command.     

:p.:hp2.Examples
:ehp2.

      ? file('c&colon.\harbour\doc\compiler.txt&cdq.)
      ? file('c&colon./harbour/doc/subcodes.txt&cdq.)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible.     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=91.SET PATH:elink.
.br
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=90.FREADSTR()
:i1 id=FREADSTR().FREADSTR()
:p.FREADSTR()
:p.:hp2.Reads a string from a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FREADSTR(<nHandle>, <nBytes>) --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nHandle>:ehp2.   DOS file handle number.      

      :hp2. <nBytes>:ehp2.    Number of bytes to read.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.   an characted expression    

:p.:hp2.Description
:ehp2.
     This function returns a character string of <nBytes> bytes from a  file whose DOS file handle is <nHandle>.       

     The value of the file handle <nHandle> is obtained from either the  FOPEN() or FCREATE() functions.       

     The value of <nBytes> is the number of bytes to read from the file.  The returned string will be the number of characters specified in  <nBytes> or the number of bytes read before an end-of-file charac-  ter (ASCII 26) is found.       

     NOTE  This function is similar to the FREAD() function&comma. except that  it will not     read binary characters that may he required as part of  a header of a file construct. Characters Such as CHR(0) and CHR(26)  may keep this   function from performing its intended operation. In this  event&comma. the FREAD() function should he used in place of the FREADSTR()  function.     

:p.:hp2.Examples
:ehp2.

      IF ( nH &colon.= FOPEN(&cdq.x.txt&cdq.) ) > 0
         cStr &colon.= Freadstr(nH&comma.100)
         ? cStr
      ENDIF
      FCLOSE(nH)
   
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is not CA-Clipper compliant since may read  strings greather the 65K depending of platform.     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=20.BIN2I():elink.
.br
:link reftype=hd res=21.BIN2L():elink.
.br
:link reftype=hd res=19.BIN2W():elink.
.br
:link reftype=hd res=82.FERROR():elink.
.br
:link reftype=hd res=28.FREAD():elink.
.br
:link reftype=hd res=89.FSEEK():elink.
.br
:h1 res=88.RENAME
:i1 id=RENAME.RENAME
:p.RENAME
:p.:hp2.Changes the name of a specified file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RENAME <cOldFile> TO <cNewFile>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOldFile>:ehp2.   Old filename      

      :hp2. <cNewFile>:ehp2.   New Filename    

:p.:hp2.Description
:ehp2.
     This command changes the name of <cOldFile> to <cNewFile>.Both  <cOldFile> and <cNewFile> must include a file extension.This command  if not affected by the SET PATH TO or SET DEFAULT TO commands;drive  and directoy designaters must be specified if either file is in a  directory other then the default drive and directory.       

     If <cNewFile> id currently open or if it previously exists&comma. this  command will not perform the desired operation.     

:p.:hp2.Examples
:ehp2.

      RENAME c&colon.\autoexec.bat to c&colon.\autoexec.old
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=93.CURDIR():elink.
.br
:link reftype=hd res=86.ERASE:elink.
.br
:link reftype=hd res=87.FILE():elink.
.br
:link reftype=hd res=84.FERASE():elink.
.br
:link reftype=hd res=85.FRENAME():elink.
.br
:h1 res=86.ERASE
:i1 id=ERASE.ERASE
:p.ERASE
:p.:hp2.Remove a file from disk
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ERASE <xcFile>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xcFile>:ehp2.   Name of file to remove    

:p.:hp2.Description
:ehp2.
     This command removes a file from the disk.The use of a drive&comma.directo-  ry&comma.and wild-card skeleton operator is allowed for the root of the  filename.The file extension is required.The SET DEFAULT and SET PATH  commands do not affect this command.       

     The file must be considered closed by the operating system before it  may be deleted.     

:p.:hp2.Examples
:ehp2.

      Erase c&colon.\autoexec.bat
      Erase c&colon./temp/read.txt
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA-Clipper compatible     
.br
See Also&colon.
:link reftype=hd res=93.CURDIR():elink.
.br
:link reftype=hd res=87.FILE():elink.
.br
:link reftype=hd res=84.FERASE():elink.
.br
:link reftype=hd res=94.DELETE FILE:elink.
.br
:h1 res=94.DELETE FILE
:i1 id=DELETE FILE.DELETE FILE
:p.DELETE FILE
:p.:hp2.Remove a file from disk
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DELETE FILE <xcFile>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xcFile>:ehp2.   Name of file to remove    

:p.:hp2.Description
:ehp2.
     This command removes a file from the disk.The use of a drive&comma.directo-  ry&comma.and wild-card skeleton operator is allowed for the root of the  filename.The file extension is required.The SET DEFAULT and SET PATH  commands do not affect this command.       

     The file must be considered closed by the operating system before it  may be deleted.     

:p.:hp2.Examples
:ehp2.

      Erase c&colon.\autoexec.bat
      Erase c&colon./temp/read.txt
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA-Clipper compatible     
.br
See Also&colon.
:link reftype=hd res=93.CURDIR():elink.
.br
:link reftype=hd res=87.FILE():elink.
.br
:link reftype=hd res=84.FERASE():elink.
.br
:link reftype=hd res=86.ERASE:elink.
.br
:h1 res=95.__TYPEFILE()
:i1 id=__TYPEFILE().__TYPEFILE()
:p.__TYPEFILE()
:p.:hp2.Show the content of a file on the console and/or printer
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__TYPEFILE( <cFile>, [<lPrint>] ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   is a name of the file to display. If the file have an extension, it must be specified (there is no default value).       

      :hp2. <lPrint>:ehp2.   is an optional logical value that specifies whether the output should go only to the screen (.F.) or to both the screen and  printer (.T.), the default is (.F.).     

:p.:hp2.Returns
:ehp2.
      :hp2. __TYPEFILE():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __TYPEFILE() function type the content of a text file on the screen  with an option to send this information also to the printer. The  file is displayed as is without any headings or formating.       

     If <cFile> contain no path&comma. __TYPEFILE() try to find the file first  in the SET DEFAULT directory and then in search all of the SET PATH  directories. If <cFile> can not be found a run-time error occur.       

     Use SET CONSOLE OFF to suppress screen output.  You can pause the output using Ctrl-S&comma. press any key to resume.       

     __TYPEFILE() function is used in the preprocessing of the TYPE  command.     

:p.:hp2.Examples
:ehp2.

      The following examples assume a file name MyText.DAT exist in all
      specified paths&comma. a run-time error would displayed if it does not

      // display MyText.DAT file on screen
      __TYPEFILE( &cdq.MyText.DAT&cdq. )

      // display MyText.DAT file on screen and printer
      __TYPEFILE( &cdq.MyText.DAT&cdq.&comma. .T. )

      // display MyText.DAT file on printer only
      SET CONSOLE OFF
      __TYPEFILE( &cdq.MyText.DAT&cdq.&comma. .T. )
      SET CONSOLE ON
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __TYPEFILE() works exactly like CA-Clipper's __TYPEFILE()     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=96.COPY FILE:elink.
.br
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:link reftype=hd res=91.SET PATH:elink.
.br
:link reftype=hd res=97.SET PRINTER:elink.
.br
:link reftype=hd res=98.TYPE:elink.
.br
:h1 res=98.TYPE
:i1 id=TYPE.TYPE
:p.TYPE
:p.:hp2.Show the content of a file on the console, printer or file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.TYPE <xcFile> [TO PRINTER] [TO FILE <xcDestFile>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xcFile>:ehp2.   is a name of the file to display. If the file have an extension, it must be specified (there is no default value).  It can be specified as literal file name or as a character  expression enclosed in parentheses.       

      TO  PRINTER is an optional keyword that specifies that the output should go to both the screen and printer.       

      TO  FILE <xcDestFile> copy the source <xcFile> also to a file. If no extension is given (.txt) is added to the output file name.  <xcDestFile> can be specified as literal file name or as a character  expression enclosed in parentheses.     

:p.:hp2.Description
:ehp2.
     TYPE command type the content of a text file on the screen  with an option to send this information also to the printer or to  an alternate file. The file is displayed as is without any headings  or formating.       

     If <xcFile> contain no path&comma. TYPE try to find the file first in the  SET DEFAULT directory and then in search all of the SET PATH  directories. If <xcFile> can not be found a run-time error occur.       

     If <xcDestFile> contain no path it is created in the SET DEFAULT  directory.       

     Use SET CONSOLE OFF to suppress screen output.  You can pause the output using Ctrl-S&comma. press any key to resume.     

:p.:hp2.Examples
:ehp2.

      The following examples assume a file name MyText.DAT exist in all
      specified paths&comma. a run-time error would displayed if it does not

      // display MyText.DAT file on screen
      TYPE MyText.DAT

      // display MyText.DAT file on screen and printer
      TYPE MyText.DAT TO PRINTER

      // display MyText.DAT file on printer only
      SET CONSOLE OFF
      TYPE MyText.DAT TO PRINTER
      SET CONSOLE ON

      // display MyText.DAT file on screen and into a file MyReport.txt
      TYPE MyText.DAT TO FILE MyReport
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     TYPE works exactly like CA-Clipper's TYPE     
.br
See Also&colon.
:link reftype=hd res=96.COPY FILE:elink.
.br
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:link reftype=hd res=91.SET PATH:elink.
.br
:link reftype=hd res=97.SET PRINTER:elink.
.br
:link reftype=hd res=95.__TYPEFILE():elink.
.br
:h1 res=93.CURDIR()
:i1 id=CURDIR().CURDIR()
:p.CURDIR()
:p.:hp2.Returns the current OS directory name.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CURDIR( [<cDrive>] )  --> cPath
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDir>:ehp2.   OS drive letter    

:p.:hp2.Returns
:ehp2.
      :hp2. <cPath>:ehp2.   Name of directory    

:p.:hp2.Description
:ehp2.
     This function yields the name of the current OS directory on a  specified drive.If <cDrive> is not speficied&comma.the currently logged  drive will be used.       

     This function should not return the leading and trailing  (back)slashes.       

     If an error has been detected by the function&comma.or the current OS  directory is the root&comma.the value of the function will be a NULL  byte.     

:p.:hp2.Examples
:ehp2.

      ? Curdir()
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper Compatible     

:p.:hp2.Platforms
:ehp2.
     ALL     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=87.FILE():elink.
.br
:h1 res=96.COPY FILE
:i1 id=COPY FILE.COPY FILE
:p.COPY FILE
:p.:hp2.Copies a file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.COPY FILE <cfile> TO <cfile1>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.     Filename of source file <cFile1>  Filename of target file     

:p.:hp2.Description
:ehp2.
     This command makes an exact copy of <cFile> and names it <cFile1>.  Both files must have the file extension included; the drive and the  directory names must also be specified if they are different from  the default drive and/or director.<cFile1> also can refer to a OS  device (e.g. LPT1).This command does not obsert the SET PATH TO or  SET DEFAULT TO settings.     

:p.:hp2.Examples
:ehp2.

      COPY FILE C&colon.\HARBOUR\TESTS\ADIRTEST.PRG to C&colon.\TEMP\ADIRTEST.PRG
      COPY FILE c&colon.\harbour\utils\hbdoc\gennf.prg to LPT1
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=86.ERASE:elink.
.br
:link reftype=hd res=88.RENAME:elink.
.br
:link reftype=hd res=85.FRENAME():elink.
.br
:link reftype=hd res=84.FERASE():elink.
.br
:h1 res=99.PROCNAME()
:i1 id=PROCNAME().PROCNAME()
:p.PROCNAME()
:p.:hp2.Gets the name of the current function on the stack
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PROCNAME( <nLevel> ) --> <cProcName>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nLevel>:ehp2.   is the function level required.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cProcName>:ehp2.   The name of the function that it is being executed.    

:p.:hp2.Description
:ehp2.
     This function looks at the top of the stack and gets the current  executed function if no arguments are passed. Otherwise it returns  the name of the function or procedure at <nLevel>.        

:p.:hp2.Examples
:ehp2.

      See Test
  

:p.:hp2.Tests
:ehp2.

      This test will show the functions and procedures in stack.
      before executing it.
      function Test()
         LOCAL n &colon.= 1
         while !Empty( ProcName( n ) )
            ? ProcName( n++ )
         end do
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     PROCNAME() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=100.PROCLINE():elink.
.br
:link reftype=hd res=101.PROCFILE():elink.
.br
:h1 res=100.PROCLINE()
:i1 id=PROCLINE().PROCLINE()
:p.PROCLINE()
:p.:hp2.Gets the line number of the current function on the stack.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PROCLINE( <nLevel> ) --> <nLine>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nLevel>:ehp2.   is the function level required.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nLine>:ehp2.   The line number of the function that it is being executed.    

:p.:hp2.Description
:ehp2.
     This function looks at the top of the stack and gets the current  line number of the executed function if no arguments are passed.  Otherwise it returns the line number of the function or procedure  at <nLevel>.        

:p.:hp2.Examples
:ehp2.

      See Test
  

:p.:hp2.Tests
:ehp2.

      function Test()
         ? ProcLine( 0 )
         ? ProcName( 2 )
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     PROCLINE() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=99.PROCNAME():elink.
.br
:link reftype=hd res=101.PROCFILE():elink.
.br
:h1 res=101.PROCFILE()
:i1 id=PROCFILE().PROCFILE()
:p.PROCFILE()
:p.:hp2.This function allways returns an empty string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PROCFILE( <xExp> ) --> <cEmptyString>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xExp>:ehp2.   is any valid type.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cEmptyString>:ehp2.   Return an empty string    

:p.:hp2.Description
:ehp2.
     This function is added to the RTL for full compatibility. It  always returns an empty string.        

:p.:hp2.Examples
:ehp2.

      ? ProcFile()
  

:p.:hp2.Tests
:ehp2.

      function Test()
         ? ProcFile()
         ? ProcFile( NIL )
         ? ProcFile( 2 )
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     PROCFILE() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=99.PROCNAME():elink.
.br
:link reftype=hd res=100.PROCLINE():elink.
.br
:h1 res=102.HB_PVALUE()
:i1 id=HB_PVALUE().HB_PVALUE()
:p.HB_PVALUE()
:p.:hp2.Retrieves the value of an argument.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_PVALUE( <nArg> ) --> <xExp>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      A  number that indicates the argument to check.    

:p.:hp2.Returns
:ehp2.
      :hp2. <xExp>:ehp2.   Returns the value stored by an argument.    

:p.:hp2.Description
:ehp2.
     This function is useful to check the value stored in an argument.   

:p.:hp2.Examples
:ehp2.

      See Test
  

:p.:hp2.Tests
:ehp2.

      function Test( nValue&comma. cString )
         if PCount() == 2
            ? hb_PValue( 1 )&comma. nValue
            ? hb_PValue( 2 )&comma. cString
         endif
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     HB_PVALUE() is a new function and hence not CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=103.PCOUNT():elink.
.br
:h1 res=103.PCOUNT()
:i1 id=PCOUNT().PCOUNT()
:p.PCOUNT()
:p.:hp2.Retrieves the number of arguments passed to a function.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PCOUNT() --> <nArgs>
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <nArgs>:ehp2.   A number that indicates the number of arguments passed to a function or procedure.        

:p.:hp2.Description
:ehp2.
     This function is useful to check if a function or procedure  has received the required number of arguments.        

:p.:hp2.Examples
:ehp2.

      See Test
  

:p.:hp2.Tests
:ehp2.

      function Test( xExp )
         if PCount() == 0
            ? &cdq.This function needs a parameter&cdq.
         else
            ? xExp
         endif
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     PCOUNT() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=102.HB_PVALUE():elink.
.br
:h1 res=104.__QUIT()
:i1 id=__QUIT().__QUIT()
:p.__QUIT()
:p.:hp2.Terminates an application.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__QUIT() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
       NIL    

:p.:hp2.Description
:ehp2.
     This function terminates the current application and returns  to the system.        

:p.:hp2.Examples
:ehp2.

      See Test
  

:p.:hp2.Tests
:ehp2.

      function EndApp( lYesNo )
         if lYesNo
            __Quit()
         endif
      return nil
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __QUIT() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=105.QUIT:elink.
.br
:h1 res=106.CLIPINIT()
:i1 id=CLIPINIT().CLIPINIT()
:p.CLIPINIT()
:p.:hp2.Initialize various Harbour sub-systems
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CLIPINIT() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       none.    

:p.:hp2.Returns
:ehp2.
      :hp2. CLIPINIT():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     CLIPINIT() is one of the pre-defined INIT PROCEDURE and is executed  at program startup. It declare an empty MEMVAR PUBLIC array called  GetList that is going to be used by the Get system. It activates the  default error handler&comma. and (at least for the moment) calls the  function that sets the default help key.        
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     It is said that CLIPINIT() should not call the function that sets  the default help key since CA-Clipper does it in some other place.        

:p.:hp2.Platforms
:ehp2.
     All   
.br
See Also&colon.
:link reftype=hd res=107.INIT PROCEDURE:elink.
.br
:h1 res=108.__SETHELPK()
:i1 id=__SETHELPK().__SETHELPK()
:p.__SETHELPK()
:p.:hp2.Set F1 as the default help key
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__SetHelpK() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. __SetHelpK():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     Set F1 to execute a function called HELP if such a function is  linked into the program.        
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __SetHelpK() works exactly like CA-Clipper's __SetHelpK()   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=109.__XHelp():elink.
.br
:link reftype=hd res=110.SET KEY:elink.
.br
:link reftype=hd res=111.SETKEY():elink.
.br
:h1 res=112.BREAK()
:i1 id=BREAK().BREAK()
:p.BREAK()
:p.:hp2.Exits from a BEGIN SEQUENCE block
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BREAK( <xExp> ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xExp>:ehp2.   is any valid expression. It is always required. If do not want to pass any argument, just use NIL.        

:p.:hp2.Returns
:ehp2.
       NIL    

:p.:hp2.Description
:ehp2.
     This function passes control to the RECOVER statement in a  BEGIN SEQUENCE block.        

:p.:hp2.Examples
:ehp2.

      Break( NIL )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     BREAK() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=113.BEGIN SEQUENCE:elink.
.br
:h1 res=114.DO()
:i1 id=DO().DO()
:p.DO()
:p.:hp2.Calls a procedure or a function
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DO( <xFuncProc> [, <xArguments...>] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xFuncProc>:ehp2.   = Either a string with a function/procedure name to be called or a codeblock to evaluate.        
      :hp2. <xArguments>:ehp2.   = arguments passed to a called function/procedure or to a codeblock.        

:p.:hp2.Returns
:ehp2.
      A  value that was returned from called function.    

:p.:hp2.Description
:ehp2.
     This function can be called either by the harbour compiler or by user.  The compiler always passes the item of IT_SYMBOL type that stores the  name of procedure specified in DO <proc> WITH ... statement.        
     If called procedure/function doesn't exist then a runtime error  is generated.        
     This function can be used as replacement of macro operator.  It is also used internally to implement DO <proc> WITH <args...>  In this case <xFuncProc> is of type HB_SYMB.        

:p.:hp2.Examples
:ehp2.

      cbCode ={|x| MyFunc( x )}
      DO( cbCode&comma. 1 )

      cFunction &colon.= &cdq.MyFunc&cdq.
      xRetVal &colon.=DO( cFunction&comma. 2 )

      Old style (slower)&colon.
      DO &cFunction WITH 3
  

:p.:hp2.Files
:ehp2.
     Library is rtl     
:h1 res=115.__VMVARLGET()
:i1 id=__VMVARLGET().__VMVARLGET()
:p.__VMVARLGET()
:p.:hp2.Retrive a local variable from a procedure level
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__VMVARLGET( <nProcLevel>, <nLocal> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nProcLevel>:ehp2.   Is the procedure level, same as used in ProcName() and ProcLine(), from which a local variable containts is going to  be retrieved.        
      :hp2. <nLocal>:ehp2.   Is the index of the local variable to retrieve.    

:p.:hp2.Returns
:ehp2.
      The  containts of a specific local variable    

:p.:hp2.Description
:ehp2.
     This function is used from the debugger   

:p.:hp2.Files
:ehp2.
     Library is vm     
:h1 res=116.INKEY()
:i1 id=INKEY().INKEY()
:p.INKEY()
:p.:hp2.Extracts the next key code from the Harbour keyboard buffer.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.INKEY( [<nTimeout>] [,<nEvents>] ) --> nKey
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nTimeout>:ehp2.   is an optional timeout value in seconds, with a granularity of 1/10th of a second. If omitted, INKEY() returns immediately. If set  to 0, INKEY() waits until an input event occurs. If set to any other  value, INKEY() will return either when an input event occurs or when  the timeout period has elapsed. If only this parameter is specified  and it is not numeric, it will be treated as if it were 0. But if both  parameters are specified and this parameter is not numeric, it will be  treated as if it were not present.       

      :hp2. <nEvents>:ehp2.   is an optional mask of input events that are to be enabled. If omitted, defaults to hb_set.HB_SET_EVENTMASK. Valid input masks are  in inkey.ch and are explained below. It is recommended that the mask  names be used rather than their numeric values, in case the numeric  values change in future releases of Harbour. To allow more than one  type of input event, simply add the various mask names together.       


:cgraphic.
 
        inkey.ch         Meaning

        INKEY_MOVE       Mouse motion events are allowed
        INKEY_LDOWN      The mouse left click down event is allowed
        INKEY_LUP        The mouse left click up event is allowed
        INKEY_RDOWN      The mouse right click down event is allowed
        INKEY_RUP        The mouse right click up event is allowed
        INKEY_KEYBOARD   All keyboard events are allowed
        INKEY_ALL        All mouse and keyboard events are allowed
 
:ecgraphic.

      If  the parameter is not numeric, it will be treated as if it were set to hb_set.HB_SET_EVENTMASK.     

:p.:hp2.Returns
:ehp2.
      0  in case of timeout with no input event, otherwise returns a value in the range -39 to 386 for keyboard events or the range 1001 to 1007  for mouse events. Mouse events and non-printable keyboard events are  represented by the K_<event> values listed in inkey.ch. Keyboard  event return codes in the range 32 through 127 are equivalent to the  printable ASCII character set. Keyboard event return codes in the  range 128 through 255 are assumed to be printable, but results may  vary based on hardware and nationality.     

:p.:hp2.Description
:ehp2.
     INKEY() can be used to detect input events&comma. such as keypress&comma. mouse  movement&comma. or mouse key clicks (up and/or down).     

:p.:hp2.Examples
:ehp2.

      // Wait for the user to press the Esc key
      ? &cdq.Please press the ESC key.&cdq.
      WHILE INKEY( 0.1 ) != K_ESC
      END
  

:p.:hp2.Tests
:ehp2.

      KEYBOARD &cdq.AB&cdq.; ? INKEY()&comma. INKEY() ==>   65   66
  
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     INKEY() is compliant with the Clipper 5.3 INKEY() function with one  exception&colon. The Harbour INKEY() function will raise an argument error  if the first parameter is less than or equal to 0 and the second  parameter (or the default mask) is not valid&comma. because otherwise INKEY  would never return&comma. because it was&comma. in effect&comma. asked to wait forever  for no events (Note&colon. In Clipper&comma. this also blocks SET KEY events).     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=117.inkey.ch:elink.
.br
:h1 res=118.__KEYBOARD()
:i1 id=__KEYBOARD().__KEYBOARD()
:p.__KEYBOARD()
:p.:hp2.DO NOT CALL THIS FUNCTION DIRECTLY!
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.KEYBOARD <cString>
:ehp2.
:p.:hp2.CLEAR TYPEAHEAD
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   is the optional string to stuff into the Harbour keyboard buffer after clearing it first. Note: The character ";" is converted  to CHR(13) (this is an undocumented CA-Clipper feature).     

:p.:hp2.Returns
:ehp2.
      There  is no return value.    

:p.:hp2.Description
:ehp2.
     Clears the Harbour keyboard typeahead buffer and then inserts an  optional string into it.     

:p.:hp2.Examples
:ehp2.

      // Stuff an Enter key into the keyboard buffer
      KEYBOARD CHR(13)
      // Clear the keyboard buffer
      CLEAR TYPEAHEAD
  

:p.:hp2.Tests
:ehp2.

      KEYBOARD CHR(13); ? INKEY() ==> 13
      KEYBOARD &cdq.;&cdq. ? INKEY() ==> 13
      KEYBOARD &cdq.HELLO&cdq.; CLEAR TYPEAHEAD; ? INKEY() ==> 0
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __KEYBOARD() is compliant with CA-Clipper 5.3     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=119.CLEAR TYPEAHEAD:elink.
.br
:link reftype=hd res=120.KEYBOARD:elink.
.br
:h1 res=121.HB_KEYPUT()
:i1 id=HB_KEYPUT().HB_KEYPUT()
:p.HB_KEYPUT()
:p.:hp2.Put an inkey code to the keyboard buffer.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_KEYPUT( <nInkeyCode> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nInkeyCode>:ehp2.   is the inkey code, which should be inserted into the keyboard buffer.     

:p.:hp2.Returns
:ehp2.
      There  is no return value.    

:p.:hp2.Description
:ehp2.
     Inserts an inkey code to the string buffer. The buffer is *not*  cleared in this operation. This function allows to insert such  inkey codes which are not in the range of 0 to 255. To insert more  than one code&comma. call the function repeatedly. The zero code cannot  be inserted.     

:p.:hp2.Examples
:ehp2.

      // Stuff an Alt+PgDn key into the keyboard buffer
      HB_KEYPUT( K_ALT_PGDN )
  

:p.:hp2.Tests
:ehp2.

      HB_KEYPUT( K_ALT_PGDN ) ; ? INKEY() ==> 417
      HB_KEYPUT( K_F11 ) ; ? INKEY() ==> -40
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     HB_KEYPUT() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=120.KEYBOARD:elink.
.br
:link reftype=hd res=119.CLEAR TYPEAHEAD:elink.
.br
:link reftype=hd res=116.INKEY():elink.
.br
:h1 res=122.NEXTKEY()
:i1 id=NEXTKEY().NEXTKEY()
:p.NEXTKEY()
:p.:hp2.Get the next key code in the buffer without extracting it.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.NEXTKEY() --> nKey
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <nKey>:ehp2.    The value of the next key in the Harbour keyboard buffer.    

:p.:hp2.Description
:ehp2.
     Returns the value of the next key in the Harbour keyboard buffer  without extracting it.     

:p.:hp2.Examples
:ehp2.

      // Use NEXTKEY() with INKEY() to change display characters&comma. or by
      // itself to exit the loop&comma. so that the caller can detect the Esc.
      LOCAL nKey&comma. cChar &colon.= &cdq.+&cdq.
      WHILE TRUE
         ?? cChar
         nKey &colon.= NEXTKEY()
         IF nKey == K_ESC
            EXIT
         ELSE
            IF nKey != 0
               cChar &colon.= CHR( nKey )
            END IF
         END IF
      END WHILE
  

:p.:hp2.Tests
:ehp2.

      KEYBOARD &cdq.AB&cdq.; ? NEXTKEY()&comma. NEXTKEY() ==>   65   65
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     NEXTKEY() is compliant with CA-Clipper 5.3     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=116.INKEY():elink.
.br
:link reftype=hd res=123.LASTKEY():elink.
.br
:h1 res=123.LASTKEY()
:i1 id=LASTKEY().LASTKEY()
:p.LASTKEY()
:p.:hp2.Get the last key extracted from the keyboard buffer.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LASTKEY() --> nKey
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <nKey>:ehp2.    The last key extracted from the keyboard buffer.    

:p.:hp2.Description
:ehp2.
     Returns the value of the last key exttracted from the Harbour  keyboard buffer     

:p.:hp2.Examples
:ehp2.

      // Continue looping unless the ESC key was pressed in MainFunc()
      WHILE TRUE
         MainFunc()
         IF LASTKEY() == K_ESC
            EXIT
         ENDIF
      END WHILE
  

:p.:hp2.Tests
:ehp2.

      KEYBOARD &cdq.AB&cdq.; ? INKEY()&comma. LASTKEY() ==>   65   65
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     LASTKEY() is compliant with CA-Clipper 5.3     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=116.INKEY():elink.
.br
:link reftype=hd res=123.LASTKEY():elink.
.br
:h1 res=120.KEYBOARD
:i1 id=KEYBOARD.KEYBOARD
:p.KEYBOARD
:p.:hp2.Stuffs the keyboard with a string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.KEYBOARD <cString>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   String to be processed, one character at a time, by the Harbour keyboard processor     

:p.:hp2.Description
:ehp2.
     This command stuffs the input buffer with <cString>. The  number of characters that can be stuffed into the keyboard  buffer is controlled by the SET TYPEAHEAD command and may range  from 0 to 32&comma.622&comma. with each character appearing in the ASCII  range of 0 to 255. None of the extended keys may be stuffed  into the keyboard buffer.  Issuing a KEYBOARD &cdq. &cdq. will clear the keyboard buffer.     

:p.:hp2.Examples
:ehp2.

      // Stuff an Enter key into the keyboard buffer
      KEYBOARD CHR(13)
      // Clear the keyboard buffer
      CLEAR TYPEAHEAD
  

:p.:hp2.Tests
:ehp2.

      KEYBOARD CHR(13); ? INKEY() ==> 13
      KEYBOARD &cdq.HELLO&cdq.; CLEAR TYPEAHEAD; ? INKEY() ==> 0
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __KEYBOARD() is compliant with CA-Clipper 5.3     
.br
See Also&colon.
:link reftype=hd res=119.CLEAR TYPEAHEAD:elink.
.br
:link reftype=hd res=118.__KEYBOARD():elink.
.br
:h1 res=124.READKEY()*
:i1 id=READKEY()*.READKEY()*
:p.READKEY()*
:p.:hp2.Find out which key terminated a READ.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.READKEY() --> nKeyCode
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. READKEY():ehp2.   returns a numeric code representing the key that caused READ to terminate.     

:p.:hp2.Description
:ehp2.
     READKEY() is used after a READ was terminated to determine the exit  key pressed. If the GET buffer was updated during READ&comma. 256 is added  to the return code.       


:cgraphic.
 
      Exit               Return code     Return code
      Key                (not updated)   (updated)

      Up                    4            260
      Down                  5            261
      Page-Up               6            262
      Page-Down             7            263
      Ctrl Page-Up         34            290
      Ctrl Page-Down       35            291
      Esc                  12            268
      Ctrl End             14            270
      Enter                15            271
      Key >= 32            15            271
      otherwise             0            0
 
:ecgraphic.

     READKEY() is a compatibility function so try not to use it.  READKEY() is superseded by LASTKEY() which returns the INKEY()  code for that key.  UPDATED() could be used to find if the  GET buffer was changed during the READ.     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     READKEY() is compliant with CA-Clipper 5.3     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=125.@...GET:elink.
.br
:link reftype=hd res=116.INKEY():elink.
.br
:link reftype=hd res=123.LASTKEY():elink.
.br
:link reftype=hd res=126.READ:elink.
.br
:link reftype=hd res=127.READEXIT():elink.
.br
:link reftype=hd res=128.UPDATED():elink.
.br
:h1 res=129.MROW()
:i1 id=MROW().MROW()
:p.MROW()
:p.:hp2.Returns the mouse cursor row position.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MRow() --> nMouseRow
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <nMouseRow>:ehp2.   The mouse cursor row position.    

:p.:hp2.Description
:ehp2.
     This function returns the current mouse row cursor position.  On graphical systems the value represents pixel rows.  On character-based systems the value represents character  rows as in Clipper.     

:p.:hp2.Examples
:ehp2.

      IF MRow() < 1
         ? &cdq.Mouse is on top row!&cdq.
      ENDIF
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     MROW() is compliant with CA-Clipper 5.3&comma. but has been extended  to work on graphical systems as well as character-based systems.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=130.MCOL():elink.
.br
:h1 res=130.MCOL()
:i1 id=MCOL().MCOL()
:p.MCOL()
:p.:hp2.Returns the mouse cursor column position.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MCol() --> nMouseColumn
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <nMouseColumn>:ehp2.   The mouse cursor column position.    

:p.:hp2.Description
:ehp2.
     This function returns the column position of the mouse cursor.  On graphical systems the value represents pixels.  On character-based systems the value represents character  columns as in Clipper.     

:p.:hp2.Examples
:ehp2.

      IF MCol() < 1
         ? &cdq.Mouse is on left edge!&cdq.
      ENDIF
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     MROW() is compliant with CA-Clipper 5.3&comma. but has been extended  to work on graphical systems as well as character-based systems.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=129.MROW():elink.
.br
:h1 res=131.LICENSE
:i1 id=LICENSE.LICENSE
:p.LICENSE
:p.:hp2.Harbour License
:ehp2.

:p.:hp2.Description
:ehp2.

 &colon.hp2. THE HARBOUR PROJECT LICENSE&colon.ehp2.    
 ===========================   

 This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by  the Free Software Foundation; either version 2 of the License&comma. or  (at your option) any later version&comma. with one exception&colon.        

 The exception is that if you link the Harbour Runtime Library (HRL)  and/or the Harbour Virtual Machine (HVM) with other files to produce  an executable&comma. this does not by itself cause the resulting executable  to be covered by the GNU General Public License. Your use of that  executable is in no way restricted on account of linking the HRL  and/or HVM code into it.        

 This program is distributed in the hope that it will be useful&comma.  but &colon.hp2. WITHOUT ANY WARRANTY&colon.ehp2. ; without even the implied warranty of  &colon.hp2. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE&colon.ehp2. .  See the  GNU General Public License for more details.        

 You should have received a copy of the GNU General Public License  along with this program; if not&comma. write to the Free Software  Foundation&comma. Inc.&comma. 675 Mass Ave&comma. Cambridge&comma. MA 02139&comma. USA (or visit  their web site at http&colon.//www.gnu.org/).        

.br
See Also&colon.
:link reftype=hd res=132.OverView:elink.
.br
:h1 res=133.ABS()
:i1 id=ABS().ABS()
:p.ABS()
:p.:hp2.Return the absolute value of a number.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ABS(<nNumber>) --> <nAbsNumber>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   Any number.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nAbsNumber>:ehp2.   The absolute numeric value.    

:p.:hp2.Description
:ehp2.
     This function yields the absolute value of the numeric value or  expression <nNumber>.     

:p.:hp2.Examples
:ehp2.

      Proc Main()

      Local nNumber&colon.=50
      Local nNumber1&colon.=27
      cls

      qout(nNumber-nNumber1)
      qout(nNumber1-nNumber)
      qout(ABS(nNumber-nNumber1))
      qout(ABSnNumber1-nNumber))
      qout(ABS( -1 * 345))
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=134.EXP():elink.
.br
:h1 res=134.EXP()
:i1 id=EXP().EXP()
:p.EXP()
:p.:hp2.Calculates the value of e raised to the passed power.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.EXP( <nNumber> ) --> <nValue>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   Any  real number.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nValue>:ehp2.    The anti-logarithm of <nNumber>    

:p.:hp2.Description
:ehp2.
     This function returns the value of e raised to the power of  <nNumber>.  It is the inverse of LOG().     

:p.:hp2.Examples
:ehp2.

      ? EXP(45)
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=135.LOG():elink.
.br
:h1 res=136.INT()
:i1 id=INT().INT()
:p.INT()
:p.:hp2.Return the integer port of a numeric value.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.INT( <nNumber> ) --> <nIntNumber>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   Any  numeric value.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nIntNumber>:ehp2.   The integer portion of the numeric value.    

:p.:hp2.Description
:ehp2.
     This function converts a numeric expression to an integer. All  decimal digits are truncated. This function does not round a value  upward or downward; it merely truncates a number at the decimal point.     

:p.:hp2.Examples
:ehp2.

      SET Decimal to 5
      ? INT(632512.62541)
      ? INT(845414111.91440)
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=137.ROUND():elink.
.br
:link reftype=hd res=138.STRZERO():elink.
.br
:h1 res=135.LOG()
:i1 id=LOG().LOG()
:p.LOG()
:p.:hp2.Returns the natural logarithm of a number.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LOG( <nNumber> ) --> <nLog>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   Any numeric expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nExponent>:ehp2.   The natural logarithm of <nNumber>.    

:p.:hp2.Description
:ehp2.
     This function returns the natural logarithm of the number <nNumber>.  If <nNumber> is 0 or less than 0&comma. a numeric overflow occurs&comma.  which is depicted on the display device as a series of asterisks.  This function is the inverse of EXP().     

:p.:hp2.Examples
:ehp2.

      ? LOG(632512)
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=134.EXP():elink.
.br
:h1 res=139.MAX()
:i1 id=MAX().MAX()
:p.MAX()
:p.:hp2.Returns the maximum of two numbers or dates.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MAX(<xValue>,<xValue1>)  --> <xMax>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xValue>:ehp2.    Any date or numeric value.      

      :hp2. <xValue1>:ehp2.   Any date or numeric value (same type as <xValue>).    

:p.:hp2.Returns
:ehp2.
      :hp2. <xMax>:ehp2.   The larger numeric (or later date) value.    

:p.:hp2.Description
:ehp2.
     This function returns the larger of the two passed espressions. If  <xValue> and <xValue1> are numeric data types&comma. the value returned by  this function will be a numeric data type as well and will be the  larger of the two numbers passed to it. If <xValue> and <xValue1> are  date data types&comma. the return value will be a date data  type as well. It will be the later of the two dates passed to it.     

:p.:hp2.Examples
:ehp2.

      ? MAX(214514214&comma.6251242142)
      ? MAX(CTOD('11/11/2000')&comma.CTOD('21/06/2014')
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=140.Min():elink.
.br
:h1 res=141.MIN()
:i1 id=MIN().MIN()
:p.MIN()
:p.:hp2.Determines the minumum of two numbers or dates.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MIN(<xValue>,<xValue1>)  --> <xMin>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xValue>:ehp2.    Any date or numeric value.      

      :hp2. <xValue1>:ehp2.   Any date or numeric value.    

:p.:hp2.Returns
:ehp2.
      :hp2. <xMin>:ehp2.    The smaller numeric (or earlier date) value.    

:p.:hp2.Description
:ehp2.
     This function returns the smaller of the two passed espressions.  <xValue> and <xValue1> must be the same data type. If numeric&comma. the  smaller number is returned. If dates&comma. the earlier date is returned.     

:p.:hp2.Examples
:ehp2.

      ? MIN(214514214&comma.6251242142)
      ? MIN(CTOD('11/11/2000')&comma.CTOD('21/06/2014')
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=139.MAX():elink.
.br
:h1 res=142.MOD()
:i1 id=MOD().MOD()
:p.MOD()
:p.:hp2.Return the modulus of two numbers.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MOD( <nNumber>,<nNumber1>) -->  <nRemainder>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.    Numerator in a divisional expression.      

      :hp2. <nNumber1>:ehp2.   Denominator in a divisional expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nRemainder>:ehp2.    The remainder after the division operation.    

:p.:hp2.Description
:ehp2.
     This functuion returns the remainder of one number divided by another.     

:p.:hp2.Examples
:ehp2.

      ? MOD(12&comma.8.521)
      ? Mod(12&comma.0)
      ? Mod(62412.5142&comma.4522114.12014)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This Function is Ca-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=143.%:elink.
.br
:h1 res=144.SQRT()
:i1 id=SQRT().SQRT()
:p.SQRT()
:p.:hp2.Calculates the square root of a number.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SQRT( <nNumber> ) --> <nSqrt>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   Any  numeric value.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nSqrt>:ehp2.     The square root of <number>.    

:p.:hp2.Description
:ehp2.
     This function returns the square root of <nNumber>. The precision of  this evaluation is based solely on the settings of the SET DECIMAL TO  command. Any negative number passed as <nNumber> will always return a 0.     

:p.:hp2.Examples
:ehp2.

      SET Decimal to 5
      ? SQRT(632512.62541)
      ? SQRT(845414111.91440)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=137.ROUND():elink.
.br
:h1 res=137.ROUND()
:i1 id=ROUND().ROUND()
:p.ROUND()
:p.:hp2.Rounds off a numeric expression.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ROUND( <nNumber>,<nPlace> ) --> <nResult>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   Any numeric value.      

      :hp2. <nPlace>:ehp2.    The number of places to round to.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nResult>:ehp2.   The rounded number.    

:p.:hp2.Description
:ehp2.
     This function rounds off the value of <nNumber> to the number of  decimal places specified by <nPlace>. If the value of <nPlace> is a  negative number&comma. the function will attempt to round <nNumber> in whole  numbers. Numbers from 5 through 9 will be rounded up&comma. all others will  be rounded down.     

:p.:hp2.Examples
:ehp2.

      ? ROUND(632512.62541&comma.5)
      ? ROUND(845414111.91440&comma.3)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=136.INT():elink.
.br
:link reftype=hd res=145.STR():elink.
.br
:link reftype=hd res=146.VAL():elink.
.br
:link reftype=hd res=147.SET FIXED:elink.
.br
:h1 res=148.MEMOTRAN()
:i1 id=MEMOTRAN().MEMOTRAN()
:p.MEMOTRAN()
:p.:hp2.Converts hard and soft carriage returns within strings.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MEMOTRAN( <cString>, <cHard>, <cSoft> ) --> <cConvertedString>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   is a string of chars to convert.      

      :hp2. <cHard>:ehp2.   is the character to replace hard returns with. If not specified defaults to semicolon.       

      :hp2. <cSoft>:ehp2.   is the character to replace soft returns with. If not specified defaults to single space.     

:p.:hp2.Returns
:ehp2.
      :hp2. <cConvertedString>:ehp2.   Trasformed string.    

:p.:hp2.Description
:ehp2.
     Returns a string/memo with carriage return chars converted to  specified chars.     

:p.:hp2.Examples
:ehp2.

      ? MEMOTRAN( DATA->CNOTES )
  

:p.:hp2.Tests
:ehp2.

      @ 1&comma. 1 SAY MEMOTRAN( Data->CNOTES )
      will display converted string starting on row two&comma. column two of the
      current device.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     MEMOTRAN() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=149.HARDCR():elink.
.br
:link reftype=hd res=150.STRTRAN():elink.
.br
:h1 res=149.HARDCR()
:i1 id=HARDCR().HARDCR()
:p.HARDCR()
:p.:hp2.Replace all soft carriage returns with hard carriages returns.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HARDCR( <cString> ) --> <cConvertedString>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   is a string of chars to convert.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cConvertedString>:ehp2.   Trasformed string.    

:p.:hp2.Description
:ehp2.
     Returns a string/memo with soft carriage return chars converted to  hard carriage return chars.     

:p.:hp2.Examples
:ehp2.

      ? HARDCR( Data->CNOTES )
  

:p.:hp2.Tests
:ehp2.

      @ 1&comma. 1 SAY HARDCR( Data->CNOTES )
      will display converted string starting on row two&comma. column two of the
      current device.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     HARDCR() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=148.MEMOTRAN():elink.
.br
:link reftype=hd res=150.STRTRAN():elink.
.br
:h1 res=151.ACHOICE()
:i1 id=ACHOICE().ACHOICE()
:p.ACHOICE()
:p.:hp2.Allows selection of an element from an array
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ACHOICE(<nTop>, <nLeft>, <nBottom>, <nRight>, <acMenuItems>, [<alSelableItems> | <lSelableItems>], [<cUserFunction> | <bUserBlock>], [<nInitialItem>], [<nWindowRow>]) --> nPosition
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nTop>:ehp2.             - topmost row used to display array (default 0)      

      :hp2. <nLeft>:ehp2.            - leftmost row used to display array (default 0)      

      :hp2. <nBottom>:ehp2.          - bottommost row used to display array (default MAXROW())      

      :hp2. <nRight>:ehp2.           - rightmost row used to display array (default MAXCOL())      

      :hp2. <acMenuItems>:ehp2.      - the character array of items from which to select      

      :hp2. <alSelableItems>:ehp2.   - an array of items, either logical or character, which is used to determine if a particular item  may be selected.  If the type of a given item is  character, it is macro evaluated, and the result  is expected to be a logical.  A value of .T. means  that the item may be selected, .F. that it may not.  (See next argument: lSelectableItems)       

      :hp2. <lSelableItems>:ehp2.    - a logical value which is used to apply to all items in acMenuItems.  If .T., all items may be  selected; if .F., none may be selected.  (See previous argument: alSelectableItems)  Default .T.       

      :hp2. <cUserFunction>:ehp2.    - the name of a function to be called which may affect special processing of keystrokes.  It is  specified without parentheses or parameters.  When it is called, it will be supplied with the  parameters: nMode, nCurElement, and nRowPos.  Default NIL.       

      :hp2. <bUserBlock>:ehp2.       - a codeblock to be called which may affect special processing of keystrokes. It  should be specified in the form  {|nMode, nCurElemenet, nRowPos| ;  MyFunc(nMode, nCurElemenet, nRowPos) }.  Default NIL.       

      :hp2. <nInitialItem>:ehp2.     - the number of the element to be highlighted as the current item when the array is initially  displayed.  1 origin.  Default 1.       

      :hp2. <nWindowRow>:ehp2.       - the number of the window row on which the initial item is to be displayed. 0 origin.  Default 0.     

:p.:hp2.Returns
:ehp2.
      :hp2. <nPosition>:ehp2.    - the number of the item to be selected, or 0 if the selection was aborted.     

:p.:hp2.Description
:ehp2.
     Allows selection of an element from an array.  Please see standard Clipper documentation for ACHOICE for  additional detail.     

:p.:hp2.Examples
:ehp2.

      aItems &colon.= { &cdq.One&cdq.&comma. &cdq.Two&cdq.&comma. &cdq.Three&cdq. }
      nChoice &colon.= ACHOICE( 10&comma. 10&comma. 20&comma. 20&comma. aItems )
      IF nChoice == 0
          ? &cdq.You did not choose an item&cdq.
      ELSE
          ? &cdq.You chose element &cdq. + LTRIM( STR( nChoice ) )
          ?? &cdq. which has a value of &cdq. + aItems[ nChoice ]
      ENDIF
  

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=152.MENU TO:elink.
.br
:h1 res=153.__ATPROMPT()
:i1 id=__ATPROMPT().__ATPROMPT()
:p.__ATPROMPT()
:p.:hp2.Display a menu item on screen and define a message
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__AtPrompt( <nRow>, <nCol>, <cPrompt>, [<xMsg>] ) --> .F.
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRow>:ehp2.   is the row number to display the menu <cPrompt>. Value could range from zero to MAXROW().       

      :hp2. <nCol>:ehp2.   is the column number to display the menu <cPrompt>. Value could range from zero to MAXCOL().       

      :hp2. <cPrompt>:ehp2.   is the menu item character string to display.      

      :hp2. <xMsg>:ehp2.   define a message to display each time this menu item is highlighted. <xMsg> could be a character string or code block that  is evaluated to a character string. If <xMsg> is not specified or  got the wrong type, an empty string ("") would be used.     

:p.:hp2.Returns
:ehp2.
      :hp2. __AtPrompt():ehp2.   always return .F.    

:p.:hp2.Description
:ehp2.
     With __AtPrompt() you define and display a menu item&comma. each call to  __AtPrompt() add another item to the menu&comma. to start the menu itself  you should call the __MenuTo() function (MENU TO command). You can  define any row and column combination and they will be displayed at  the order of definition. After each call to __AtPrompt()&comma. the cursor  is placed one column to the right of the last text displayed&comma. and  ROW() and COL() are updated.       

     @...PROMPT command is preprocessed into __AtPrompt() function during  compile time.     

:p.:hp2.Examples
:ehp2.

      // display a two line menu with status line at the bottom
      // let the user select favorite day
      SET MESSAGE TO 24 CENTER
      @ 10&comma. 2 PROMPT &cdq.Sunday&cdq. MESSAGE &cdq.This is the 1st item&cdq.
      @ 11&comma. 2 PROMPT &cdq.Monday&cdq. MESSAGE &cdq.Now we're on the 2nd item&cdq.
      MENU TO nChoice
      DO CASE
         CASE nChoice == 0           // user press Esc key
              QUIT
         CASE nChoice == 1           // user select 1st menu item
              ? &cdq.Guess you don't like Mondays&cdq.
         CASE nChoice == 2           // user select 2nd menu item
              ? &cdq.Just another day for some&cdq.
      ENDCASE
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CA-Clipper array is limited to 4096 items&comma. and therefor 4096 menu  items are the maximum that could be defined per one menu&comma. Harbour  does not have this limit (not that you'll ever need that).     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=151.ACHOICE():elink.
.br
:link reftype=hd res=152.MENU TO:elink.
.br
:link reftype=hd res=154.SET MESSAGE:elink.
.br
:link reftype=hd res=155.SET INTENSITY:elink.
.br
:link reftype=hd res=156.SET WRAP:elink.
.br
:link reftype=hd res=157.__MENUTO():elink.
.br
:h1 res=158.@...PROMPT
:i1 id=@...PROMPT.@...PROMPT
:p.@...PROMPT
:p.:hp2.Display a menu item on screen and define a message
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.@ <nRow>, <nCol> PROMPT <cPrompt> [MESSAGE <xMsg>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRow>:ehp2.   is the row number to display the menu <cPrompt>. Value could range from zero to MAXROW().       

      :hp2. <nCol>:ehp2.   is the column number to display the menu <cPrompt>. Value could range from zero to MAXCOL().       

      :hp2. <cPrompt>:ehp2.   is the menu item character string to display.      

      :hp2. <xMsg>:ehp2.   define a message to display each time this menu item is highlighted. <xMsg> could be a character string or code block that  is evaluated to a character string. If <xMsg> is not specified or  got the wrong type, an empty string ("") would be used.     

:p.:hp2.Returns
:ehp2.
      :hp2. @...Prompt:ehp2.   always return .F.    

:p.:hp2.Description
:ehp2.
     With @...Prompt you define and display a menu item&comma. each call to  @...Prompt add another item to the menu&comma. to start the menu itself  you should call the __MenuTo() function (MENU TO command). You can  define any row and column combination and they will be displayed at  the order of definition. After each call to @...Prompt&comma. the cursor  is placed one column to the right of the last text displayed&comma. and  ROW() and COL() are updated.       

     @...PROMPT command is preprocessed into __AtPrompt() function during  compile time.     

:p.:hp2.Examples
:ehp2.

      // display a two line menu with status line at the bottom
      // let the user select favorite day
      SET MESSAGE TO 24 CENTER
      @ 10&comma. 2 PROMPT &cdq.Sunday&cdq. MESSAGE &cdq.This is the 1st item&cdq.
      @ 11&comma. 2 PROMPT &cdq.Monday&cdq. MESSAGE &cdq.Now we're on the 2nd item&cdq.
      MENU TO nChoice
      DO CASE
         CASE nChoice == 0           // user press Esc key
              QUIT
         CASE nChoice == 1           // user select 1st menu item
              ? &cdq.Guess you don't like Mondays&cdq.
         CASE nChoice == 2           // user select 2nd menu item
              ? &cdq.Just another day for some&cdq.
      ENDCASE
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CA-Clipper array is limited to 4096 items&comma. and therefor 4096 menu  items are the maximum that could be defined per one menu&comma. Harbour  does not have this limit (not that you'll ever need that).     
.br
See Also&colon.
:link reftype=hd res=151.ACHOICE():elink.
.br
:link reftype=hd res=152.MENU TO:elink.
.br
:link reftype=hd res=154.SET MESSAGE:elink.
.br
:link reftype=hd res=155.SET INTENSITY:elink.
.br
:link reftype=hd res=156.SET WRAP:elink.
.br
:link reftype=hd res=157.__MENUTO():elink.
.br
:h1 res=157.__MENUTO()
:i1 id=__MENUTO().__MENUTO()
:p.__MENUTO()
:p.:hp2.Invoked a menu defined by set of @...PROMPT
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MenuTo( <bBlock>, <cVariable> ) --> nChoice
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <bBlock>:ehp2.   is a set/get code block for variable named <cVariable>.      

      :hp2. <cVariable>:ehp2.   is a character string that contain the name of the variable to hold the menu choices, if this variable does not exist  a PRIVATE variable with the name <cVariable> would be created to  hold the result.     

:p.:hp2.Returns
:ehp2.
      :hp2. __MenuTo():ehp2.   return the number of select menu item, or 0 if there was no item to select from or if the user pressed the Esc key.     

:p.:hp2.Description
:ehp2.
     __MenuTo() invoked the menu define by previous __AtPrompt() call  and display a highlight bar that the user can move to select an  option from the menu. If <cVariable> does not exist or not visible&comma.  a PRIVATE variable named <cVariable> is created and hold the current  menu selection. If there is a variable named <cVariable>&comma. its value  is used to select the first highlighted item.       

     Menu prompts and messages are displayed in current Standard color&comma.  highlighted bar is displayed using current Enhanced color.       

     Pressing the arrow keys move the highlighted bar. When a menu item  is highlighted the message associated with it is displayed on the  line specified with SET MESSAGE. If SET WRAP is ON and the user  press UP arrow while on the first selection the last menu item is  highlighted&comma. if the user press Down arrow while on the last item&comma.  the first item is highlighted.       

     Following are active keys that handled by __MenuTo()&colon.  -----------------------------------------------------       


:cgraphic.
 
       key            Meaning

       Up             Move to previous item
       Down           Move to next item
       Left           Move to previous item
       Right          Move to next item
       Home           Move to the first item
       End            Move to the last item
       Page-Up        Select menu item&comma. return position
       Page-Down      Select menu item&comma. return position
       Enter          Select menu item&comma. return position
       Esc            Abort selection&comma. return 0
       First letter   Select next menu with the same first letter&comma.
                      return this item position.
 
:ecgraphic.

     upon exit the cursor is placed at MAXROW()-1&comma. 0  __MenuTo() can be nested without loosing the previous prompts.       

     MENU TO command is preprocessed into __MenuTo() function during  compile time.     

:p.:hp2.Examples
:ehp2.

      // display menu item on each screen corner and let user select one
      CLS
      SET MESSAGE TO MAXROW()/2 CENTER
      SET WRAP ON
      @ 0&comma.         0           PROMPT &cdq.1. Upper left&cdq.   MESSAGE &cdq. One &cdq.
      @ 0&comma.         MAXCOL()-16 PROMPT &cdq.2. Upper right&cdq.  MESSAGE &cdq. Two &cdq.
      @ MAXROW()-1&comma.MAXCOL()-16 PROMPT &cdq.3. Bottom right&cdq. MESSAGE &cdq.Three&cdq.
      @ MAXROW()-1&comma.0           PROMPT &cdq.4. Bottom left&cdq.  MESSAGE &cdq.Four &cdq.
      MENU TO nChoice
      SETPOS ( MAXROW()/2&comma. MAXCOL()/2 - 10 )
      if nChoice == 0
         ?? &cdq.Esc was pressed&cdq.
      else
         ?? &cdq.Selected option is&cdq.&comma. nChoice
      endif
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=151.ACHOICE():elink.
.br
:link reftype=hd res=154.SET MESSAGE:elink.
.br
:link reftype=hd res=155.SET INTENSITY:elink.
.br
:link reftype=hd res=156.SET WRAP:elink.
.br
:link reftype=hd res=153.__ATPROMPT():elink.
.br
:h1 res=152.MENU TO
:i1 id=MENU TO.MENU TO
:p.MENU TO
:p.:hp2.Invoked a menu defined by set of @...PROMPT
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MENU TO <cVariable>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cVariable>:ehp2.   is a character string that contain the name of the variable to hold the menu choices, if this variable does not exist  a PRIVATE variable with the name <cVariable> would be created to  hold the result.     

:p.:hp2.Returns
:ehp2.
      Menu  To return the number of select menu item, or 0 if there was no item to select from or if the user pressed the Esc key.     

:p.:hp2.Description
:ehp2.
     Menu To() invoked the menu define by previous __AtPrompt() call  and display a highlight bar that the user can move to select an  option from the menu. If <cVariable> does not exist or not visible&comma.  a PRIVATE variable named <cVariable> is created and hold the current  menu selection. If there is a variable named <cVariable>&comma. its value  is used to select the first highlighted item.       

     Menu prompts and messages are displayed in current Standard color&comma.  highlighted bar is displayed using current Enhanced color.       

     Pressing the arrow keys move the highlighted bar. When a menu item  is highlighted the message associated with it is displayed on the  line specified with SET MESSAGE. If SET WRAP is ON and the user  press UP arrow while on the first selection the last menu item is  highlighted&comma. if the user press Down arrow while on the last item&comma.  the first item is highlighted.       

     Following are active keys that handled by Menu To&colon.  -----------------------------------------------------       


:cgraphic.
 
       key              Meaning

       Up             - Move to previous item
       Down           - Move to next item
       Left           - Move to previous item
       Right          - Move to next item
       Home           - Move to the first item
       End            - Move to the last item
       Page-Up        - Select menu item&comma. return position
       Page-Down      - Select menu item&comma. return position
       Enter          - Select menu item&comma. return position
       Esc            - Abort selection&comma. return 0
       First letter   - Select next menu with the same first letter&comma.
                      return this item position.
 
:ecgraphic.

     upon exit the cursor is placed at MAXROW()-1&comma. 0  Menu To can be nested without loosing the previous prompts.       

     MENU TO command is preprocessed into __MenuTo() function during  compile time.     

:p.:hp2.Examples
:ehp2.

      // display menu item on each screen corner and let user select one
      CLS
      SET MESSAGE TO MAXROW()/2 CENTER
      SET WRAP ON
      @ 0&comma.         0           PROMPT &cdq.1. Upper left&cdq.   MESSAGE &cdq. One &cdq.
      @ 0&comma.         MAXCOL()-16 PROMPT &cdq.2. Upper right&cdq.  MESSAGE &cdq. Two &cdq.
      @ MAXROW()-1&comma.MAXCOL()-16 PROMPT &cdq.3. Bottom right&cdq. MESSAGE &cdq.Three&cdq.
      @ MAXROW()-1&comma.0           PROMPT &cdq.4. Bottom left&cdq.  MESSAGE &cdq.Four &cdq.
      MENU TO nChoice
      SETPOS ( MAXROW()/2&comma. MAXCOL()/2 - 10 )
      if nChoice == 0
         ?? &cdq.Esc was pressed&cdq.
      else
         ?? &cdq.Selected option is&cdq.&comma. nChoice
      endif
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=151.ACHOICE():elink.
.br
:link reftype=hd res=154.SET MESSAGE:elink.
.br
:link reftype=hd res=155.SET INTENSITY:elink.
.br
:link reftype=hd res=156.SET WRAP:elink.
.br
:link reftype=hd res=153.__ATPROMPT():elink.
.br
:h1 res=159.OS()
:i1 id=OS().OS()
:p.OS()
:p.:hp2.Return the current operating system.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.OS()   --> <cOperatingSystem>
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <cOperatinSystem>:ehp2.    -> The Current operating system.    

:p.:hp2.Description
:ehp2.
     This function will return the current operating system.     

:p.:hp2.Examples
:ehp2.

      ? OS()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compatible.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     source/rtl/version.c     
:h1 res=160.VERSION()
:i1 id=VERSION().VERSION()
:p.VERSION()
:p.:hp2.Returns the HARBOUR Version or the Harbour/Compiler Version.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.VERSION()  --> <cReturn>
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.     String containing the Harbour Version/    

:p.:hp2.Description
:ehp2.
     This function returns the current Harbour Version.     

:p.:hp2.Examples
:ehp2.

      ? QOUT(VERSION())
      &cdq.Harbour Terminal&colon. Standard stream console&cdq.

:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compatible.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     source/rtl/version.c  Library is rtl     
.br
See Also&colon.
:link reftype=hd res=159.OS():elink.
.br
:h1 res=161.GETENV()
:i1 id=GETENV().GETENV()
:p.GETENV()
:p.:hp2.Obtains system environmental settings.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.GETENV(<cEnviroment>, <cDefaultValue> )  --> <cReturn>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cEnviroment>:ehp2.   Enviromental variable to obtain.      

      :hp2. <cDefaultValue>:ehp2.   Optional value to return if <cEnvironment> is not found.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.       Value of the Environment Variable.    

:p.:hp2.Description
:ehp2.
     This function yields a string that is the value of the  environment variable <cEnviroment>&comma. which is stored at the  system level with the Set command. If no environment variable  can be found&comma. the value of the function will be <cDefaultValue>  if it is passed&comma. else an empty string.     

:p.:hp2.Examples
:ehp2.

      ? QOUT(GETENV('PATH'))
      ? QOUT(GETENV('CONFIG'))
      ? QOUT(GETENV('HARBOURCMD'&comma. '-n -l -es2'))
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant.  The <cDefaultValue> parameter is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
    source/rtl/gete.c  Library is rtl     
:h1 res=162.__RUN()
:i1 id=__RUN().__RUN()
:p.__RUN()
:p.:hp2.Run an external program.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__RUN( <cCommand> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cCommand>:ehp2.   Command to execute.    

:p.:hp2.Description
:ehp2.
     This command runs an external program. Please make sure that  you have enough free memory to be able to run the external  program. Do not use it to run Terminate and Stay Resident programs  (in case of DOS) since that causes several problems.       

     Note&colon. This function is what the RUN command preprocesses into.  It is considered bad form to use this function directly.  Use the RUN command instead.     

:p.:hp2.Examples
:ehp2.

      __Run( &cdq.edit &cdq. + cMyTextFile )    // Runs an external editor
      __Run( &cdq.command&cdq. )                // Gives a DOS shell (DOS only)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     source/rtl/run.c  Library is rtl     
.br
See Also&colon.
:link reftype=hd res=163.RUN:elink.
.br
:h1 res=164.TONE()
:i1 id=TONE().TONE()
:p.TONE()
:p.:hp2.Sound a tone with a specified frequency and duration.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.TONE( <nFrequency>, <nDuration> ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nFrequency>:ehp2.    A non-negative numeric value that specifies the frequency of the tone in hertz.       

      :hp2. <nDuration>:ehp2.     A positive numeric value which specifies the duration of the tone in 1/18 of a second units.     

:p.:hp2.Returns
:ehp2.
      :hp2. TONE():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     TONE() is a sound function that could be used to irritate the end  user&comma. his or her dog&comma. and the surrounding neighborhood. The frequency  is clamped to the range 0 to 32767 Hz.     

:p.:hp2.Examples
:ehp2.

      If lOk   // Good Sound
         TONE(  500&comma. 1 )
         TONE( 4000&comma. 1 )
         TONE( 2500&comma. 1 )
      Else     // Bad Sound
         TONE(  300&comma. 1 )
         TONE(  499&comma. 5 )
         TONE(  700&comma. 5 )
      EndIf
      

:p.:hp2.Tests
:ehp2.

      TONE( 800&comma. 1 )                         // same as ? CHR(7)
      TONE( 32000&comma. 200 )                     // any dogs around yet?
      TONE( 130.80&comma. 1 )                      // musical note - C
      TONE( 400&comma. 0 )                         // short beep
      TONE( 700 )                            // short beep
      TONE( 10&comma. 18.2 )                       // 1 second delay
      TONE( -1 )                             // 1/18.2 second delay
      TONE( )                                // 1/18.2 second delay
  

:p.:hp2.Tests
:ehp2.
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     TONE() works exactly like CA-Clipper's TONE().     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=165.CHR():elink.
.br
:link reftype=hd res=166.SET BELL:elink.
.br
:h1 res=163.RUN
:i1 id=RUN.RUN
:p.RUN
:p.:hp2.Run an external program.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RUN  <cCommand>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cCommand>:ehp2.   Command to execute.    

:p.:hp2.Description
:ehp2.
     This command runs an external program. Please make sure that you have  enough free memory to be able to run the external program.  Do not use it to run Terminate and Stay Resident programs  (in case of DOS) since that causes several problems.     

:p.:hp2.Examples
:ehp2.

      Run  &cdq.edit &cdq. + cMyTextFile      // Runs an external editor
      Run  &cdq.command&cdq.                  // Gives a DOS shell (DOS only)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     source/rtl/run.c  Library is rtl     
.br
See Also&colon.
:link reftype=hd res=163.RUN:elink.
.br
:h1 res=167.ISAFFIRM()
:i1 id=ISAFFIRM().ISAFFIRM()
:p.ISAFFIRM()
:p.:hp2.Checks if passed char is an affirmation char
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISAFFIRM( <cChar> ) --> <lTrueOrFalse>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cChar>:ehp2.   is a char or string of chars    

:p.:hp2.Returns
:ehp2.
      :hp2. <lTrueOrFalse>:ehp2.   True if passed char is an affirmation char,otherwise false        

:p.:hp2.Description
:ehp2.
     This function is used to check if a user's input is true or not  according to the msgxxx module used.        

:p.:hp2.Examples
:ehp2.

      // Wait until user enters Y
      DO WHILE !ISAFFIRM( cYesNo )
        ACCEPT &cdq.Sure&colon. &cdq. TO cYesNo
      END DO
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ISAFFIRM() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=168.ISNEGATIVE():elink.
.br
:link reftype=hd res=169.NATIONMSG():elink.
.br
:h1 res=168.ISNEGATIVE()
:i1 id=ISNEGATIVE().ISNEGATIVE()
:p.ISNEGATIVE()
:p.:hp2.Checks if passed char is a negation char.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISNEGATIVE( <cChar> ) --> <lTrueOrFalse>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cChar>:ehp2.   is a char or string of chars    

:p.:hp2.Returns
:ehp2.
      :hp2. <lTrueOrFalse>:ehp2.   True if passed char is a negation char, otherwise false.        

:p.:hp2.Description
:ehp2.
     This function is used to check if a user's input is true or not  according to the msgxxx module used.        

:p.:hp2.Examples
:ehp2.

      // Wait until user enters N
      DO WHILE !ISNEGATIVE( cYesNo )
        ACCEPT &cdq.Sure&colon. &cdq. TO cYesNo
      END DO
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ISNEGATIVE() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=167.ISAFFIRM():elink.
.br
:link reftype=hd res=169.NATIONMSG():elink.
.br
:h1 res=169.NATIONMSG()
:i1 id=NATIONMSG().NATIONMSG()
:p.NATIONMSG()
:p.:hp2.Returns international strings messages.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.NATIONMSG( <nMsg> ) --> <cMessage>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nMsg>:ehp2.   is the message number you want to get.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cMessage>:ehp2.   If <nMsg> is a valid message selector, returns the message. If <nMsg> is nil returns "Invalid Argument", and if <nMsg> is any  other type it returns an empty string.        

:p.:hp2.Description
:ehp2.
     NATIONMSG() returns international message descriptions.   

:p.:hp2.Examples
:ehp2.

      // Displays &cdq.Sure Y/N&colon. &cdq.  and waits until user enters Y
      // Y/N is the string for NATIONMSG( 12 ) with default natmsg module.
      DO WHILE !ISAFFIRM( cYesNo )
        ACCEPT &cdq.Sure &cdq. + NATIONMSG( 12 ) + &cdq.&colon. &cdq. TO cYesNo
      END DO
  
:p.:hp2.Status
:ehp2.
   Not Started

:p.:hp2.Compliance
:ehp2.
     NATIONMSG() is fully CA-Clipper compliant.   

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=167.ISAFFIRM():elink.
.br
:link reftype=hd res=168.ISNEGATIVE():elink.
.br
:h1 res=170.__OBJHASDATA()
:i1 id=__OBJHASDATA().__OBJHASDATA()
:p.__OBJHASDATA()
:p.:hp2.Determine whether a symbol exist in object as DATA
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objHasData( <oObject>, <cSymbol> ) --> lExist
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is an object to scan.      

      :hp2. <cSymbol>:ehp2.   is the name of the symbol to look for.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objHasData():ehp2.   return .T. if the given <cSymbol> exist as DATA (instance variable) in object <oObject), .F. if it does not exist.     

:p.:hp2.Description
:ehp2.
     __objHasData() is a low level class support function that let you  find out if a symbol is an instance variable in a given object.     

:p.:hp2.Examples
:ehp2.

      oB &colon.= TBrowseNew( 0&comma. 0&comma. 24&comma. 79 )
      ? __objHasData( oB&comma. &cdq.nLeft&cdq. )      // this should return .T.
      ? __objHasData( oB&comma. &cdq.lBugFree&cdq. )   // hopefully this should be .F.
      ? __objHasData( oB&comma. &cdq.Left&cdq. )       // .F. since this is a METHOD
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objHasData() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:h1 res=174.__OBJHASMETHOD()
:i1 id=__OBJHASMETHOD().__OBJHASMETHOD()
:p.__OBJHASMETHOD()
:p.:hp2.Determine whether a symbol exist in object as METHOD
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objHasMethod( <oObject>, <cSymbol> ) --> lExist
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is an object to scan.      

      :hp2. <cSymbol>:ehp2.   is the name of the symbol to look for.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objHasMethod():ehp2.   return .T. if the given <cSymbol> exist as METHOD (class function) in object <oObject), .F. if it does not exist.     

:p.:hp2.Description
:ehp2.
     __objHasMethod() is a low level class support function that let you  find out if a symbol is a class function in a given object.     

:p.:hp2.Examples
:ehp2.

      oB &colon.= TBrowseNew( 0&comma. 0&comma. 24&comma. 79 )
      ? __objHasMethod( oB&comma. &cdq.nLeft&cdq. )      // .F. since this is a DATA
      ? __objHasMethod( oB&comma. &cdq.FixBugs&cdq. )    // hopefully this should be .F.
      ? __objHasMethod( oB&comma. &cdq.Left&cdq. )       // this should return .T.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objHasMethod() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=175.__objHasData():elink.
.br
:h1 res=176.__OBJGETMSGLIST()
:i1 id=__OBJGETMSGLIST().__OBJGETMSGLIST()
:p.__OBJGETMSGLIST()
:p.:hp2.Return names of all DATA or METHOD for a given object
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objGetMsgList( <oObject>, [<lData>] ) --> aNames
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is an object to scan.      

      :hp2. <lData>:ehp2.   is an optional logical value that specifies the information to return. A value of .T. instruct the function to return list of  all DATA names, .F. return list of all METHOD names. Default value  is .T.     

:p.:hp2.Returns
:ehp2.
      :hp2. __objGetMsgList():ehp2.   return an array of character stings with all DATA names or all METHOD names for a given object. __objGetMsgList()  would return an empty array {} if the given object does not contain  the requested information.     

:p.:hp2.Description
:ehp2.
     __objGetMsgList() is a low level class support function that let you  find all instance variable or class functions names for a given  object.     

:p.:hp2.Examples
:ehp2.

      // show information about TBrowse class
      oB &colon.= TBrowseNew( 0&comma. 0&comma. 24&comma. 79 )
      aData   &colon.= __objGetMsgList( oB&comma. .T. )
      aMethod &colon.= __objGetMsgList( oB&comma. .F. )
      FOR i = 1 to len ( aData )
          ? &cdq.DATA name&colon.&cdq.&comma. aData[ i ]
      NEXT
      FOR i = 1 to len ( aMethod )
          ? &cdq.METHOD name&colon.&cdq.&comma. aMethod[ i ]
      NEXT
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objGetMsgList() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=177.__ObjGetValueList():elink.
.br
:link reftype=hd res=175.__objHasData():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:h1 res=178.__OBJGETMETHODLIST()
:i1 id=__OBJGETMETHODLIST().__OBJGETMETHODLIST()
:p.__OBJGETMETHODLIST()
:p.:hp2.Return names of all METHOD for a given object
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objGetMethodList( <oObject> ) --> aMethodNames
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is an object to scan.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objGetMethodList():ehp2.   return an array of character stings with all METHOD names for a given object. __objGetMethodList() would return  an empty array {} if the given object does not contain any METHOD.     

:p.:hp2.Description
:ehp2.
     __objGetMethodList() is a low level class support function that let  you find all class functions names for a given object.  It is equivalent to __objGetMsgList( oObject&comma. .F. ).     

:p.:hp2.Examples
:ehp2.

      // show information about TBrowse class
      oB &colon.= TBrowseNew( 0&comma. 0&comma. 24&comma. 79 )
      aMethod &colon.= __objGetMethodList( oB )
      FOR i = 1 to len ( aMethod )
          ? &cdq.METHOD name&colon.&cdq.&comma. aMethod[ i ]
      NEXT
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objGetMethodList() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=177.__ObjGetValueList():elink.
.br
:link reftype=hd res=175.__objHasData():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:h1 res=179.__OBJGETVALUELIST()
:i1 id=__OBJGETVALUELIST().__OBJGETVALUELIST()
:p.__OBJGETVALUELIST()
:p.:hp2.Return an array of DATA names and values for a given object
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objGetValueList( <oObject>, [<aExcept>] ) --> aData
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is an object to scan.      

      :hp2. <aExcept>:ehp2.   is an optional array with DATA names you want to exclude from the scan.     

:p.:hp2.Returns
:ehp2.
      :hp2. __objGetValueList():ehp2.   return a 2D array that contain pairs of a DATA symbol name and the value of DATA. __objGetValueList() would return  an empty array {} if the given object does not contain the requested  information.     

:p.:hp2.Description
:ehp2.
     __objGetValueList() is a low level class support function that  return an array with DATA names and value&comma. each array element is a  pair of&colon. aData[ i&comma. HB_OO_DATA_SYMBOL ] contain the symbol name  aData[ i&comma. HB_OO_DATA_VALUE  ] contain the value of DATA     

:p.:hp2.Examples
:ehp2.

      // show information about TBrowse class
      oB &colon.= TBrowseNew( 0&comma. 0&comma. 24&comma. 79 )
      aData &colon.= __objGetValueList( oB )
      FOR i = 1 to len ( aData )
          ? &cdq.DATA name&colon.&cdq.&comma. aData[ i&comma. HB_OO_DATA_SYMBOL ]&comma. ;
            &cdq.    value=&cdq.&comma. aData[ i&comma. HB_OO_DATA_VALUE  ]
      NEXT
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objGetValueList() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Header file is hboo.ch  Library is rtl     
.br
See Also&colon.
:link reftype=hd res=180.__objGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=175.__objHasData():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:link reftype=hd res=181.__ObjSetValueList():elink.
.br
:h1 res=182.__OBJSETVALUELIST()
:i1 id=__OBJSETVALUELIST().__OBJSETVALUELIST()
:p.__OBJSETVALUELIST()
:p.:hp2.Set object with an array of DATA names and values
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__ObjSetValueList( <oObject>, <aData> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is an object to set.      

      :hp2. <aData>:ehp2.   is a 2D array with a pair of instance variables and values for setting those variable.     

:p.:hp2.Returns
:ehp2.
      :hp2. __ObjSetValueList():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __ObjSetValueList() is a low level class support function that let  you set a group of instance variables with values. each array  element in <aData> is a pair of&colon.  aData[ i&comma. HB_OO_DATA_SYMBOL ] which contain the variable name to set  aData[ i&comma. HB_OO_DATA_VALUE  ] contain the new variable value.     

:p.:hp2.Examples
:ehp2.

      // set some TBrowse instance variable
      oB &colon.= TBrowse()&colon.New()
      aData &colon.= array( 4&comma. 2 )
      aData[ 1&comma. HB_OO_DATA_SYMBOL ] = &cdq.nTop&cdq.
      aData[ 1&comma. HB_OO_DATA_VALUE  ] = 1
      aData[ 2&comma. HB_OO_DATA_SYMBOL ] = &cdq.nLeft&cdq.
      aData[ 2&comma. HB_OO_DATA_VALUE  ] = 10
      aData[ 3&comma. HB_OO_DATA_SYMBOL ] = &cdq.nBottom&cdq.
      aData[ 3&comma. HB_OO_DATA_VALUE  ] = 20
      aData[ 4&comma. HB_OO_DATA_SYMBOL ] = &cdq.nRight&cdq.
      aData[ 4&comma. HB_OO_DATA_VALUE  ] = 70
      __ObjSetValueList( oB&comma. aData )
      ? oB&colon.nTop      // 1
      ? oB&colon.nLeft     // 10
      ? oB&colon.nBottom   // 20
      ? oB&colon.nRight    // 70
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __ObjSetValueList() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Header file is hboo.ch  Library is rtl     
.br
See Also&colon.
:link reftype=hd res=177.__ObjGetValueList():elink.
.br
:h1 res=183.__OBJADDMETHOD()
:i1 id=__OBJADDMETHOD().__OBJADDMETHOD()
:p.__OBJADDMETHOD()
:p.:hp2.Add a METHOD to an already existing class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objAddMethod( <oObject>, <cMethodName>, <nFuncPtr> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cMethodName>:ehp2.   is the symbol name of the new METHOD to add.      

      :hp2. <nFuncPtr>:ehp2.   is a pointer to a function to associate with the method.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objAddMethod():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objAddMethod() is a low level class support function that add a  new METHOD to an object. <oObject> is unchanged if a symbol with the  name <cMethodName> already exist in <oObject>.       

     Note that <nFuncPtr> is a special pointer to a function that was  created using the @ operator&comma. see example below.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a Smile method
      oHappy &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      __objAddMethod( oHappy&comma. &cdq.Smile&cdq.&comma. @MySmile() )
      ? oHappy&colon.Smile( 1 )       // &colon.)
      ? oHappy&colon.Smile( 2 )       // ;)
      ? oHappy&colon.Smile( 3 )       // *SMILE*

      STATIC FUNCTION MySmile( nType )
      LOCAL cSmile
      DO CASE
         CASE nType == 1
              cSmile &colon.= &cdq.&colon.)&cdq.
         CASE nType == 2
              cSmile &colon.= &cdq.;)&cdq.
         CASE nType == 3
              cSmile &colon.= &cdq.*SMILE*&cdq.
      ENDCASE
      RETURN cSmile
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objAddMethod() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=184.__objAddInline():elink.
.br
:link reftype=hd res=185.__objAddData():elink.
.br
:link reftype=hd res=186.__objDelMethod():elink.
.br
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:link reftype=hd res=187.__objModMethod():elink.
.br
:h1 res=188.__OBJADDINLINE()
:i1 id=__OBJADDINLINE().__OBJADDINLINE()
:p.__OBJADDINLINE()
:p.:hp2.Add an INLINE to an already existing class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objAddInline( <oObject>, <cInlineName>, <bInline> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cInlineName>:ehp2.   is the symbol name of the new INLINE to add.      

      :hp2. <bInline>:ehp2.   is a code block to associate with the INLINE method.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objAddInline():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objAddInline() is a low level class support function that add a  new INLINE method to an object. <oObject> is unchanged if a symbol  with the name <cInlineName> already exist in <oObject>.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a Smile INLINE method
      oHappy  &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      bInline &colon.= { | nType | { &cdq.&colon.)&cdq.&comma. &cdq.;)&cdq.&comma. &cdq.*SMILE*&cdq. }[ nType ] }
      __objAddInline( oHappy&comma. &cdq.Smile&cdq.&comma. bInline )
      ? oHappy&colon.Smile( 1 )       // &colon.)
      ? oHappy&colon.Smile( 2 )       // ;)
      ? oHappy&colon.Smile( 3 )       // *SMILE*
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objAddInline() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=185.__objAddData():elink.
.br
:link reftype=hd res=189.__objAddMethod():elink.
.br
:link reftype=hd res=190.__objDelInline():elink.
.br
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=191.__objHasMethod() :elink.
.br
:link reftype=hd res=192.__objModInline():elink.
.br
:h1 res=193.__OBJADDDATA()
:i1 id=__OBJADDDATA().__OBJADDDATA()
:p.__OBJADDDATA()
:p.:hp2.Add a DATA to an already existing class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objAddData( <oObject>, <cDataName> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cDataName>:ehp2.   is the symbol name of the new DATA to add.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objAddData():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objAddData() is a low level class support function that add a new  DATA to an object. <oObject> is unchanged if a symbol with the name  <cDataName> already exist in <oObject>.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a lHappy DATA
      oHappy  &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      __objAddData( oHappy&comma. &cdq.lHappy&cdq. )
      oHappy&colon.lHappy &colon.= .T.
      IF oHappy&colon.lHappy
         ? &cdq.Happy&comma. Happy&comma. Joy&comma. Joy !!!&cdq.
      ELSE
         ? &cdq.&colon.(...&cdq.
      ENDIF
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objAddData() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=184.__objAddInline():elink.
.br
:link reftype=hd res=189.__objAddMethod():elink.
.br
:link reftype=hd res=194.__objDelData():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=177.__ObjGetValueList():elink.
.br
:link reftype=hd res=175.__objHasData():elink.
.br
:link reftype=hd res=181.__ObjSetValueList():elink.
.br
:h1 res=195.__OBJMODMETHOD()
:i1 id=__OBJMODMETHOD().__OBJMODMETHOD()
:p.__OBJMODMETHOD()
:p.:hp2.Modify (replace) a METHOD in an already existing class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objModMethod( <oObject>, <cMethodName>, <nFuncPtr> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cMethodName>:ehp2.   is the symbol name of the METHOD to modify.      

      :hp2. <nFuncPtr>:ehp2.   is a pointer to a new function to associate with the method.     

:p.:hp2.Returns
:ehp2.
      :hp2. __objModMethod():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objModMethod() is a low level class support function that modify  a METHOD in an object and replace it with a new function. <oObject>  is unchanged if a symbol with the name <cMethodName> does not exist  in <oObject>. __objModMethod() is used in inheritance mechanism.       

     Note that <nFuncPtr> is a special pointer to a function that was  created using the @ operator&comma. see example below.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a Smile method
      oHappy &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      __objAddMethod( oHappy&comma. &cdq.Smile&cdq.&comma. @MySmile() )
      ? oHappy&colon.Smile( 1 )       // &colon.)
      ? oHappy&colon.Smile( 2 )       // ;)
      // replace Smile method with a new function
      __objAddMethod( oHappy&comma. &cdq.Smile&cdq.&comma. @YourSmile() )
      ? oHappy&colon.Smile( 1 )       // *SMILE*
      ? oHappy&colon.Smile( 2 )       // *WINK*

      STATIC FUNCTION MySmile( nType )
      LOCAL cSmile
      DO CASE
         CASE nType == 1
              cSmile &colon.= &cdq.&colon.)&cdq.
         CASE nType == 2
              cSmile &colon.= &cdq.;)&cdq.
      ENDCASE
      RETURN cSmile

      STATIC FUNCTION YourSmile( nType )
      LOCAL cSmile
      DO CASE
         CASE nType == 1
              cSmile &colon.= &cdq.*SMILE*&cdq.
         CASE nType == 2
              cSmile &colon.= &cdq.*WINK*&cdq.
      ENDCASE
      RETURN cSmile
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objModMethod() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=189.__objAddMethod():elink.
.br
:link reftype=hd res=186.__objDelMethod():elink.
.br
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:h1 res=196.__OBJMODINLINE()
:i1 id=__OBJMODINLINE().__OBJMODINLINE()
:p.__OBJMODINLINE()
:p.:hp2.Modify (replace) an INLINE method in an already existing class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objModInline( <oObject>, <cInlineName>, <bInline> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cInlineName>:ehp2.   is the symbol name of the INLINE method to modify.      

      :hp2. <bInline>:ehp2.   is a new code block to associate with the INLINE method.    

:p.:hp2.Returns
:ehp2.
      :hp2. __objModInline():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objModInline() is a low level class support function that modify  an INLINE method in an object and replace it with a new code block.  <oObject> is unchanged if a symbol with the name <cInlineName> does  not exist in <oObject>. __objModInline() is used in inheritance  mechanism.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a Smile INLINE method
      oHappy  &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      bMyInline   &colon.= { | nType | { &cdq.&colon.)&cdq.&comma. &cdq.;)&cdq. }[ nType ] }
      bYourInline &colon.= { | nType | { &cdq.*SMILE*&cdq.&comma. &cdq.*WINK*&cdq. }[ nType ] }
      __objAddInline( oHappy&comma. &cdq.Smile&cdq.&comma. bMyInline )
      ? oHappy&colon.Smile( 1 )       // &colon.)
      ? oHappy&colon.Smile( 2 )       // ;)
      // replace Smile inline method with a new code block
      __objModInline( oHappy&comma. &cdq.Smile&cdq.&comma. bYourInline )
      ? oHappy&colon.Smile( 1 )       // *SMILE*
      ? oHappy&colon.Smile( 2 )       // *WINK*
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objModInline() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=184.__objAddInline():elink.
.br
:link reftype=hd res=190.__objDelInline():elink.
.br
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:h1 res=197.__OBJDELMETHOD()
:i1 id=__OBJDELMETHOD().__OBJDELMETHOD()
:p.__OBJDELMETHOD()
:p.:hp2.Delete a METHOD  from class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objDelMethod( <oObject>, <cSymbol> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cSymbol>:ehp2.   is the symbol name of METHOD or INLINE method to be deleted (removed) from the object.     

:p.:hp2.Returns
:ehp2.
      :hp2. __objDelMethod():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objDelMethod() is a low level class support function that delete  (remove) a METHOD or an INLINE method from an object. <oObject> is  unchanged if a symbol with the name <cSymbol> does not exist in  <oObject>.       

     __objDelInline() is exactly the same as __objDelMethod().     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a Smile method
      oHappy &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      __objAddMethod( oHappy&comma. &cdq.Smile&cdq.&comma. @MySmile() )
      ? __objHasMethod( oHappy&comma. &cdq.Smile&cdq. )    // .T.
      // remove Smile method
      __objDelMethod( oHappy&comma. &cdq.Smile&cdq. )
      ? __objHasMethod( oHappy&comma. &cdq.Smile&cdq. )    // .F.

      STATIC FUNCTION MySmile( nType )
      LOCAL cSmile
      DO CASE
         CASE nType == 1
              cSmile &colon.= &cdq.&colon.)&cdq.
         CASE nType == 2
              cSmile &colon.= &cdq.;)&cdq.
      ENDCASE
      RETURN cSmile
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objDelMethod() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=184.__objAddInline():elink.
.br
:link reftype=hd res=189.__objAddMethod():elink.
.br
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:link reftype=hd res=192.__objModInline():elink.
.br
:link reftype=hd res=187.__objModMethod():elink.
.br
:h1 res=198.__OBJDELINLINE()
:i1 id=__OBJDELINLINE().__OBJDELINLINE()
:p.__OBJDELINLINE()
:p.:hp2.Delete a METHOD INLINE from class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objDelInline( <oObject>, <cSymbol> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cSymbol>:ehp2.   is the symbol name of METHOD or INLINE method to be deleted (removed) from the object.     

:p.:hp2.Returns
:ehp2.
      :hp2. __objDelInMethod():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objDelInMethod() is a low level class support function that delete  (remove) a METHOD or an INLINE method from an object. <oObject> is  unchanged if a symbol with the name <cSymbol> does not exist in  <oObject>.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a Smile method
      oHappy &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      __objAddMethod( oHappy&comma. &cdq.Smile&cdq.&comma. @MySmile() )
      ? __objHasMethod( oHappy&comma. &cdq.Smile&cdq. )    // .T.
      // remove Smile method
      __objDelInMethod( oHappy&comma. &cdq.Smile&cdq. )
      ? __objHasMethod( oHappy&comma. &cdq.Smile&cdq. )    // .F.

      STATIC FUNCTION MySmile( nType )
      LOCAL cSmile
      DO CASE
         CASE nType == 1
              cSmile &colon.= &cdq.&colon.)&cdq.
         CASE nType == 2
              cSmile &colon.= &cdq.;)&cdq.
      ENDCASE
      RETURN cSmile
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objDelMethod() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=184.__objAddInline():elink.
.br
:link reftype=hd res=189.__objAddMethod():elink.
.br
:link reftype=hd res=171.__ObjGetMethodList():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=173.__objHasMethod():elink.
.br
:link reftype=hd res=192.__objModInline():elink.
.br
:link reftype=hd res=187.__objModMethod():elink.
.br
:h1 res=199.__OBJDELDATA()
:i1 id=__OBJDELDATA().__OBJDELDATA()
:p.__OBJDELDATA()
:p.:hp2.Delete a DATA (instance variable) from class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__objDelMethod( <oObject>, <cDataName> ) --> oObject
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <oObject>:ehp2.   is the object to work on.      

      :hp2. <cDataName>:ehp2.   is the symbol name of DATA to be deleted (removed) from the object.     

:p.:hp2.Returns
:ehp2.
      :hp2. __objDelData():ehp2.   return a reference to <oObject>.    

:p.:hp2.Description
:ehp2.
     __objDelData() is a low level class support function that delete  (remove) a DATA from an object. <oObject> is unchanged if a symbol  with the name <cDataName> does not exist in <oObject>.     

:p.:hp2.Examples
:ehp2.

      // create a new THappy class and add a lHappy DATA
      oHappy  &colon.= TClass()&colon.New( &cdq.THappy&cdq. )
      __objAddData( oHappy&comma. &cdq.lHappy&cdq. )
      ? __objHasData( oHappy&comma. &cdq.lHappy&cdq. )    // .T.
      // remove lHappy DATA
      __objDelData( oHappy&comma. &cdq.lHappy&cdq. )
      ? __objHasData( oHappy&comma. &cdq.lHappy&cdq. )    // .F.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __objDelData() is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=185.__objAddData():elink.
.br
:link reftype=hd res=172.__objGetMsgList():elink.
.br
:link reftype=hd res=177.__ObjGetValueList():elink.
.br
:link reftype=hd res=175.__objHasData():elink.
.br
:link reftype=hd res=181.__ObjSetValueList():elink.
.br
:h1 res=200.RDDLIST()
:i1 id=RDDLIST().RDDLIST()
:p.RDDLIST()
:p.:hp2.Return an array of the available Replaceable Database Drivers
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RDDLIST([<nRDDType>]) --> aRDDList
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRDDType>:ehp2.   is an integer that represents the type of the RDD you wish to list.  The constants RDT_FULL and RDT_TRANSFER represent the two  types of RDDs currently available.       

      RDDType  Summary   Constant       Value     Meaning    RDT_FULL       1         Full RDD implementation  RDT_TRANSFER   2         Import/Export only driver         

      :hp2. RDT_FULL:ehp2.   identifies full-featured RDDs that have all the capabilities associated with an RDD.       

      :hp2. RDT_TRANSFER:ehp2.   identifies RDDs of limited capability.  They can only transfer records between files.  You cannot use these limited RDD  drivers to open a file in a work area.  The SDF and DELIM drivers are  examples of this type of RDD.  They are only used in the implementation  of APPEND FROM and COPY TO with SDF or DELIMITED files.     

:p.:hp2.Returns
:ehp2.
      :hp2. RDDLIST():ehp2.   returns a one-dimensional array of the RDD names registered with the application as <nRDDType>.     

:p.:hp2.Description
:ehp2.
    RDDLIST() is an RDD function that returns a one-dimensional array that  lists the available RDDs.       

    If you do not supply <nRDDType>&comma. all available RDDs&comma. regardless of type&comma.  are returned.     

:p.:hp2.Examples
:ehp2.

     In this example RDDLIST() returns an array containing the
      character strings&comma. &cdq.DBF&cdq.&comma. &cdq.SDF&cdq.&comma. &cdq.DELIM&cdq.&comma. &cdq.DBFCDX&cdq.&comma. and &cdq.DBFNTX&cdq.&colon.

      REQUEST DBFCDX

      .
      . < statements >
      .

      aRDDs &colon.= RDDLIST()

            // Returns {&cdq.DBF&cdq.&comma. SDF&cdq.&comma. &cdq.DELIM&cdq.&comma. &cdq.DBFCDX&cdq.&comma. &cdq.DBFNTX&cdq. }

     In this example&comma. RDDLIST() returns an array containing the
      character strings&comma. &cdq.SDF&cdq. and &cdq.DELIM&cdq.&colon.

      #include &cdq.rddsys.ch&cdq.
      .
      . < statements >
      .
      aImpExp &colon.= RDDLIST( RDT TRANSFER )


:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.

:h1 res=201.RDDNAME()
:i1 id=RDDNAME().RDDNAME()
:p.RDDNAME()
:p.:hp2.Return the name of the currently active RDD
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RDDNAME() --> cRDDName
:ehp2.
:p.:hp2.Arguments
:ehp2.

:p.:hp2.Returns
:ehp2.
      Returns  a character string, cRDDName, the registered name of the active RDD in the current or specified work area.     

:p.:hp2.Description
:ehp2.
     RDDNAME() is an RDD function that returns a character string&comma. cRDDName&comma.  the name of the active RDD in the current or specified work area.       

     You can specify a work area other than the currently active work area by  aliasing the function.     

:p.:hp2.Examples
:ehp2.

   USE Customer VIA &cdq.DBFNTX&cdq. NEW
   USE Sales    VIA &cdq.DBFCDX&cdq. NEW

   ? RDDNAME()                          // Returns&colon. DBFCDX
   ? Customer->( RDDNAME() )            // Returns&colon. DBFNTX
   ? Sales->( RDDNAME() )               // Returns&colon. DBFCDX

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=200.RDDLIST():elink.
.br
:h1 res=202.RDDSETDEFAULT()
:i1 id=RDDSETDEFAULT().RDDSETDEFAULT()
:p.RDDSETDEFAULT()
:p.:hp2.Set or return the default RDD for the application
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RDDSETDEFAULT([<cNewDefaultRDD>])
:ehp2.
:p.:hp2.--> cPreviousDefaultRDD
:ehp2.

      :hp2. <cNewDefaultRDD>:ehp2.   is a character string, the name of the RDD that is to be made the new default RDD in the application.     

:p.:hp2.Returns
:ehp2.
      :hp2. RDDSETDEFAULT():ehp2.   returns a character string, cPreviousDefaultRDD, the name of the previous default driver.  The default driver is the driver  that HARBOUR uses if you do not explicitly specify an RDD with the  VIA clause of the USE command.     

:p.:hp2.Description
:ehp2.
     RDDSETDEFAULT() is an RDD function that sets or returns the name of the  previous default RDD driver and&comma. optionally&comma. sets the current driver to  the new RDD driver specified by cNewDefaultRDD.  If <cNewDefaultDriver>  is not specified&comma. the current default driver name is returned and  continues to be the current default driver.       

   This function replaces the DBSETDRIVER() function.     

:p.:hp2.Examples
:ehp2.

   // If the default driver is not DBFNTX&comma. make it the default

   IF ( RDDSETDEFAULT() != &cdq.DBFNTX&cdq. )
      cOldRdd &colon.= RDDSETDEFAULT( &cdq.DBFNTX&cdq. )
   ENDIF

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=203.DBSETDRIVER():elink.
.br
:h1 res=204.__RDDSETDEFAULT()
:i1 id=__RDDSETDEFAULT().__RDDSETDEFAULT()
:p.__RDDSETDEFAULT()
:p.:hp2.Set or return the default RDD for the application
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__RDDSETDEFAULT([<cNewDefaultRDD>])
:ehp2.
:p.:hp2.--> cPreviousDefaultRDD
:ehp2.

      :hp2. <cNewDefaultRDD>:ehp2.   is a character string, the name of the RDD that is to be made the new default RDD in the application.     

:p.:hp2.Returns
:ehp2.
      :hp2. __RDDSETDEFAULT():ehp2.   returns a character string, cPreviousDefaultRDD, the name of the previous default driver.  The default driver is the driver  that HARBOUR uses if you do not explicitly specify an RDD with the  VIA clause of the USE command.     

:p.:hp2.Description
:ehp2.
     RDDSETDEFAULT() is an RDD function that sets or returns the name of the  previous default RDD driver and&comma. optionally&comma. sets the current driver to  the new RDD driver specified by cNewDefaultRDD.  If <cNewDefaultDriver>  is not specified&comma. the current default driver name is returned and  continues to be the current default driver.       

     This function replaces the DBSETDRIVER() function.     

:p.:hp2.Examples
:ehp2.

      // If the default driver is not DBFNTX&comma. make it the default

      IF ( __RDDSETDEFAULT() != &cdq.DBFNTX&cdq. )
           cOldRdd &colon.= __RDDSETDEFAULT( &cdq.DBFNTX&cdq. )
      ENDIF

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=203.DBSETDRIVER():elink.
.br
:h1 res=15.DBEVAL()
:i1 id=DBEVAL().DBEVAL()
:p.DBEVAL()
:p.:hp2.Performs a code block operation on the current Database
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBEVAL( <bBlock>,
:ehp2.
:p.:hp2.[<bFor>], [<bWhile>],
:ehp2.
:p.:hp2.[<nNext>], [<nRecord>],
:ehp2.
:p.:hp2.[<lRest>] ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <bBlock>:ehp2.   Operation that is to be performed      

      :hp2. <bFor>:ehp2.   Code block for the For condition      

      :hp2. <bWhile>:ehp2.   Code block for the WHILE condition      

      :hp2. <nNext>:ehp2.   Number of NEXT records  to process      

      :hp2. <nRecord>:ehp2.   Record number to work on exactly      

      :hp2. <lRest>:ehp2.   Toggle to rewind record pointer    

:p.:hp2.Returns
:ehp2.
      :hp2. DBEVAL():ehp2.   always returns NIL    

:p.:hp2.Description
:ehp2.
       Performs a code block operation on the current Database     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
         LOCAL nCount

         USE Test

         dbGoto( 4 )
         ? RecNo()
         COUNT TO nCount
         ? RecNo()&comma. nCount
         COUNT TO nCount NEXT 10
         ? RecNo()&comma. nCount

         RETURN NIL
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     DBEVAL is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=14.EVAL():elink.
.br
:h1 res=205.DBF()
:i1 id=DBF().DBF()
:p.DBF()
:p.:hp2.Alias name of a work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.Dbf() --> <cWorkArea>
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <cWorkArea>:ehp2.   Name of alias    

:p.:hp2.Description
:ehp2.
     This function returns the same alias name ofthe currently selected work  area.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()

         USE Test

         select 0
         qOut( IF(DBF()==&cdq.&cdq.&comma.&cdq.No Name&cdq.&comma.DBF()))
         Test->(qOut(DBF())
         qOut(Alias(1))

         RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBF() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=206.ALIAS():elink.
.br
:h1 res=207.DBAPPEND()
:i1 id=DBAPPEND().DBAPPEND()
:p.DBAPPEND()
:p.:hp2.Appends a new record to a database file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DbAppend(<lLock>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lLock>:ehp2.   Toggle to release record locks    

:p.:hp2.Returns
:ehp2.
      :hp2. DbAppend():ehp2.   always returns NIL    

:p.:hp2.Description
:ehp2.
    This function add a new record to the end of the database  in the selected or aliased work area. All fields in that  database will be given empty data values - character fields  will be filled with blank spaces&comma.date fields with CTOD('//')&comma.  numeric fields with 0&comma.logical fields with .F.&comma. and memo fields  with NULL bytes.The header of the database is not updated until  the record is flushed from the buffer and the contents are  written to the disk.       

    Under a networking enviroment&comma. DBAPPEND() performs an additional  operation&colon. It attrmps to lock the newly added record. If  the database file is currently locked or if a locking assignment  if made to LASTREC()+1&comma.NETERR() will return a logical true (.T.)  immediately after the DBAPPEND() function. This function does  not unlock the locked records.       

    If <lLock> is passed a logical true (.T.) value&comma. it will  release the record locks&comma. which allows the application to main-  tain multiple record locks during an appending operation. The  default for this parameter is a logical false (.F.).     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()

         USE Test
         local cName=&cdq.HARBOUR&cdq.&comma.nId=10
         Test->(DbAppend())
         Replace Test->Name wit cName&comma.Id with nId
         Use
         RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBAPPEND() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=208.DBUNLOCK():elink.
.br
:link reftype=hd res=209.DBUNLOCKALL():elink.
.br
:h1 res=210.DBCLEARFILTER()
:i1 id=DBCLEARFILTER().DBCLEARFILTER()
:p.DBCLEARFILTER()
:p.:hp2.Clears the current filter condiction in a work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DbClearFilTer() -> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DbClearFilTer():ehp2.   always returns NIL    

:p.:hp2.Description
:ehp2.
     This function clears any active filter condiction  for the current or selected work area.     

:p.:hp2.Examples
:ehp2.

      Function Main()

       Use Test

       Set Filter to Left(Test->Name&comma.2) == &cdq.An&cdq.

       Dbedit()

       Test->(DbClearFilter())

       USE

       Return Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBCLEARFILTER() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=211.DBSETFILTER():elink.
.br
:link reftype=hd res=212.DBFILTER():elink.
.br
:h1 res=213.DBCLOSEALL()
:i1 id=DBCLOSEALL().DBCLOSEALL()
:p.DBCLOSEALL()
:p.:hp2.Close all open files in all work areas.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DbCloseAll() -> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBCLOSEALL():ehp2.   always return NIL    

:p.:hp2.Description
:ehp2.
     This function close all open databases and all associated  indexes.In addition&comma. it closes all format files and moves  the work area pointer to the first position     

:p.:hp2.Examples
:ehp2.

      Function Main()

       Use Test New

       DbEdit()

       Use Test1 New

       DbEdit()

       DbCloseAll()

       USE

       Return Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBCLOSEALL() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=214.DBUSEAREA():elink.
.br
:link reftype=hd res=215.DBCLOSEAREA():elink.
.br
:h1 res=215.DBCLOSEAREA()
:i1 id=DBCLOSEAREA().DBCLOSEAREA()
:p.DBCLOSEAREA()
:p.:hp2.Close a database file in a work area.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DbCloseArea() -> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DbCloseArea():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function  will close any database open in the selected  or aliased work area.     

:p.:hp2.Examples
:ehp2.

      Function Main()

       Use Test

       Dbedit()

       Test->(DbCloseArea())

       USE

       Return Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DBCLOSEAREA() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=214.DBUSEAREA():elink.
.br
:link reftype=hd res=213.DBCLOSEALL():elink.
.br
:h1 res=216.DBCOMMIT()
:i1 id=DBCOMMIT().DBCOMMIT()
:p.DBCOMMIT()
:p.:hp2.Updates all index and database buffers for a given workarea
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBCOMMIT() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBCOMMIT():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function updates all of the information for a give&comma.selected&comma.  or active workarea.This operation includes all database and index  buffers for that work area only. This function does not update all  open work areas.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL cName&colon.=SPACE(40)
      LOCAL nId&colon.=0
      USE Test EXCLUSIVE NEW
      //
      @ 10&comma. 10 GET cName
      @ 11&comma. 10 GET nId
      READ
      //
      IF UPDATED()
         APPEND BLANK
         REPLACE Tests->Name WITH cName
         REPLACE Tests->Id WITH nId
         Tests->( DBCOMMIT() )
      ENDIF
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=213.DBCLOSEALL():elink.
.br
:link reftype=hd res=217.DBCOMMITALL():elink.
.br
:link reftype=hd res=208.DBUNLOCK():elink.
.br
:h1 res=217.DBCOMMITALL()
:i1 id=DBCOMMITALL().DBCOMMITALL()
:p.DBCOMMITALL()
:p.:hp2.Flushes the memory buffer and performs a hard-disk write
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBCOMMIT() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBCOMMIT():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function performs a hard-disk write for all work areas.  Before the disk write is performed&comma.all buffers are flushed.  open work areas.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL cName&colon.=SPACE(40)
      LOCAL nId&colon.=0
      USE Test EXCLUSIVE NEW
      USE TestId New INDEX Testid
      //
      @ 10&comma. 10 GET cName
      @ 11&comma. 10 GET nId
      READ
      //
      IF UPDATED()
         APPEND BLANK
         REPLACE Tests->Name WITH cName
         REPLACE Tests->Id WITH nId
         IF !TestId->(DBSEEK(nId))
            APPEND BLANK
            REPLACE Tests->Id WITH nId
         ENDIF
      ENDIF
      DBCOMMITALL()
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=213.DBCLOSEALL():elink.
.br
:link reftype=hd res=216.DBCOMMIT():elink.
.br
:link reftype=hd res=208.DBUNLOCK():elink.
.br
:h1 res=218.__DBCONTINUE()
:i1 id=__DBCONTINUE().__DBCONTINUE()
:p.__DBCONTINUE()
:p.:hp2.Resume a pending LOCATE
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__DbCONTINUE()   -> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. __DbCONTINUE():ehp2.    Always return nil    

:p.:hp2.Description
:ehp2.
     __DBCONTINUE is a database command that searches from the current record  position for the next record meeting the most recent LOCATE condition  executed in the current work area.  It terminates when a match is found  or end of file is encountered.  If __DBCONTINUE is successful&comma. the matching  record becomes the current record and FOUND() returns true (.T.); if  unsuccessful&comma. FOUND() returns false (.F.).       

     Each work area may have an active LOCATE condition.  In CA-Clipper&comma. a  LOCATE condition remains pending until a new LOCATE condition is  specified.  No other commands release the condition.       

     Notes       

     Scope and WHILE condition&colon. Note that the scope and WHILE  condition of the initial LOCATE are ignored; only the FOR condition  is used with CONTINUE.  If you are using a LOCATE with a WHILE  condition and want to continue the search for a matching record&comma. use  SKIP and then repeat the original LOCATE statement adding REST as the  scope.       

:p.:hp2.Examples
:ehp2.

     This example scans records in Sales.dbf for a particular
      salesman and displays a running total sales amounts&colon.

      LOCAL nRunTotal &colon.= 0
      USE Sales NEW
      LOCATE FOR Sales->Salesman = &cdq.1002&cdq.
      DO WHILE FOUND()
         ? Sales->Salesname&comma. nRunTotal += Sales->Amount
         __DBCONTINUE()
      ENDDO

     This example demonstrates how to continue if the pending
      LOCATE scope contains a WHILE condition&colon.

      LOCAL nRunTotal &colon.= 0
      USE Sales INDEX Salesman NEW
      SEEK &cdq.1002&cdq.
      LOCATE REST WHILE Sales->Salesman = &cdq.1002&cdq.;
            FOR Sales->Amount > 5000
      DO WHILE FOUND()
         ? Sales->Salesname&comma. nRunTotal += Sales->Amount
         SKIP
         LOCATE REST WHILE Sales->Salesman = &cdq.1002&cdq.;
            FOR Sales->Amount > 5000
      ENDDO

:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=220.FOUND():elink.
.br
:h1 res=61.DBCREATE()
:i1 id=DBCREATE().DBCREATE()
:p.DBCREATE()
:p.:hp2.Creates an empty database from a array.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBCREATE(<cDatabase>, <aStruct>,[<cDriver>],[<lOpen>],
:ehp2.
:p.:hp2.[<cAlias>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDatabase>:ehp2.   Name of database to be create      

      :hp2. <aStruct>:ehp2.     Name of a multidimensional array that contains the a database structure       

      :hp2. <cDriver>:ehp2.     Name of the RDD      

      :hp2. <lOpen>:ehp2.       Toggle to Open the create File      

      :hp2. <cAlias>:ehp2.      Name of database Alias    

:p.:hp2.Returns
:ehp2.
      :hp2. DBCREATE():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function creates the database file specified as <cDatabase> from the  multidimensional array <aStruct>.If no file extension is use with <cDatabase>  the .DBF extension is assumed.  The array specified in <aStruct> must follow a few guidelines when being  built prior to a call to DBCREATE()&colon.       

     - All subscripts values in the second dimension must be set to proper values       

     - The fourth subscript value in the second dimension - which contains  the decimal value-must he specified. even 1kw nonnumeric fields.       

     - The second subscript value in the second dimension-which contains  the field data type-must contain a proper value&colon. C&comma. D&comma. L&comma. M or N  It is possible to use additional letters (or clarity (e.g.&comma. 'Numeric'  for 'N')&colon. however&comma. the first letter of this array element must  be a proper value.       

     The DBCREATE( ) function does not use the decimal field to  calculate the length of a character held longer than 256. Values  up to the maximum length of a character field (which is 65&comma.519 bytes)  are stored directly in the database in the length attribute if that  database was created via this function. However&comma. a file containing  fields longer than 256 bytes is not compatible with any interpreter.       

     The <cDriver> parameter specifies the name of the Replaceable Da-  tabase Driver to use to create the database. If it is not specified&comma. then the  Replaceable Database Driver in the current work area is tised.  The <lOpen> parameter specifies if the already created database is to be opened&comma.  The <cAlias> parameter specifies the alias name for the new opened database     

:p.:hp2.Examples
:ehp2.

      function main()

      local nI&comma. aStruct &colon.= { { &cdq.CHARACTER&cdq.&comma. &cdq.C&cdq.&comma. 25&comma. 0 }&comma. ;
                          { &cdq.NUMERIC&cdq.&comma.   &cdq.N&cdq.&comma.  8&comma. 0 }&comma. ;
                          { &cdq.DOUBLE&cdq.&comma.    &cdq.N&cdq.&comma.  8&comma. 2 }&comma. ;
                          { &cdq.DATE&cdq.&comma.      &cdq.D&cdq.&comma.  8&comma. 0 }&comma. ;
                          { &cdq.LOGICAL&cdq.&comma.   &cdq.L&cdq.&comma.  1&comma. 0 }&comma. ;
                          { &cdq.MEMO1&cdq.&comma.     &cdq.M&cdq.&comma. 10&comma. 0 }&comma. ;
                          { &cdq.MEMO2&cdq.&comma.     &cdq.M&cdq.&comma. 10&comma. 0 } }

      REQUEST DBFCDX

      dbCreate( &cdq.testdbf&cdq.&comma. aStruct&comma. &cdq.DBFCDX&cdq.&comma. .t.&comma. &cdq.MYALIAS&cdq. )

      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Not CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd  Header  is Dbstruct.ch     
.br
See Also&colon.
:link reftype=hd res=221.AFIELDS():elink.
.br
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:h1 res=222.DBDELETE()
:i1 id=DBDELETE().DBDELETE()
:p.DBDELETE()
:p.:hp2.Marks records for deletion in a database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBDELETE() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBDELETE():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function marks a record for deletion in the selected  or aliased work area.If the DELETED setting is on&comma. the record  will still be visible until the record pointer in that work area  is moved to another record.       

     In a networking situation&comma. this function requires that the record  be locked prior to issuing the DBDELETE() function.     

:p.:hp2.Examples
:ehp2.

      nId&colon.=10
      USE TestId INDEX TestId NEW
      IF TestId->(DBSEEK(nId))
         IF TestId->(RLOCK())
            DBDELETE()
         ENDIF
      ENDIF
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=223.DBRECALL():elink.
.br
:h1 res=212.DBFILTER()
:i1 id=DBFILTER().DBFILTER()
:p.DBFILTER()
:p.:hp2.Return the filter expression in a work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBFILTER() --> cFilter
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBFILTER():ehp2.   returns the filter expression.    

:p.:hp2.Description
:ehp2.
     This function return the expression of the SET FILTER TO command  for the current or designated work area. If no filter condition  is present&comma.a NULL string will be returned.     

:p.:hp2.Examples
:ehp2.

      USE Test INDEX Test NEW
      SET FILTER TO Name= &cdq.Harbour&cdq.
      USE TestId INDEX TestId NEW
      SET FILTER TO Id = 1
      SELECT Test
      //
      ? DBFILTER()
      ? TestId->(DBFILTER())
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=224.DBRELATION():elink.
.br
:link reftype=hd res=225.DBRSELECT():elink.
.br
:h1 res=226.DBGOBOTTOM()
:i1 id=DBGOBOTTOM().DBGOBOTTOM()
:p.DBGOBOTTOM()
:p.:hp2.Moves the record pointer to the bottom of the database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBGOBOTTOM() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBGOBOTTOM():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function moves the record pointer in the selected or aliased  work area to the end of the file.The position of the record pointer  is affected by the values in the index key or by an active FILTER  condition.Otherwise&comma.if no index is active or if no filter condition  is present&comma.the value of the record pointer will be LASTREC().     

:p.:hp2.Examples
:ehp2.

      USE Tests
      DBGOTOP()
      ? RECNO()
      DBGOBOTTOM()
      ? RECNO()
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=227.BOF():elink.
.br
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=40.DBSKIP():elink.
.br
:link reftype=hd res=228.DBSEEK():elink.
.br
:link reftype=hd res=229.DBGOTOP():elink.
.br
:h1 res=230.DBGOTO()
:i1 id=DBGOTO().DBGOTO()
:p.DBGOTO()
:p.:hp2.Position the record pointer to a specific location.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBGOTO(<xRecordNumber>) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xRecordNumber>:ehp2.   Record number or unique identity    

:p.:hp2.Returns
:ehp2.
      :hp2. DBGOTO():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function places the record pointer&comma.if working with a .DBF file&comma.  in selected or aliased work area at the record number specified by  <xRecordNumber>.The position if not affected by an active index or  by any enviromental SET condiction.       

     Issuing a DBGOTO(RECNO()) call in a network enviroment will refresh  the database and index buffers.This is the same as a DBSKIP(0) call.  The parameter <xRecordNumber> may be something other than a record  number.In some data formats&comma. for example&comma. the value of <xRecordNumber>  is a unique primary key while in other formats&comma.<xRecordNumber> could  be an array offset if the data set was an array.     

:p.:hp2.Examples
:ehp2.



      The following example uses DBGOTO() to iteratively process
      every fourth record&colon.

      DBUSEAREA( .T.&comma. &cdq.DBFNTX&cdq.&comma. &cdq.Sales&cdq.&comma. &cdq.Sales&cdq.&comma. .T. )
      //
      // toggle every fourth record
      DO WHILE !EOF()
         DBGOTO( RECNO() + 4 )
         Sales->Group &colon.= &cdq.Bear&cdq.
      ENDDO

:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=227.BOF():elink.
.br
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=229.DBGOTOP():elink.
.br
:link reftype=hd res=226.DBGOBOTTOM():elink.
.br
:link reftype=hd res=228.DBSEEK():elink.
.br
:link reftype=hd res=40.DBSKIP():elink.
.br
:h1 res=229.DBGOTOP()
:i1 id=DBGOTOP().DBGOTOP()
:p.DBGOTOP()
:p.:hp2.Moves the record pointer to the bottom of the database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBGOTOP() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBGOTOP():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function moves the record pointer in the selected or aliased  work area to the top of the file.The position of the record pointer  is affected by the values in the index key or by an active FILTER  condition.Otherwise&comma.if no index is active or if no filter condition  is present&comma.the value of RECNO() will be 1.     

:p.:hp2.Examples
:ehp2.

      USE Tests
      DBGOTOP()
      ? RECNO()
      DBGOBOTTOM()
      ? RECNO()
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=227.BOF():elink.
.br
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=40.DBSKIP():elink.
.br
:link reftype=hd res=228.DBSEEK():elink.
.br
:link reftype=hd res=226.DBGOBOTTOM():elink.
.br
:h1 res=223.DBRECALL()
:i1 id=DBRECALL().DBRECALL()
:p.DBRECALL()
:p.:hp2.Recalls a record previousy marked for deletion.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBRECALL() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBRECALL():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function unmarks those records marked for deletion nd reactivates  them in the aliased or selected work area.If a record is DELETED and  the DELETED setting is on&comma. the record will still be visible for a  DBRECALL() provided that the database record pointer has not been  skipped.Once a record marked for deletion with the DELETE setting ON  has been skipped&comma. it no longer canbe brought back with DBRECALL().     

:p.:hp2.Examples
:ehp2.

      USE Test NEW
      DBGOTO(10)
      DBDELETE()
      ? DELETED()
      DBRECALL()
      ? DELETED()
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=222.DBDELETE():elink.
.br
:h1 res=231.DBRLOCK()
:i1 id=DBRLOCK().DBRLOCK()
:p.DBRLOCK()
:p.:hp2.This function locks the record basedon identify
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBRLOCK([<xIdentity>]) --> lSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xIdentity>:ehp2.   Record indetifier    

:p.:hp2.Returns
:ehp2.
      :hp2. DBRLOCK():ehp2.   returns a logical true (.T.) if lock was successful    

:p.:hp2.Description
:ehp2.
     This function attempts to lock a record which is indentified  by <xIdentity> in the active data set.If the lock is successful  the function will return a logical true (.T.) value;otherwise  a logical false (.F.) will be returned.If <xIdentity> is not  passed it will be assumed to lock the current active record/data item.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL x&colon.=0
      USE Tests New
      FOR x&colon.=1 to reccount()
        IF !DBRLOCK()
          DBUNLOCK()
        ENDIF
      NEXT
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=208.DBUNLOCK():elink.
.br
:link reftype=hd res=209.DBUNLOCKALL():elink.
.br
:link reftype=hd res=232.FLOCK():elink.
.br
:link reftype=hd res=233.RLOCK():elink.
.br
:h1 res=234.DBRLOCKLIST()
:i1 id=DBRLOCKLIST().DBRLOCKLIST()
:p.DBRLOCKLIST()
:p.:hp2.This function return a list of records in the database work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBRLOCKLIST() --> aRecordLocks
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <aRecordList>:ehp2.   is an array of lock records    

:p.:hp2.Description
:ehp2.
     This function will return an array of locked records in a given  and active work area.If the return array is an empty array  (meaning no elements in it)&comma.then there are no locked record in that  work area.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL aList&colon.={}
      LOCAL x&colon.=0
      USE Tests NEW
      DBGOTO(10)
      RLOCK()
      DBGOTO(100)
      RLOCK()
      aList&colon.=DBRLOCKLIST()
      FOR x&colon.=1 TO LEN(aList)
         ? aList[x]
      NEXT
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=233.RLOCK():elink.
.br
:link reftype=hd res=231.DBRLOCK():elink.
.br
:link reftype=hd res=235.DBRUNLOCK():elink.
.br
:h1 res=235.DBRUNLOCK()
:i1 id=DBRUNLOCK().DBRUNLOCK()
:p.DBRUNLOCK()
:p.:hp2.Unlocks a record base on its indentifier
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBRUNLOCK([<xIdentity>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xIdentity>:ehp2.   Record indentifier,tipicaly a record number    

:p.:hp2.Returns
:ehp2.
      :hp2. DBRUNLOCK():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function will attempt to unlock the record specified as  <xIdentity>&comma.which in a .DBF format is the record number.If not  specified&comma.them the current active record/data item will be  unlocked     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Tests New
      DBGOTO(10)
      IF RLOCK()
         ? Tests->ID
         DBRUNLOCK()
      ENDIF
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=233.RLOCK():elink.
.br
:link reftype=hd res=231.DBRLOCK():elink.
.br
:link reftype=hd res=234.DBRLOCKLIST():elink.
.br
:h1 res=228.DBSEEK()
:i1 id=DBSEEK().DBSEEK()
:p.DBSEEK()
:p.:hp2.Searches for a value based on an active index.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBSEEK(<expKey>, [<lSoftSeek>],[<lFindLast>]) --> lFound
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <expKey>:ehp2.   Any expression      

      :hp2. <lSoftSeek>:ehp2.   Toggle SOFTSEEK condition      

      :hp2. <lFindLast>:ehp2.   is an optional logical value that set the current record position to the last record if successful     

:p.:hp2.Returns
:ehp2.
      :hp2. DBSEEK():ehp2.   returns logical true (.T.) if found, otherwise false    

:p.:hp2.Description
:ehp2.
     This function searches for the first record in a database file whose index  key matches <expKey>. If the item is found&comma. the function will return a logical  true (.T.)&comma. the value of FOUND() wilI be a logical true (.T.)&comma. and the value of  EOF() wilI be a logical false (.F.). If no item is found. then the function will  return a logical false&comma. the value of FOUND( ) will be a logical false (.F.)&comma. and  the value of EOF( ) will be a logical true (.T.).       

     This function always &cdq.rewinds&cdq. the database pointer and starts the search from  the top of the file.       

     If the SOFTSEEK flag is on or if <lSoftSeek> is set to a logical true (.T.)  the value of FOUND() wilI be a logical false and EOF() will he a logical  false if there is an item in the index key with a greater value than the key  expression <expKey>; at this point the record pointer will position itself on that  record. However&comma. if there is no greater key in the index&comma.EOF() will return a  logical true (.T.) value. If <lSoftSeek> is not passed&comma. the function will look  to the internal status of SOFTSEEK before performing the operation. The default  of <lSoftSeek> is a logical false (.F.)     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Tests New INDEX Tests
      DBGOTO(10)
      nId&colon.=Tests->nId
      IF Tests->(DBSEEK(nId))
        IF RLOCK()
           ? Tests->Name
           DBRUNLOCK()
        ENDIF
      ENDIF
      USE
      RETURN NIL

      ACCEPT &cdq.Employee name&colon. &cdq. TO cName
      IF ( Employee->(DBSEEK(cName)) )
         Employee->(ViewRecord())
      ELSE
         ? &cdq.Not found&cdq.
      END

:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     DBSEEK() is  Compatible with CA-Clipper 5.3     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=226.DBGOBOTTOM():elink.
.br
:link reftype=hd res=229.DBGOTOP():elink.
.br
:link reftype=hd res=40.DBSKIP():elink.
.br
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=227.BOF():elink.
.br
:link reftype=hd res=220.FOUND():elink.
.br
:h1 res=236.DBSELECTAREA()
:i1 id=DBSELECTAREA().DBSELECTAREA()
:p.DBSELECTAREA()
:p.:hp2.Change to another work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBSELECTAREA(<xArea>) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xArea>:ehp2.   Alias or work area    

:p.:hp2.Returns
:ehp2.
      :hp2. DBSELECTAREA():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function moves the Harbour internal primary focus to the work  area designated by <xArea>. If <xArea> is numeric&comma. them it will  select the numeric work area;if <xArea> is character&comma.then it will  select the work area with the alias name.       

     DBSELECTAREA(0) will select the next avaliable and unused work area.  Up to 255 work areas are supported.Each work area has its own alias  and record pointer&comma. as well as its own FOUND()&comma.DBFILTER()&comma.DBRSELECT()&comma.  and DBRELATION() function values.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL nId
      USE Tests NEW INDEX Tests
      USE Tests1 NEW INDEX Tests1
      DBSELECTAREA(1)
      nId&colon.=Tests->Id
      DBSELECTAREA(2)
      IF DBSEEK(nId)
         ? Tests1->cName
      ENDIF
      DBCLOSEALL()
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-CLIPPER compatible.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=214.DBUSEAREA():elink.
.br
:link reftype=hd res=237.SELECT():elink.
.br
:h1 res=203.DBSETDRIVER()
:i1 id=DBSETDRIVER().DBSETDRIVER()
:p.DBSETDRIVER()
:p.:hp2.Establishes the name of replaceable daabas driver for a selected work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBSETDRIVER([<cDriver>]) --> cCurrentDriver
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cDriver>:ehp2.   Optional database driver name    

:p.:hp2.Returns
:ehp2.
      :hp2. DBSETDRIVER():ehp2.   returns the name of active driver    

:p.:hp2.Description
:ehp2.
     This function returns the name of the current database driver for the  selected work area. The default will be &cdq.DBFNTX&cdq.. If specified&comma.<cDriver>  contains the name of the database driver that should be used to activate  and manage the work area.If the specified driver is not avaliable&comma.this  function will have no effect.     

:p.:hp2.Examples
:ehp2.

      DBSETDRIVER(&cdq.ADS&cdq.)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=214.DBUSEAREA():elink.
.br
:h1 res=40.DBSKIP()
:i1 id=DBSKIP().DBSKIP()
:p.DBSKIP()
:p.:hp2.Moves the record pointer in the selected work area.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBSKIP([<nRecords>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRecords>:ehp2.   Numbers of records to move record pointer.    

:p.:hp2.Returns
:ehp2.
      :hp2. DBSKIP():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function moves the record pointer <nRecords> in the selected or  aliased work area.The default value for <nRecords> will be 1.  A DBSKIP(0) will flush and refresh the internal database bufer and make  any changes made to the record visible without moving the record pointer  in either direction.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Tests NEW
      DBGOTOP()
      WHILE !EOF()
        ? Tests->Id&comma.Tests->Name
        DBSKIP()
      ENDDO
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-CLIPPER compatible     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=227.BOF():elink.
.br
:link reftype=hd res=226.DBGOBOTTOM():elink.
.br
:link reftype=hd res=229.DBGOTOP():elink.
.br
:link reftype=hd res=228.DBSEEK():elink.
.br
:link reftype=hd res=219.EOF():elink.
.br
:h1 res=211.DBSETFILTER()
:i1 id=DBSETFILTER().DBSETFILTER()
:p.DBSETFILTER()
:p.:hp2.Establishes a filter condition for a work area.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBSETFILTER(<bCondition>, [<cCondition>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <bCondition>:ehp2.   Code block expression for filtered evaluation.      

      :hp2. <cCondition>:ehp2.   Optional character expression of code block.    

:p.:hp2.Returns
:ehp2.
      :hp2. DBSETFILTER():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function masks a database so that only those records that meet the  condition prescribed by the expression in the code block <bCondition>  and literally expressed as <cCondition> are visible.  If <cCondition> is not passed to this function&comma.then the DBFILTER()  function will return an empty string showing no filter in that work area  which in fact&comma.would be not correct.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Tests NEW
      DBSETFILTER({|| Tests->Id <100}&comma.&cdq.Tests->Id <100&cdq.)
      DBGOTOP()

:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=212.DBFILTER():elink.
.br
:link reftype=hd res=210.DBCLEARFILTER():elink.
.br
:h1 res=11.DBSTRUCT()
:i1 id=DBSTRUCT().DBSTRUCT()
:p.DBSTRUCT()
:p.:hp2.Creates a multidimensional array of a database structure.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBSTRUCT() --> aStruct
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBSTRUCT():ehp2.   returns an array pointer to database structure    

:p.:hp2.Description
:ehp2.
     This function returns a multidimensional array.This array has array  pointers to other arrays&comma.each of which contains the characteristic  of a field in the active work area.The lenght of this array is based  in the number of fields in that particular work area.In other words&comma.  LEN(DBSTRUCT()) is equal to the value obtained from FCOUNT().  Each subscript position     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      LOCAL aStru&comma.x
      USE Tests NEW
      aStru&colon.=DBSTRUCT()
      FOR x&colon.=1 TO LEN(aStru)
        ? aStru[x&comma.1]
      NEXT
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd  Header is  DbStruct.ch     
.br
See Also&colon.
:link reftype=hd res=221.AFIELDS():elink.
.br
:h1 res=208.DBUNLOCK()
:i1 id=DBUNLOCK().DBUNLOCK()
:p.DBUNLOCK()
:p.:hp2.Unlock a record or release a file lock
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBUNLOCK() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBUNLOCK():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function releases the file or record lock in the currently selected  or aliased work area.It will not unlock an associated lock in a related data-  bases.     

:p.:hp2.Examples
:ehp2.

      nId&colon.=10
      USE TestId INDEX TestId NEW
      IF TestId->(DBSEEK(nId))
         IF TestId->(RLOCK())
            DBDELETE()
         ELSE
             DBUNLOCK()
         ENDIF
      ENDIF
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=209.DBUNLOCKALL():elink.
.br
:link reftype=hd res=232.FLOCK():elink.
.br
:link reftype=hd res=233.RLOCK():elink.
.br
:h1 res=209.DBUNLOCKALL()
:i1 id=DBUNLOCKALL().DBUNLOCKALL()
:p.DBUNLOCKALL()
:p.:hp2.Unlocks all records and releases all file locks in all work areas.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBUNLOCKALL() --> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DBUNLOCKALL():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function will remove all file and record locks in all work area.     

:p.:hp2.Examples
:ehp2.

      nId&colon.=10
      USE Tests INDEX TestId NEW
      USE Tests1 INDEX Tests NEW
      IF TestId->(DBSEEK(nId))
         IF TestId->(RLOCK())
            DBDELETE()
         ELSE
            DBUNLOCK()
         ENDIF
      ELSE
         DBUNLOCKALL()
      ENDIF
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=208.DBUNLOCK():elink.
.br
:link reftype=hd res=232.FLOCK():elink.
.br
:link reftype=hd res=233.RLOCK():elink.
.br
:h1 res=214.DBUSEAREA()
:i1 id=DBUSEAREA().DBUSEAREA()
:p.DBUSEAREA()
:p.:hp2.Opens a work area and uses a database file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DBUSEAREA( [<lNewArea>], [<cDriver>], <cName>, [<xcAlias>],
:ehp2.
:p.:hp2.[<lShared>], [<lReadonly>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lNewArea>:ehp2.    A optional logical expression for the new work area      

      :hp2. <cDriver>:ehp2.     Database driver name      

      :hp2. <cName>:ehp2.       File Name      

      :hp2. <xcAlias>:ehp2.     Alias name      

      :hp2. <lShared>:ehp2.     Shared/exclusive status flag      

      :hp2. <lReadonly>:ehp2.   Read-write status flag.    

:p.:hp2.Returns
:ehp2.
      :hp2. DBUSEAREA():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
     This function opens an existing database named <cName> in the current  work area. If <lNewArea> is set to a logical true (.T.) value&comma. then  the database <cName> will be opened in the next available and unused  work area. The default value of <lNewArea> is a logical false (.F.).  If used&comma. <cDriver> is the name of the database driver associated with  the file <cName> that is opened. The default for this will be the value  of DBSETDRlVER().       

     IF used&comma. <xcAlias> contains the alias name for that work area&comma. If not  specified&comma. the root name of the database specified in <cName> will be  used.       

     If <lShared> is set to a logical true (.T.) value&comma. the database that  is specified in <cName> will be opened by the user EXCLUSIVELY. Thus  locking it from all other nodes or users on the network. If <lShared> is  set to a logical false (.F.) value&comma. then the database will be in SHARED  mode. If <lShared> is not passed&comma. then the function will turn to the  internal setting of SET EXCLUSIVE to determine a setting.       

     If <lReadOnly> is specified&comma. the file will be set to READ ONLY mode.  If it is not specified&comma. the file will he opened in normal read-write  mode.     

:p.:hp2.Examples
:ehp2.

      DBUSEAREA(.T.&comma.&comma.&cdq.Tests&cdq.)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=215.DBCLOSEAREA():elink.
.br
:link reftype=hd res=203.DBSETDRIVER():elink.
.br
:link reftype=hd res=237.SELECT():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=238.__DBZAP()
:i1 id=__DBZAP().__DBZAP()
:p.__DBZAP()
:p.:hp2.Remove all records from the current database file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__DbZap()  -> NIL
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. __DbZap():ehp2.     will always return nil    

:p.:hp2.Description
:ehp2.
     __DbZap( is a database command that permanently removes all records from  files open in the current work area.  This includes the current database  file&comma. index files&comma. and associated memo file.  Disk space previously  occupied by the ZAPped files is released to the operating system.  __DbZap() performs the same operation as DELETE ALL followed by PACK but is  almost  instantaneous.       

  To ZAP in a network environment&comma. the current database file must be USEd  EXCLUSIVEly.       

:p.:hp2.Examples
:ehp2.

      This example demonstrates a typical ZAP operation in a network
      environment&colon.

      USE Sales EXCLUSIVE NEW
      IF !NETERR()
         SET INDEX TO Sales&comma. Branch&comma. Salesman
         __dbZAP()
         CLOSE Sales
      ELSE
         ? &cdq.Zap operation failed&cdq.
         BREAK
      ENDIF
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
:h1 res=239.ORDBAGEXT()
:i1 id=ORDBAGEXT().ORDBAGEXT()
:p.ORDBAGEXT()
:p.:hp2.Return the default Order Bag RDD extension
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDBAGEXT() --> cBagExt
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <cBagExt>:ehp2.   a character expression.    

:p.:hp2.Description
:ehp2.
     ORDBAGEXT() is an Order management function that returns a character  expression that is the default Order Bag extension of the current or  aliased work area.  cBagExt is determined by the RDD active in the  current work area.       

     ORDBAGEXT() supersedes the INDEXEXT() and is not recommended.       

:p.:hp2.Examples
:ehp2.

     USE sample VIA &cdq.DBFNTX&cdq.
     ? ORDBAGEXT()      //  Returns .ntx

:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=240.INDEXEXT():elink.
.br
:link reftype=hd res=241.ORDBAGNAME():elink.
.br
:h1 res=241.ORDBAGNAME()
:i1 id=ORDBAGNAME().ORDBAGNAME()
:p.ORDBAGNAME()
:p.:hp2.Return the Order Bag name of a specific Order
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDBAGNAME(<nOrder> | <cOrderName>) --> cOrderBagName
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nOrder>:ehp2.   is an integer that identifies the position in the Order List of the target Order whose Order Bag name is sought.       

      :hp2. <cOrderName>:ehp2.   is a character string that represents the name of the target Order whose Order Bag name is sought.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDBAGNAME():ehp2.   returns a character string, the Order Bag name of the specific Order.     

:p.:hp2.Description
:ehp2.
    ORDBAGNAME() is an Order management function that lets you access the  name of the Order Bag in which <cOrderName> resides.  You may identify  the Order as a character string or with an integer that represents its  position in the Order List.  In case of duplicate names&comma. ORDBAGNAME()  only recognizes the first matching name.     

:p.:hp2.Examples
:ehp2.

     The following example uses ORDBAGNAME() with the default
      DBFNTX driver&colon.

      USE Customer VIA &cdq.DBFNTX&cdq. NEW
      SET INDEX TO CuAcct&comma. CuName&comma. CuZip
      ORDBAGNAME( 2 )               // Returns&colon. CuName
      ORDBAGNAME( 1 )               // Returns&colon. CuAcct
      ORDBAGNAME( 3 )               // Returns&colon. CuZip


     In this example&comma. Customer.cdx contains three orders named
      CuAcct&comma. CuName&comma. CuZip&colon.

      USE Customer VIA &cdq.DBFCDX&cdq. NEW
      SET INDEX TO Customer
      ORDBAGNAME( &cdq.CuAcct&cdq. )        // Returns&colon. Customer
      ORDBAGNAME( &cdq.CuName&cdq. )        // Returns&colon. Customer
      ORDBAGNAME( &cdq.CuZip&cdq. )         // Returns&colon. Customer
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=239.ORDBAGEXT():elink.
.br
:h1 res=242.ORDCONDSET()
:i1 id=ORDCONDSET().ORDCONDSET()
:p.ORDCONDSET()
:p.:hp2.Set the Condition and scope for an order
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDCONSET([<cForCondition>],
:ehp2.
:p.:hp2.[<bForCondition>],
:ehp2.
:p.:hp2.[<lAll>],
:ehp2.
:p.:hp2.[<bWhileCondition>],
:ehp2.
:p.:hp2.[<bEval>],
:ehp2.
:p.:hp2.[<nInterval>],
:ehp2.
:p.:hp2.[<nStart>],
:ehp2.
:p.:hp2.[<nNext>],
:ehp2.
:p.:hp2.[<nRecord>],
:ehp2.
:p.:hp2.[<lRest>],
:ehp2.
:p.:hp2.[<lDescend>],
:ehp2.
:p.:hp2.[<lAdditive>],
:ehp2.
:p.:hp2.[<lCurrent>],
:ehp2.
:p.:hp2.[<lCustom>],
:ehp2.
:p.:hp2.[<lNoOptimize>])
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cForCondition>:ehp2.   is a string that specifies the FOR condition for the order.  <bForCondition> is a code block that defines a FOR condition that  each record within the scope must meet in order to be processed. If  a record does not meet the specified condition,it is ignored and the  next  record is processed.Duplicate keys values are not added to the  index file when a FOR condition is Used.     

:p.:hp2.Returns
:ehp2.

:p.:hp2.Description
:ehp2.

:p.:hp2.Examples
:ehp2.



:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.
     ORDCONDSET() is CA-Clipper compliant     
:h1 res=243.ORDCREATE()
:i1 id=ORDCREATE().ORDCREATE()
:p.ORDCREATE()
:p.:hp2.Create an Order in an Order Bag
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDCREATE(<cOrderBagName>,[<cOrderName>],    <cExpKey>,
:ehp2.
:p.:hp2.[<bExpKey>], [<lUnique>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or extension.  If you do not include the extension as part  of <cOrderBagName> HARBOUR uses the default extension of the current  RDD.       

      :hp2. <cOrderName>:ehp2.   is the name of the Order to be created.      

      Note:  Although both <cOrderBagName> and <cOrderName> are both optional, at least one of them must be specified.       

      :hp2. <cExpKey>:ehp2.   is an expression that returns the key value to place in the Order for each record in the current work area.  <cExpKey> can  represent a character, date, logical, or numeric data type.  The maximum  length of the index key expression is determined by the database driver.       

      :hp2. <bExpKey>:ehp2.   is a code block that evaluates to a key value that is placed in the Order for each record in the current work area.  If you do  not supply <bExpKey>, it is macro-compiled from <cExpKey>.       

      :hp2. <lUnique>:ehp2.   is an optional logical value that specifies whether a unique Order is to be created.  If <lUnique> is omitted, the current  global _SET_UNIQUE setting is used.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDCREATE():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
    ORDCREATE() is an Order management function that creates an Order in the  current work area.  It works like DBCREATEINDEX() except that it lets  you create Orders in RDDs that recognize multiple-Order Bags.  ORDCREATE() supersedes the DBCREATEINDEX() function because of this  capability&comma. and is the preferred function.       

    The active RDD determines the Order capacity of an Order Bag.  The  default  DBFNTX and the DBFNDX drivers only support single-Order Bags&comma.  while other RDDs may support multiple-Order Bags (e.g.&comma. the DBFCDX and  DBFMDX drivers).       

    In RDDs that support production or structural indexes (e.g.&comma. DBFCDX&comma.  DBFMDX)&comma. if you specify a Tag but do not specify an Order Bag&comma. the Tag is  created and added to the index.  If no production or structural index  exists&comma. it will be created and the Tag will be added to it.  When using  RDDs that support multiple Order Bags&comma. you must explicitly SET ORDER (or  ORDSETFOCUS()) to the desired controlling Order.  If you do not specify  a controlling Order&comma. the data file will be viewed in natural Order.       

    If <cOrderBagName> does not exist&comma. it is created in accordance with the  RDD in the current or specified work area.       

   If <cOrderBagName> exists and the RDD specifies that Order Bags can only  contain a single Order&comma. <cOrderBagName> is erased and the new Order is  added to the Order List in the current or specified work area.       

    If <cOrderBagName> exists and the RDD specifies that Order Bags can  contain multiple Tags&comma. <cOrderName> is created if it does not already  exist&comma. otherwise <cOrderName> is replaced in <cOrderBagName> and the  Order is added to the Order List in the current or specified work area.     

:p.:hp2.Examples
:ehp2.

     The following example demonstrates ORDCREATE() with the DBFNDX
      driver&colon.

      USE Customer VIA &cdq.DBFNDX&cdq. NEW
      ORDCREATE( &cdq.CuAcct&cdq.&comma.&comma. &cdq.Customer->Acct&cdq. )


     The following example demonstrates ORDCREATE() with the
      default DBFNTX driver&colon.

      USE Customer VIA &cdq.DBFNTX&cdq. NEW
      ORDCREATE( &cdq.CuAcct&cdq.&comma. &cdq.CuAcct&cdq.&comma. &cdq.Customer->Acct&cdq.&comma. ;
            {|| Customer->Acct } )

     The following example demonstrates ORDCREATE() with the FoxPro
      driver&comma. DBFCDX&colon.

      USE Customer VIA &cdq.DBFCDX&cdq. NEW
      ORDCREATE( &cdq.Customer&cdq.&comma. &cdq.CuAcct&cdq.&comma. &cdq.Customer->Acct&cdq. )

     This example creates the Order &cdq.CuAcct&cdq. and adds it to the
      production index (Order Bag) &cdq.Customer&cdq..  The production index &comma. will
      be created if it doesn't exist&colon.

      USE Customer VIA &cdq.DBFMDX&cdq. NEW
      ORDCREATE( &comma. &cdq.CuAcct&cdq.&comma. &cdq.Customer->Acct&cdq. )

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=244.DBCREATEINDEX():elink.
.br
:h1 res=245.ORDDESTROY()
:i1 id=ORDDESTROY().ORDDESTROY()
:p.ORDDESTROY()
:p.:hp2.Remove a specified Order from an Order Bag
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDDESTROY(<cOrderName> [, <cOrderBagName> ]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOrderName>:ehp2.   is the name of the Order to be removed from the current or specified work area.       

      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <cOrderBagName> HARBOUR uses the default  extension of the current RDD.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDDESTROY():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
    ORDDESTROY() is an Order management function that removes a specified  Order from multiple-Order Bags.       

    The active RDD determines the Order capacity of an Order Bag.  The  default DBFNTX and the DBFNDX drivers only support single-Order Bags&comma.  while other RDDs may support multiple-Order Bags (e.g.&comma. the DBFCDX and  DBPX drivers).       

    Note&colon.  RDD suppliers may define specific behaviors for this command.       

    Warning!  ORDDESTROY() is not supported for DBFNDX and DBFNTX.     

:p.:hp2.Examples
:ehp2.

     This example demonstrates ORDDESTROY() with the FoxPro driver&comma.
      DBFCDX&colon.

      USE Customer VIA &cdq.DBFCDX&cdq. NEW
      SET INDEX TO Customer&comma. CustTemp
      ORDDESTROY( &cdq.CuAcct&cdq.&comma. &cdq.Customer&cdq. )

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=243.ORDCREATE():elink.
.br
:h1 res=246.ORDFOR()
:i1 id=ORDFOR().ORDFOR()
:p.ORDFOR()
:p.:hp2.Return the FOR expression of an Order
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDFOR(<cOrderName> | <nOrder>
:ehp2.
:p.:hp2.[, <cOrderBagName>]) --> cForExp
:ehp2.

      :hp2. <cOrderName>:ehp2.   is the name of the target Order, whose cForExp is sought.       

      :hp2. <nOrder>:ehp2.   is an integer that identifies the position in the Order List of the target Order whose cForExp is sought.       

      :hp2. <cOrderBagName>:ehp2.   is the name of an Order Bag containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <cOrderBagName> HARBOUR uses the default  extension of the current RDD.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDFOR():ehp2.   returns a character expression, cForExp, that represents the FOR condition of the specified Order.  If the Order was not created  using the FOR clause the return value will be an empty string ("").  If  the database driver does not support the FOR condition, it may either  return an empty string ("") or raise an "unsupported function" error,  depending on the driver.     

:p.:hp2.Description
:ehp2.
    ORDFOR() is an Order management function that returns the character  string&comma. cForExp&comma. that represents the logical FOR condition of the Order&comma.  <cOrderName> or <nOrder>.     

:p.:hp2.Examples
:ehp2.

     This example retrieves the FOR condition from an Order&colon.

      USE Customer NEW
      INDEX ON  Customer->Acct ;
         TO  Customer          ;
         FOR Customer->Acct > &cdq.AZZZZZ&cdq.

      ORDFOR( &cdq.Customer&cdq. )      // Returns&colon. Customer->Acct > &cdq.AZZZZZ&cdq.

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=247.ORDKEY():elink.
.br
:link reftype=hd res=243.ORDCREATE():elink.
.br
:link reftype=hd res=248.ORDNAME():elink.
.br
:link reftype=hd res=249.ORDNUMBER():elink.
.br
:h1 res=247.ORDKEY()
:i1 id=ORDKEY().ORDKEY()
:p.ORDKEY()
:p.:hp2.Return the key expression of an Order
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDKEY(<cOrderName> | <nOrder>
:ehp2.
:p.:hp2.[, <cOrderBagName>]) --> cExpKey
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOrderName>:ehp2.   is the name of an Order, a logical ordering of a database.       

      :hp2. <nOrder>:ehp2.   is an integer that identifies the position in the Order List of the target Order whose cExpKey is sought.       

      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <cOrderBagName> HARBOUR uses the default  extension of the current RDD.     

:p.:hp2.Returns
:ehp2.
      Returns  a character string, cExpKey.    

:p.:hp2.Description
:ehp2.
    ORDKEY() is an Order management function that returns a character  expression&comma. cExpKey&comma. that represents the key expression of the specified  Order.       

    You may specify the Order by name or with a number that represents its  position in the Order List.  Using the Order name is the preferred  method.       

    The active RDD determines the Order capacity of an Order Bag.  The  default DBFNTX and the DBFNDX drivers only support single-Order Bags&comma.  while other RDDs may support multiple-Order Bags (e.g.&comma. the DBFCDX and  DBFMDX drivers).     

:p.:hp2.Examples
:ehp2.

     This example retrieves the index expression from an Order&colon.

      USE Customer NEW
      INDEX ON  Customer->Acct  ;
         TO  Customer           ;
         FOR Customer->Acct > &cdq.AZZZZZ&cdq.

      ORDKEY( &cdq.Customer&cdq. )      // Returns&colon. Customer->Acct

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=246.ORDFOR():elink.
.br
:link reftype=hd res=248.ORDNAME():elink.
.br
:link reftype=hd res=249.ORDNUMBER():elink.
.br
:h1 res=250.ORDLISTADD()
:i1 id=ORDLISTADD().ORDLISTADD()
:p.ORDLISTADD()
:p.:hp2.Add Orders to the Order List
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDLISTADD(<cOrderBagName>
:ehp2.
:p.:hp2.[, <cOrderName>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <cOrderBagName> HARBOUR uses the default  extension of the current RDD.       

      :hp2. <cOrderName>:ehp2.   the name of the specific Order from the Order Bag to be added to the Order List of the current work area.  If you do not specify  <cOrderName>, all orders in the Order Bag are added to the Order List of  the current work area.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDLISTADD():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
    ORDLISTADD() is an Order management function that adds the contents of  an Order Bag &comma. or a single Order in an Order Bag&comma. to the Order List.  This function lets you extend the Order List without issuing a SET INDEX  command that&comma. first&comma. clears all the active Orders from the Order List.       

    Any Orders already associated with the work area continue to be active.  If the newly opened Order Bag contains the only Order associated with  the work area&comma. it becomes the controlling Order; otherwise&comma. the  controlling Order remains unchanged.       

    After the new Orders are opened&comma. the work area is positioned to the  first logical record in the controlling Order.       

    ORDLISTADD() is similar to the SET INDEX command or the INDEX clause of  the USE command&comma. except that it does not clear the Order List prior to  adding the new order(s).       

    ORDLISTADD() supersedes the DBSETINDEX() function.       

    The active RDD determines the Order capacity of an Order Bag.  The  default  DBFNTX and the DBFNDX drivers only support single-Order Bags&comma.  while other RDDs may support multiple-Order Bags (e.g.&comma. the DBFCDX and  DBPX drivers).  When using RDDs that support multiple Order Bags&comma. you  must explicitly SET ORDER (or ORDSETFOCUS()) to the desired controlling  Order.  If you do not specify a controlling Order&comma. the data file will be  viewed in natural Order.     

:p.:hp2.Examples
:ehp2.

     In this example Customer.cdx contains three orders&comma. CuAcct&comma.
      CuName&comma. and CuZip.  ORDLISTADD() opens Customer.cdx but only uses the
      order named CuAcct&colon.

      USE Customer VIA &cdq.DBFCDX&cdq. NEW
      ORDLISTADD( &cdq.Customer&cdq.&comma. &cdq.CuAcct&cdq. )

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=251.DBSETINDEX():elink.
.br
:h1 res=252.ORDLISTCLEAR()
:i1 id=ORDLISTCLEAR().ORDLISTCLEAR()
:p.ORDLISTCLEAR()
:p.:hp2.Clear the current Order List
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDLISTCLEAR() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. ORDLISTCLEAR():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
    ORDLISTCLEAR() is an Order management function that removes all Orders  from the Order List for the current or aliased work area.  When you are  done&comma. the Order List is empty.       

   This function supersedes the function DBCLEARINDEX().       

:p.:hp2.Examples
:ehp2.

   USE Sales NEW
   SET INDEX TO SaRegion&comma. SaRep&comma. SaCode
   .
   . < statements >
   .
   ORDLISTCLEAR()      // Closes all the current indexes

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=253.DBCLEARINDEX():elink.
.br
:h1 res=254.ORDLISTREBUILD()
:i1 id=ORDLISTREBUILD().ORDLISTREBUILD()
:p.ORDLISTREBUILD()
:p.:hp2.Rebuild all Orders in the Order List of the current work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDLISTREBUILD() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. ORDLISTREBUILD():ehp2.   always returns NIL.    

:p.:hp2.Description
:ehp2.
    ORDLISTREBUILD() is an Order management function that rebuilds all the  orders in the current or aliased Order List.       

    To only rebuild a single Order use the function ORDCREATE().       

    Unlike ORDCREATE()&comma. this function rebuilds all Orders in the Order List.  It is equivalent to REINDEX.       

:p.:hp2.Examples
:ehp2.

   USE Customer NEW
   SET INDEX TO CuAcct&comma. CuName&comma. CuZip
   ORDLISTREBUILD()     // Causes CuAcct&comma. CuName&comma. CuZip to
                        // be rebuilt


:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=243.ORDCREATE():elink.
.br
:h1 res=248.ORDNAME()
:i1 id=ORDNAME().ORDNAME()
:p.ORDNAME()
:p.:hp2.Return the name of an Order in the Order List
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDNAME(<nOrder>[,<cOrderBagName>])
:ehp2.
:p.:hp2.--> cOrderName
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nOrder>:ehp2.   is an integer that identifies the position in the Order List of the target Order whose database name is sought.       

      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <xcOrderBagName> HARBOUR uses the default  extension of the current RDD.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDNAME():ehp2.   returns the name of the specified Order in the current Order List or the specified Order Bag if opened in the Current Order list.     

:p.:hp2.Description
:ehp2.
    ORDNAME() is an Order management function that returns the name of the  specified Order in the current Order List.       

    If <cOrderBagName> is an Order Bag that has been emptied into the  current Order List&comma. only those Orders in the Order List that correspond  to <cOrderBagName> Order Bag are searched.       

    The active RDD determines the Order capacity of an Order Bag.  The  default DBFNTX and the DBFNDX drivers only support single-Order Bags&comma.  while other RDDs may support multiple-Order Bags (e.g.&comma. the DBFCDX and  DBPX drivers).     

:p.:hp2.Examples
:ehp2.

     This example retrieves the name of an Order using its position
      in the order list&colon.

      USE Customer NEW
      SET INDEX TO CuAcct&comma. CuName&comma. CuZip
      ORDNAME( 2 )                        // Returns&colon. CuName

     This example retrieves the name of an Order given its position
      within a specific Order Bag in the Order List&colon.

      USE Customer NEW
      SET INDEX TO Temp&comma. Customer
      // Assume Customer contains CuAcct&comma. CuName&comma. CuZip
      ORDNAME( 2&comma. &cdq.Customer&cdq. )            // Returns&colon. CuName

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=246.ORDFOR():elink.
.br
:link reftype=hd res=247.ORDKEY():elink.
.br
:link reftype=hd res=249.ORDNUMBER():elink.
.br
:h1 res=249.ORDNUMBER()
:i1 id=ORDNUMBER().ORDNUMBER()
:p.ORDNUMBER()
:p.:hp2.Return the position of an Order in the current Order List
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDNUMBER(<cOrderName>
:ehp2.
:p.:hp2.[, <cOrderBagName>]) --> nOrderNo
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cOrderName>:ehp2.   the name of the specific Order whose position in the Order List is sought.       

      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <cOrderBagName> HARBOUR uses the default  extension of the current RDD.     

:p.:hp2.Returns
:ehp2.
      Returns  nOrderNo, an integer that represents the position of the specified Order in the Order List.     

:p.:hp2.Description
:ehp2.
    ORDNUMBER() is an Order management function that lets you determine the  position in the current Order List of the specified Order.  ORDNUMBER()  searches the Order List in the current work area and returns the  position of the first Order that matches <cOrderName>.    If  <cOrderBagName> is the name of an Order Bag newly emptied into the  current Order List&comma. only those orders in the Order List that have been  emptied from <cOrderBagName> are searched.       

    If <cOrderName> is not found ORDNUMBER() raises a recoverable runtime  error.       

    The active RDD determines the Order capacity of an Order Bag.  The  default DBFNTX driver only supports single-Order Bags&comma. while other RDDs  may support multiple-Order Bags (e.g.&comma. the DBFCDX and DBPX drivers).     

:p.:hp2.Examples
:ehp2.

   USE Customer VIA &cdq.DBFNTX&cdq. NEW
   SET INDEX TO CuAcct&comma. CuName&comma. CuZip
   ORDNUMBER( &cdq.CuName&cdq. )            // Returns&colon. 2

:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

.br
See Also&colon.
:link reftype=hd res=255.INDEXORD():elink.
.br
:h1 res=256.ORDSETFOCUS()
:i1 id=ORDSETFOCUS().ORDSETFOCUS()
:p.ORDSETFOCUS()
:p.:hp2.Set focus to an Order in an Order List
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ORDSETFOCUS([<cOrderName> | <nOrder>]
:ehp2.
:p.:hp2.[,<cOrderBagName>]) --> cPrevOrderNameInFocus
:ehp2.

      :hp2. <cOrderName>:ehp2.   is the name of the selected Order, a logical ordering of a database.  ORDSETFOCUS() ignores any invalid values of  <cOrderName>.       

      :hp2. <nOrder>:ehp2.   is a number representing the position in the Order List of the selected Order.       

      :hp2. <cOrderBagName>:ehp2.   is the name of a disk file containing one or more Orders.  You may specify <cOrderBagName> as the filename with or without  the pathname or appropriate extension.  If you do not include the  extension as part of <cOrderBagName> HARBOUR uses the default  extension of the current RDD.     

:p.:hp2.Returns
:ehp2.
      :hp2. ORDSETFOCUS():ehp2.   returns the Order Name of the previous controlling Order.    

:p.:hp2.Description
:ehp2.
    ORDSETFOCUS() is an Order management function that returns the Order  Name of the previous controlling Order and optionally sets the focus to  an new Order.       

    If you do not specify <cOrderName> or <nOrder>&comma. the name of the  currently controlling order is returned and the controlling order  remains unchanged.       

    All Orders in an Order List are properly updated no matter what  <cOrderName> is the controlling Order.  After a change of controlling  Orders&comma. the record pointer still points to the same record.       

    The active RDD determines the Order capacity of an Order Bag.  The  default DBFNTX driver only supports single-Order Bags&comma. while other RDDs  may support multiple-Order Bags (e.g.&comma. the DBFCDX and DBPX drivers).       

    ORDSETFOCUS() supersedes INDEXORD().     

:p.:hp2.Examples
:ehp2.



   USE Customer VIA &cdq.DBFNTX&cdq. NEW
   SET INDEX TO CuAcct&comma. CuName&comma. CuZip
   ? ORDSETFOCUS( &cdq.CuName&cdq. )        // Displays&colon. &cdq.CuAcct&cdq.
   ? ORDSETFOCUS()                  // Displays&colon. &cdq.CuName&cdq.
:p.:hp2.Tests
:ehp2.



:p.:hp2.Status
:ehp2.
   Started
:p.:hp2.Compliance
:ehp2.

:h1 res=240.INDEXEXT()
:i1 id=INDEXEXT().INDEXEXT()
:p.INDEXEXT()
:p.:hp2.Returns the file extension of the index module used in an application
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.INDEXEXT() --> <cExtension>
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cExtension>:ehp2.     Current driver file extension    

:p.:hp2.Description
:ehp2.
     This function returns a string that tells what indexes are to be used  or will be created in the compiled application.The default value is  &cdq..NTX&cdq.. This is controled by the particular database driver that is  linked with the application&comma..     

:p.:hp2.Examples
:ehp2.

      IF INDEXEXT()==&cdq..NTX&cdq.
          ? &cdq.Current driver being used is DBFNTX&cdq.
      Endif
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=257.INDEXKEY():elink.
.br
:link reftype=hd res=255.INDEXORD():elink.
.br
:h1 res=257.INDEXKEY()
:i1 id=INDEXKEY().INDEXKEY()
:p.INDEXKEY()
:p.:hp2.Yields the key expression of a specified index file.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.INDEXKEY(<nOrder>) --> <cIndexKey>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nOrder>:ehp2.    Index order number    

:p.:hp2.Returns
:ehp2.
      :hp2. <cIndexKey>:ehp2.     The index key    

:p.:hp2.Description
:ehp2.
     This function returns a character string stored in the header of the  index file       

     The index key is displayed for an index file that is designated by  <nOrder>&comma.its position in the USE...INDEX or SET INDEX TO command in  the currently selected or designated work area.If there is no  corresnponding index key at the specified order position&comma.a NULL  byte will be returned.     

:p.:hp2.Examples
:ehp2.

      USE TESTS NEW INDEX TEST1
      ? INDEXKEY(1)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=255.INDEXORD():elink.
.br
:h1 res=255.INDEXORD()
:i1 id=INDEXORD().INDEXORD()
:p.INDEXORD()
:p.:hp2.Returns the numeric position of the controlling index.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.INDEXORD() --> <nPosition>
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nPosition>:ehp2.     Ordinal position of a controling index    

:p.:hp2.Description
:ehp2.
     The INDEXORD() function returns the numeric position of the current  controlling index in the selected or designated work area.  A returned value of 0 indicated that no active index is controlling  the database&comma.which therefore is in the natural order.     

:p.:hp2.Examples
:ehp2.

      USE TESTS NEW INDEX TEST1
      IF INDEXORD()>0
          ? &cdq.Current order is &cdq.&comma.INDEXORD()
      Endif
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=257.INDEXKEY():elink.
.br
:h1 res=221.AFIELDS()
:i1 id=AFIELDS().AFIELDS()
:p.AFIELDS()
:p.:hp2.Fills referenced arrays with database field information
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AFields(<aNames>[,<aTypes>][,<aLen>][,<aDecs>]) --> <nFields>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <aNames>:ehp2.    Array of field names      

      :hp2. <aTypes>:ehp2.    Array of field names      

      :hp2. <aLens>:ehp2.    Array of field names      

      :hp2. <aDecs>:ehp2.    Array of field names    

:p.:hp2.Returns
:ehp2.
      :hp2. <nFields>:ehp2.   Number od fields in a database or work area    

:p.:hp2.Description
:ehp2.
     This function will fill a series of arrays with field  names&comma.field types&comma.field lenghts&comma. and number of field  decimal positions for the currently selected or designed  database. Each array parallels the different descriptors  of a file's structure.The first array will consist of the  names of the fields in the current work area.All other arrays  are optional and will be filled with the corrensponding data.  This function will return zero if no parameters are specified  or if no database is avaliable in the current work area.Otherwise&comma.  the number of fields or the lenght of the shortest array argument&comma.  witchever is smaller&comma. will be returned.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
         LOCAL aNames&colon.={}&comma.aTypes&colon.={}&comma.aLens&colon.={}&comma.aDecs&colon.={}&comma.nFields&colon.=0

         USE Test

         dbGoTop()
         nFields&colon.=aFields(aNames&comma.aTypes&comma.aLens&comma.aDecs)

         ? &cdq.Number of fields&cdq.&comma. nFields

         RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     AFIELDS() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
:h1 res=206.ALIAS()
:i1 id=ALIAS().ALIAS()
:p.ALIAS()
:p.:hp2.Returns the alias name of a work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.Alias([<nWorkArea>]) --> <cWorkArea>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nWorkArea>:ehp2.   Number of a work area    

:p.:hp2.Returns
:ehp2.
      :hp2. <cWorkArea>:ehp2.   Name of alias    

:p.:hp2.Description
:ehp2.
     This function returns the alias of the work area indicated by <nWorkArea>  If <nWorkArea> is not provided&comma. the alias of the current work area is  returned.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()

      USE Test
      select 0
      qOut( IF(Alias()==&cdq.&cdq.&comma.&cdq.No Name&cdq.&comma.Alias()))
      Test->(qOut(Alias())
      qOut(Alias(1))

      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ALIAS() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=205.DBF():elink.
.br
:h1 res=227.BOF()
:i1 id=BOF().BOF()
:p.BOF()
:p.:hp2.Test for the beggining-of-file condition
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.BOF() --> <lBegin>
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. BOF():ehp2.   Logical true (.T.) or false (.F.)    

:p.:hp2.Description
:ehp2.
     This function determines if the beggining of the file marker has been  reached. If so&comma. the function will return a logical true (.T.); otherwise&comma.  a logical false(.F.) will be returned.  By default&comma. BOF() will apply to the currently selected database unless  the function is preceded by an alias     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
        USE Tests NEW
        DBGOTOP()
        ? &cdq.Is Eof()&cdq.&comma.EOF()
        DBGOBOTTOM()
        ? &cdq.Is Eof()&cdq.&comma.EOF()
        USE
     RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     BOF() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=220.FOUND():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:h1 res=259.ZAP
:i1 id=ZAP.ZAP
:p.ZAP
:p.:hp2.Remove all records from the current database file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ZAP
:ehp2.

:p.:hp2.Description
:ehp2.
     This command removes all of the records from the database in the  current work area.This operation also updates any index file in  use at the time of this operation.In addition&comma. this command removes  all items within an associated memo file.  In a network enviroment&comma.any file that is about to be ZAPped must  be used exclusively.     

:p.:hp2.Examples
:ehp2.

      USE Tests NEW index Tests
      ZAP
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=260.DELETE:elink.
.br
:link reftype=hd res=261.PACK:elink.
.br
:link reftype=hd res=262.USE:elink.
.br
:h1 res=263.DELETED()
:i1 id=DELETED().DELETED()
:p.DELETED()
:p.:hp2.Tests the record's deletion flag.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DELETED() --> lDeleted
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. DELETED():ehp2.   return a logical true (.T.) or false (.F.).    

:p.:hp2.Description
:ehp2.
     This function returns a logical true (.T.) is the current record in the  selected or designated work area ha ben marked for deletion.If not&comma. the  function will return a logical false (.F.).     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Test New
      DBGOTO()
      DBDELETE()
      ? &cdq.Is Record Deleted&cdq.&comma.Test->(DELETED())
      DBRECALL()
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=222.DBDELETE():elink.
.br
:h1 res=219.EOF()
:i1 id=EOF().EOF()
:p.EOF()
:p.:hp2.Test for end-of-file condition.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.EOF() --> <lEnd>
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <lEnd>:ehp2.   A logical true (.T.) or false (.F.)    

:p.:hp2.Description
:ehp2.
     This function determines if the end-of-file marker has been reached.  If it has&comma. the function will return a logical true (.T.); otherwise  a logical false (.F.) will be returnd     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
        USE Tests NEW
        DBGOTOP()
        ? &cdq.Is Eof()&cdq.&comma.EOF()
        DBGOBOTTOM()
        ? &cdq.Is Eof()&cdq.&comma.EOF()
        USE
     RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     EOF() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=227.BOF():elink.
.br
:link reftype=hd res=220.FOUND():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:h1 res=264.FCOUNT()
:i1 id=FCOUNT().FCOUNT()
:p.FCOUNT()
:p.:hp2.Counts the number of fields in an active database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FCOUNT() --> nFields
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <nFields>:ehp2.   Return the number of fields    

:p.:hp2.Description
:ehp2.
     This function returns the number of fields in the current or designated  work area.If no database is open in this work area&comma. the function will  return 0.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
        USE Tests NEW
        ? &cdq.This database have &cdq.&comma.Tests->(FCOUNT())&comma.&cdq.Fields&cdq.
        USE
      RETURN Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=265.FIELDNAME():elink.
.br
:link reftype=hd res=266.TYPE():elink.
.br
:h1 res=267.FIELDGET()
:i1 id=FIELDGET().FIELDGET()
:p.FIELDGET()
:p.:hp2.Obtains the value  of a specified field
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDGET(<nField>) --> ValueField
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nField>:ehp2.   Is the numeric field position    

:p.:hp2.Returns
:ehp2.
      :hp2. <ValueField>:ehp2.    Any expression    

:p.:hp2.Description
:ehp2.
     This function returns the value of the field at the <nField>th location  in the selected or designed work area.If the value in <nField> does not  correspond to n avaliable field position in this work area&comma. the function  will return a NIL data type.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Test NEW
      ? Test->(FieldGet(1))
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper Compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=268.FIELDPUT():elink.
.br
:h1 res=265.FIELDNAME()
:i1 id=FIELDNAME().FIELDNAME()
:p.FIELDNAME()
:p.:hp2.Return the name of a field at a numeric field location.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDNAME/FIELD(<nPosition>) --> cFieldName
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nPosition>:ehp2.   Field order in the database.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cFieldName>:ehp2.   returns the field name.    

:p.:hp2.Description
:ehp2.
     This function return the name of the field at the <nPosition>th position.  If the numeric value passed to this function does not correspond to an  existing field in the designated or selected work area&comma.this function  will return a NULL byte.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
        LOCAL x
        USE Tests NEW
        FOR x &colon.= 1 to Tests->(FCOUNT())
          ? &cdq.Field Name&cdq.&comma.FieldName(x)
        NEXT
        USE
      RETURN Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=11.DBSTRUCT():elink.
.br
:link reftype=hd res=264.FCOUNT():elink.
.br
:link reftype=hd res=8.LEN():elink.
.br
:link reftype=hd res=269.VALTYPE():elink.
.br
:h1 res=270.FIELDPOS()
:i1 id=FIELDPOS().FIELDPOS()
:p.FIELDPOS()
:p.:hp2.Return the ordinal position of a field.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDPOS(<cFieldName>) --> nFieldPos
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFieldName>:ehp2.   Name of a field.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nFieldPos>:ehp2.   is ordinal position of the field.    

:p.:hp2.Description
:ehp2.
     This function return the ordinal position of the specified field <cField>  in the current or aliased work areaIf there isn't  field under the name  of <cField> or of no database is open in the selected work area&comma. the func-  tion will return a 0.     

:p.:hp2.Examples
:ehp2.

      FUNCTION Main()
      USE Test NEW
      ? Test->(FIELDPOS(&cdq.ID&cdq.))
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=267.FIELDGET():elink.
.br
:link reftype=hd res=268.FIELDPUT():elink.
.br
:h1 res=268.FIELDPUT()
:i1 id=FIELDPUT().FIELDPUT()
:p.FIELDPUT()
:p.:hp2.Set the value of a field variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDPUT(<nField>, <expAssign>) --> ValueAssigned
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nField>:ehp2.   The field numeric position      

      :hp2. <expAssign>:ehp2.   Expression to be assigned to the specified field    

:p.:hp2.Returns
:ehp2.
      :hp2. <ValueAssigned>:ehp2.   Any expression    

:p.:hp2.Description
:ehp2.
     This function assings the value in <expAssing> to the <nField>th  field in the current or designated work area.If the operation is  successful&comma.the return value of the function will be the same value  assigned to the specified field.If the operation is not successful&comma.  the function will return a NIL data type     

:p.:hp2.Examples
:ehp2.

      USE Tests New
      FIELDPUT(1&comma.&cdq.Mr. Jones&cdq.)
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible.     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=267.FIELDGET():elink.
.br
:h1 res=232.FLOCK()
:i1 id=FLOCK().FLOCK()
:p.FLOCK()
:p.:hp2.Locks a file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FLOCK() --> lSuccess
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <lSuccess>:ehp2.   A true (.T.) value, if the lock was successful;otherwise false (.F.)     

:p.:hp2.Description
:ehp2.
     This function returns a logical true (.T.0 if a file lock is  attempted and is successfully placed on the current or designated  database.This function will also unlock all records locks placed  by the same network station.     

:p.:hp2.Examples
:ehp2.

      USE Tests New
      IF FLOCK()
         SUM Tests->Ammount
      ENDIF
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=233.RLOCK():elink.
.br
:h1 res=220.FOUND()
:i1 id=FOUND().FOUND()
:p.FOUND()
:p.:hp2.Determine the success of a previous search operation.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FOUND() --> lSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <lSuccess>:ehp2.   A logical true (.T.) is successful;otherwise, false (.F.)    

:p.:hp2.Description
:ehp2.
     This function is used to test if the previous SEEK&comma.LOCATE&comma.CONTINUE&comma.  or FIND operation was successful.Each wrk area has its own FOUND()  flag&comma.so that a FOUND() condition may be tested in unselected work  areas by using an alias.     

:p.:hp2.Examples
:ehp2.

      nId&colon.=100
      USE Tests NEW INDEX Tests
      SEEK nId
      IF FOUND()
        ? Tests->Name
      ENDIF
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=219.EOF():elink.
.br
:h1 res=271.HEADER()
:i1 id=HEADER().HEADER()
:p.HEADER()
:p.:hp2.Return the length of a database file header
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HEADER() --> nBytes
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <nBytes>:ehp2.   The numeric size of a database file header in bytes    

:p.:hp2.Description
:ehp2.
     This function returns the number of bytes in the header of the  selected database ot the database in the designated work area.       

     If used in conjunction with the LASTREC()&comma.RECSIZE() and DISKSPACE()  functions&comma.this functions is capable of implementing a backup and  restore routine.     

:p.:hp2.Examples
:ehp2.

      USE Tests New
      ? Header()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=72.DISKSPACE():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:link reftype=hd res=272.RECSIZE():elink.
.br
:h1 res=258.LASTREC()
:i1 id=LASTREC().LASTREC()
:p.LASTREC()
:p.:hp2.Returns the number of records in an active work area or database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LASTREC() | RECCOUNT()* --> nRecords
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <nRecords:ehp2.   > The number of records    

:p.:hp2.Description
:ehp2.
     This function returns the number of records present in the database  in the selected or designated work area.If no records are present  the value of this function will be 0.Additionaly&comma.if no database is  in use in the selected or designated work area&comma.this function will  return a 0 value as well.     

:p.:hp2.Examples
:ehp2.

      USE Tests NEW
      ? LASTREC()&comma. RECCOUNT()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compatible     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=219.EOF():elink.
.br
:h1 res=273.LUPDATE()
:i1 id=LUPDATE().LUPDATE()
:p.LUPDATE()
:p.:hp2.Yields the date the database was last updated.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LUPDATE() --> dModification
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. <dModification>:ehp2.    The date of the last modification.    

:p.:hp2.Description
:ehp2.
     This function returns the date recorded by the OS when the selected  or designated database was last written to disk.This function will  only work for those database files in USE.     

:p.:hp2.Examples
:ehp2.

      Function Main

      Use Tests New
      ? Lupdate() // 04/25/2000
      Use
      Return Nil
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=265.FIELDNAME():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:link reftype=hd res=272.RECSIZE():elink.
.br
:h1 res=274.NETERR()
:i1 id=NETERR().NETERR()
:p.NETERR()
:p.:hp2.Tests the success of a network function
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.NETERR([<lNewError>]) --> lError
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lNewError>:ehp2.   Is a logical Expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <lError>:ehp2.   A value based on the success of a network operation or function.     

:p.:hp2.Description
:ehp2.
     This function return a logical true (.T.) is a USE&comma.APPEND BLANK&comma. or  a USE...EXCLUSIVE command is issue and fails in a network enviroment.  In the case of USE and USE...EXCLUSIVE commands&comma.a NETERR() value  of .T. would be returned if another node of the network has the  exclusive use of a file.And the case of the APPEND BLANK command&comma.  NETERR() will return a logical true (.T.) if the file or record  is locked by another node or the value of LASTREC() has been advanced  The value of NETERR() may be changed via the value of <lNewError>.  This allow the run-time error-handling system to control the way  certains errors are handled.     

:p.:hp2.Examples
:ehp2.

      USE TEST NEW Index Test
      If !NetErr()
          Seek Test->Name=&cdq.HARBOUR&cdq.
          If Found()
             ? Test->Name
          Endif
      Endif
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=232.FLOCK():elink.
.br
:link reftype=hd res=233.RLOCK():elink.
.br
:h1 res=275.RECCOUNT()
:i1 id=RECCOUNT().RECCOUNT()
:p.RECCOUNT()
:p.:hp2.Counts the number of records in a database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RECCOUNT()* | LASTREC() --> nRecords
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nRecords>:ehp2.    The number of records    

:p.:hp2.Description
:ehp2.
     This function returns the number of records present in the database  in the selected or designated work area.If no records are present  the value of this function will be 0.Additionaly&comma.if no database is  in use in the selected or designated work area&comma.this function will  return a 0 value as well.     

:p.:hp2.Examples
:ehp2.

      Use Test NEW
      USE Harbour NEW
      ? Reccount()
      ? Test->(RECCOUNT())
      CLOSE ALL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:link reftype=hd res=276.RECNO():elink.
.br
:link reftype=hd res=226.DBGOBOTTOM():elink.
.br
:h1 res=276.RECNO()
:i1 id=RECNO().RECNO()
:p.RECNO()
:p.:hp2.Returns the current record number or identity.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RECNO() --> Identity
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. RECNO():ehp2.   The record number or indentity    

:p.:hp2.Description
:ehp2.
     This function returns the position of the record pointer in the  currently selected ot designated work area.  If the database file is empty and if the RDD is the traditional .DBF  file&comma.the value of this function will be 1.     

:p.:hp2.Examples
:ehp2.

      USE Tests NEW
      DBGOTOP()
      RECNO()            // Returns 1
      DBGOTO(50)
      RECNO()            // Returns 50
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=230.DBGOTO():elink.
.br
:link reftype=hd res=229.DBGOTOP():elink.
.br
:link reftype=hd res=226.DBGOBOTTOM():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:link reftype=hd res=219.EOF():elink.
.br
:link reftype=hd res=227.BOF():elink.
.br
:h1 res=272.RECSIZE()
:i1 id=RECSIZE().RECSIZE()
:p.RECSIZE()
:p.:hp2.Returns the size of a single record in an active database.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RECSIZE() --> nBytes
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nBytes>:ehp2.   The record size.    

:p.:hp2.Description
:ehp2.
     This function returns the number os bytes used by a single record  in the currently selected or designated database file.If no database  is in use in this work area&comma.the return value from this function  will be 0.     

:p.:hp2.Examples
:ehp2.

      USE Tests NEW
      DBGOTOP()
      RECSIZE()            // Returns 1
      DBGOTO(50)
      RECSIZE()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=72.DISKSPACE():elink.
.br
:link reftype=hd res=265.FIELDNAME():elink.
.br
:link reftype=hd res=271.HEADER():elink.
.br
:link reftype=hd res=258.LASTREC():elink.
.br
:h1 res=233.RLOCK()
:i1 id=RLOCK().RLOCK()
:p.RLOCK()
:p.:hp2.Lock a record in a work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RLOCK() --> lSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      :hp2. RLOCK():ehp2.   True (.T.) if record lock is successful; otherwise, it returns false (.F.).     

:p.:hp2.Description
:ehp2.
     This function returns a logical true (.T.) if an attempt to lock a  specific record in a selected or designated work area is successful.  It will yield a false (.F.) if either the file or the desired record  is currently locked.  A record that is locked remains locked until another RLOCK() is issued  or until an UNLOCK command is executed.  On a Network enviroment the follow command need that the record is  locked&colon.       

     @...GET       

     DELETE (single record)       

     RECALL (single record)       

     REPLACE (single record)     

:p.:hp2.Examples
:ehp2.

      nId&colon.=10
      USE TestId INDEX TestId NEW
      IF TestId->(DBSEEK(nId))
         IF TestId->(RLOCK())
            DBDELETE()
         ENDIF
      ENDIF
      USE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=232.FLOCK():elink.
.br
:h1 res=237.SELECT()
:i1 id=SELECT().SELECT()
:p.SELECT()
:p.:hp2.Returns the work area number for a specified alias.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SELECT([<cAlias>]) --> nWorkArea
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cAlias>:ehp2.   is the target work area alias name.    

:p.:hp2.Returns
:ehp2.
      :hp2. SELECT():ehp2.   returns the work area number.    

:p.:hp2.Description
:ehp2.
     This function returns the work area number for the specified alias  name <cAlias>.If no parameter is specified&comma.the current work area will  be the return value of the function.     

:p.:hp2.Examples
:ehp2.

      USE TESTS NEW
      USE NAMES NEW
      cOldArea&colon.=SELECT(&cdq.NAMES&cdq.)
      select TEST
      LIST
      SELECT cOldArea
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=206.ALIAS():elink.
.br
:link reftype=hd res=277.USED():elink.
.br
:h1 res=277.USED()
:i1 id=USED().USED()
:p.USED()
:p.:hp2.Checks whether a database is in use in a work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.USED() --> lDbfOpen
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <lDbfOpen>:ehp2.   True is a database is Used;otherwise False    

:p.:hp2.Description
:ehp2.
     This function returns a logical true (.T.) if a database file is in  USE in the current or designated work area. If no alias is specified  along with this function &comma. it will default to the currently selected  work area.     

:p.:hp2.Examples
:ehp2.

      Use TESTS NEW
      USE Names New
      ? USED()    // .T.
      ? TESTS->(USED()) //.t.
      CLOSE
      ? USED()  // .F.
      Select TESTS
      ? USED() //.T.

:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-clipper Compliant     

:p.:hp2.Files
:ehp2.
     Library is rdd     
.br
See Also&colon.
:link reftype=hd res=206.ALIAS():elink.
.br
:link reftype=hd res=237.SELECT():elink.
.br
:h1 res=278.OVERVIEW
:i1 id=OVERVIEW.OVERVIEW
:p.OVERVIEW
:p.:hp2.HARBOUR Read me
:ehp2.

:p.:hp2.Description
:ehp2.

                       &colon.hp2. The Harbour project&colon.ehp2.    

&colon.hp2. ************************************************************************&colon.ehp2.    
&colon.hp2. *  This file contains information on obtaining&comma. installing&comma. and using  *&colon.ehp2.    
&colon.hp2. *  Harbour.  Please read it *completely* before asking for help.       *&colon.ehp2.    
&colon.hp2. ************************************************************************&colon.ehp2.    

Harbour is a free implementation of an xBase language compiler. It is  designed to be source code compatible with the CA-Clipper(r) compiler.  That means that if you've got some code that would compile using  CA-Clipper(r) then it should compile under Harbour. The Harbour-Project  web page is&colon.        
             &colon.hp2. http&colon.//www.Harbour-Project.org/&colon.ehp2.    


Status and other information is always available from the web site.  There is a Harbour mailing list. Harbour is still at a very early  stage of development&comma. so the mailing list is very much a Developers  only list&comma. although every body is welcome to join in the discussions.        

We would like you to join the Harbour development team. If you are  interested you may suscribe to our mailing list and start contributing  to this free public project.        

Please feel free to report all questions&comma. ideas&comma. suggestions&comma. fixes&comma.  code&comma. etc. you may need and want. With the help of all of you&comma. the Harbour  compiler and runtime libraries will become a reality very soon.        


&colon.hp2. What this distribution contains&colon.ehp2.    
===============================   

This distribution is a Source code only distribution. It does not contain  any executable files. Executable versions of Harbour are available from  the web site. Executable versions of Harbour DO NOT create runable  programs. Harbour at the moment produces C output code&comma. which must be  compiled with the Harbour Virtual Machine and the support libraries  in order to create a functioning program.        
Please test running Harbour against your Clipper source code and report  any problems that might occur.         

Very important&colon. The preprocessor functionality is not built in yet. So  you may test only Clipper language without preprocessor commands&comma. etc.        


&colon.hp2. Installation&colon.ehp2.    
------------   

1. Unzip with Harbour zip file using pkunzip or equivalent.   
        E.G. pkunzip -d build72.zip   
   This will create Harbour/ directory and all the relevant sub  directories.        

2. Compile Harbour using your C compiler. Make files for different  platforms are included in the <WHERE ARE THEY?> directory.        


&colon.hp2. --- COPYRIGHT ---&colon.ehp2.    

What copyright information do we have   


&colon.hp2. --- LICENCE ---&colon.ehp2.    

Information about the License for usage of Harbour is available in the  file LICENCE.TXT (when we have a license)        

&colon.hp2. --- DISCLAIMER ---&colon.ehp2.    

Participants of The Harbour Project assume no responsibility for errors or  omissions in these materials.        

&colon.hp2. THESE MATERIALS ARE PROVIDED &cdq.AS IS&cdq. WITHOUT WARRANTY OF ANY KIND&comma. EITHER  EXPRESS OR IMPLIED&comma. INCLUDING BUT NOT LIMITED TO&comma. THE IMPLIED WARRANTIES  OF MERCHANTABILITY&comma. FITNESS FOR A PARTICULAR PURPOSE&comma. OR NON-INFRINGEMENT.&colon.ehp2.         

Participants of The Harbour Project further do not warrant the accuracy or  completeness of the code&comma. information&comma. text&comma. output or any other items  contained within these materials. Participants of The Harbour Project  shall not be liable for any special&comma. direct&comma. indirect&comma. incidental&comma. or  consequential damages&comma. including without limitation&comma. lost revenues or  lost profits&comma. which may result from the use or mis-use of these materials.        

The information in The Harbour Project is subject to change without notice  and does not represent any future commitment by the participants of The  Harbour Project.           

The Harbour Project   

.br
See Also&colon.
:link reftype=hd res=279.License:elink.
.br
:h1 res=280.__SETCENTURY()
:i1 id=__SETCENTURY().__SETCENTURY()
:p.__SETCENTURY()
:p.:hp2.Set the Current Century
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__SETCENTURY([<lFlag> | <cOnOff> ] ) --> lPreviousValue
:ehp2.
:p.:hp2.Arguments
:ehp2.
      optional  <lFlag> or <cOnOff> (not case sensitive) .T. or "ON" to enable the century setting (4-digit years)  .F. or "OFF" to disable the century setting (2-digit years)     

:p.:hp2.Returns
:ehp2.
      Either  the current or previous century setting as a logical value    

:p.:hp2.Files
:ehp2.
     Library is rtl     
:h1 res=92.SET()
:i1 id=SET().SET()
:p.SET()
:p.:hp2.Changes or evaluated enviromental settings
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.Set(<nSet> [, <xNewSetting> [, <xOption> ] ] ) --> xPreviousSetting
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nSet>:ehp2.   Set Number      

      :hp2. <xNewSetting>:ehp2.   Any expression to assing a value to the seting      

      :hp2. <xOption>:ehp2.   Logical expression      

      :hp2. <nSet>:ehp2.              <xNewSetting>          <xOption>      

      :hp2. _SET_ALTERNATE:ehp2.     <lFlag> | <cOnOff>      

      If  enabled, QOUT() and QQOUT() write to the screen and to a file, provided that a file has been opened or created  with _SET_ALTFILE. If disabled, which is the default,  QOUT() and QQOUT() only write to the screen (and/or to  the PRINTFILE). Defaults to disabled.       

      :hp2. _SET_ALTFILE:ehp2.       <cFileName>             <lAdditive>      

      When  set, creates or opens file to write QOUT() and QQOUT() output to. If <lAdditive> is TRUE and the file  already exists, the file is opened and positioned at end  of file. Otherwise, the file is created. If a file is  already opened, it is closed before the new file is  opened or created (even if it is the same file). The  default file extension is ".txt". There is no default  file name. Call with an empty string to close the file.       

      :hp2. _SET_AUTOPEN:ehp2.       <lFlag> | <cOnOff>      

      TODO:  Document      

      :hp2. _SET_AUTORDER:ehp2.      <lFlag> | <cOnOff>      

      TODO:  Document      

      :hp2. _SET_AUTOSHARE:ehp2.     <lFlag> | <cOnOff>      

      TODO:  Document      

      :hp2. _SET_BELL:ehp2.          <lFlag> | <cOnOff>      

      When  enabled, the bell sounds when the last position of a GET is reached and/or when a GET validation fails.  Disabled by default.       

      :hp2. _SET_CANCEL:ehp2.        <lFlag> | <cOnOff>      

      When  enabled, which is the default, pressing Alt+C or Ctrl+Break terminates the program. When disabled, both  keystrokes can be read by INKEY(). Note: SET KEY has  precedence over SET CANCEL.       

      :hp2. _SET_COLOR:ehp2.         <cColorSet>      

      Sets  the current color scheme, using color pairs in the sequence "<standard>,<enhanced>,<border>,<background>,  <unselected>". Each color pair uses the format  "<foreground>/<background>". The color codes are space  or "N" for black, "B" for blue, "G" for green, "BG" for  Cyan, "R" for red, "RB" for magenta, "GR" for brown, "W"  for white, "N+" for gray, "B+" for bright blue, "G+" for  bright green, "BG+" for bright cyan, "R+" for bright red,  "RB+" for bright magenta, "GR+" for yellow, and "W+" for  bright white. Special codes are "I" for inverse video,  "U" for underline on a monochrome monitor (blue on a  color monitor), and "X" for blank. The default color is  "W/N,N/W,N,N,N/W".       

      :hp2. _SET_CONFIRM:ehp2.       <lFlag> | <cOnOff>      

      If  enabled, an exit key must be pressed to leave a GET. If disabled, which is the default, typing past the end  will leave a GET.       

      :hp2. _SET_CONSOLE:ehp2.       <lFlag> | <cOnOff>      

      If  enabled, which is the default, all screen output goes to the screen. When disabled, screen output is suppressed  (Note: This setting does not affect OUTSTD() or OUTERR()).       

      :hp2. _SET_CURSOR:ehp2.        <nCursorType>      

      If  enabled, which is the default, the cursor is displayed on screen. If disabled, the screen cursor is hidden.       

      :hp2. _SET_DATEFORMAT:ehp2.    <cDateFormat>      

      Sets  the default date format for display, date input, and date conversion. Defaults to American ("mm/dd/yy"). Other  formats include ANSI ("yy.mm.dd"), British ("dd/mm/yy"),  French ("dd/mm/yy"), German ("dd.mm.yy"), Italian  ("dd-mm-yy"), Japan ("yy/mm/dd"), and USA ("mm-dd-yy").  SET CENTURY modifies the date format. SET CENTURY ON  replaces the "y"s with "YYYY". SET CENTURY OFF replaces  the "y"s with "YY".       

      :hp2. _SET_DEBUG:ehp2.         <lStatus>      

      When  set to .t., pressing Alt+D activates the debugger. When set to .f., which is the default, Alt+D can be read  by INKEY(). (Also affected by AltD(1) and AltD(0))       

      :hp2. _SET_DECIMALS:ehp2.      <nNumberOfDecimals>      

      Sets  the number of decimal digits to use when displaying printing numeric values when SET FIXED is ON. Defaults to  2. If SET FIXED is OFF, then SET DECIMALS is only used to  determine the number of decimal digits to use after using  EXP(), LOG(), SQRT(), or division. Other math operations  may adjust the number of decimal digits that the result  will display. Note: This never affects the precision of  a number. Only the display format is affected.       

      :hp2. _SET_DEFAULT:ehp2.       <cDefaultDirectory>      

      Sets  the default directory in which to open, create and check for files. Defaults to current directory (blank).       

      :hp2. _SET_DELETED:ehp2.       <lFlag> | <cOnOff>      

      If  enabled, deleted records will be processed.  disabled, which is the default, deleted records will  be ignored.       

      :hp2. _SET_DELIMCHARS:ehp2.    <cDelimiters>      

      Sets  the GET delimiter characters. Defaults to "::".      

      :hp2. _SET_DELIMITERS:ehp2.    <lFlag> | <cOnOff>      

      If  enabled, GETs are delimited on screen.  disabled, which is the default, no GET delimiters are used.       

      :hp2. _SET_DEVICE:ehp2.        <cDeviceName>      

      Selects  the output device for DEVOUT(). When set to "PRINTER", all output is sent to the printer device or  file set by _SET_PRINTFILE. When set to anything else,  all output is sent to the screen. Defaults to "SCREEN".       

      :hp2. _SET_EPOCH:ehp2.         <nYear>      

      Determines  how to handle the conversion of 2-digit years to 4 digit years. When a 2-digit year is greater than or  equal to the year part of the epoch, the century part of  the epoch is added to the year. When a 2-digit year is  less than the year part of the epoch, the century part  of the epoch is incremented and added to the year. The  default epoch is 1900, which converts all 2-digit years  to 19xx. Example: If the epoch is set to 1950, 2-digit  years in the range from 50 to 99 get converted to 19xx  and 2-digit years in the range 00 to 49 get converted  to 20xx.       

      :hp2. _SET_ESCAPE:ehp2.        <lFlag> | <cOnOff>   *      

      When  enabled, which is the default, pressing Esc will exit a READ. When disabled, pressing Esc during a READ  is ignored, unless the Esc key has been assigned to a  function using SET KEY.       

      :hp2. _SET_EVENTMASK:ehp2.     <nEventCodes>      

      Determines  which events INKEY() will respond to. INKEY_MOVE allows mouse movement events. INKEY_LDOWN  allows the left mouse button down click. INKEY_LUP  allows the left mouse button up click. INKEY_RDOWN  allows the right mouse button down click. INKEY_RUP  allows the right mouse button up clock. INKEY_KEYBOARD  allows keyboard keystrokes. INKEY_ALL allows all of the  preceding events. Events may be combined (e.g., using  INKEY_LDOWN + INKEY_RUP will allow left mouse button  down clicks and right mouse button up clicks). The  default is INKEY_KEYBOARD.       

      :hp2. _SET_EXACT:ehp2.         <lFlag> | <cOnOff>      

      When  enabled, all string comparisons other than "==" exclude trailing spaces when checking for equality.  When disabled, which is the default, all string  comparisons other than "==" treat two strings as  equal if the right hand string is "" or if the right  hand string is shorter than or the same length as the  left hand string and all of the characters in the right  hand string match the corresponding characters in the  left hand string.       

      :hp2. _SET_EXCLUSIVE:ehp2.     <lFlag> | <cOnOff>      

      When  enabled, which is the default, all database files are opened in exclusive mode. When disabled, all  database files are opened in shared mode. Note: The  EXCLUSIVE and SHARED clauses of the USE command can be  used to override this setting.       

      :hp2. _SET_EXIT:ehp2.          <lFlag> | <cOnOff>      

      Toggles  the use of Uparrow and Dnarrow as READ exit keys. Specifying true (.T.) enables them as exit keys, and  false (.F.) disables them. Used internally by the  ReadExit() function.       

      :hp2. _SET_EXTRA:ehp2.         <lFlag> | <cOnOff>      

      QUESTION:  What is this for? It does not affect _SET_EXTRAFILE in Clipper!       

      :hp2. _SET_EXTRAFILE:ehp2.     <cFileName>             <lAdditive>      

      When  set, creates or opens file to write QOUT() and QQOUT() output to. If <lAdditive> is TRUE and the file  already exists, the file is opened and positioned at end  of file. Otherwise, the file is created. If a file is  already opened, it is closed before the new file is  opened or created (even if it is the same file). The  default file extension is ".prn". There is no default  file name. Call with an empty string to close the file.       

      :hp2. _SET_FIXED:ehp2.         <lFlag> | <cOnOff>      

      When  enabled, all numeric values will be displayed and printed with the number of decimal digits set  by SET DECIMALS, unless a PICTURE clause is used.  When disabled, which is the default, the number  of decimal digits that are displayed depends upon  a variety of factors. See _SET_DECIMALS for more.       

      :hp2. _SET_INSERT:ehp2.        <lFlag> | <cOnOff>      

      When  enabled, characters typed in a GET or MEMOEDIT are inserted. When disabled, which is the default,  characters typed in a GET or MEMOEDIT overwrite.  Note: This setting can also be toggled between on and  off by pressing the Insert key during a GET or MEMOEDIT.       

      :hp2. _SET_INTENSITY:ehp2.     <lFlag> | <cOnOff>      

      When  enabled, which is the default, GETs and PROMPTs are displayed using the enhanced color setting. When  disabled, GETs and PROMPTs are displayed using the  standard color setting.       

      :hp2. _SET_LANGUAGE:ehp2.      <cLanguageID>      

      Specifies  the language to be used for Harbour messages.      

      :hp2. _SET_MARGIN:ehp2.        <nColumns>      

      Sets  the left margin for all printed output. The default value is 0. Note: PCOL() reflects the printer's column  position including the margin (e.g., SET MARGIN TO 5  followed by DEVPOS(5, 10) makes PCOL() return 15).       

      :hp2. _SET_MBLOCKSIZE:ehp2.   <nMemoBlockSize>      

      TODO:  Document      

      :hp2. _SET_MCENTER:ehp2.       <lFlag> | <cOnOff>      

      If  enabled, display PROMPTs centered on the MESSAGE row. If disabled, which is the default, display PROMPTS at  column position 0 on the MESSAGE row.       

      :hp2. _SET_MESSAGE:ehp2.       <nRow>      

      If  set to 0, which is the default, PROMPTs are always suppressed. Otherwise, PROMPTs are displayed on the  set row. Note: It is not possible to display prompts  on the top-most screen row, because row 0 is reserved  for the SCOREBOARD, if enabled.       

      :hp2. _SET_MFILEEXT:ehp2.      <cMemoFileExt>      

      TODO:  Document      

      :hp2. _SET_OPTIMIZE:ehp2.      <lFlag> | <cOnOff>      

      TODO:  Document      

      :hp2. _SET_PATH:ehp2.          <cDirectories>      

      Specifies  a path of directories to search through to locate a file that can't be located in the DEFAULT  directory. Defaults to no path (""). Directories must  be separated by a semicolon (e.g., "C:\DATA;C:\MORE").       

      :hp2. _SET_PRINTER:ehp2.       <lFlag> | <cOnOff>      

      If  enabled, QOUT() and QQOUT() write to the screen and to a file, provided that a file has been opened or created  with _SET_ALTFILE. If disabled, which is the default,  QOUT() and QQOUT() only write to the screen (and/or to  the ALTFILE).       

      :hp2. _SET_PRINTFILE:ehp2.     <cFileName>             <lAdditive>      

      When  set, creates or opens file to write QOUT(), QQOUT() and DEVOUT() output to. If <lAdditive> is TRUE and the  file already exists, the file is opened and positioned  at end of file. Otherwise, the file is created. If a  file is already opened, it is closed before the new file  is opened or created (even if it is the same file). The  default file extension is ".prn". The default file name  is "PRN", which maps to the default printer device. Call  with an empty string to close the file.       

      :hp2. _SET_SCOREBOARD:ehp2.    <lFlag> | <cOnOff>      

      When  enabled, which is the default, READ and MEMOEDIT display status messages on screen row 0. When disabled,  READ and MEMOEDIT status messages are suppressed.       

      :hp2. _SET_SCROLLBREAK:ehp2.   <lFlag> | <cOnOff>      

      QUESTION:  What is this flag for?      

      :hp2. _SET_SOFTSEEK:ehp2.      <lFlag> | <cOnOff>      

      When  enabled, a SEEK that fails will position the record pointer to the first key that is higher than the sought  after key or to LASTREC() + 1 if there is no higher key.  When disabled, which is the default, a SEEK that fails  will position the record pointer to LASTREC()+1.       

      :hp2. _SET_STRICTREAD:ehp2.    <lFlag> | <cOnOff>      

      TODO:  Document      

      :hp2. _SET_TYPEAHEAD:ehp2.     <nKeyStrokes>      

      Sets  the size of the keyboard typeahead buffer. Defaults to 50. The minimum is 16 and the maximum is 4096.       

      :hp2. _SET_UNIQUE:ehp2.        <lFlag> | <cOnOff>      

      When  enabled, indexes are not allowed to have duplicate keys. When disabled, indexes are allowed duplicate keys.       

      :hp2. _SET_VIDEOMODE:ehp2.     <nValue>      

      TODO:  Document      

      :hp2. _SET_WRAP:ehp2.          <lFlag> | <cOnOff>      

      When  enabled, lightbar menus can be navigated from the last position to the first and from the first position  to the last. When disabled, which is the default, there  is a hard stop at the first and last positions.     

:p.:hp2.Returns
:ehp2.
      :hp2. SET():ehp2.   The current or previous setting    

:p.:hp2.Files
:ehp2.
     Library is rtl     
:h1 res=281.__SETFUNCTION()
:i1 id=__SETFUNCTION().__SETFUNCTION()
:p.__SETFUNCTION()
:p.:hp2.Assign a character string to a function key
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__SetFunction( <nFunctionKey>, [<cString>] ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nFunctionKey>:ehp2.   is a number in the range 1..40 that represent the function key to be assigned.       

      :hp2. <cString>:ehp2.   is a character string to set. If  is not specified, the function key is going to be set to NIL releasing by  that any previous __SetFunction() or SETKEY() for that function.     

:p.:hp2.Returns
:ehp2.
      :hp2. __SetFunction():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __SetFunction() assign a character string with a function key&comma. when  this function key is pressed&comma. the keyboard is stuffed with this  character string. __SetFunction() has the effect of clearing any  SETKEY() previously set to the same function number and vice versa.       


:cgraphic.
 
      nFunctionKey    Key to be set

         1 .. 12      F1 .. F12
        13 .. 20      Shift-F3 .. Shift-F10
        21 .. 30      Ctrl-F1 .. Ctrl-F10
        31 .. 40      Alt-F1 .. Alt-F10
 
:ecgraphic.

     SET FUNCTION command is preprocessed into __SetFunction() function  during compile time.     

:p.:hp2.Examples
:ehp2.

      // Set F1 with a string
      CLS
      __SetFunction( 1&comma. &cdq.I Am Lazy&cdq. + CHR( 13 ) )
      cTest &colon.= SPACE( 20 )
      @ 10&comma. 0 SAY &cdq.type something or F1 for lazy mode &cdq. GET cTest
      READ
      ? cTest
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Harbour use 11 and 12 to represent F11 and F12&comma. while CA-Clipper use  11 and 12 to represent Shift-F1 and Shift-F2.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=116.INKEY():elink.
.br
:link reftype=hd res=111.SETKEY():elink.
.br
:link reftype=hd res=282.__Keyboard():elink.
.br
:link reftype=hd res=110.SET KEY:elink.
.br
:h1 res=283.SET FUNCTION
:i1 id=SET FUNCTION.SET FUNCTION
:p.SET FUNCTION
:p.:hp2.Assign a character string to a function key
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET FUNCTION <nFunctionKey> TO [<cString>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nFunctionKey>:ehp2.   is a number in the range 1..40 that represent the function key to be assigned.       

      :hp2. <cString>:ehp2.   is a character string to set. If  is not specified, the function key is going to be set to NIL releasing by  that any previous  Set Function or SETKEY() for that function.     

:p.:hp2.Description
:ehp2.
       Set Function assign a character string with a function key&comma. when  this function key is pressed&comma. the keyboard is stuffed with this  character string. Set Function has the effect of clearing any  SETKEY() previously set to the same function number and vice versa.       


:cgraphic.
 
      nFunctionKey    Key to be set

         1 .. 12      F1 .. F12
        13 .. 20      Shift-F3 .. Shift-F10
        21 .. 30      Ctrl-F1 .. Ctrl-F10
        31 .. 40      Alt-F1 .. Alt-F10
 
:ecgraphic.

     SET FUNCTION command is preprocessed into __SetFunction() function  during compile time.     

:p.:hp2.Examples
:ehp2.

      // Set F1 with a string
      CLS
      Set Function  1 to  &cdq.I Am Lazy&cdq. + CHR( 13 )
      cTest &colon.= SPACE( 20 )
      @ 10&comma. 0 SAY &cdq.type something or F1 for lazy mode &cdq. GET cTest
      READ
      ? cTest
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Harbour use 11 and 12 to represent F11 and F12&comma. while CA-Clipper use  11 and 12 to represent Shift-F1 and Shift-F2.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=116.INKEY():elink.
.br
:link reftype=hd res=111.SETKEY():elink.
.br
:link reftype=hd res=282.__Keyboard():elink.
.br
:h1 res=111.SETKEY()
:i1 id=SETKEY().SETKEY()
:p.SETKEY()
:p.:hp2.Assign an action block to a key
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SETKEY( <anKey> [, <bAction> [, <bCondition> ] ] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <anKey>:ehp2.   is either a numeric key value, or an array of such values      

      :hp2. <bAction>:ehp2.   is an optional code-block to be assigned      

      :hp2. <bCondition>:ehp2.   is an optional condition code-block    

:p.:hp2.Returns
:ehp2.
      Current  assigned action-block    

:p.:hp2.Description
:ehp2.
     The SetKey() function returns the current code-block assigned to a  key when called with only the key value.  If the action block (and  optionally the condition block) are passed&comma. the current block is  returned&comma. and the new code block and condition block are stored.  A group of keys may be assigned the same code block/condition block  by using an array of key values in place on the first parameter.     

:p.:hp2.Examples
:ehp2.

      local bOldF10 &colon.= setKey( K_F10&comma. {|| Yahoo() } )
      ... // some other processing
      SetKey( K_F10&comma. bOldF10 )
      ... // some other processing
      bBlock &colon.= SetKey( K_SPACE )
      if bBlock != NIL ...

      // make F10 exit current get&comma. but only if in a get - ignores other
      // wait-states such as menus&comma. achoices&comma. etc...
      SetKey( K_F10&comma. {|| GetActive()&colon.State &colon.= GE_WRITE }&comma.;
       {|| GetActive() != NIL } )
  

:p.:hp2.Tests
:ehp2.

      None definable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     SETKEY() is mostly CA-Clipper compliant. The only difference is the  addition of the condition code-block parameter&comma. allowing set-keys to  be conditionally turned off or on.  This condition-block cannot be  returned once set - see SetKeyGet()     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=284.HB_SETKEYSAVE():elink.
.br
:h1 res=285.HB_SETKEYGET()
:i1 id=HB_SETKEYGET().HB_SETKEYGET()
:p.HB_SETKEYGET()
:p.:hp2.Determine a set-key code block & condition-block
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_SETKEYGET( <nKey> [, <bConditionByRef> ] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <anKey>:ehp2.   is an numeric key value      

      :hp2. <bConditionByRef>:ehp2.   is an optional return-parameter    

:p.:hp2.Returns
:ehp2.
      Current  assigned action-block    

:p.:hp2.Description
:ehp2.
     The HB_SetKeyGet() function returns the current code-block assigned to  a key&comma. and optionally assignes the condition-block to the  return-parameter     

:p.:hp2.Examples
:ehp2.

      local bOldF10&comma. bOldF10Cond
      bOldF10 &colon.= HB_SetKeyGet( K_F10&comma. @bOldF10Cond )
      ... // some other processing
      SetKey( K_F10&comma. bOldF10&comma. bOldF10Cond )
  

:p.:hp2.Tests
:ehp2.

      See test code above
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     HB_SETKEYGET() is a new function and hence not CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=111.SETKEY():elink.
.br
:link reftype=hd res=284.HB_SETKEYSAVE():elink.
.br
:link reftype=hd res=286.HB_SETKEYCHECK():elink.
.br
:h1 res=284.HB_SETKEYSAVE()
:i1 id=HB_SETKEYSAVE().HB_SETKEYSAVE()
:p.HB_SETKEYSAVE()
:p.:hp2.Returns a copy of internal set-key list, optionally overwriting
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_SETKEYSAVE( [ <OldKeys> ] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <OldKeys>:ehp2.   is an optional set-key list from a previous call to HB_SetKeySave(), or NIL to clear current set-key list     

:p.:hp2.Returns
:ehp2.
      Current  set-key list    

:p.:hp2.Description
:ehp2.
    HB_SetKeySave() is designed to act like the set() function which  returns the current state of an environment setting&comma. and optionally  assigning a new value.  In this case&comma. the &cdq.environment setting&cdq. is the  internal set-key list&comma. and the optional new value is either a value  returned from a previous call to SetKeySave() - to restore that list&comma.  or the value of NIL to clear the current list.     

:p.:hp2.Examples
:ehp2.

     local aKeys &colon.= HB_SetKeySave( NIL )  // removes all current set=keys
     ... // some other processing
     HB_SetKeySave( aKeys )
  

:p.:hp2.Tests
:ehp2.

     None definable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    HB_SETKEYSAVE() is new.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=111.SETKEY():elink.
.br
:h1 res=286.HB_SETKEYCHECK()
:i1 id=HB_SETKEYCHECK().HB_SETKEYCHECK()
:p.HB_SETKEYCHECK()
:p.:hp2.Impliments common hot-key activation code
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_SetKeyCheck( <nKey> [, <p1> ][, <p2> ][, <p3> ] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nKey>:ehp2.   is a numeric key value to be tested code-block, if executed      

      :hp2. <p1>..<p3>:ehp2.   are optional parameters that will be passed to the code-block    

:p.:hp2.Returns
:ehp2.
      True  if there is a hot-key associated with <nKey> and it was executed; otherwise False  If there is a hot-key association (before checking any condition):  - if there is a condition-block, it is passed one parameter - <nKey>  - when the hot-key code-block is called, it is passed 1 to 4 parameters,  depending on the parameters passed to HB_SetKeyCheck().  Any  parameters so passed are directly passed to the code-block, with an  additional parameter being <nKey>     

:p.:hp2.Description
:ehp2.
     HB_SetKeyCheck() is intended as a common interface to the SetKey()  functionality for such functions as ACHOICE()&comma. DBEDIT()&comma. MEMOEDIT()&comma.  ACCEPT&comma. INPUT&comma. READ&comma. and WAIT     

:p.:hp2.Examples
:ehp2.

      // within ReadModal()
      if HB_SetKeyCheck( K_ALT_X&comma. GetActive() )
      ... // some other processing
      endif
      // within TBrowse handler
      case HB_SetKeyCheck( nInkey&comma. oTBrowse )
        return
      case nInKey == K_ESC
      ... // some other processing
  

:p.:hp2.Tests
:ehp2.

      None definable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     HB_SETKEYCHECK() is new.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=111.SETKEY():elink.
.br
:link reftype=hd res=284.HB_SETKEYSAVE():elink.
.br
:h1 res=110.SET KEY
:i1 id=SET KEY.SET KEY
:p.SET KEY
:p.:hp2.Assign an action block to a key
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET KEY   <anKey> to p<bAction>] [when  <bCondition> ]  )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <anKey>:ehp2.   is either a numeric key value, or an array of such values      

      :hp2. <bAction>:ehp2.   is an optional code-block to be assigned      

      :hp2. <bCondition>:ehp2.   is an optional condition code-block    

:p.:hp2.Description
:ehp2.
     The Set Key Command function is translated to the SetKey() function  witch returns the current code-block assigned to a  key when called with only the key value.  If the action block (and  optionally the condition block) are passed&comma. the current block is  returned&comma. and the new code block and condition block are stored.  A group of keys may be assigned the same code block/condition block  by using an array of key values in place on the first parameter.     

:p.:hp2.Examples
:ehp2.

      local bOldF10 &colon.= setKey( K_F10&comma. {|| Yahoo() } )
      ... // some other processing
      Set Key  K_F10 to  bOldF10)
      ... // some other processing
      bBlock &colon.= SetKey( K_SPACE )
      if bBlock != NIL ...

      // make F10 exit current get&comma. but only if in a get - ignores other
      // wait-states such as menus&comma. achoices&comma. etc...
      SetKey( K_F10&comma. {|| GetActive()&colon.State &colon.= GE_WRITE }&comma.;
       {|| GetActive() != NIL } )
  

:p.:hp2.Tests
:ehp2.

      None definable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     SET KEY is mostly CA-Clipper compliant. The only difference is the  addition of the condition code-block parameter&comma. allowing set-keys to  be conditionally turned off or on.  This condition-block cannot be  returned once set - see SetKeyGet()     
.br
See Also&colon.
:link reftype=hd res=284.HB_SETKEYSAVE():elink.
.br
:h1 res=287.SETTYPEAHEAD()
:i1 id=SETTYPEAHEAD().SETTYPEAHEAD()
:p.SETTYPEAHEAD()
:p.:hp2.Sets the typeahead buffer to given size.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SETTYPEAHEAD( <nSize> ) --> <nPreviousSize>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nSize>:ehp2.   is a valid typeahead size.    

:p.:hp2.Returns
:ehp2.
      :hp2. <nPreviousSize>:ehp2.   The previous state of _SET_TYPEAHEAD    

:p.:hp2.Description
:ehp2.
     This function sets the typeahead buffer to a valid given size as is  Set( _SET_TYPEAHEAD ) where used.     

:p.:hp2.Examples
:ehp2.

      // Sets typeahead to 12
      SetTypeahead( 12 )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     SETTYPEAHEAD() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=288.__ACCEPT():elink.
.br
:link reftype=hd res=289.__INPUT():elink.
.br
:h1 res=290.__XHELP()
:i1 id=__XHELP().__XHELP()
:p.__XHELP()
:p.:hp2.Looks if a Help() user defined function exist.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__XHELP() --> <xValue>
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
      This  function returns aleatory values.    

:p.:hp2.Description
:ehp2.
     This is an internal undocumented Clipper function&comma. which will  try to call the user defined function HELP() if it's defined  in the current application. This is the default SetKey() handler  for the F1 key.     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __XHELP() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
:h1 res=75.SET DEFAULT
:i1 id=SET DEFAULT.SET DEFAULT
:p.SET DEFAULT
:p.:hp2.Establishes the Harbour search drive and directory.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET DEFAULT TO [<cPath>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cPath>:ehp2.   Drive and/or path.    

:p.:hp2.Description
:ehp2.
     This command changes the drive and directory used for reading and  writting database&comma.index&comma.memory&comma. and alternate files.Specifying no  parameters with this command will default the operation to the  current logged drive and directory.     

:p.:hp2.Examples
:ehp2.

      SET DEFAULT to c&colon.\TEMP
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper Compliant.     
.br
See Also&colon.
:link reftype=hd res=91.SET PATH:elink.
.br
:link reftype=hd res=93.CURDIR():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=156.SET WRAP
:i1 id=SET WRAP.SET WRAP
:p.SET WRAP
:p.:hp2.Toggle wrapping the PROMPTs in a menu.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET WRAP on | OFF | (<lWrap>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lWrap>:ehp2.   Logical expression for toggle    

:p.:hp2.Description
:ehp2.
     This command toggles the highlighted bars in a @...PROMPT command  to wrap around in a bottom-to-top and top-to-bottom manner.If the  value of the logical expression <lWrap> is a logical false (.F.)&comma.  the wrapping mode is set OFF;otherwise&comma.it is set ON.     

:p.:hp2.Examples
:ehp2.

      See Tests/menutest.prg
   
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper Compliant.     
.br
See Also&colon.
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=152.MENU TO:elink.
.br
:h1 res=154.SET MESSAGE
:i1 id=SET MESSAGE.SET MESSAGE
:p.SET MESSAGE
:p.:hp2.Extablishes a message row for @...PROMPT command
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET MESSAGE TO [<nRow> [CENTER]]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRow>:ehp2.   Row number to display the message    

:p.:hp2.Description
:ehp2.
     This command is designed to work in conjuntion with the MENU TO and  @...PROMPT commands.With this command&comma. a row number between 0 and  MAXROW() may be specified in <nRow>.This establishes the row on  witch any message associated with an @...PROMPT command will apear.       

     If the value of <nRow> is 0&comma.all messages will be supressed.  All messaged will be left-justifies unless the CENTER clause is  used.In this case&comma.the individual messages in each @...PROMPT command  will be centered at the designated row (unless <nRow> is 0).All  messages are independent;therefor&comma.the screen area is cleared out  by the centered message will vary based on the length of each  individual message.       

     Specifying no parameters with this command set the row value to 0&comma.  witch suppresses all messages output.  The British spelling of CENTRE is also supported.     

:p.:hp2.Examples
:ehp2.

      See Tests/menutest.prg
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper Compliant.     
.br
See Also&colon.
:link reftype=hd res=92.SET():elink.
.br
:link reftype=hd res=156.SET WRAP:elink.
.br
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=152.MENU TO:elink.
.br
:h1 res=91.SET PATH
:i1 id=SET PATH.SET PATH
:p.SET PATH
:p.:hp2.Specifies a search path for opening files
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET PATH TO [<cPath>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cPath>:ehp2.   Search path for files    

:p.:hp2.Description
:ehp2.
     This command specifies the search path for files required by most  commands and functions not found in the current drive and directory.  This pertains primarily&comma.but not exclusively&comma. to databases&comma.indexes&comma.  and memo files&comma.as well as to memory&comma.labels&comma.and reports files. The  search hirarchy is&colon. 1 Current drive and directory&comma.2 The SET DEFAULT  path;3 The SET PATH path.     

:p.:hp2.Examples
:ehp2.

      SET PATH TO c&colon.\Harbour\Test
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper Compliant.     
.br
See Also&colon.
:link reftype=hd res=75.SET DEFAULT:elink.
.br
:link reftype=hd res=93.CURDIR():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=155.SET INTENSITY
:i1 id=SET INTENSITY.SET INTENSITY
:p.SET INTENSITY
:p.:hp2.Toggles the enhaced display of PROMPT's and GETs.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET INTENSITY  ON | off | (<lInte>)
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lInte>:ehp2.   Logical expression for toggle command    

:p.:hp2.Description
:ehp2.
     This command set the field input color and @...PROMPT menu color  to either highlighted (inverse video) or normal color. The default  condition is ON (highlighted).     

:p.:hp2.Examples
:ehp2.

      SET INTENSITY ON
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper Compliant.     
.br
See Also&colon.
:link reftype=hd res=125.@...GET:elink.
.br
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=32.@...SAY:elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=291.SET ALTERNATE
:i1 id=SET ALTERNATE.SET ALTERNATE
:p.SET ALTERNATE
:p.:hp2.Toggle and echos output to an alternate file
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET ALTERNATE to <cFile> [ADDITIVE]
:ehp2.
:p.:hp2.SET ALTERNATE  on | OFF | (<lAlter>)
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   Name of alternate file.      

      :hp2. <lAlter>:ehp2.   Logical expression for toggle    

:p.:hp2.Description
:ehp2.
     This command toggles and output console information to the alternate  file <cFile>&comma.provided that the command is toggled on or the condition  <lAlter> is set to a logical true (.T.). If <cFile> does not has a  file extension&comma. .TXT will be assumed.The file name may optionally  have a drive letter and/or directory path.If none is speficied&comma. the  current drive and directory will be used.  If the ALTERNATE file is created but no ALTERNATE ON command is  issued&comma.nothing will be echoed to the file.  If ADDITIVE clause is used&comma.then the information will be appended  to the existing alternate file.Otherwise&comma.a new file will be created  with the specified name (or an existing one will be overwritten) and  the information will be appended to the file.The default is to create  a new file.  A SET ALTERNATE TO command will close the alternate file     

:p.:hp2.Examples
:ehp2.

      SET ALTERNATE TO test.txt
      SET ALTERNATE ON
      ? 'Harbour'
      ? &cdq.is&cdq.
      ? &cdq.Power&cdq.
      SET ALTERNATE TO
      SET ALTERNATE OFF
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper Compliant.     
.br
See Also&colon.
:link reftype=hd res=292.CLOSE:elink.
.br
:link reftype=hd res=97.SET PRINTER:elink.
.br
:link reftype=hd res=293.SET CONSOLE:elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=294.SET CENTURY
:i1 id=SET CENTURY.SET CENTURY
:p.SET CENTURY
:p.:hp2.Toggle the century digits in all dates display
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET CENTURY on | OFF | (<lCent>)
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lCent>:ehp2.   Logical expression for toggle    

:p.:hp2.Description
:ehp2.
     This command allows the input and display of dates with the century  prefix.It will be in the standart MM/DD/YYYY format unless specified  by the SET DATE command or SET() function.If <lCent> is a logical  true (.T.)&comma.the command will be set on;otherwise&comma. the command will  be set off     

:p.:hp2.Examples
:ehp2.

      SET CENTURY ON
      ? DATE()
      SET CENTURY OFF
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=52.SET DATE:elink.
.br
:link reftype=hd res=295.SET EPOCH:elink.
.br
:link reftype=hd res=50.CTOD():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=52.SET DATE
:i1 id=SET DATE.SET DATE
:p.SET DATE
:p.:hp2.Assings a date format or chooses a predefined date data set.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET DATE FORMAT [TO] <cFormat>
:ehp2.
:p.:hp2.SET DATE [TO] [ ANSI / BRITISH / FRENCH / GERMAN / ITALIAN / JAPAN
:ehp2.
:p.:hp2./ USA / AMERICAN]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFormat>:ehp2.   Keyword for date format    

:p.:hp2.Description
:ehp2.
     This command sets the date format for function display purposes.  If specified&comma.<cFormat> may be a customized date format in which the  letters d&comma.m and y may be used to desing a date format.The default  is an AMERICAN date format;specifying no parameters will set the  date format to AMERICAN.Below is a table of the varius predefined  dates formats.       


:cgraphic.
 
       Syntax         Date Format
       ANSI           yy.mm.dd
       BRITISH        dd/mm/yy
       FRENCH         dd/mm/yy
       GERMAN         dd.mm.yy
       ITALIAN        dd-mm-yy
       JAPAN          yy.mm.dd
       USA            mm-dd-yy
       AMERICAN       mm/dd/yy
 
:ecgraphic.


:p.:hp2.Examples
:ehp2.

      SET DATE JAPAN
      ? DATE()
      SET DATE GERMAN
      ? Date()

:p.:hp2.Tests
:ehp2.

      See tests/dates.prg
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=52.SET DATE:elink.
.br
:link reftype=hd res=295.SET EPOCH:elink.
.br
:link reftype=hd res=50.CTOD():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=295.SET EPOCH
:i1 id=SET EPOCH.SET EPOCH
:p.SET EPOCH
:p.:hp2.Specifie a base year for interpreting dates
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET EPOCH TO <nEpoch>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nEpoch>:ehp2.   Base Century.    

:p.:hp2.Description
:ehp2.
     This command sets the base year value for dates that have only two  digits.The default setting is 1900.Dates between 01/01/0100 and  12/31/2999 are fully supported.     

:p.:hp2.Examples
:ehp2.

      SET EPOCH TO 2000
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=52.SET DATE:elink.
.br
:link reftype=hd res=294.SET CENTURY:elink.
.br
:link reftype=hd res=50.CTOD():elink.
.br
:link reftype=hd res=45.DATE():elink.
.br
:link reftype=hd res=49.DTOC():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=147.SET FIXED
:i1 id=SET FIXED.SET FIXED
:p.SET FIXED
:p.:hp2.Set the number of decimal position to be displayed
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET FIXED on | OFF | (<lFixed>)
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lFixed>:ehp2.   Logical expression for toggle    

:p.:hp2.Description
:ehp2.
     This command activates a system wide fixed placement of decimals  places shown for all numeric outputs.If the value of <lFixed> is  a logical true (.T.)&comma.FIXED will be turned ON;otherwise it will be  turned OFF.       

     When SET DECIMALS OFF is used&comma. the follow rules aply to the number  of decimal placed displayed.       


:cgraphic.
 
       Addition         Same as operand with the greatest number of decimal digits
       Subraction       Same as operand with the greatest number of decimal digits
       Multiplication   Sum of operand decimal digits
       Division         Determined by SET DECIMAL TO
       Exponential      Determined by SET DECIMAL TO
       LOG()            Determined by SET DECIMAL TO
       EXP()            Determined by SET DECIMAL TO
       SQRT()           Determined by SET DECIMAL TO
       VAL()            Determined by SET DECIMAL TO
 
:ecgraphic.


:p.:hp2.Examples
:ehp2.

      SET FIXED ON
      ? 25141251/362
      SET FIXED OFF
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=296.SET DECIMALS:elink.
.br
:link reftype=hd res=134.EXP():elink.
.br
:link reftype=hd res=135.LOG():elink.
.br
:link reftype=hd res=144.SQRT():elink.
.br
:link reftype=hd res=146.VAL():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=97.SET PRINTER
:i1 id=SET PRINTER.SET PRINTER
:p.SET PRINTER
:p.:hp2.Toggles the printer and controls the printer device
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET PRINTER on | OFF
:ehp2.
:p.:hp2.SET PRINTER (<lPrinter>)
:ehp2.
:p.:hp2.SET PRINTER TO [<cPrinter>] [ADDITIVE]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lFixed>:ehp2.     Logical condition by which to toggle the printer <cPrinter> A device name or an alternate name     

:p.:hp2.Description
:ehp2.
     This command can direct all output that is not controled by the  @...SAY command and the DEVPOS() and DEVOUT() functions to the  printer.If specified&comma.the condition <lPrinter> toggles the printer  ON if a logical true (.T.) and OFF if a logical false (.F.).If no  argument is specified in the command&comma. the alternate file (if one  is open) is closed&comma. or the device is reselected and the PRINTER  option is turned OFF.       

     If a device is specified in <cPrinter>&comma. the outpur will be directed  to that device instead of to the PRINTER.A specified device may be  a literal string or a variable&comma. as long as the variable is enclosed  in parentheses.For a network&comma.do not use a trailing colon when  redirecting to a device.       

     If an alternate file is specified&comma.<cPrinter> becomes the name of a  file that will contain the output.If no file extension is specified  an extension of.PRN will be defaulted to.       

     If the ADDITIVE clause is specified&comma.the information will be appended  to the end of the specified output file.Otherwise&comma. a new file will  be created with the specified name (or an existing file will first  be cleared) and the information will then be appended to the file.  The default is to create a new file.     

:p.:hp2.Examples
:ehp2.

      SET PRINTER ON
      SET PRINTER TO LPT1
      ? 25141251/362
      SET PRINTER .F.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=297.SET DEVICE:elink.
.br
:link reftype=hd res=293.SET CONSOLE:elink.
.br
:link reftype=hd res=298.DEVOUT():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=293.SET CONSOLE
:i1 id=SET CONSOLE.SET CONSOLE
:p.SET CONSOLE
:p.:hp2.Toggle the console display
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET CONSOLE ON | off | (<lConsole>)
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lConsole>:ehp2.   Logical expression for toggle command    

:p.:hp2.Description
:ehp2.
     This command turns the screen display either off or on for all  screens display other then direct output via the @...SAY commands  or the <-> DEVOUT() function.       

     If <lConsole > is a logical true (.T.)&comma.the console will be turned  ON;otherwise&comma. the console will be turned off.     

:p.:hp2.Examples
:ehp2.

      SET console on
      ? DATE()
      SET console off
      ? date()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=297.SET DEVICE:elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=296.SET DECIMALS
:i1 id=SET DECIMALS.SET DECIMALS
:p.SET DECIMALS
:p.:hp2.Toggle the console display
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET DECIMALS TO [<nDecimal>]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nDecimal>:ehp2.   Number of decimals places    

:p.:hp2.Description
:ehp2.
     This command establishes the number of decimal places that Harbour  will display in mathematical calculations&comma.functions&comma.memory variables&comma.  and fields.Issuing no parameter with this command will the default  number of decimals to 0.For decimals to be seen&comma.the SET FIXED ON  command must be activated.     

:p.:hp2.Examples
:ehp2.

      SET FIXED ON
      ? 25141251/362
      SET DECIMALS TO 10
      ? 214514.214/6325
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=147.SET FIXED:elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=297.SET DEVICE
:i1 id=SET DEVICE.SET DEVICE
:p.SET DEVICE
:p.:hp2.Directs all @...SAY output to a device.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET DEVICE TO [printer | SCREEN ]
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Description
:ehp2.
     This command determines whether the output from the @...SAY command  and the DEVPOS() and DEVOUT() function will be displayed on the  printer.       

     When the device is set to the PRINTER&comma.the SET MARGIN value adjusts  the position of the column values accordingly.Also&comma.an automatic  page eject will be issued when the current printhead position is  less than the last printed row.Finally&comma.if used in conjunction with  the @...GET commands&comma.the values for the GETs will all be ignored.     

:p.:hp2.Examples
:ehp2.

      SET DEVICE TO SCRENN
      ? 25141251/362
      SET DEVICE TO PRINTER
      SET PRINTER TO LPT1
      ? 214514.214/6325
      SET PRINTER OFF
      SET DEVICE TO SCREEN
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=32.@...SAY:elink.
.br
:link reftype=hd res=97.SET PRINTER:elink.
.br
:link reftype=hd res=299.SETPRC():elink.
.br
:link reftype=hd res=92.SET():elink.
.br
:h1 res=166.SET BELL
:i1 id=SET BELL.SET BELL
:p.SET BELL
:p.:hp2.Toggle the bell to sound once a GET has been completed.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SET BELL on | OFF | (<lBell>)
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <lBell>:ehp2.   Logical expression for toggle command    

:p.:hp2.Description
:ehp2.
     This command toggles the bell to sound whenever a character is  entered into the last character positionof a GET&comma.of if an invalid  data type is entered into a GET.       

     If <lBell > is a logical true (.T.)&comma.the bell will be turned  ON;otherwise&comma. the belle will be turned off.     

:p.:hp2.Examples
:ehp2.

      SET BEEL ON
      cDummy&colon.=space(20)
      ? 3&comma.2 get cDummy
      Read
      SET bell off
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is Ca-Clipper compliant     
.br
See Also&colon.
:link reftype=hd res=92.SET():elink.
.br
:h1 res=300.ISALPHA()
:i1 id=ISALPHA().ISALPHA()
:p.ISALPHA()
:p.:hp2.Checks if leftmost character in a string is an alphabetic character
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISALPHA(<cString>) --> lAlpha
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Any character string    

:p.:hp2.Returns
:ehp2.
      lAlpha  Logical true (.T.) or false (.F.).    

:p.:hp2.Description
:ehp2.
     This function return a logical true (.T.) if the first character  in <cString> is an alphabetic character.If not&comma. the function will  return a logical false (.F.).     

:p.:hp2.Examples
:ehp2.

      QOUT( &cdq.isalpha( 'hello' ) = &cdq.&comma. isalpha( 'hello' ) )
      QOUT( &cdq.isalpha( '12345' ) = &cdq.&comma. isalpha( '12345' ) )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=301.ISDIGIT():elink.
.br
:link reftype=hd res=302.ISLOWER():elink.
.br
:link reftype=hd res=303.ISUPPER():elink.
.br
:link reftype=hd res=304.LOWER():elink.
.br
:link reftype=hd res=305.UPPER():elink.
.br
:h1 res=301.ISDIGIT()
:i1 id=ISDIGIT().ISDIGIT()
:p.ISDIGIT()
:p.:hp2.Checks if leftmost character is a digit character
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISDIGIT(<cString>) --> lDigit
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Any character string    

:p.:hp2.Returns
:ehp2.
      lDigit  Logical true (.T.) or false (.F.).    

:p.:hp2.Description
:ehp2.
     This function takes the caracter string <cString> and checks to  see if the leftmost character is a digit&comma.from 1 to 9.If so&comma. the  function will return a logical true (.T.);otherwise&comma. it will  return a logical false (.F.).     

:p.:hp2.Examples
:ehp2.

      QOUT( &cdq.isdigit( '12345' ) = &cdq.&comma. isdigit( '12345' ) )
      QOUT( &cdq.isdigit( 'abcde' ) = &cdq.&comma. isdigit( 'abcde' ) )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=300.ISALPHA():elink.
.br
:link reftype=hd res=302.ISLOWER():elink.
.br
:link reftype=hd res=303.ISUPPER():elink.
.br
:link reftype=hd res=304.LOWER():elink.
.br
:link reftype=hd res=305.UPPER():elink.
.br
:h1 res=303.ISUPPER()
:i1 id=ISUPPER().ISUPPER()
:p.ISUPPER()
:p.:hp2.Checks if leftmost character is an uppercased letter.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISUPPER(<cString>) --> lUpper
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Any character string    

:p.:hp2.Returns
:ehp2.
      lUpper  Logical true (.T.) or false (.F.).    

:p.:hp2.Description
:ehp2.
     This function takes the caracter string <cString> and checks to  see if the leftmost character is a uppercased letter.If so&comma. the  function will return a logical true (.T.);otherwise&comma. it will  return a logical false (.F.).     

:p.:hp2.Examples
:ehp2.

      QOUT( &cdq.isupper( 'Abcde' ) = &cdq.&comma. isupper( 'Abcde' ) )
      QOUT( &cdq.isupper( 'abcde' ) = &cdq.&comma. isupper( 'abcde' ) )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=300.ISALPHA():elink.
.br
:link reftype=hd res=302.ISLOWER():elink.
.br
:link reftype=hd res=301.ISDIGIT():elink.
.br
:link reftype=hd res=304.LOWER():elink.
.br
:link reftype=hd res=305.UPPER():elink.
.br
:h1 res=302.ISLOWER()
:i1 id=ISLOWER().ISLOWER()
:p.ISLOWER()
:p.:hp2.Checks if leftmost character is an lowercased letter.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ISLOWER(<cString>) --> lLower
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Any character string    

:p.:hp2.Returns
:ehp2.
      lLower  Logical true (.T.) or false (.F.).    

:p.:hp2.Description
:ehp2.
     This function takes the caracter string <cString> and checks to  see if the leftmost character is a lowercased letter.If so&comma. the  function will return a logical true (.T.);otherwise&comma. it will  return a logical false (.F.).     

:p.:hp2.Examples
:ehp2.

      QOUT( &cdq.islower( 'Abcde' ) = &cdq.&comma. islower( 'Abcde' ) )
      QOUT( &cdq.islower( 'abcde' ) = &cdq.&comma. islower( 'abcde' ) )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=300.ISALPHA():elink.
.br
:link reftype=hd res=301.ISDIGIT():elink.
.br
:link reftype=hd res=303.ISUPPER():elink.
.br
:link reftype=hd res=304.LOWER():elink.
.br
:link reftype=hd res=305.UPPER():elink.
.br
:h1 res=306.LTRIM()
:i1 id=LTRIM().LTRIM()
:p.LTRIM()
:p.:hp2.Removes leading spaces from a string
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LTRIM(<cString>)   --> <cReturn>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.    Character expression with leading spaces    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.    The same character expression with leading spaces removed    

:p.:hp2.Description
:ehp2.
     This function trims the leading space blank     

:p.:hp2.Examples
:ehp2.

      ? QOUT( LTRIM(&cdq.HELLO     &cdq.))
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This functions is CA-CLIPPER compatible     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=307.TRIM():elink.
.br
:link reftype=hd res=308.RTRIM():elink.
.br
:link reftype=hd res=309.ALLTRIM():elink.
.br
:h1 res=310.AT()
:i1 id=AT().AT()
:p.AT()
:p.:hp2.Locates the position of a substring in a main string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.AT(<cSearch>,<cString>) --> nPos
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cSearch>:ehp2.    Substring to search for      

      :hp2. <cString>:ehp2.    Main string    

:p.:hp2.Returns
:ehp2.
      :hp2. AT():ehp2.   return the starting position of the first occurrence of the substring in the main string     

:p.:hp2.Description
:ehp2.
     This function searches the string <cString> for the characters in  the first string <cSearch>. If the substring is not contained within  the second expression&comma.the function will return 0.     

:p.:hp2.Examples
:ehp2.

      QOUT( &cdq.at( 'cde'&comma. 'abcdefgfedcba' ) = '&cdq. +;
      at( 'cde'&comma. 'abcsefgfedcba' ) + &cdq.'&cdq. )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=311.RAT():elink.
.br
:h1 res=311.RAT()
:i1 id=RAT().RAT()
:p.RAT()
:p.:hp2.Searches for a substring from the right side of a string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RAT(<cSearch>,<cString>) --> nPos
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cSearch>:ehp2.    Substring to search for      

      :hp2. <cString>:ehp2.    Main string    

:p.:hp2.Returns
:ehp2.
      :hp2. RAT():ehp2.   return the location of beginnig position.    

:p.:hp2.Description
:ehp2.
     This function searches througt <cString> for the first existence  of <cSearch>.The search operation is performed from the right side  of <cString> to the left. If the function is unable to find any  occurence of <cSearch> in <cString>&comma.the value of the function will be 0.     

:p.:hp2.Examples
:ehp2.

      QOUT( &cdq.rat( 'cde'&comma. 'abcdefgfedcba' ) = '&cdq. +;
      rat( 'cde'&comma. 'abcsefgfedcba' ) + &cdq.'&cdq. )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Will not work with a search string > 64 KB on some platforms     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=310.AT():elink.
.br
:link reftype=hd res=312.SUBSTR():elink.
.br
:link reftype=hd res=313.RIGHT():elink.
.br
:h1 res=314.LEFT()
:i1 id=LEFT().LEFT()
:p.LEFT()
:p.:hp2.Extract the leftmost substring of a character expression
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LEFT(<cString>,<nPos>) --> <cReturn>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Main character to be parsed      

      :hp2. <nPos>:ehp2.      Number of bytes to return beggining at the leftmost position    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.    Substring of evaluation    

:p.:hp2.Description
:ehp2.
     This functions returns the leftmost <nPos> characters of <cString>.  It is equivalent to the following programing expression&colon.  SUBSTR(<cString>&comma.1&comma.<nPos>     

:p.:hp2.Examples
:ehp2.

      ? QOUT(LEFT('HELLO HARBOUR'&comma.5))
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This functions is CA CLIPPER compatible     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=312.SUBSTR():elink.
.br
:link reftype=hd res=313.RIGHT():elink.
.br
:link reftype=hd res=310.AT():elink.
.br
:link reftype=hd res=311.RAT():elink.
.br
:h1 res=313.RIGHT()
:i1 id=RIGHT().RIGHT()
:p.RIGHT()
:p.:hp2.Extract the rightmost substring of a character expression
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SUBSTR(<cString>,<nPos>) --> <cReturn>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Character expression to be parsed      

      :hp2. <nPos>:ehp2.      Number of bytes to return beggining at the rightmost position    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.    Substring of evaluation    

:p.:hp2.Description
:ehp2.
     This functions returns the rightmost <nPos> characters of <cString>.     

:p.:hp2.Examples
:ehp2.

      ? QOUT(RIGHT('HELLO HARBOUR'&comma.5))
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This functions is CA CLIPPER compatible     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=312.SUBSTR():elink.
.br
:link reftype=hd res=314.LEFT():elink.
.br
:link reftype=hd res=310.AT():elink.
.br
:link reftype=hd res=311.RAT():elink.
.br
:h1 res=312.SUBSTR()
:i1 id=SUBSTR().SUBSTR()
:p.SUBSTR()
:p.:hp2.Returns a substring from a main string
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SUBSTR(<cString>,<nStart>[,<nLen>)] --> <cReturn>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Character expression to be parsed      

      :hp2. <nStart>:ehp2.    Start position      

      :hp2. <nLen>:ehp2.      Number of characters to return    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.    Substring of evaluation    

:p.:hp2.Description
:ehp2.
     This functions returns a character string formed from <cString>&comma.  starting at the position of <nStart> and continuing on for a  lenght of <nLen> characters. If <nLen> is not specified&comma. the value  will be all remaining characters from the position of <nStart>.       

     The value of <nStart> may be negative. If it is&comma. the direction of  operation is reversed from a default of left-to-right to right-to-left  for the number of characters specified in <nStart>.     

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()
      LOCAL X&colon.=REPLICATE('ABCD'&comma.70000)

      ? QOUT(SUBSTR(X&comma.65519&comma.200)

      RETURN NIL
  

:p.:hp2.Tests
:ehp2.

      ? QOUT(SUBSTR('HELLO HARBOUR'&comma.5)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This functions is CA CLIPPER compatible with the execption that  CA CLIPPER will generate an error if the passed string is >65519 bytes  and Harbour depends of plataform.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=314.LEFT():elink.
.br
:link reftype=hd res=310.AT():elink.
.br
:link reftype=hd res=313.RIGHT():elink.
.br
:h1 res=145.STR()
:i1 id=STR().STR()
:p.STR()
:p.:hp2.Convert a numeric expression to a character string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.STR(<nNumber>, [<nLength>], [<nDecimals>]) --> cNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   is the numeric expression to be converted to a character string.       

      :hp2. <nLength>:ehp2.   is the length of the character string to return, including decimal digits, decimal point, and sign.       

      :hp2. <nDecimals>:ehp2.   is the number of decimal places to return.    

:p.:hp2.Returns
:ehp2.
      :hp2. STR():ehp2.   returns <nNumber> formatted as a character string.  If the optional length and decimal arguments are not specified, STR()  returns the character string according to the following rules:       

      Results  of STR() with No Optional Arguments      


:cgraphic.
 
      Expression               Return Value Length

      Field Variable           Field length plus decimals
      Expressions/constants    Minimum of 10 digits plus decimals
      VAL()                    Minimum of 3 digits
      MONTH()/DAY()            3 digits
      YEAR()                   5 digits
      RECNO()                  7 digits
 
:ecgraphic.


:p.:hp2.Description
:ehp2.
     STR() is a numeric conversion function that converts numeric values  to character strings. It is commonly used to concatenate numeric values  to character strings. STR() has applications displaying numbers&comma.  creating codes such as part numbers from numeric values&comma. and creating  index keys that combine numeric and character data.       

     STR() is like TRANSFORM()&comma. which formats numeric values as character  strings using a mask instead of length and decimal specifications.       

     The inverse of STR() is VAL()&comma. which converts character numbers to  numerics.       

     *  If <nLength> is less than the number of whole number digits in  <nNumber>&comma. STR() returns asterisks instead of the number.       

     *  If <nLength> is less than the number of decimal digits  required for the decimal portion of the returned string&comma. Harbour  rounds the number to the available number of decimal places.       

     *  If <nLength> is specified but <nDecimals> is omitted (no  decimal places)&comma. the return value is rounded to an integer.     

:p.:hp2.Examples
:ehp2.

      ? STR( 10&comma. 6&comma. 2 ) // &cdq. 10.00&cdq.
      ? STR( -10&comma. 8&comma. 2 ) // &cdq.  -10.00&cdq.
      

:p.:hp2.Tests
:ehp2.

      see the regression test suit for comprehensive tests.
          
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CA-Clipper compatible.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=138.STRZERO():elink.
.br
:h1 res=138.STRZERO()
:i1 id=STRZERO().STRZERO()
:p.STRZERO()
:p.:hp2.Convert a numeric expression to a character string, zero padded.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.STRZERO(<nNumber>, [<nLength>], [<nDecimals>]) --> cNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nNumber>:ehp2.   is the numeric expression to be converted to a character string.       

      :hp2. <nLength>:ehp2.   is the length of the character string to return, including decimal digits, decimal point, and sign.       

      :hp2. <nDecimals>:ehp2.   is the number of decimal places to return.    

:p.:hp2.Returns
:ehp2.
      :hp2. STRZERO():ehp2.   returns <nNumber> formatted as a character string.  If the optional length and decimal arguments are not specified, STRZERO()  returns the character string according to the following rules:       

      Results  of STRZERO() with No Optional Arguments      


:cgraphic.
 
      Expression               Return Value Length

      Field Variable           Field length plus decimals
      Expressions/constants    Minimum of 10 digits plus decimals
      VAL()                    Minimum of 3 digits
      MONTH()/DAY()            3 digits
      YEAR()                   5 digits
      RECNO()                  7 digits
 
:ecgraphic.


:p.:hp2.Description
:ehp2.
     STRZERO() is a numeric conversion function that converts numeric values  to character strings. It is commonly used to concatenate numeric values  to character strings. STRZERO() has applications displaying numbers&comma.  creating codes such as part numbers from numeric values&comma. and creating  index keys that combine numeric and character data.       

     STRZERO() is like TRANSFORM()&comma. which formats numeric values as character  strings using a mask instead of length and decimal specifications.       

     The inverse of STRZERO() is VAL()&comma. which converts character numbers to  numerics.       

     *  If <nLength> is less than the number of whole number digits in  <nNumber>&comma. STR() returns asterisks instead of the number.       

     *  If <nLength> is less than the number of decimal digits  required for the decimal portion of the returned string&comma. Harbour  rounds the number to the available number of decimal places.       

     *  If <nLength> is specified but <nDecimals> is omitted (no  decimal places)&comma. the return value is rounded to an integer.     

:p.:hp2.Examples
:ehp2.

      ? STRZERO( 10&comma. 6&comma. 2 ) // &cdq.010.00&cdq.
      ? STRZERO( -10&comma. 8&comma. 2 ) // &cdq.-0010.00&cdq.
  

:p.:hp2.Tests
:ehp2.

      see the regression test suit for comprehensive tests.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CA-Clipper compatible (it was not mentioned in the docs though).     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=145.STR():elink.
.br
:h1 res=315.HB_VALTOSTR()
:i1 id=HB_VALTOSTR().HB_VALTOSTR()
:p.HB_VALTOSTR()
:p.:hp2.Converts any scalar type to a string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_VALTOSTR( <xValue> ) --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xValue>:ehp2.   is any scalar argument.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.    A string representation of <xValue> using default conversions.    

:p.:hp2.Description
:ehp2.
     HB_VALTOSTR can be used to convert any scalar value to a string.     

:p.:hp2.Examples
:ehp2.

      ? HB_VALTOSTR( 4 )
      ? HB_VALTOSTR( &cdq.String&cdq. )
  

:p.:hp2.Tests
:ehp2.

      ? HB_VALTOSTR( 4 ) == &cdq.         4&cdq.
      ? HB_VALTOSTR( 4.0 / 2 ) == &cdq.         2.00&cdq.
      ? HB_VALTOSTR( &cdq.String&cdq. ) == &cdq.String&cdq.
      ? HB_VALTOSTR( CTOD( &cdq.01/01/2001&cdq. ) ) == &cdq.01/01/01&cdq.
      ? HB_VALTOSTR( NIL ) == &cdq.NIL&cdq.
      ? HB_VALTOSTR( .F. ) == &cdq..F.&cdq.
      ? HB_VALTOSTR( .T. ) == &cdq..T.&cdq.
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     HB_VALTOSTR() is a Harbour enhancement.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=145.STR():elink.
.br
:h1 res=8.LEN()
:i1 id=LEN().LEN()
:p.LEN()
:p.:hp2.Returns size of a string or size of an array.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LEN( <cString> | <aArray> ) --> <nLength>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <acString>:ehp2.   is a character string or the array to check.    

:p.:hp2.Returns
:ehp2.
      The  length of the string or the number of elements that contains an array.     

:p.:hp2.Description
:ehp2.
     This function returns the string length or the size of an array. If  it is used with a multidimensional array it returns the size of the  first dimension.     

:p.:hp2.Examples
:ehp2.

      ? Len( &cdq.Harbour&cdq. ) --> 7
      ? Len( { &cdq.One&cdq.&comma. &cdq.Two&cdq. } ) --> 2
  

:p.:hp2.Tests
:ehp2.

      function Test()
         LOCAL cName &colon.= &cdq.&cdq.
         ACCEPT &cdq.Enter your name&colon. &cdq. TO cName
         ? Len( cName )
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     LEN() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=316.EMPTY():elink.
.br
:link reftype=hd res=308.RTRIM():elink.
.br
:link reftype=hd res=306.LTRIM():elink.
.br
:link reftype=hd res=2.AADD():elink.
.br
:link reftype=hd res=6.ASIZE():elink.
.br
:h1 res=316.EMPTY()
:i1 id=EMPTY().EMPTY()
:p.EMPTY()
:p.:hp2.Checks if the passed argument is empty.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.EMPTY( <xExp> ) --> <lIsEmpty>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xExp>:ehp2.   is any valid expression.    

:p.:hp2.Returns
:ehp2.
      A  logical value. It is true (.T.) if the passed argument is empty otherwise it is false (.F.).     

:p.:hp2.Description
:ehp2.
     This function checks if an expression has empty value and returns a  logical indicating whether it the expression is empty or not.     

:p.:hp2.Examples
:ehp2.

      ? Empty( &cdq.I'm not empty&cdq. )
  

:p.:hp2.Tests
:ehp2.

      function Test()
         ? Empty( 1 )       --> .f.
         ? Empty( Date() )  --> .f.
         ? Empty( .f. )     --> .t.
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     EMPTY() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=8.LEN():elink.
.br
:h1 res=317.DESCEND()
:i1 id=DESCEND().DESCEND()
:p.DESCEND()
:p.:hp2.Inverts an expression of string, logical, date or numeric type.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DESCEND( <xExp> ) --> <xExpInverted>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xExp>:ehp2.   is any valid expression.    

:p.:hp2.Returns
:ehp2.
      Inverted  value of the same type as passed.    

:p.:hp2.Description
:ehp2.
     This function converts an expression in his inverted form. It is  useful to build descending indexes.     

:p.:hp2.Examples
:ehp2.

      // Seek for Smith in a descending index
      SEEK DESCEND( &cdq.SMITH&cdq. )
    

:p.:hp2.Tests
:ehp2.

      DATA->( DBSEEK( DESCEND( &cdq.SMITH&cdq. ) ) )
      will seek &cdq.SMITH&cdq. into a descending index.
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DESCEND() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=318.INDEX:elink.
.br
:link reftype=hd res=319.SEEK:elink.
.br
:h1 res=320.HB_ANSITOOEM()
:i1 id=HB_ANSITOOEM().HB_ANSITOOEM()
:p.HB_ANSITOOEM()
:p.:hp2.Convert a windows Character to a Dos based character
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_ANSITOOEM(<cString>)  -> cDosString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.    Windows ansi string to convert to DOS oem String    

:p.:hp2.Returns
:ehp2.
      :hp2. <cDosString>:ehp2.   Dos based  string    

:p.:hp2.Description
:ehp2.
     This function converts each character in <cString> to the corresponding  character in the MS-DOS (OEM) character set.The character expression  <cString> should contain characters from the ANSI character set.  If a character in <cString> doesn't have a MS-DOS equivalent&comma. the  character is converted to a similar MS-DOS character.     

:p.:hp2.Examples
:ehp2.

      ? HB_OEMTOANSI(&cdq.Harbour&cdq.)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Platforms
:ehp2.
     This functions work only on Windows Plataform     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=321.HB_OEMTOANSI():elink.
.br
:h1 res=321.HB_OEMTOANSI()
:i1 id=HB_OEMTOANSI().HB_OEMTOANSI()
:p.HB_OEMTOANSI()
:p.:hp2.Convert a DOS(OEM) Character to a WINDOWS (ANSI) based character
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_OEMTOANSI(<cString>)  -> cDosString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.    DOS (OEM)  string to convert to WINDOWS (ANSI) String    

:p.:hp2.Returns
:ehp2.
      :hp2. <cDosString>:ehp2.   WINDOWS based  string    

:p.:hp2.Description
:ehp2.
     This function converts each character in <cString> to the corresponding  character in the Windows (ANSI) character set.The character expression  <cString> should contain characters from the OEM character set.  If a character in <cString> doesn't have a ANSI equivalent&comma. the  character is remais the same.     

:p.:hp2.Examples
:ehp2.

      ? HB_OEMTOANSI(&cdq.Harbour&cdq.)
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Platforms
:ehp2.
     This functions work only on Windows Plataform     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=320.HB_ANSITOOEM():elink.
.br
:h1 res=304.LOWER()
:i1 id=LOWER().LOWER()
:p.LOWER()
:p.:hp2.Universally lowercases a character string expression.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LOWER( <cString> ) --> cLowerString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Any character expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cLowerString>:ehp2.   Lowercased value of <cString>    

:p.:hp2.Description
:ehp2.
     This function converts any character expression passes as <cString>  to its lowercased representation.Any nonalphabetic character withing  <cString> will remain unchanged.     

:p.:hp2.Examples
:ehp2.

      ? Lower(&cdq.HARBOUR&cdq.)
      ? Lower(&cdq.Hello All&cdq.)
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible     

:p.:hp2.Platforms
:ehp2.
     ALL     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=305.UPPER():elink.
.br
:link reftype=hd res=302.ISLOWER():elink.
.br
:link reftype=hd res=303.ISUPPER():elink.
.br
:h1 res=305.UPPER()
:i1 id=UPPER().UPPER()
:p.UPPER()
:p.:hp2.Converts a character expression to uppercase format
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.UPPER( <cString> ) --> cUpperString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.   Any character expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cUpperString>:ehp2.   Uppercased value of <cString>    

:p.:hp2.Description
:ehp2.
     This function converts all alpha characters in <cString> to upper  case values and returns that formatted character expression.     

:p.:hp2.Examples
:ehp2.

      ? UPPER(&cdq.harbour&cdq.)
      ? UPPER(&cdq.Harbour&cdq.)
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is CA-Clipper compatible     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=304.LOWER():elink.
.br
:link reftype=hd res=303.ISUPPER():elink.
.br
:link reftype=hd res=302.ISLOWER():elink.
.br
:h1 res=165.CHR()
:i1 id=CHR().CHR()
:p.CHR()
:p.:hp2.Converts an ASCII value to it character value
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CHR(<nAsciiNum>)  --> cReturn
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nAsciiNum>:ehp2.   Any ASCII character code.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturn>:ehp2.   Character expression of that ASCII value    

:p.:hp2.Description
:ehp2.
     This function returns the ASCII character code for <nAsciiNum>.The  number expressed must be an interger value within the range of 0 to  255 inclusive.The CHR() function will send the character returned  to whatever device is presently set.       

     The CHR() function may be used for printing special codes as well  as normal and graphics character codes.     

:p.:hp2.Examples
:ehp2.

      ? CHR(32)
      ? chr(215)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=322.ASC():elink.
.br
:link reftype=hd res=116.INKEY():elink.
.br
:h1 res=322.ASC()
:i1 id=ASC().ASC()
:p.ASC()
:p.:hp2.Returns the ASCII value of a character
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ASC( <cCharacter> ) --> nAscNumber
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cCharacter>:ehp2.   Any character expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <nAscNumber>:ehp2.   ASCII value    

:p.:hp2.Description
:ehp2.
     This function return the ASCII value of the leftmost character of  any character expression passed as <cCharacter>.     

:p.:hp2.Examples
:ehp2.

      ? ASC(&cdq.A&cdq.)
      ? ASC(&cdq.&cdq.)
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=165.CHR():elink.
.br
:h1 res=323.PADC()
:i1 id=PADC().PADC()
:p.PADC()
:p.:hp2.Centers an expression for a given width
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PADC(<xVal>,<nWidth>,<cFill>)  --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xVal>:ehp2.      An number,Character or date to pad      

      :hp2. <nWidth>:ehp2.    Width of output string      

      :hp2. <cFill>:ehp2.     Character to fill in the string    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.   The Center string of <xVal>    

:p.:hp2.Description
:ehp2.
     This function takes an date&comma.number&comma.or character expression <xVal>  and attempt to center the expression within a string of a given width  expressed as <nWidth>.The default character used to pad either side  of <xVal> will be an blank space;however&comma.this character may be  explicitly specified the value of <cFill>.       

     If the lenght of <xVal> is longer then <nWidth>&comma.this function will  truncate the string <xVal> from the leftmost side to the lenght of  <nWidth>.     

:p.:hp2.Examples
:ehp2.

      ? PADC('Harbour'&comma.20)
      ? PADC(34.5142&comma.20)
      ? PADC(Date()&comma.35)

:p.:hp2.Tests
:ehp2.

      See Examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compilant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=309.ALLTRIM():elink.
.br
:link reftype=hd res=324.PADL():elink.
.br
:link reftype=hd res=325.PADR():elink.
.br
:h1 res=324.PADL()
:i1 id=PADL().PADL()
:p.PADL()
:p.:hp2.Left-justifies an expression for a given width
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PADL(<xVal>,<nWidth>,<cFill>)  --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xVal>:ehp2.      An number,Character or date to pad      

      :hp2. <nWidth>:ehp2.    Width of output string      

      :hp2. <cFill>:ehp2.     Character to fill in the string    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.   The left-justifies string of <xVal>    

:p.:hp2.Description
:ehp2.
     This function takes an date&comma.number&comma.or character expression <xVal>  and attempt to left-justify it within a string of a given width  expressed as <nWidth>.The default character used to pad left side  of <xVal> will be an blank space;however&comma.this character may be  explicitly specified the value of <cFill>.       

     If the lenght of <xVal> is longer then <nWidth>&comma.this function will  truncate the string <xVal> from the leftmost side to the lenght of  <nWidth>.     

:p.:hp2.Examples
:ehp2.

      ? PADC('Harbour'&comma.20)
      ? PADC(34.5142&comma.20)
      ? PADC(Date()&comma.35)

:p.:hp2.Tests
:ehp2.

      See examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compilant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=309.ALLTRIM():elink.
.br
:link reftype=hd res=323.PADC():elink.
.br
:link reftype=hd res=325.PADR():elink.
.br
:h1 res=325.PADR()
:i1 id=PADR().PADR()
:p.PADR()
:p.:hp2.Right-justifies an expression for a given width
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.PADR(<xVal>,<nWidth>,<cFill>)  --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xVal>:ehp2.      An number,Character or date to pad      

      :hp2. <nWidth>:ehp2.    Width of output string      

      :hp2. <cFill>:ehp2.     Character to fill in the string    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.   The right-justifies string of <xVal>    

:p.:hp2.Description
:ehp2.
     This function takes an date&comma.number&comma.or character expression <xVal>  and attempt to right-justify it within a string of a given width  expressed as <nWidth>.The default character used to pad right side  of <xVal> will be an blank space;however&comma.this character may be  explicitly specified the value of <cFill>.       

     If the lenght of <xVal> is longer then <nWidth>&comma.this function will  truncate the string <xVal> from the leftmost side to the lenght of  <nWidth>.     

:p.:hp2.Examples
:ehp2.

      ? PADC('Harbour'&comma.20)
      ? PADC(34.5142&comma.20)
      ? PADC(Date()&comma.35)

:p.:hp2.Tests
:ehp2.

      See examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compilant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=309.ALLTRIM():elink.
.br
:link reftype=hd res=323.PADC():elink.
.br
:link reftype=hd res=324.PADL():elink.
.br
:h1 res=309.ALLTRIM()
:i1 id=ALLTRIM().ALLTRIM()
:p.ALLTRIM()
:p.:hp2.Removes leading and trailing blank spaces from a string
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ALLTRIM( <cString> ) --> cExpression
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.     Any character string    

:p.:hp2.Returns
:ehp2.
      :hp2. <cExpression>:ehp2.   An string will all blank spaces removed from <cString>    

:p.:hp2.Description
:ehp2.
     This function returns the string <cExpression> will all leading and  trailing blank spaces removed.     

:p.:hp2.Examples
:ehp2.

      ? ALLTRIM(&cdq.HELLO HARBOUR&cdq.)
      ? ALLTRIM(&cdq.     HELLO HARBOUR&cdq.)
      ? ALLTRIM(&cdq.HELLO HARBOUR     &cdq.)
      ? ALLTRIM(&cdq.     HELLO HARBOUR     &cdq.)

:p.:hp2.Tests
:ehp2.

      See Examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compilant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=306.LTRIM():elink.
.br
:link reftype=hd res=308.RTRIM():elink.
.br
:link reftype=hd res=307.TRIM():elink.
.br
:h1 res=308.RTRIM()
:i1 id=RTRIM().RTRIM()
:p.RTRIM()
:p.:hp2.Remove trailing spaces from a string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RTRIM(<cExpression>)   --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cExpression>:ehp2.     Any character expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.         A formated string with out any blank spaced.    

:p.:hp2.Description
:ehp2.
     This function returns the value of <cString> with any trailing blank  removed.       

     This function is indentical to RTRIM() and the opposite of LTRIM().  Together with LTRIM()&comma.this function equated to the ALLTRIM()  function.     

:p.:hp2.Examples
:ehp2.

      ? RTrim(&cdq.HELLO&cdq.)     //               &cdq.HELLO&cdq.
      ? RTrim( &cdq.&cdq. )       //                &cdq.&cdq.
      ? RTrim( &cdq.UA   &cdq. )  //                &cdq.UA&cdq.
      ? RTrim( &cdq.   UA&cdq. )  //                &cdq.   UA&cdq.

:p.:hp2.Tests
:ehp2.

      See Examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compilant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=309.ALLTRIM():elink.
.br
:link reftype=hd res=306.LTRIM():elink.
.br
:link reftype=hd res=307.TRIM():elink.
.br
:h1 res=307.TRIM()
:i1 id=TRIM().TRIM()
:p.TRIM()
:p.:hp2.Remove trailing spaces from a string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.TRIM(<cExpression>)   --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cExpression>:ehp2.     Any character expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.         A formated string with out any blank spaced.    

:p.:hp2.Description
:ehp2.
     This function returns the value of <cString> with any trailing blank  removed.       

     This function is indentical to RTRIM() and the opposite of LTRIM().  Together with LTRIM()&comma.this function equated to the ALLTRIM()  function.     

:p.:hp2.Examples
:ehp2.

      ? Trim(&cdq.HELLO&cdq.)     //               &cdq.HELLO&cdq.
      ? Trim( &cdq.&cdq. )       //                &cdq.&cdq.
      ? Trim( &cdq.UA   &cdq. )  //                &cdq.UA&cdq.
      ? Trim( &cdq.   UA&cdq. )  //                &cdq.   UA&cdq.

:p.:hp2.Tests
:ehp2.

      See Examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compilant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=308.RTRIM():elink.
.br
:link reftype=hd res=306.LTRIM():elink.
.br
:link reftype=hd res=309.ALLTRIM():elink.
.br
:h1 res=326.REPLICATE()
:i1 id=REPLICATE().REPLICATE()
:p.REPLICATE()
:p.:hp2.Repeats a single character expression
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.REPLICATE(<cString>,<nSize>)  --> cReplicateString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cString>:ehp2.    Character string to be replicated      

      :hp2. <nSize>:ehp2.      Number of times to replicate <cString>    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReplicateString>:ehp2.    A character expression containg the <cString> fill character.     

:p.:hp2.Description
:ehp2.
     This function returns a string composed of <nSize> repetitions of  <cString>.The lenght of the character string returned by this  function is limited to the memory avaliable.       

     A value of 0 for <nSize> will return a NULL string.     

:p.:hp2.Examples
:ehp2.

      ? Replicate('a'&comma.10)    // aaaaaaaaaa
      ? Replicate('b'&comma.100000)

:p.:hp2.Tests
:ehp2.

      See Examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant in all aspects&comma. with the  exception don't have the Clipper 64Kb string length.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=327.SPACE():elink.
.br
:link reftype=hd res=323.PADC():elink.
.br
:link reftype=hd res=324.PADL():elink.
.br
:link reftype=hd res=325.PADR():elink.
.br
:h1 res=327.SPACE()
:i1 id=SPACE().SPACE()
:p.SPACE()
:p.:hp2.Returns a string of blank spaces
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SPACE( <nSize> ) --> cString
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nSize>:ehp2.      The lenght of the string    

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.    An string containing blank spaces    

:p.:hp2.Description
:ehp2.
     This function returns a string consisting of <nSize> blank spaces. If  the value of <nSize> is 0&comma.a NULL string will be returned.       

     This function is useful to declare the lenght of a character memory  variable.     

:p.:hp2.Examples
:ehp2.

      FUNC MAIN
      LOCAL cBigString
      LOCAL cFirst
      LOCAL cString &colon.= Space(20)   //Create an characte memory variable
                                   // with lenght 20
      ? len(cString)      // 20
      cBigString&colon.=space(100000)    // create a memory variable with 100000
                                   // blank spaces
      ?  len(cBigString)
      Use Tests New
      cFirst&colon.= makeempty(1)
      ? len(cFirst)
      Return Nil

      Function MakeEmpty(xField)
      LOCAL nRecord
      LOCAL xRetValue

      If !empty(alias())
          nRecord&colon.=recno()
          dbgoto(0)
          if valtype(xField)==&cdq.C&cdq.
              xField&colon.= ascan(dbstruct()&comma.{|aFields| aFields[1]==upper(xfield)})
          else
              default xField to 0
              if xField < 1 .or. xField>fcount()
                  xfield&colon.=0
              endif
          endif
          if !(xfield ==0)
              xRetvalue&colon.=fieldget(xfield)
          endif
          dbgoto(nrecord)
      endif
      return( xRetvalue)

:p.:hp2.Tests
:ehp2.

      See examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compliant in all aspects&comma. with the  exception don't have the Clipper 64Kb string length.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is Rtl     
.br
See Also&colon.
:link reftype=hd res=323.PADC():elink.
.br
:link reftype=hd res=324.PADL():elink.
.br
:link reftype=hd res=325.PADR():elink.
.br
:link reftype=hd res=326.REPLICATE():elink.
.br
:h1 res=328.TCLASS()
:i1 id=TCLASS().TCLASS()
:p.TCLASS()
:p.:hp2.TClass() is used in the creation of all classes
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.oClass := TClass():New("TMyClass")
:ehp2.
:p.:hp2.-or-
:ehp2.
:p.:hp2.TClass() is usually accessed by defining a class with the commands
:ehp2.
:p.:hp2.defined in hbclass.h:
:ehp2.
:p.:hp2.CLASS TGetList    // Calls TClass() to create the TGetList class
:ehp2.
:p.:hp2....
:ehp2.
:p.:hp2.ENDCLASS
:ehp2.
:p.:hp2.Arguments
:ehp2.

:p.:hp2.Returns
:ehp2.
      An  instance of the TClass Class. This special object's :New() method can then create the classes you define.     

:p.:hp2.Description
:ehp2.
     TClass is a class that ...  The class methods are as follows&colon.       

       New()                 Create a new instance of the class     

:p.:hp2.Examples
:ehp2.

      FUNCTION TestObject()
      local oObject

      oObject &colon.= TClass()&colon.New(&cdq.TMyClass&cdq.)
      oObject&colon.End()

     RETURN Nil
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Object Oriented syntax in Harbour is compatible with CA-CLIPPER.  But Clipper only allowed creation of objects from a few standard  classes&comma. and did not let the programmer create new classes.  In Harbour&comma. you can create your own classes--complete with  Methods&comma. Instance Variables&comma. Class Variables and Inheritance.  Entire applications can be designed and coded in Object Oriented  style.     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=175.__objHasData():elink.
.br
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:h1 res=331.__XSAVESCREEN()
:i1 id=__XSAVESCREEN().__XSAVESCREEN()
:p.__XSAVESCREEN()
:p.:hp2.Save whole screen image and coordinate to an internal buffer
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__XSaveScreen() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       none.    

:p.:hp2.Returns
:ehp2.
      :hp2. __XSaveScreen():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __XSaveScreen() save the image of the whole screen into an internal  buffer&comma. it also save current cursor position. The information could  later be restored by __XRestScreen(). Each call to __XSaveScreen()  overwrite the internal buffer.       

     SAVE SCREEN command is preprocessed into __XSaveScreen() function  during compile time. Note that SAVE SCREEN TO is preprocessed into  SAVESCREEN() function.       

     __XSaveScreen() is a compatibility function&comma. it is superseded by  SAVESCREEN() which allow you to save part or all the screen into a  variable.     

:p.:hp2.Examples
:ehp2.

      // save the screen&comma. display list of files than restore the screen
      SAVE SCREEN
      DIR *.*
      WAIT
      RESTORE SCREEN
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __XSaveScreen() works exactly like CA-Clipper's __XSaveScreen()     

:p.:hp2.Platforms
:ehp2.
     __XSaveScreen() is part of the GT API&comma. and supported only by some  platforms.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=332.RESTORE SCREEN:elink.
.br
:link reftype=hd res=333.RESTSCREEN():elink.
.br
:link reftype=hd res=334.SAVESCREEN():elink.
.br
:h1 res=335.SAVE SCREEN
:i1 id=SAVE SCREEN.SAVE SCREEN
:p.SAVE SCREEN
:p.:hp2.Save whole screen image and coordinate to an internal buffer
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SAVE SCREEN
:ehp2.
:p.:hp2.Arguments
:ehp2.
       none.    

:p.:hp2.Returns
:ehp2.
      SAVE  SCREEN always return NIL.    

:p.:hp2.Description
:ehp2.
     SAVE SCREEN save the image of the whole screen into an internal  buffer&comma. it also save current cursor position. The information could  later be restored by REST SCREEN. Each call to SAVE SCREEN  overwrite the internal buffer.       

     SAVE SCREEN command is preprocessed into __XSaveScreen() function  during compile time. Note that SAVE SCREEN TO is preprocessed into  SAVESCREEN() function.     

:p.:hp2.Examples
:ehp2.

      // save the screen&comma. display list of files than restore the screen
      SAVE SCREEN
      DIR *.*
      WAIT
      RESTORE SCREEN
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __XSaveScreen() works exactly like CA-Clipper's __XSaveScreen()     

:p.:hp2.Platforms
:ehp2.
     __XSaveScreen() is part of the GT API&comma. and supported only by some  platforms.     
.br
See Also&colon.
:link reftype=hd res=332.RESTORE SCREEN:elink.
.br
:link reftype=hd res=336.__XRESTSCREEN():elink.
.br
:link reftype=hd res=331.__XSAVESCREEN():elink.
.br
:h1 res=336.__XRESTSCREEN()
:i1 id=__XRESTSCREEN().__XRESTSCREEN()
:p.__XRESTSCREEN()
:p.:hp2.Restore screen image and coordinate from an internal buffer
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__XRestScreen() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       none.    

:p.:hp2.Returns
:ehp2.
      :hp2. __XRestScreen():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __XRestScreen() restore saved image of the whole screen from an  internal buffer that was saved by __XSaveScreen()&comma. it also restore  cursor position. After a call to __XRestScreen() the internal buffer  is cleared.       

     RESTORE SCREEN command is preprocessed into __XRestScreen() function  during compile time. Note that RESTORE SCREEN FROM is preprocessed  into RESTSCREEN() function.       

     __XRestScreen() is a compatibility function&comma. it is superseded by  RESTSCREEN() which allow you to restore the screen from a variable.     

:p.:hp2.Examples
:ehp2.

      // save the screen&comma. display list of files than restore the screen
      SAVE SCREEN
      DIR *.*
      WAIT
      RESTORE SCREEN
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __XRestScreen() works exactly like CA-Clipper's __XRestScreen()     

:p.:hp2.Platforms
:ehp2.
     __XRestScreen() is part of the GT API&comma. and supported only by some  platforms.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=336.__XRESTSCREEN():elink.
.br
:link reftype=hd res=335.SAVE SCREEN:elink.
.br
:link reftype=hd res=331.__XSAVESCREEN():elink.
.br
:h1 res=332.RESTORE SCREEN
:i1 id=RESTORE SCREEN.RESTORE SCREEN
:p.RESTORE SCREEN
:p.:hp2.Restore screen image and coordinate from an internal buffer
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.RESTORE SCREEN
:ehp2.
:p.:hp2.Arguments
:ehp2.
       none.    

:p.:hp2.Returns
:ehp2.
      REST  SCREEN always return NIL.    

:p.:hp2.Description
:ehp2.
     Rest Screen restore saved image of the whole screen from an  internal buffer that was saved by Save Screen&comma. it also restore  cursor position. After a call to Rest Screen the internal buffer  is cleared.       

     RESTORE SCREEN command is preprocessed into __XRestScreen() function  during compile time. Note that RESTORE SCREEN FROM is preprocessed  into RESTSCREEN() function.     

:p.:hp2.Examples
:ehp2.

      // save the screen&comma. display list of files than restore the screen
      SAVE SCREEN
      DIR *.*
      WAIT
      RESTORE SCREEN
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Rest Screen() works exactly like CA-Clipper's Rest Screen     

:p.:hp2.Platforms
:ehp2.
     Rest Screen is part of the GT API&comma. and supported only by some  platforms.     
.br
See Also&colon.
:link reftype=hd res=336.__XRESTSCREEN():elink.
.br
:link reftype=hd res=335.SAVE SCREEN:elink.
.br
:link reftype=hd res=331.__XSAVESCREEN():elink.
.br
:h1 res=337.ALERT()
:i1 id=ALERT().ALERT()
:p.ALERT()
:p.:hp2.Display a dialog box with a message
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ALERT( <xMessage>, [<aOptions>], [<cColorNorm>], [<nDelay>] ) --> nChoice or NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xMessage>:ehp2.   Message to display in the dialog box.  can be of any Harbour type.  If <xMessage> is an array of Character strings, each element would  be displayed in a new line. If <xMessage> is a Character  string, you could split the message to several lines by placing  a semicolon (;) in the desired places.       

      :hp2. <aOptions>:ehp2.   Array with available response. Each element should be Character string. If omitted, default is { "Ok" }.       

      :hp2. <cColorNorm>:ehp2.   Color string to paint the dialog box with. If omitted, default color is "W+/R".       

      :hp2. <nDelay>:ehp2.   Number of seconds to wait to user response before abort. Default value is 0, that wait forever.     

:p.:hp2.Returns
:ehp2.
      :hp2. ALERT():ehp2.   return Numeric value representing option number chosen. If ESC was pressed, return value is zero. The return value is NIL  if ALERT() is called with no parameters, or if <xMessage> type is  not Character and HB_C52_STRICT option was used. If <nDelay> seconds  had passed without user response, the return value is 1.     

:p.:hp2.Description
:ehp2.
     ALERT() display simple dialog box on screen and let the user select  one option. The user can move the highlight bar using arrow keys or  TAB key. To select an option the user can press ENTER&comma. SPACE or the  first letter of the option.       

     If the program is executed with the //NOALERT command line switch&comma.  nothing is displayed and it simply returns NIL. This switch could  be overridden with __NONOALERT().       

     If the GT system is linked in&comma. ALERT() display the message using  the full screen I/O system&comma. if not&comma. the information is printed to  the standard output using OUTSTD().     

:p.:hp2.Examples
:ehp2.

      LOCAL cMessage&comma. aOptions&comma. nChoice

      // harmless message
      cMessage &colon.= &cdq.Major Database Corruption Detected!;&cdq. +  ;
                  &cdq.(deadline in few hours);;&cdq.             +  ;
                  &cdq.where DO you want to go today?&cdq.

      // define response option
      aOptions &colon.= { &cdq.Ok&cdq.&comma. &cdq.www.jobs.com&cdq.&comma. &cdq.Oops&cdq. }

      // show message and let end user select panic level
      nChoice &colon.= ALERT( cMessage&comma. aOptions )
      DO CASE
         CASE nChoice == 0
              // do nothing&comma. blame it on some one else
         CASE nChoice == 1
              ? &cdq.Please call home and tell them you're gonn'a be late&cdq.
         CASE nChoice == 2
              // make sure your resume is up to date
         CASE nChoice == 3
              ? &cdq.Oops mode is not working in this version&cdq.
      ENDCASE
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is sensitive to HB_C52_STRICT settings during the  compilation of source/rtl/alert.prg       

     &colon.hp2. defined&colon.ehp2. &colon. <xMessage> accept Character values only and return  NIL if other types are passed.       

     &colon.hp2. undefined&colon.ehp2. &colon. <xMessage> could be any type&comma. and internally  converted to Character string. If type is Array&comma. multi-line message  is displayed.       

     &colon.hp2. defined&colon.ehp2. &colon. Only the first four valid <aOptions> are taken.       

     &colon.hp2. undefined&colon.ehp2. &colon. <aOptions> could contain as many as needed options.       

     If HB_COMPAT_C53 was define during compilation of  source/rtl/alert.prg the Left-Mouse button could be used to select  an option.       

     The interpretation of the //NOALERT command line switch is done only  if HB_C52_UNDOC was define during compilation of source/rtl/alert.prg       

     <cColorNorm> is a Harbour extension&comma. or at least un-documented  in Clipper 5.2 NG.       

     <nDelay> is a Harbour extension.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=152.MENU TO:elink.
.br
:link reftype=hd res=338.STDOUT():elink.
.br
:link reftype=hd res=339.__NONOALERT():elink.
.br
:h1 res=339.__NONOALERT()
:i1 id=__NONOALERT().__NONOALERT()
:p.__NONOALERT()
:p.:hp2.Override //NOALERT command line switch
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__NONOALERT() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      This  function takes no arguments.    

:p.:hp2.Returns
:ehp2.
      :hp2. __NONOALERT():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     The //NOALERT command line switch cause Clipper to ignore calls to  the ALERT() function&comma. this function override this behavior  and always display ALERT() dialog box.     

:p.:hp2.Examples
:ehp2.

      // make sure alert are been displayed
      __NONOALERT()
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Files
:ehp2.
     Library is rtl     

:p.:hp2.Compliance
:ehp2.
     __NONOALERT() is an undocumented CA-Clipper function and exist only  if HB_C52_UNDOC was defined during the compilation of  source/rtl/alert.prg     
:h1 res=340.HB_OSNEWLINE()
:i1 id=HB_OSNEWLINE().HB_OSNEWLINE()
:p.HB_OSNEWLINE()
:p.:hp2.Returns the newline character(s) to use with the current OS
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_OSNewLine() --> cString
:ehp2.

:p.:hp2.Returns
:ehp2.
      :hp2. <cString>:ehp2.   A character string containing the character or characters required to move the screen cursor or print head to the start of a  new line. The string will hold either CHR(10) or CHR(13) + CHR(10).     

:p.:hp2.Description
:ehp2.
     Returns a character string containing the character or characters  required to move the screen cursor or print head to the start of a  new line for the operating system that the program is running on  (or thinks it is running on&comma. if an OS emulator is being used).     

:p.:hp2.Examples
:ehp2.

      // Get the newline character(s) for the current OS using defaults.
      STATIC s_cNewLine
      ...
      s_cNewLine &colon.= HB_OSNewLine()
      ...
      OutStd( &cdq.Hello World!&cdq. + s_cNewLine )
      ...

:p.:hp2.Tests
:ehp2.

      
      valtype( HB_OSNewLine() ) == &cdq.C&cdq.
      LEN( HB_OSNewLine() ) == 1
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This is an add-on Operating System Tool function.     

:p.:hp2.Platforms
:ehp2.
     Under OS_UNIX_COMPATIBLE operating system the return value is the  Line-Feed (0x0a) character CHR(10)&comma. with other operating systems  (like DOS) the return value is the Carriage-Return plus Line-Feed  (0x0d 0x0a) characters CHR(13)+CHR(10).     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=159.OS():elink.
.br
:link reftype=hd res=341.OUTSTD():elink.
.br
:link reftype=hd res=342.OUTERR():elink.
.br
:h1 res=343.HB_COLORINDEX()
:i1 id=HB_COLORINDEX().HB_COLORINDEX()
:p.HB_COLORINDEX()
:p.:hp2.Extract one color from a full Clipper colorspec string.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.hb_ColorIndex( <cColorSpec>, <nIndex> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cColorSpec>:ehp2.   is a Clipper color list      

      :hp2. <nIndex>:ehp2.   is the position of the color item to be extracted, the first position is the zero.     

:p.:hp2.Returns
:ehp2.
      The  selected color string, or if anything goes wrong, an empty string.     

:p.:hp2.Description
:ehp2.
     Clipper has a color spec string&comma. which has more than one  color in it&comma. separated with commas. This function is able to extract  a given item from this list. You may use the manifest constants  defined in color.ch to extract common Clipper colors.     

:p.:hp2.Examples
:ehp2.

      ? hb_ColorIndex( &cdq.W/N&comma. N/W&cdq.&comma. CLR_ENHANCED ) // &cdq.N/W&cdq.

:p.:hp2.Tests
:ehp2.

      see the regression test suit for comprehensive tests.
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Was not part of CA-Clipper.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=344.ColorSelect():elink.
.br
:h1 res=345.DEVOUTPICT()
:i1 id=DEVOUTPICT().DEVOUTPICT()
:p.DEVOUTPICT()
:p.:hp2.Displays a value to a device using a picture template
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DEVOUTPICT(<xExp>,<cPicture>[,<cColorString>]) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xExp>:ehp2.   is any valid expression.      

      :hp2. <cPicture>:ehp2.   is any picture transformation that TRANSFORM() can use.      

      :hp2. <cColorString>:ehp2.   is an optional string that specifies a screen color to use in place of the default color when the output goes to the screen.     

:p.:hp2.Returns
:ehp2.
       NIL    

:p.:hp2.Description
:ehp2.
     Outputs any expression using a picture transformation instead of  using the default transformation for the type of expression.     

:p.:hp2.Examples
:ehp2.

      // Output a negative dollar amount using debit notation.
      DEVOUTPICT( -1.25&comma. &cdq.@D$ 99&comma.999.99 )

:p.:hp2.Tests
:ehp2.

      
      @ 3&comma.1 SAY -1.25 PICTURE &cdq.@D$ 99&comma.999.99&cdq.
      will display &cdq.$(     1.25)&cdq. starting on row four&comma. column two of the
      current device (without the double quotation marks&comma. of course).
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DEVOUTPICT() is mostly CA-Clipper compliant. Any differences are due  to enhancements in the Harbour TRANSFORM() over CA-Clipper.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=298.DEVOUT():elink.
.br
:link reftype=hd res=35.TRANSFORM():elink.
.br
:h1 res=289.__INPUT()
:i1 id=__INPUT().__INPUT()
:p.__INPUT()
:p.:hp2.Stops application
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__INPUT( <cMessage> ) --> <cString>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cMessage>:ehp2.   is any valid expression.    

:p.:hp2.Returns
:ehp2.
      Macroed  <cString>    

:p.:hp2.Description
:ehp2.
     This function waits for a console input and returns macroed  expression entered.     
:p.:hp2.Status
:ehp2.
   Started

:p.:hp2.Compliance
:ehp2.
     __INPUT() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=346.__WAIT():elink.
.br
:link reftype=hd res=288.__ACCEPT():elink.
.br
:h1 res=347.__TEXTSAVE()
:i1 id=__TEXTSAVE().__TEXTSAVE()
:p.__TEXTSAVE()
:p.:hp2.Redirect console output to printer or file and save old settings
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__TextSave( <cFile> ) --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFile>:ehp2.   is either "PRINTER" (note the uppercase) in which console output is SET to PRINTER, or a name of a text file with a default  ".txt" extension, that is used to redirect console output.     

:p.:hp2.Returns
:ehp2.
      :hp2. __TextSave():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __TextSave() is used in the preprocessing of the TEXT TO command to  redirect the console output while saving old settings that can be  restored later by __TextRestore().     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __TextSave() is an Undocumented CA-Clipper function     

:p.:hp2.Platforms
:ehp2.
     ALL     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=92.SET():elink.
.br
:link reftype=hd res=291.SET ALTERNATE:elink.
.br
:link reftype=hd res=97.SET PRINTER:elink.
.br
:link reftype=hd res=348.TEXT:elink.
.br
:link reftype=hd res=349.__TextRestore():elink.
.br
:h1 res=350.__TEXTRESTORE()
:i1 id=__TEXTRESTORE().__TEXTRESTORE()
:p.__TEXTRESTORE()
:p.:hp2.Restore console output settings as saved by __TextSave()
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__TextRestore() --> NIL
:ehp2.
:p.:hp2.Arguments
:ehp2.
       none.    

:p.:hp2.Returns
:ehp2.
      :hp2. __TextRestore():ehp2.   always return NIL.    

:p.:hp2.Description
:ehp2.
     __TextRestore() is used in the preprocessing of the TEXT TO command  to restore console output settings that were previously saved by  __TextSave().     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __TextRestore() is an Undocumented CA-Clipper function     

:p.:hp2.Platforms
:ehp2.
      All     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=92.SET():elink.
.br
:link reftype=hd res=291.SET ALTERNATE:elink.
.br
:link reftype=hd res=97.SET PRINTER:elink.
.br
:link reftype=hd res=348.TEXT:elink.
.br
:link reftype=hd res=351.__TextSave():elink.
.br
:h1 res=346.__WAIT()
:i1 id=__WAIT().__WAIT()
:p.__WAIT()
:p.:hp2.Stops the application until a key is pressed.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__WAIT( <cMessage> ) --> <cKey>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cMessage>:ehp2.   is a string.    

:p.:hp2.Returns
:ehp2.
      Pressed  key.    

:p.:hp2.Description
:ehp2.
     This function stops the application until a key is pressed. The key  must be in the range 32..255. Control keys are not processed.     

:p.:hp2.Examples
:ehp2.

      // Wait for a key stroke
      __Wait( &cdq.Press a key to continue&cdq. )

:p.:hp2.Tests
:ehp2.

      
      do while cKey != &cdq.Q&cdq.
        cKey &colon.= __Wait( &cdq.Press 'Q' to continue&cdq. )
      end do
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     __WAIT() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=288.__ACCEPT():elink.
.br
:link reftype=hd res=289.__INPUT():elink.
.br
:h1 res=352.READVAR()
:i1 id=READVAR().READVAR()
:p.READVAR()
:p.:hp2.Return variable name of current GET or MENU
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.READVAR( [<cVarName>] ) --> cOldVarName
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cVarName>:ehp2.   is a new variable name to set.    

:p.:hp2.Returns
:ehp2.
      :hp2. READVAR():ehp2.   return the old variable name. If no variable previously was set, READVAR() return "".        

:p.:hp2.Description
:ehp2.
     READVAR() is set inside a READ or MENU TO command to hold the  uppercase name of the GET / MENU TO variable&comma. and re-set back to old  value when those commands finished. You should not normally set a  variable name but rather use it to retrieve the name of a GET  variable when executing a VALID or WHEN clause&comma. or during SET KEY  execution and you are inside a READ or MENU TO.        

:p.:hp2.Examples
:ehp2.

      // display a menu&comma. press F1 to view the MENU TO variable name
      CLS
      @ 1&comma. 10 PROMPT &cdq.blood sucking insect that infect beds   &cdq.
      @ 2&comma. 10 PROMPT &cdq.germ; virus infection                   &cdq.
      @ 3&comma. 10 PROMPT &cdq.defect; snag; (source of) malfunctioning&cdq.
      @ 4&comma. 10 PROMPT &cdq.small hidden microphone                 &cdq.
      @ 6&comma. 10 SAY &cdq.(Press F1 for a hint)&cdq.
      SET KEY 28 TO ShowVar
      MENU TO What_Is_Bug

      PROCEDURE ShowVar
      ALERT( READVAR() )        // WHAT_IS_BUG in red ALERT() box
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     READVAR() works exactly like CA-Clipper's READKEY()&comma. note however&comma.  that the <cVarName> parameter is not documented and used internally  by CA-Clipper.        

:p.:hp2.Platforms
:ehp2.
     All   

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=125.@...GET:elink.
.br
:link reftype=hd res=158.@...PROMPT:elink.
.br
:link reftype=hd res=152.MENU TO:elink.
.br
:link reftype=hd res=126.READ:elink.
.br
:link reftype=hd res=110.SET KEY:elink.
.br
:link reftype=hd res=353.__AtPrompt():elink.
.br
:link reftype=hd res=354.__MenuTo():elink.
.br
:h1 res=355.LABEL FORM
:i1 id=LABEL FORM.LABEL FORM
:p.LABEL FORM
:p.:hp2.Displays labels to the screen or an alternate device
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.LABEL FORM <cLabelName> [TO PRINTER] [TO FILE <cFile>] [<cScope>] [WHILE <bWhile> ] [FOR <bFor> ] [SAMPLE] [NOCONSOLE]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cLabelName>:ehp2.     Name of label file    

      :hp2. <cFile>:ehp2.          Name of an alternate file    

      :hp2. <cScope>:ehp2.         Expression of a scoping condition    

      :hp2. <bWhile>:ehp2.         WHILE condition    

      :hp2. <bFor>:ehp2.           FOR condition    

:p.:hp2.Description
:ehp2.
     This command allows labels to be printed based on the format outlined in  .LBL file specified as <cLabelName>. By default&comma. output will go to the  screen however this output may be rerouted with either the TO PRINTER or  the TO FILE clause.        

     If the TO FILE clause is specified&comma. the name of the ASCII text file  containing the generated labels will be <cFile>.        

     If no file extension is specified a .TXT extension is added.  <cScope> is the scope condition for this command. Valid scopes include  NEXT <expN> (number of records to be displayed&comma. where <expN> is the number  of records)&comma. RECORD <expN> (a specific record to be printed)&comma. REST (all  records starting from the current record position&comma.and ALL (all records).  The default is ALL.        

     Both logical expression may work ill conjunction with one another where  <bFor> is the logical expression for the FOR condition (for records to  be displayed whitin a given value range) and <bWhile> for the WHILE  condition (for records to be displayed until they fail to meet the  condition).        

     If the SAMPLE clause is specified&comma. test labels will be generated.   

     If the NOCONSOLE clause is specified&comma.the console will be turned off while  this command is being executed.        

     This command follows the search criteria outlined in the SET PATH TO  command. The path may be specified&comma. along&comma. with (the drive letter&comma. in  <cLabelName>        

:p.:hp2.Examples
:ehp2.

      FUNCTION MAIN()
      USE Test New
      LABEL FORM EE
      USE
      RETURN NIL


:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This command is CA-Clipper compliant.   

:p.:hp2.Platforms
:ehp2.
     ALL   

:p.:hp2.Files
:ehp2.
     Library is Rtl.lib     
.br
See Also&colon.
:link reftype=hd res=356.REPORT FORM:elink.
.br
:h1 res=356.REPORT FORM
:i1 id=REPORT FORM.REPORT FORM
:p.REPORT FORM
:p.:hp2.Display a report
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.REPORT FORM <cReportName> [TO PRINTER] [TO FILE <cFile>] [<cScope>] [WHILE <bWhile> ] [FOR <bFor> ] [PLAIN |HEADING <cHeading>] [NOEJECT] [SUMMARY] [NOCONSOLE]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cReportName>:ehp2.   Name of report file      

      :hp2. <cFile>:ehp2.         Name of alternate file      

      :hp2. <cScope>:ehp2.        Scope.      

      :hp2. <bWhile>:ehp2.        Logical expression of WHILE condition .      

      :hp2. <bFor>:ehp2.          Logical expression of FOR condition.      

      :hp2. <cHeading>:ehp2.      Report heading    

:p.:hp2.Returns
:ehp2.
       NIL    

:p.:hp2.Description
:ehp2.
     This command prints out the report named <cReportName>&comma. which is a standard  FRM file. The file extension is not required because FRM will be assumed.  The SET PATH TO and SET DEFAULT TO commands affect the search for the file  <cReportName>; unless a drive and path are specified in <cReportName>&comma. REPORT  will search the path specified in the SET PATH command if it cannot find the  report form in the current directory.       

     The output of the report will be offset based on the setting of the SET MARGIN  TO value.       

     By default&comma. output will go to the console; however&comma. it may be controlled via  either the TO PRINTER or TO FILE clause. If the output is to go to the file&comma.  the name of the alternate file is specified in <cFile>. Unless specified in  <cFile>&comma. the default file extension will be .TXT .  <cScope> is the scope for this command. Valid scopes include NEXT <expN> (where  <expN> is tile number of records)&comma. RECORD <expN> (a specific record to be  displayed)&comma. REST (all records from the current record position)&comma. and ALL  (all records). The default is ALL.       

     Both logical expressions may work in conjuntion with one another&comma. where <bFor>  is the logical expression for the FOR condition (for records to be displayed  within a given range) and <bWhile> for the WHILE condition (for records to be  displayed until the condition fails).       

     If the PLAIN clause is specified&comma. date and page numbers are suppressed. In  addition&comma. there is no  automatic page breaking&comma. and the report title and  column headings appear only once at the top of the form.       

     If the HEADING clause is used&comma. <cHeading> is displayed on the first title  of each report page. The value of <cHeading> is evaluated only once before  executing the report; varying the values of <cHeading> is not allowed. The  PLAIN clause will take precedence over the HEADING clause if both are included.       

     If the NOEJECT clause is used&comma. the initial page eject on the report will not be  issued when the output clause TO PRINTER is specified. Otherwise&comma. this clause has  no effect.       

     If the SUMMARY Clause is specified&comma. the report will contain only groups&comma. subgroups&comma.  and grand total information. The detailed title item information will be ignored.       

     If the NOCONSOLE clause is specified&comma.output to the console will be turned off  while this command is being executed.     

:p.:hp2.Examples
:ehp2.

      FUNCTION() MAIN
      USE Test New
      Report FORM EE
      USE
      RETURN NIL
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This Command is CA-Clipper compliant.     

:p.:hp2.Platforms
:ehp2.
     ALL     

:p.:hp2.Files
:ehp2.
     Library is Rtl.lib     
.br
See Also&colon.
:link reftype=hd res=355.LABEL FORM:elink.
.br
:h1 res=357.__MVPUBLIC()
:i1 id=__MVPUBLIC().__MVPUBLIC()
:p.__MVPUBLIC()
:p.:hp2.This function creates a PUBLIC variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVPUBLIC( <variable_name> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <variable_name>:ehp2.   = either a string that contains the variable's name or an one-dimensional array of strings with variable names  No skeleton are allowed here.     

:p.:hp2.Returns
:ehp2.
       Nothing    

:p.:hp2.Description
:ehp2.
     This function can be called either by the harbour compiler or by user.  The compiler always passes the item of IT_SYMBOL type that stores the  name of variable.  If a variable with the same name exists already then the new  variable is not created - the previous value remains unchanged.  If it is first variable with this name then the  variable is  initialized with .T. value.     

:p.:hp2.Examples
:ehp2.

      None Avaliable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
:h1 res=358.__MVPRIVATE()
:i1 id=__MVPRIVATE().__MVPRIVATE()
:p.__MVPRIVATE()
:p.:hp2.This function creates a PRIVATE variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVPRIVATE( <variable_name> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <variable_name>:ehp2.   = either a string that contains the variable's name or an one-dimensional array of strings with variable names  No skeleton are allowed here.     

:p.:hp2.Returns
:ehp2.
       Nothing    

:p.:hp2.Description
:ehp2.
     This function can be called either by the harbour compiler or by user.  The compiler always passes the item of IT_SYMBOL type that stores the  name of variable.  If a variable with the same name exists already then the value of old  variable is hidden until the new variable is  released. The new variable  is always initialized to NIL value.     

:p.:hp2.Examples
:ehp2.

      None Avaliable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
:h1 res=359.__MVXRELEASE()
:i1 id=__MVXRELEASE().__MVXRELEASE()
:p.__MVXRELEASE()
:p.:hp2.This function releases value stored in PRIVATE or PUBLIC variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVXRELEASE( <variable_name> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <variable_name>:ehp2.   = either a string that contains the variable's name or an one-dimensional array of strings with variable names  No skeleton are allowed here.     

:p.:hp2.Returns
:ehp2.
       Nothing    

:p.:hp2.Description
:ehp2.
     This function releases values stored in memory variable. It shouldn't  be called directly&comma. rather it should be placed into RELEASE command.  If the released variable is a PRIVATE variable then previously hidden  variable with the same name becomes visible after exit from the  procedure where released variable was created. If you access  the released variable in the same function/procedure where it  was created the the NIL value is returned. You can however assign  a new value to released variable without any side effects.       

     It releases variable even if this variable was created in different  procedure     

:p.:hp2.Examples
:ehp2.



      PROCEDURE MAIN()
      PRIVATE mPrivate

        mPrivate &colon.=&cdq.PRIVATE from MAIN()&cdq.
        ? mPrivate     //PRIVATE from MAIN()
        Test()
        ? mPrivate     //PRIVATE from MAIN()

      RETURN

      PROCEDURE Test()
      PRIVATE mPrivate

        mPrivate &colon.=&cdq.PRIVATE from Test()&cdq.
        ? mPrivate           //PRIVATE from TEST()
        RELEASE mPrivate
        ? mPrivate           //NIL
        mPrivate &colon.=&cdq.Again in Test()&cdq.

      RETURN
  
:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm       

:h1 res=360.__MVRELEASE()
:i1 id=__MVRELEASE().__MVRELEASE()
:p.__MVRELEASE()
:p.:hp2.This function releases PRIVATE variables
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVRELEASE( <skeleton>, <include_exclude_flag> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <skeleton>:ehp2.   = string that contains the wildcard mask for variables' names that will be released. Supported wildcards: '*' and '?'  <include_exclude_flag> = logical value that specifies if variables  that match passed skeleton should be either included in deletion  (if .T.) or excluded from deletion (if .F.)     

:p.:hp2.Returns
:ehp2.
       Nothing    

:p.:hp2.Description
:ehp2.
     This function releases values stored in memory variables. It shouldn't  be called directly&comma. it should be placed into RELEASE ALL command.  If the released variable is a PRIVATE variable then previously hidden  variable with the same name becomes visible after exit from the  procedure where released variable was created. If you access  the released variable in the same function/procedure where it  was created the the NIL value is returned. You can however assign  a new value to released variable without any side effects.  PUBLIC variables are not changed by this function.     

:p.:hp2.Examples
:ehp2.

      None Avaliable
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
:h1 res=361.__MVSCOPE()
:i1 id=__MVSCOPE().__MVSCOPE()
:p.__MVSCOPE()
:p.:hp2.If variable exists then returns its scope.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVSCOPE( <cVarName> )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cVarName>:ehp2.   = a string with a variable name to check    

:p.:hp2.Returns
:ehp2.
      The  symbolic values are defined in include/hbmemvar.ch HB_MV_NOT_FOUND     =variable is not declared (not found in symbol table)  HB_MV_UNKNOWN       =if variable doesn't exist (but found in symbol table)  HB_MV_ERROR         =if information cannot be obtained (memory error  or argument error)  HB_MV_PUBLIC         =for public variables  HB_MV_PRIVATE_GLOBAL =for private variables declared outside of current  function/procedure  HB_MV_PRIVATE_LOCAL  =for private variables declared in current  function/procedure     

:p.:hp2.Examples
:ehp2.



      PROCEDURE MAIN()
      PUBLIC mPublic
      PRIVATE mPrivateGlobal

      CallProc()
      ? __mvScope( &cdq.mPrivateLocal&cdq. )      //HB_MV_UNKNOWN

      RETURN

      PROCEDURE CallProc()
      PRIVATE mPrivateLocal

      ? __mvScope( &cdq.mPublic&cdq. )            //HB_MV_PUBLIC
      ? __mvScope( &cdq.mPrivateGlobal&cdq. )     //HB_MV_PRIVATE_GLOBAL
      ? __mvScope( &cdq.mPrivateLocal&cdq. )      //HB_MV_PRIVATE_LOCAL
      ? __mvScope( &cdq.mFindMe&cdq. )            //HB_MV_NOT_FOUND

      IF( __mvScope( &cdq.mPublic&cdq. ) > HB_MV_ERROR )
         ? &cdq.Variable exists&cdq.
      ELSE
         ? &cdq.Variable not created yet&cdq.
      ENDIF

      RETURN

  
:p.:hp2.Status
:ehp2.
   Ready
:p.:hp2.Compliance
:ehp2.
     This function is a Harbour Extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=362.include/hbmemvar.ch:elink.
.br
:h1 res=363.__MVCLEAR()
:i1 id=__MVCLEAR().__MVCLEAR()
:p.__MVCLEAR()
:p.:hp2.This function releases all PRIVATE and PUBLIC variables
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVCLEAR()
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None    

:p.:hp2.Returns
:ehp2.
       Nothing    

:p.:hp2.Description
:ehp2.
     This function releases all PRIVATE and PUBLIC variables.  It is used to implement CLEAR MEMORY statement.  The memory occupied by all visible variables are released - any  attempt to access the variable will result in a runtime error.  You have to reuse PRIVATE or PUBLIC statement to create again  the variable that was cleared by this function.     
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=357.__MVPUBLIC():elink.
.br
:h1 res=364.__MVDBGINFO()
:i1 id=__MVDBGINFO().__MVDBGINFO()
:p.__MVDBGINFO()
:p.:hp2.This function returns the information about the variables for debugger
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVDBGINFO( <nScope> [, <nPosition> [, @<cVarName>] ] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nScope>:ehp2.   = the scope of variables for which an information is asked Supported values (defined in hbmemvar.ch)  HB_MV_PUBLIC  HB_MV_PRIVATE (or any other value)  <nPosition> = the position of asked variable on the list of variables  with specified scope - it should start from position 1  <cVarName> = the value is filled with a variable name if passed by  reference and <nPosition> is specified     

:p.:hp2.Returns
:ehp2.
      The  return value depends on the number of arguments passed    

:p.:hp2.Description
:ehp2.
     This function retrieves the information about memvar variables.  It returns either the number of variables with given scope (when the  first argument is passed only) or a value of variable identified by its  position in the variables' list (when second argument is passed).  It also returns the name of a variable if optional third argument  is passed by reference.       

     If requested variable doesn't exist (requested position is  greater then the number of defined variables) then NIL value is  returned and variable name is set to &cdq.?&cdq.       

     The dynamic symbols table is used to find a PUBLIC variable then  the PUBLIC variables are always sorted alphabetically. The PRIVATE  variables are sorted in the creation order.       

     Note&colon.  Due to dynamic nature of memvar variables there is no guarantee that  successive calls to retrieve the value of <Nth> PUBLIC variable will  return the value of the same variable.     

:p.:hp2.Examples
:ehp2.



      #include <hbmemvar.ch>

      LOCAL nCount&comma. i&comma. xValue&comma. cName

      nCount =_mvDBGINFO( HB_MV_PUBLIC )
      FOR i&colon.=1 TO nCount
          xValue =__mvDBGINFO( HB_MV_PUBLIC&comma. i&comma. @cName )
          ? i&comma. cName&comma. xValue
      NEXT
   
:p.:hp2.Tests
:ehp2.

      #include <hbmemvar.ch>
      PROCEDURE MAIN()

      ? 'PUBLIC='&comma. __mvDBGINFO( HB_MV_PUBLIC )
      ? 'PRIVATE='&comma. __mvDBGINFO( HB_MV_PRIVATE )

      PUBLIC cPublic&colon.='cPublic in MAIN'

      ? 'PUBLIC='&comma. __mvDBGINFO( HB_MV_PUBLIC )
      ? 'PRIVATE='&comma. __mvDBGINFO( HB_MV_PRIVATE )

      PRIVATE cPrivate&colon.='cPrivate in MAIN'

      ? 'PUBLIC='&comma. __mvDBGINFO( HB_MV_PUBLIC )
      ? 'PRIVATE='&comma. __mvDBGINFO( HB_MV_PRIVATE )

      CountMemvars()

      ? 'Back in Main'
      ? 'PUBLIC='&comma. __mvDBGINFO( HB_MV_PUBLIC )
      ? 'PRIVATE='&comma. __mvDBGINFO( HB_MV_PRIVATE )


      RETURN

      PROCEDURE CountMemvars()
      LOCAL i&comma. nCnt&comma. xVal&comma. cName
      PUBLIC ccPublic&colon.='ccPublic'
      PRIVATE ccPrivate&colon.='ccPrivate'

      ? 'In CountMemvars'
      ? 'PUBLIC='&comma. __mvDBGINFO( HB_MV_PUBLIC )
      ? 'PRIVATE='&comma. __mvDBGINFO( HB_MV_PRIVATE )

      PRIVATE cPublic&colon.='cPublic'

      ? 'PUBLIC='&comma. __mvDBGINFO( HB_MV_PUBLIC )
      ? 'PRIVATE='&comma. __mvDBGINFO( HB_MV_PRIVATE )

      nCnt =__mvDBGINFO( HB_MV_PRIVATE ) +1
      FOR i&colon.=1 TO nCnt
        xVal =__mvDBGINFO( HB_MV_PRIVATE&comma. i&comma. @cName )
        ? i&comma. '='&comma. cName&comma. xVal
      NEXT

      nCnt =__mvDBGINFO( HB_MV_PUBLIC ) +1
      FOR i&colon.=1 TO nCnt
        xVal =__mvDBGINFO( HB_MV_PUBLIC&comma. i&comma. @cName )
        ? i&comma. '='&comma. cName&comma. xVal
      NEXT

      RETURN
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
    This function should be called from the debugger only.     

:p.:hp2.Files
:ehp2.
     Library is vm     
:h1 res=365.__MVGET()
:i1 id=__MVGET().__MVGET()
:p.__MVGET()
:p.:hp2.This function returns value of memory variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVGET( <cVarName> )  --> <xVar>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cVarName>:ehp2.   - string that specifies the name of variable    

:p.:hp2.Returns
:ehp2.
      :hp2. <xVar>:ehp2.   The value of variable    

:p.:hp2.Description
:ehp2.
     This function returns the value of PRIVATE or PUBLIC variable if  this variable exists otherwise it generates a runtime error.  The variable is specified by its name passed as the function parameter.     

:p.:hp2.Examples
:ehp2.

      FUNCTION MEMVARBLOCK( cMemvar )
      RETURN {|x| IIF( PCOUNT()==0&comma. __MVGET( cMemvar )&comma.;
      __MVPUT( cMemvar&comma. x ) ) }
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=366.__MVPUT():elink.
.br
:h1 res=366.__MVPUT()
:i1 id=__MVPUT().__MVPUT()
:p.__MVPUT()
:p.:hp2.This function set the value of memory variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.__MVGET( <cVarName> [, <xValue>] )  --> <xValue>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cVarName>:ehp2.   - string that specifies the name of variable <xValue>   - a value of any type that will be set - if it is not  specified then NIL is assumed     

:p.:hp2.Returns
:ehp2.
      :hp2. <xValue>:ehp2.   A value assigned to the given variable.    

:p.:hp2.Description
:ehp2.
     This function sets the value of PRIVATE or PUBLIC variable if  this variable exists otherwise it generates a runtime error.  The variable is specified by its name passed as the function  parameter.  If a value is not specified then the NIL is assumed     

:p.:hp2.Examples
:ehp2.

      FUNCTION MEMVARBLOCK( cMemvar )
      RETURN {|x| IIF( PCOUNT()==0&comma. __MVGET( cMemvar )&comma.;
      __MVPUT( cMemvar&comma. x ) ) }
   
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour extension     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=366.__MVPUT():elink.
.br
:h1 res=367.MEMVARBLOCK()
:i1 id=MEMVARBLOCK().MEMVARBLOCK()
:p.MEMVARBLOCK()
:p.:hp2.Returns a codeblock that sets/gets a value of memvar variable
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MEMVARBLOCK( <cMemvarName> ) --> <bBlock>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cMemvarName>:ehp2.   - a string that contains the name of variable    

:p.:hp2.Returns
:ehp2.
      :hp2. <bBlock>:ehp2.   a codeblock that sets/get the value of variable    

:p.:hp2.Description
:ehp2.
     This function returns a codeblock that sets/gets the value of  PRIVATE or PUBLIC variable. When this codeblock is evaluated  without any parameters passed then it returns the current value  of given variable. If the second parameter is passed for  the codeblock evaluation then its value is used to set the new  value of given variable - the passed value is also returned  as a value of the codeblock evaluation.     

:p.:hp2.Examples
:ehp2.

      PROCEDURE MAIN()
      LOCAL cbSetGet
      PUBLIC xPublic

      cbSetGet = MEMVARBLOCK( &cdq.xPublic&cdq. )
      EVAL( cbSetGet&comma. &cdq.new value&cdq. )
      ? &cdq.Value of xPublic variable&cdq.&comma. EVAL( cbSetGet )

      RETURN
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca-Clipper compatible     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=365.__MVGET():elink.
.br
:link reftype=hd res=366.__MVPUT():elink.
.br
:h1 res=368.FIELDBLOCK()
:i1 id=FIELDBLOCK().FIELDBLOCK()
:p.FIELDBLOCK()
:p.:hp2.Return a code block that sets/gets a value for a given field
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDBLOCK( <cFieldName> ) --> bFieldBlock
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFieldName>:ehp2.   is a string that contain the field name.    

:p.:hp2.Returns
:ehp2.
      :hp2. FIELDBLOCK():ehp2.   return a code block that when evaluate could retrieve field value or assigning a new value to the field. If <cFieldName>  is not specified or from type other than character, FIELDBLOCK()  return NIL.     

:p.:hp2.Description
:ehp2.
     FIELDBLOCK() return a code block that sets/gets the value of field.  When this code block is evaluated without any parameters passed then  it returns the current value of the given field. If the code block  is evaluated with a parameter&comma. than its value is used to set a new  value to the field&comma. this value is also return by the block. If the  block is evaluate and there is no field with the name <cFieldName>  in the current work area&comma. the code block return NIL.       

     Note that FIELDBLOCK() works on the current work area&comma. if you need  a specific work area code block use FIELDWBLOCK() instead.     

:p.:hp2.Examples
:ehp2.

      // open a file named Test that have a field named &cdq.name&cdq.
      LOCAL bField
      bFiled &colon.= FIELDBLOCK( &cdq.name&cdq. )
      USE Test
      ? 'Original value of field &cdq.name&cdq. &colon.'&comma. EVAL( bField )
      EVAL( bField&comma. &cdq.Mr X new name&cdq. )
      ? 'New value for the field &cdq.name&cdq. &colon.'&comma. EVAL( bField )
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     If the block is evaluate and there is no field with the name  <cFieldName> in the current work area&comma. the code block return NIL.       

     CA-Clipper would raise BASE/1003 error if the field does not exist.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=14.EVAL():elink.
.br
:link reftype=hd res=369.FIELDWBLOCK():elink.
.br
:link reftype=hd res=367.MEMVARBLOCK():elink.
.br
:h1 res=369.FIELDWBLOCK()
:i1 id=FIELDWBLOCK().FIELDWBLOCK()
:p.FIELDWBLOCK()
:p.:hp2.Return a sets/gets code block for field in a given work area
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.FIELDWBLOCK( <cFieldName>, <nWorkArea> ) --> bFieldBlock
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cFieldName>:ehp2.   is a string that contain the field name.      

      :hp2. <nWorkArea>:ehp2.   is the work area number in which <cFieldName> exist.    

:p.:hp2.Returns
:ehp2.
      :hp2. FIELDWBLOCK():ehp2.   return a code block that when evaluate could retrieve field value or assigning a new value for a field in a given work  area. If <cFieldName> is not specified or from type other than  character, or if <nWorkArea> is not specified or is not numeric  FIELDWBLOCK() return NIL.     

:p.:hp2.Description
:ehp2.
     FIELDWBLOCK() return a code block that sets/gets the value of field  from a given work area. When this code block is evaluated without  any parameters passed then it returns the current value of the given  field. If the code block is evaluated with a parameter&comma. than its  value is used to set a new value to the field&comma. this value is also  return by the block. If the block is evaluate and there is no field  with the name <cFieldName> in work area number <nWorkArea>&comma. the code  block return NIL.     

:p.:hp2.Examples
:ehp2.

      LOCAL bField
      // this block work on the field &cdq.name&cdq. that exist on work area 2
      bFiled &colon.= FIELDBLOCK( &cdq.name&cdq.&comma. 2 )
      // open a file named One in work area 1
      // that have a field named &cdq.name&cdq.
      SELECT 1
      USE One
      // open a file named Two in work area 2
      // it also have a field named &cdq.name&cdq.
      SELECT 2
      USE Two
      SELECT 1
      ? &cdq.Original names&colon. &cdq.&comma. One->name&comma. Two->name
      ? &cdq.Name value for file Two &colon.&cdq.&comma. EVAL( bField )
      EVAL( bField&comma. &cdq.Two has new name&cdq. )
      ? &cdq.and now&colon. &cdq.&comma. One->name&comma. Two->name
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     If the block is evaluate and there is no field with the name  <cFieldName> in the given work area&comma. the code block return NIL.       

     CA-Clipper would raise BASE/1003 error if the field does not exist.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=14.EVAL():elink.
.br
:link reftype=hd res=368.FIELDBLOCK():elink.
.br
:link reftype=hd res=367.MEMVARBLOCK():elink.
.br
:h1 res=266.TYPE()
:i1 id=TYPE().TYPE()
:p.TYPE()
:p.:hp2.Retrieves the type of an expression
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.TYPE( <cExp> ) --> <cRetType>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cExp>:ehp2.   must be a character expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cRetType>:ehp2.   a string indicating the type of the passed expression.      


:cgraphic.
 
    <cRetType>   Meaning

    &cdq.A&cdq.          array
    &cdq.B&cdq.          block
    &cdq.C&cdq.          string
    &cdq.D&cdq.          date
    &cdq.L&cdq.          logical
    &cdq.M&cdq.          memo
    &cdq.N&cdq.          numeric
    &cdq.O&cdq.          object
    &cdq.U&cdq.          NIL&comma. local&comma. or static variable&comma. or not linked-in function
    &cdq.UE&cdq.         syntax error in the expression or invalid arguments
    &cdq.UI&cdq.         function with non-reserved name was requested
 
:ecgraphic.


:p.:hp2.Description
:ehp2.
     This function returns a string which represents the data type  of the argument. The argument can be any valid Harbour expression.  If there is a syntax error in passed expression then &cdq.UE&cdq. is returned.  If there is a call for any non-reserved Harbour function then &cdq.UI&cdq.  is returned (in other words there is no call for passed UDF function  during a data type determination - this is Clipper compatible  behavior). Additionally if requested user defined function is not  linked into executable then &cdq.U&cdq. is returned.       

     The data type of expression is checked by invoking a macro compiler  and by evaluation of generated code (if there is no syntax errors).  This causes that TYPE() cannot determine a type of local or static  variables - only symbols visible at runtime can be checked.       

     Notice the subtle difference between TYPE and VALTYPE functions.  VALTYPE() function doesn't call a macro compiler - it simply checks  the type of passed argument of any type. TYPE() requires a string  argument with a valid Harbour expression - the data type of this  expression is returned.     

:p.:hp2.Examples
:ehp2.

       ? TYPE( &cdq.{ 1&comma. 2 }&cdq. )                            //prints &cdq.A&cdq.
       ? TYPE( &cdq.IIF(.T.&comma. SUBSTR('TYPE'&comma.2&comma.1)&comma. .F.)&cdq. )   //prints &cdq.C&cdq.
       ? TYPE( &cdq.AT( 'OK'&comma. MyUDF())>0&cdq. )                //prints &cdq.UI&cdq.
       ? TYPE( &cdq.{ 1&comma. 2 }[ 5 ]&cdq. )                       //prints &cdq.UE&cdq.

       //--------------------------------------------------------

       LOCAL c
       PRIVATE a&colon.=&cdq.A&cdq.&comma. b&colon.=&cdq.B&cdq.
       ? TYPE( &cdq.a + b + c&cdq. )     //prints&colon. &cdq.U&cdq. ('C' variable is a local one)

       //--------------------------------------------------------

       LOCAL cFilter &colon.= SPACE( 60 )
       ACCEPT &cdq.Enter filter expression&colon.&cdq. TO cFilter
       IF( TYPE( cFilter ) $ &cdq.CDLMN&cdq. ) )
          // this is a valid expression
          SET FILTER TO &cFilter
       ENDIF

  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.

     - Incompatibility with Clipper&colon.  In the following code&colon.       

         PRIVATE lCond &colon.= 0  ? TYPE( &cdq.IIF( lCond&comma. 'true'&comma. MyUDF() )&cdq. )       

         Clipper will print &cdq.UE&cdq. - in Harbour the output will be &cdq.UI&cdq.       

     - if &cdq.UI&cdq. is returned then the syntax of the expression is  correct. However invalid arguments can be passed to  function/procedure that will cause runtime errors during  evaluation of expression.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=269.VALTYPE():elink.
.br
:h1 res=269.VALTYPE()
:i1 id=VALTYPE().VALTYPE()
:p.VALTYPE()
:p.:hp2.Retrieves the data type of an expression
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.VALTYPE( <xExp> ) --> <cReturnType>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <xExp>:ehp2.   is any valid expression.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cReturnType>:ehp2.   a character indicating the type of the passed expression.    

:p.:hp2.Description
:ehp2.
     This function returns one character which represents the date type  of the argument.     

:p.:hp2.Examples
:ehp2.

      See Test
  

:p.:hp2.Tests
:ehp2.

      function Test()
         ? ValType( Array( 1 ) )  --> &cdq.A&cdq.
         ? ValType( {|| 1 + 1 } ) --> &cdq.B&cdq.
         ? ValType( &cdq.HARBOUR&cdq. )   --> &cdq.C&cdq.
         ? ValType( Date() )      --> &cdq.D&cdq.
         ? ValType( .T. )         --> &cdq.L&cdq.
         ? ValType( 1 )           --> &cdq.N&cdq.
         ? ValType( TBrowse() )   --> &cdq.O&cdq.
         ? ValType( NIL )         --> &cdq.U&cdq.
      return nil
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     VALTYPE() is fully CA-Clipper compliant.     

:p.:hp2.Files
:ehp2.
     Library is rtl     
.br
See Also&colon.
:link reftype=hd res=266.TYPE():elink.
.br
:h1 res=370.BASE/1003
:i1 id=BASE/1003.BASE/1003
:p.BASE/1003
:p.:hp2.Attempt to acces nonexisting or hidden variable
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified variable was not found. 
     If it is a database field make sure that the required database is open.  
     If it is a private or public variable then you must first create it  using PRIVATE or PUBLIC statement.       

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=371.BASE/1068
:i1 id=BASE/1068.BASE/1068
:p.BASE/1068
:p.:hp2.Invalid type of argument
:ehp2.
:p.:hp2.Description
:ehp2.
     The used data is not of logical type  

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=371.BASE/1068
:i1 id=BASE/1068.BASE/1068
:p.BASE/1068
:p.:hp2.Bound error in array access
:ehp2.
:p.:hp2.Description
:ehp2.
     The attempt to retrieve data from non-array value  

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=372.BASE/1069
:i1 id=BASE/1069.BASE/1069
:p.BASE/1069
:p.:hp2.Bound error in array access
:ehp2.
:p.:hp2.Description
:ehp2.
     The attempt to set data to non-array value  

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=373.BASE/1078
:i1 id=BASE/1078.BASE/1078
:p.BASE/1078
:p.:hp2.Invalid type of arguments
:ehp2.
:p.:hp2.Description
:ehp2.
     The type of compared arguments do not match  

:p.:hp2.Function
:ehp2.
     ==  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=374.BASE/1072
:i1 id=BASE/1072.BASE/1072
:p.BASE/1072
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of compared arguments do not match  

:p.:hp2.Function
:ehp2.
     <>  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=375.BASE/1073
:i1 id=BASE/1073.BASE/1073
:p.BASE/1073
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of compared argument do not match  

:p.:hp2.Function
:ehp2.
     <  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=376.BASE/1074
:i1 id=BASE/1074.BASE/1074
:p.BASE/1074
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of compared arguments do not match  

:p.:hp2.Function
:ehp2.
     <=  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=377.BASE/1075
:i1 id=BASE/1075.BASE/1075
:p.BASE/1075
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of compared arguments do not match  

:p.:hp2.Function
:ehp2.
     >  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=378.BASE/1076
:i1 id=BASE/1076.BASE/1076
:p.BASE/1076
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of compared arguments do not match  

:p.:hp2.Function
:ehp2.
     >=  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=379.BASE/1077
:i1 id=BASE/1077.BASE/1077
:p.BASE/1077
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     Operation is not allowed for passed argument. The argument is not  a logical value.       

:p.:hp2.Function
:ehp2.
     !  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=373.BASE/1078
:i1 id=BASE/1078.BASE/1078
:p.BASE/1078
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of one or both arguments is not a logical  

:p.:hp2.Function
:ehp2.
     .AND.  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=380.BASE/1079
:i1 id=BASE/1079.BASE/1079
:p.BASE/1079
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The type of one or both arguments is not a logical  

:p.:hp2.Function
:ehp2.
     .OR.  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=378.BASE/1076
:i1 id=BASE/1076.BASE/1076
:p.BASE/1076
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The value of argument cannot be incremented  

:p.:hp2.Function
:ehp2.
     ++  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=381.BASE/1081
:i1 id=BASE/1081.BASE/1081
:p.BASE/1081
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The plus operation is not allowed for used arguments.  

:p.:hp2.Function
:ehp2.
     +  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=382.BASE/1082
:i1 id=BASE/1082.BASE/1082
:p.BASE/1082
:p.:hp2.Invalid type of arguments
:ehp2.

:p.:hp2.Description
:ehp2.
     The minus operation is not allowed for used arguments.  

:p.:hp2.Function
:ehp2.
     -  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=383.BASE/1100
:i1 id=BASE/1100.BASE/1100
:p.BASE/1100
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified argument is not a string.  

:p.:hp2.Function
:ehp2.
     RTRIM&comma. TRIM  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=384.BASE/1101
:i1 id=BASE/1101.BASE/1101
:p.BASE/1101
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified argument is not a string.  

:p.:hp2.Function
:ehp2.
     LTRIM  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=385.BASE/1102
:i1 id=BASE/1102.BASE/1102
:p.BASE/1102
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The first argument passed to a function is not a string.  

:p.:hp2.Function
:ehp2.
     UPPER  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=386.BASE/1103
:i1 id=BASE/1103.BASE/1103
:p.BASE/1103
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The first argument passed to a function is not a string.  

:p.:hp2.Function
:ehp2.
     LOWER  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=387.BASE/1104
:i1 id=BASE/1104.BASE/1104
:p.BASE/1104
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified argument is not a numeric value.  

:p.:hp2.Function
:ehp2.
     CHR  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=388.BASE/1105
:i1 id=BASE/1105.BASE/1105
:p.BASE/1105
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The arguments passed to a function are of incorrect type.  

:p.:hp2.Function
:ehp2.
     SPACE  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=389.BASE/1106
:i1 id=BASE/1106.BASE/1106
:p.BASE/1106
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The arguments passed to a function are of incorrect type.  

:p.:hp2.Function
:ehp2.
     REPLICATE  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=390.BASE/1107
:i1 id=BASE/1107.BASE/1107
:p.BASE/1107
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified argument is not a string.  

:p.:hp2.Function
:ehp2.
     ASC  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=391.BASE/1108
:i1 id=BASE/1108.BASE/1108
:p.BASE/1108
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified argument is not a string.  

:p.:hp2.Function
:ehp2.
     AT  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=378.BASE/1076
:i1 id=BASE/1076.BASE/1076
:p.BASE/1076
:p.:hp2.Invalid type of arguments
:ehp2.
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=392.BASE/1110
:i1 id=BASE/1110.BASE/1110
:p.BASE/1110
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The first argument passed to a function is not a string.  

:p.:hp2.Function
:ehp2.
     SUBSTR  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=392.BASE/1110
:i1 id=BASE/1110.BASE/1110
:p.BASE/1110
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The passed argument is neither a string nor an array.  

:p.:hp2.Function
:ehp2.
     LEN  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=393.BASE/1112
:i1 id=BASE/1112.BASE/1112
:p.BASE/1112
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function are of incorrect  type       

:p.:hp2.Function
:ehp2.
     YEAR  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=394.BASE/1113
:i1 id=BASE/1113.BASE/1113
:p.BASE/1113
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function are of incorrect  type       

:p.:hp2.Function
:ehp2.
     MONTH  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=395.BASE/1114
:i1 id=BASE/1114.BASE/1114
:p.BASE/1114
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function are of incorrect  type        

:p.:hp2.Function
:ehp2.
     DAY  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=396.BASE/1115
:i1 id=BASE/1115.BASE/1115
:p.BASE/1115
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function are of incorrect  type       

:p.:hp2.Function
:ehp2.
     DOW   
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=397.BASE/1116
:i1 id=BASE/1116.BASE/1116
:p.BASE/1116
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function are of incorrect  type       

:p.:hp2.Function
:ehp2.
     CMONTH  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=398.BASE/1117
:i1 id=BASE/1117.BASE/1117
:p.BASE/1117
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is of incorrect  type         

:p.:hp2.Function
:ehp2.
     CDOW    
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=399.BASE/1120
:i1 id=BASE/1120.BASE/1120
:p.BASE/1120
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is of incorrect  type       

:p.:hp2.Function
:ehp2.
     DTOS  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=400.BASE/1122
:i1 id=BASE/1122.BASE/1122
:p.BASE/1122
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is of incorrect  type       

:p.:hp2.Function
:ehp2.
     TRANSFORM  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=401.BASE/1124
:i1 id=BASE/1124.BASE/1124
:p.BASE/1124
:p.:hp2.Incorrect type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The first argument is not a string.  

:p.:hp2.Function
:ehp2.
     LEFT  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=402.BASE/1126
:i1 id=BASE/1126.BASE/1126
:p.BASE/1126
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The first arguments passed to a function is not a string.  

:p.:hp2.Function
:ehp2.
     STRTRAN  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=403.BASE/1132
:i1 id=BASE/1132.BASE/1132
:p.BASE/1132
:p.:hp2.Bound error in array access
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified index into an array was greater then the number of  elements in the array.       

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=404.BASE/1133
:i1 id=BASE/1133.BASE/1133
:p.BASE/1133
:p.:hp2.Bound error in array assigment
:ehp2.
:p.:hp2.Description
:ehp2.
     The specified index into an array was greater then the number of  elements in the array.       

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=371.BASE/1068
:i1 id=BASE/1068.BASE/1068
:p.BASE/1068
:p.:hp2.Bound error in array element assigment
:ehp2.
:p.:hp2.Description
:ehp2.
     The specified index into an array was greater then the number of  elements in the array.       

:p.:hp2.Function
:ehp2.

:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=405.BASE/1085
:i1 id=BASE/1085.BASE/1085
:p.BASE/1085
:p.:hp2.Invalid argument passed to function
:ehp2.
:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     MOD  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=406.BASE/1089
:i1 id=BASE/1089.BASE/1089
:p.BASE/1089
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     ABS  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=407.BASE/1090
:i1 id=BASE/1090.BASE/1090
:p.BASE/1090
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     INT  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=408.BASE/1092
:i1 id=BASE/1092.BASE/1092
:p.BASE/1092
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     MIN  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=409.BASE/1093
:i1 id=BASE/1093.BASE/1093
:p.BASE/1093
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     MAX  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=410.BASE/1094
:i1 id=BASE/1094.BASE/1094
:p.BASE/1094
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     ROUND  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=411.BASE/1095
:i1 id=BASE/1095.BASE/1095
:p.BASE/1095
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     LOG  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=412.BASE/1096
:i1 id=BASE/1096.BASE/1096
:p.BASE/1096
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     EXP  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=413.BASE/1097
:i1 id=BASE/1097.BASE/1097
:p.BASE/1097
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not an numeric  value       

:p.:hp2.Function
:ehp2.
     SQRT  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=414.BASE/1098
:i1 id=BASE/1098.BASE/1098
:p.BASE/1098
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not a string  value       

:p.:hp2.Function
:ehp2.
     VAL  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=415.BASE/1099
:i1 id=BASE/1099.BASE/1099
:p.BASE/1099
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The argument (or arguments) passed to a function is not a numeric  value       

:p.:hp2.Function
:ehp2.
     STR  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=416.BASE/2010
:i1 id=BASE/2010.BASE/2010
:p.BASE/2010
:p.:hp2.Incorrect arguments type
:ehp2.

:p.:hp2.Description
:ehp2.
     Passed Run Time Errors was not strings with filenames to copy/  

:p.:hp2.Function
:ehp2.
     __COPYFILE  

:p.:hp2.Compliance
:ehp2.
     Harbour specific     
:h1 res=417.BASE/2012
:i1 id=BASE/2012.BASE/2012
:p.BASE/2012
:p.:hp2.File error
:ehp2.

:p.:hp2.Description
:ehp2.
     An error has occured during the attempt to open&comma. create or write  during copy operation       

:p.:hp2.Function
:ehp2.
     __COPYFILE  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=418.BASE/2017
:i1 id=BASE/2017.BASE/2017
:p.BASE/2017
:p.:hp2.Invalid argument passed to a function
:ehp2.

:p.:hp2.Description
:ehp2.
     The first argument is not an array or/and the second argument  is not a code block       

:p.:hp2.Function
:ehp2.
     AEVAL  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=419.BASE/2020
:i1 id=BASE/2020.BASE/2020
:p.BASE/2020
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The passed value is negative. Only values > 0 are allowed.  

:p.:hp2.Function
:ehp2.
     SET DECIMALS  
     SET EPOCH     
     SET MARGIN    
     SET MESSAGE   
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=420.BASE/3001
:i1 id=BASE/3001.BASE/3001
:p.BASE/3001
:p.:hp2.Incorrect argument type
:ehp2.

:p.:hp2.Description
:ehp2.
     The passed argument is not an object. Only data of type OBJECT  can be cloned by this function       

:p.:hp2.Function
:ehp2.
     OCLONE  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=421.BASE/3002
:i1 id=BASE/3002.BASE/3002
:p.BASE/3002
:p.:hp2.Super class does not return an object
:ehp2.

:p.:hp2.Description
:ehp2.
     Passed argument is not a name of defined class or specified class  doesn't have a super class       

:p.:hp2.Function
:ehp2.
     __INSTSUPER  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=422.BASE/3003
:i1 id=BASE/3003.BASE/3003
:p.BASE/3003
:p.:hp2.Cannot find super class
:ehp2.

:p.:hp2.Description
:ehp2.
     Passed argument is not a name of defined class  

:p.:hp2.Function
:ehp2.
     __INSTSUPER  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=423.BASE/3004
:i1 id=BASE/3004.BASE/3004
:p.BASE/3004
:p.:hp2.Cannot modify a DATA item in a class
:ehp2.

:p.:hp2.Description
:ehp2.
     The attempt to modify a data member of a class was made.  Only INLINE and METHOD can be modified       

:p.:hp2.Function
:ehp2.
     CLASSMOD  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=424.BASE/3005
:i1 id=BASE/3005.BASE/3005
:p.BASE/3005
:p.:hp2.Incorrect arguments type
:ehp2.

:p.:hp2.Description
:ehp2.
     Either the first argument was not an object or the second argument  wasn't a string.       

:p.:hp2.Function
:ehp2.
     ISMESSAGE&comma. OSEND  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=425.BASE/3007
:i1 id=BASE/3007.BASE/3007
:p.BASE/3007
:p.:hp2.Invalid type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The passed arguments are causing conflict in hanndling of the request.  There is no point in waiting forever for no input events!       

:p.:hp2.Function
:ehp2.
     INKEY  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=426.BASE/3008
:i1 id=BASE/3008.BASE/3008
:p.BASE/3008
:p.:hp2.Invalid type of argument
:ehp2.

:p.:hp2.Description
:ehp2.
     The passed argument(s) is not a string. It should be a string with  a variable name or an one-dimensional array of strings.       

:p.:hp2.Function
:ehp2.
     __MVPRIVATE&comma. __MVPUBLIC  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=427.BASE/3009
:i1 id=BASE/3009.BASE/3009
:p.BASE/3009
:p.:hp2.Incorrect argument passed to __MVGET function
:ehp2.

:p.:hp2.Description
:ehp2.
     __MVGET function expects only one argument&colon. a string with a name  of variable. The value of this variable will be returned.       

:p.:hp2.Function
:ehp2.
     __MVGET  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=428.BASE/3010
:i1 id=BASE/3010.BASE/3010
:p.BASE/3010
:p.:hp2.Incorrect argument passed to __MVPUT function
:ehp2.

:p.:hp2.Description
:ehp2.
     __MVPUT function expects at least one argument&colon. a string with a name  of variable. The value of this variable will be set.       

:p.:hp2.Function
:ehp2.
     __MVPUT  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=429.BASE/3011
:i1 id=BASE/3011.BASE/3011
:p.BASE/3011
:p.:hp2.Invalid argument passed to a function
:ehp2.

:p.:hp2.Description
:ehp2.
     The attempt to retrieve the function argument that was not passed.  The number of requested argument is greated then the number of  passed arguments.       

:p.:hp2.Function
:ehp2.
     PVALUE  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=430.BASE/3012
:i1 id=BASE/3012.BASE/3012
:p.BASE/3012
:p.:hp2.Invalid argument passed to a function
:ehp2.

:p.:hp2.Description
:ehp2.
     The first argument is not a string with function/procedure name  that should be called.       

:p.:hp2.Function
:ehp2.
     DO  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=431.BASE/3101
:i1 id=BASE/3101.BASE/3101
:p.BASE/3101
:p.:hp2.Invalid argument passed to an object/class function
:ehp2.

:p.:hp2.Description
:ehp2.
     One passed argument is not of the required type.  

:p.:hp2.Function
:ehp2.
     __OBJ*()  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=432.BASE/3102
:i1 id=BASE/3102.BASE/3102
:p.BASE/3102
:p.:hp2.A symbol should be modified or deleted from a class, but the symbol
:ehp2.

:p.:hp2.Description
:ehp2.
     A symbol should be modified or deleted from a class&comma. but the symbol  doesn't exist.       

:p.:hp2.Function
:ehp2.
     __OBJ*()  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=433.BASE/3103
:i1 id=BASE/3103.BASE/3103
:p.BASE/3103
:p.:hp2.A symbol should be added to a class, but the symbol already exists.
:ehp2.

:p.:hp2.Description
:ehp2.
     A symbol should be added to a class&comma. but the symbol already exists.  

:p.:hp2.Function
:ehp2.
     __OBJ*()  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=434.TOOLS/4001
:i1 id=TOOLS/4001.TOOLS/4001
:p.TOOLS/4001
:p.:hp2.Invalid argument passed to function
:ehp2.

:p.:hp2.Description
:ehp2.
     The second arguments passed to a function is not a string.  

:p.:hp2.Function
:ehp2.
     ISLEAPYEAR  
:p.:hp2.Status
:ehp2.
      Harbour specific
:h1 res=435.TERM/2013
:i1 id=TERM/2013.TERM/2013
:p.TERM/2013
:p.:hp2.Create error
:ehp2.

:p.:hp2.Description
:ehp2.
     The specified file cannot be created due some OS error.  

:p.:hp2.Function
:ehp2.
     SET&comma. SET ALTERNATE TO  
:p.:hp2.Status
:ehp2.
      Clipper
:h1 res=436.HARBOUR EXTENSIONS
:i1 id=HARBOUR EXTENSIONS.HARBOUR EXTENSIONS
:p.HARBOUR EXTENSIONS
:p.:hp2.Harbour Extensions
:ehp2.

:p.:hp2.Description
:ehp2.
hp2. Language extensions&colon.&colon.ehp2.    
-------------------       

 Class generation and management.   

       Clipper only allowed creation of objects from a few standard  classes.        
       In Harbour&comma. you can create your own classes--complete with  Methods&comma. Instance Variables&comma. Class Variables and Inheritance.  Entire applications can be designed and coded in Object Oriented  style.        

 @<FunctionName>()   
       Returns the pointer (address) to a function.   

       The returned value is not useful to application-level programming&comma. but  is used at a low level to implement object oriented coding.  (Internally&comma. a class method is a static function and there is no  symbol for it&comma. so it is accessed via its address).        

 Class TGetList   
       Object oriented support for GetLists management.   

 ProcName() support for class Method names.   
       Class Methods can be retrieved from the call stack.   

 Memory() has new return values.   
       See hbmemory.ch   

 Transform()  --> new function in format string   
       @0      Make a zero padded string out of the number.   

 SToD()  --> dDate   
       New function that converts a yyyymmdd string to a Date value.   

 Optional Compile Time STRONG TYPE declaration (and compile time TYPE  MISMATCH warnings)           

 Example&colon. LOCAL/STATIC Var AS ...   

 The Harbour debugger provides new interesting classes&colon.   
 - Class TDbWindow could be the foundation for a generic multiplatform   
 - Class TForm   
 - Class TDbMenu implement both pulldown and popup menus.   



hp2. RTL enhanced functionality&colon.&colon.ehp2.    
--------------------------   

 Directory( <cMask>&comma. <cFlags>&comma. <lEightDotThree> )   
 The 3rd parameter is a Harbour (optional) parameter and indicates that on  those platforms that support long filenames&comma. that you wish to receive what  would be considered the dos equivalant 8.3 name.  Could affect Adir() and Dir if they were modified to take advantage  of it - currently&comma. they will return long names if the os supports it.        

 DiskSpace( <nDrive>&comma. <nType> )   
 The second parameter is a Harbour (optional) parameter and indicates the  type of diskinfo being requested.  See en/diskspac.txt for info.        

:h1 res=437.GNU LICENSE
:i1 id=GNU LICENSE.GNU LICENSE
:p.GNU LICENSE
:p.:hp2.Gnu License File Part 1
:ehp2.
:p.:hp2.Description
:ehp2.

     GNU GENERAL PUBLIC LICENSE   
     Version 2&comma. June 1991   
     Copyright (C) 1989&comma. 1991 Free Software Foundation&comma. Inc.  59 Temple Place - Suite 330&comma. Boston&comma. MA  02111-1307&comma. USA        

     Everyone is permitted to copy and distribute verbatim copies  of this license document&comma. but changing it is not allowed.        

     Preamble   

     The licenses for most software are designed to take away your  freedom to share and change it. By contrast&comma. the GNU General Public  License is intended to guarantee your freedom to share and change  free software--to make sure the software is free for all its users.  This General Public License applies to most of the Free Software  Foundation's software and to any other program whose authors commit  to using it. (Some other Free Software Foundation software is  covered by the GNU Library General Public License instead.)  You can apply it to your programs&comma. too.        

     When we speak of free software&comma. we are referring to freedom&comma. not  price. Our General Public Licenses are designed to make sure that  you have the freedom to distribute copies of free software (and  charge for this service if you wish)&comma. that you receive source code  or can get it if you want it&comma. that you can change the software or  use pieces of it in new free programs; and that you know you can do  these things.        

     To protect your rights&comma. we need to make restrictions that forbid  anyone to deny you these rights or to ask you to surrender the  rights. These restrictions translate to certain responsibilities  for you if you distribute copies of the software&comma. or if you modify  it.                  

     For example&comma. if you distribute copies of such a program&comma. whether  gratis or for a fee&comma. you must give the recipients all the rights  that you have. You must make sure that they&comma. too&comma. receive or can  get the source code. And you must show them these terms so they  know their rights.        

     We protect your rights with two steps&colon. (1) copyright the software&comma.  and (2) offer you this license which gives you legal permission to  copy&comma. distribute and/or vmodify the software.        

     Also&comma. for each author's protection and ours&comma. we want to make  certain that everyone understands that there is no warranty for  this free software. If the software is modified by someone else and  passed on&comma. we want its recipients to know that what they have is  not the original&comma. so that any problems introduced by others will  not reflect on the original authors' reputations.        

     Finally&comma. any free program is threatened constantly by software  patents. We wish to avoid the danger that redistributors of a free  program will individually obtain patent licenses&comma. in effect making  the program proprietary. To prevent this&comma. we have made it clear  that any patent must be licensed for everyone's free use or not  licensed at all.        

     The precise terms and conditions for copying&comma. distribution and  modification follow.        

     &colon.hp2. TERMS AND CONDITIONS FOR COPYING&comma. DISTRIBUTION AND MODIFICATION&colon.ehp2.    

     0. This License applies to any program or other work which contains  a notice placed by the copyright holder saying it may be  distributed under the terms of this General Public License. The  &cdq.Program&cdq.&comma. below&comma. refers to any such program or work&comma. and a &cdq.work  based on the Program&cdq. means either the Program or any derivative  work under copyright law&colon. that is to say&comma. a work containing the  Program or a portion of it&comma. either verbatim or with modifications  and/or translated into another language. (Hereinafter&comma. translation  is included without limitation in the term &cdq.modification&cdq..) Each  licensee is addressed as &cdq.you&cdq.. Activities other than copying&comma.  distribution and modification are not covered by this License; they  are outside its scope. The act of running the Program is not  restricted&comma. and the output from the Program is covered only if its  contents constitute a work based on the Program (independent of  having been made by running the Program). Whether that is true  depends on what the Program does.        

     1. You may copy and distribute verbatim copies of the Program's  source code as you receive it&comma. in any medium&comma. provided that you  conspicuously and appropriately publish on each copy an appropriate  copyright notice and disclaimer of warranty; keep intact all the  notices that refer to this License and to the absence of any  warranty; and give any other recipients of the Program a copy of  this License along with the Program. You may charge a fee for the  physical act of transferring a copy&comma. and you may at your option  offer warranty protection in exchange for a fee.        

     2. You may modify your copy or copies of the Program or any portion  of it&comma. thus forming a work based on the Program&comma. and copy and  distribute such modifications or work under the terms of Section 1  above&comma. provided that you also meet all of these conditions&colon.        

       a) You must cause the modified files to carry prominent notices  stating that you changed the files and the date of any change.        

       b) You must cause any work that you distribute or publish&comma. that  in whole or in part contains or is derived from the Program or  any part thereof&comma. to be licensed as a whole at no charge to all  third parties under the terms of this License.        

       c) If the modified program normally reads commands interactively  when run&comma. you must cause it&comma. when started running for such  interactive use in the most ordinary way&comma. to print or display an  announcement including an appropriate copyright notice and a  notice that there is no warranty (or else&comma. saying that you  provide a warranty) and that users may redistribute the program  under these conditions&comma. and telling the user how to view a copy  of this License. (Exception&colon. if the Program itself is interactive  but does not normally print such an announcement&comma. your work based  on the Program is not required to print an announcement.)        

     These requirements apply to the modified work as a whole. If  identifiable sections of that work are not derived from the  Program&comma. and can be reasonably considered independent and separate  works in themselves&comma. then this License&comma. and its terms&comma. do not apply  to those sections when you distribute them as separate works. But  when you distribute the same sections as part of a whole which is a  work based on the Program&comma. the distribution of the whole must be on  the terms of this License&comma. whose permissions for other licensees  extend to the entire whole&comma. and thus to each and every part  regardless of who wrote it.        

     Thus&comma. it is not the intent of this section to claim rights or  contest your rights to work written entirely by you; rather&comma. the  intent is to exercise the right to control the distribution of  derivative or collective works based on the Program.        

     In addition&comma. mere aggregation of another work not based on the  Program with the Program (or with a work based on the Program) on a  volume of a storage or distribution medium does not bring the other  work under the scope of this License.        

     3. You may copy and distribute the Program (or a work based on it&comma.  under Section 2) in object code or executable form under the terms  of Sections 1 and 2 above provided that you also do one of the  following&colon.        

       a) Accompany it with the complete corresponding machine-readable  source code&comma. which must be distributed under the terms of  Sections 1 and 2 above on a medium customarily used for software  interchange; or&comma.        

       b) Accompany it with a written offer&comma. valid for at least three  years&comma. to give any third party&comma. for a charge no more than your  cost of physically performing source distribution&comma. a complete  machine-readable copy of the corresponding source code&comma. to be  distributed under the terms of Sections 1 and 2 above on a medium  customarily used for software interchange; or&comma.        

       c) Accompany it with the information you received as to the offer  to distribute corresponding source code. (This alternative is  allowed only for noncommercial distribution and only if you  received the program in object code or executable form with such  an offer&comma. in accord with Subsection b above.)         

     The source code for a work means the preferred form of the work for  making modifications to it. For an executable work&comma. complete source  code means all the source code for all modules it contains&comma. plus  any associated interface definition files&comma. plus the scripts used to  control compilation and installation of the executable. However&comma. as  a special exception&comma. the source code distributed need not include  anything that is normally distributed (in either source or binary  form) with the major components (compiler&comma. kernel&comma. and so on) of  the operating system on which the executable runs&comma. unless that  component itself accompanies the executable.            

     If distribution of executable or object code is made by offering  access to copy from a designated place&comma. then offering equivalent  access to copy the source code from the same place counts as  distribution of the source code&comma. even though third parties are not  compelled to copy the source along with the object code.        

     4. You may not copy&comma. modify&comma. sublicense&comma. or distribute the Program  except as expressly provided under this License. Any attempt  otherwise to copy&comma. modify&comma. sublicense or distribute the Program is  void&comma. and will automatically terminate your rights under this  License. However&comma. parties who have received copies&comma. or rights&comma. from  you under this License will not have their licenses terminated so  long as such parties remain in full compliance.         

     5. You are not required to accept this License&comma. since you have not  signed it. However&comma. nothing else grants you permission to modify or  distribute the Program or its derivative works. These actions are  prohibited by law if you do not accept this License. Therefore&comma. by  modifying or distributing the Program (or any work based on the  Program)&comma. you indicate your acceptance of this License to do so&comma.  and all its terms and conditions for copying&comma. distributing or  modifying the Program or works based on it.             

     6. Each time you redistribute the Program (or any work based on the  Program)&comma. the recipient automatically receives a license from the  original licensor to copy&comma. distribute or modify the Program subject  to these terms and conditions. You may not impose any further  restrictions on the recipients' exercise of the rights granted  herein. You are not responsible for enforcing compliance by third  parties to this License.        

.br
See Also&colon.
:link reftype=hd res=438.GNU License Part 2:elink.
.br
:h1 res=439.GNU LICENSE PART 2
:i1 id=GNU LICENSE PART 2.GNU LICENSE PART 2
:p.GNU LICENSE PART 2
:p.:hp2.Gnu License File Part 2
:ehp2.
:p.:hp2.Description
:ehp2.

     7. If&comma. as a consequence of a court judgment or allegation of patent  infringement or for any other reason (not limited to patent  issues)&comma. conditions are imposed on you (whether by court order&comma.  agreement or otherwise) that contradict the conditions of this  License&comma. they do not excuse you from the conditions of this  License. If you cannot distribute so as to satisfy simultaneously  your obligations under this License and any other pertinent  obligations&comma. then as a consequence you may not distribute the  Program at all. For example&comma. if a patent license would not permit  royalty-free redistribution of the Program by all those who receive  copies directly or indirectly through you&comma. then the only way you  could satisfy both it and this License would be to refrain entirely  from distribution of the Program.        

     If any portion of this section is held invalid or unenforceable  under any particular circumstance&comma. the balance of the section is  intended to apply and the section as a whole is intended to apply  in other circumstances.        

     It is not the purpose of this section to induce you to infringe any  patents or other property right claims or to contest validity of  any such claims; this section has the sole purpose of protecting  the integrity of the free software distribution system&comma. which is  implemented by public license practices. Many people have made  generous contributions to the wide range of software distributed  through that system in reliance on consistent application of that  system; it is up to the author/donor to decide if he or she is  willing to distribute software through any other system and a  licensee cannot impose that choice.        

     This section is intended to make thoroughly clear what is believed  to be a consequence of the rest of this License.        

     8. If the distribution and/or use of the Program is restricted in  certain countries either by patents or by copyrighted interfaces&comma.  the original copyright holder who places the Program under this  License may add an explicit geographical distribution limitation  excluding those countries&comma. so that distribution is permitted only  in or among countries not thus excluded. In such case&comma. this License  incorporates the limitation as if written in the body of this  License.        

     9. The Free Software Foundation may publish revised and/or new  versions of the General Public License from time to time. Such new  versions will be similar in spirit to the present version&comma. but may  differ in detail to address new problems or concerns.        

     Each version is given a distinguishing version number. If the  Program specifies a version number of this License which applies to  it and &cdq.any later version&cdq.&comma. you have the option of following the  terms and conditions either of that version or of any later version  published by the Free Software Foundation. If the Program does not  specify a version number of this License&comma. you may choose any  version ever published by the Free Software Foundation.        

     10. If you wish to incorporate parts of the Program into other free  programs whose distribution conditions are different&comma. write to the  author to ask for permission. For software which is copyrighted by  the Free Software Foundation&comma. write to the Free Software  Foundation; we sometimes make exceptions for this. Our decision  will be guided by the two goals of preserving the free status of  all derivatives of our free software and of promoting the sharing  and reuse of software generally.        

     &colon.hp2. NO WARRANTY&colon.ehp2.    
     11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE&comma. THERE IS NO  WARRANTY FOR THE PROGRAM&comma. TO THE EXTENT PERMITTED BY APPLICABLE  LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS  AND/OR OTHER PARTIES PROVIDE THE PROGRAM &cdq.AS IS&cdq. WITHOUT WARRANTY  OF ANY KIND&comma. EITHER EXPRESSED OR IMPLIED&comma. INCLUDING&comma. BUT NOT  LIMITED TO&comma. THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS  FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND  PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE  DEFECTIVE&comma. YOU ASSUME THE COST OF ALL NECESSARY SERVICING&comma. REPAIR  OR CORRECTION.        

     12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN  WRITING WILL ANY COPYRIGHT HOLDER&comma. OR ANY OTHER PARTY WHO MAY  MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE&comma. BE  LIABLE TO YOU FOR DAMAGES&comma. INCLUDING ANY GENERAL&comma. SPECIAL&comma.  INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR  INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF  DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU  OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY  OTHER PROGRAMS)&comma. EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN  ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.        

     &colon.hp2. END OF TERMS AND CONDITIONS&colon.ehp2.    


     Appendix&colon. How to Apply These Terms to Your New Programs   

     If you develop a new program&comma. and you want it to be of the greatest  possible use to the public&comma. the best way to achieve this is to make  it free software which everyone can redistribute and change under  these terms.        

     To do so&comma. attach the following notices to the program. It is safest  to attach them to the start of each source file to most effectively  convey the exclusion of warranty; and each file should have at  least the &cdq.copyright&cdq. line and a pointer to where the full notice  is found&colon.           

     <One line to give the program's name and an idea of what it does.>  Copyright (C) yyyy  <name of author>        


     This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License  as published by the Free Software Foundation; either version 2  of the License&comma. or (at your option) any later version.        

     This program is distributed in the hope that it will be useful&comma.  but &colon.hp2. WITHOUT ANY WARRANTY&colon.ehp2. ; without even the implied warranty of  &colon.hp2. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE&colon.ehp2. .  See the  GNU General Public License for more details.        

     You should have received a copy of the GNU General Public License  along with this program; if not&comma. write to the Free Software  Foundation&comma. Inc.&comma.        
     59 Temple Place - Suite 330&comma. Boston&comma. MA  02111-1307&comma. USA.   

     Also add information on how to contact you by electronic and paper  mail. If the program is interactive&comma. make it output a short notice  like this when it starts in an interactive mode&colon.        

     Gnomovision version 69&comma. Copyright (C) year name of author  Gnomovision comes with ABSOLUTELY NO WARRANTY; for details  type `show w'.  This is free software&comma. and you are welcome  to redistribute it under certain conditions; type `show c'  for details.        

     The hypothetical commands `show w' and `show c' should show the  appropriate parts of the General Public License. Of course&comma. the  commands you use may be called something other than `show w' and  `show c'; they could even be mouse-clicks or menu items--whatever  suits your program.        

     You should also get your employer (if you work as a programmer) or  your school&comma. if any&comma. to sign a &cdq.copyright disclaimer&cdq. for the  program&comma. if necessary. Here is a sample; alter the names&colon.        

     Yoyodyne&comma. Inc.&comma. hereby disclaims all copyright interest in the  program `Gnomovision' (which makes passes at compilers) written by  James Hacker.        

     signature of Ty Coon&comma. 1 April 1989   
     Ty Coon&comma. President of Vice           

     This General Public License does not permit incorporating your  program into proprietary programs. If your program is a subroutine  library&comma. you may consider it more useful to permit linking  proprietary applications with the library. If this is what you want  to do&comma. use the GNU Library General Public License instead of this  License.             


     FSF & GNU inquiries & questions to gnu@gnu.org.   
     Copyright notice above.   

     Free Software Foundation&comma. Inc.&comma.   
     59 Temple Place - Suite 330&comma. Boston&comma. MA 02111&comma. USA   
     Updated&colon. 3 Jan 2000 rms   

.br
See Also&colon.
:link reftype=hd res=279.License:elink.
.br
:link reftype=hd res=440.GNU License:elink.
.br
:h1 res=441.COMPILER OPTIONS
:i1 id=COMPILER OPTIONS.COMPILER OPTIONS
:p.COMPILER OPTIONS
:p.:hp2.Compiler Options
:ehp2.
:p.:hp2.Description
:ehp2.

     Invoking the Harbour compiler&colon.   
     ==============================   

        harbour <file[.prg]> [options]   
     or                                  
        harbour [options] <file[.prg]>   
     or   
        harbour [options] <file[.prg]> [options]   


     The command line options have to be separated by at least one space.  The option can start with either '/' character or '-' character.        

     The Harbour command line options&colon.   
     =================================   

     /a               automatic memvar declaration   
     -----------------   
         This causes all variables declared by PARAMETER&comma. PRIVATE or PUBLIC  statements to be automatically declared as MEMVAR variables.        

     /b               debug info   
     -----------------   
         The compiler generates all information required for debugging   

     /d<id>[=<val>]   #define <id>   
     -----------------   

     /es[<level>]     set exit severity   
     -----------------   

         /es or /es0 - all warnings are ignored and exit code returned by  the compiler (accessed by DOS ERRORLEVEL command)  is equal to 0 if there are no errors in compiled  source file.        
         /es1        - any warnings generate a non-zero exit code&comma. but  output is still created.        
         /es2        - all warnings are treated as errors and no output  file is created. The exit code is set to a non-zero  value.        

     /g<type>         output type generated is <type>   
     -----------------                                  

         /gc          output type&colon. C source (.c) (default)   
         /gf          output type&colon. Windows/DOS OBJ32 (.obj)   
         /gh          output type&colon. Harbour Portable Object (.hrb)   
         /gj          output type&colon. Java source (.java)      
         /gp          output type&colon. Pascal source (.pas)     
         /gr          output type&colon. Windows resource (.rc)   

     /i<path>         add #include file search path   
     -----------------   

     /l               suppress line number information      
     -----------------   
         The compiler does not generate the source code line numbers in  the output file. The PROCLINE() function will return 0 for  modules compiled using this option.        

     /m               compile current module only   
     -----------------   

     /n               no implicit starting procedure   
     -----------------   
         The compiler does not create a procedure with the same name as  the compiled file. This means that any declarations placed  before the first PROCEDURE or FUNCTION statement have file-  wide scope and can be accessed/used in all functions/procedures  defined in the compiled source file. All executable statements  placed at the beginning of the file and before the first  PROCEDURE/FUNCTION statement are ignored.        

     /o<path>         output file drive and/or path   
     -----------------   

     /p               generate pre-processed output (.ppo) file   
     -----------------   
         The compiler only creates the file that contains the result of  pre-processing the source file.        

     /q               quiet   
     -----------------   
         The compiler does not print any messages during compiling  (except the copyright info).        

         /q0     be really quiet and don't display even the copyright info   

     /r[<lib>]        request linker to search <lib> (or none)   
     -----------------   
         Currently not supported in Harbour.   

     /s               syntax check only   
     -----------------   
         The compiler checks the syntax only. No output file is generated.   

     /t<path>         path for temp file creation   
     -----------------   
         Currently not used in Harbour (the Harbour compiler does not  create any temporary files).        

     /u[<file>]       use command definition set in <file> (or none)   
     -----------------   
         Not supported yet.   

     /v               variables are assumed M->   
     -----------------   
         All undeclared or unaliased variables are assumed MEMVAR  variables (private or public variables). If this switch is not  used then the scope of such variables is checked at runtime.        

     /w[<level>]      set warning level number (0..4&comma. default 1)   
     -----------------   

         /w0         - no warnings   
         /w or /w1   - Clipper compatible warnings   
         /w2         - some useful warnings missed in Clipper   
         /w3         - warnings generated for Harbour language extensions  and also enables strong type checking but only  warns against declared types&comma. or types which may be  calculated at compile time        
         /w4         - Enables warning about suspicious operations&comma. which  means if you mix undeclared types&comma. or types which  can not be calculated at compile time&comma.together with  declared types&comma. a warning will be  generated.       

     /x[<prefix>]     set symbol init function name prefix (for .c only)   
     -----------------   
         Sets the prefix added to the generated symbol init function name  (in C output currently). This function is generated  automatically for every PRG module compiled. This additional  prefix can be used to suppress problems with duplicated symbols  during linking an application with some third party libraries.        

     /y               trace lex & yacc activity   
     -----------------   
         The Harbour compiler uses the FLEX and YACC utilities to parse  the source code and to generate the required output file. This  option traces the activity of these utilities.        

     /z               suppress logical shortcutting (.and. & .or.)   
     -----------------   

     /10              restrict symbol length to 10 characters   
     -----------------   
         All variable and function names are cut to maximum 10 characters.   


     Compilation in batch mode.   
     ==========================   

      @<file>         compile list of modules in <file>   
     -----------------        
         Not supported yet.   



     Known incompatibilities between harbour and clipper compilers   
     =============================================================   

     NOTE&colon.   
       If you want a 100% compatible compile and runtime libraries then  you have to define HARBOUR_STRICT_CLIPPER_COMPATIBILITY. This  option should be defined in the file include/hbsetup.h (in fact this  option is placed in a comment by default - you need to remove the  /* */ characters only). This change has to be done before invoking  the make utility.        


     Handling of undeclared variables   
     --------------------------------   
       When a value is assigned to an undeclared variable and the '-v'  command line option is not used&comma. then the Clipper compiler assumes  that the variable is a PRIVATE or a PUBLIC variable and generates  POPM (pop memvar) opcode.        

       When the value of an undeclared variable is accessed and the '-v'  command line option is not used&comma. the Clipper compiler generates PUSHV  (push variable) opcode that determines the type of variable at runtime.  If a field with the requested name exists in the current workarea then  its value is used. If there is no field then a PRIVATE or a PUBLIC  variable is used (if exists).        

       The Harbour compiler generates an opcode to determine the type of  variable at runtime (POPVARIABLE or PUSHVARIABLE) in both cases  (assignment and access).        

     The difference can be checked by the following code&colon.   

          
      PROCEDURE MAIN()
      PRIVATE myname

        DBCREATE( &cdq.TEST&cdq.&comma. { { &cdq.MYNAME&cdq.&comma. &cdq.C&cdq.&comma. 10&comma. 0} } )
        USE test NEW
        SELECT test
        APPEND BLANK

        FIELD->myname  &colon.= &cdq.FIELD&cdq.
        MEMVAR->myname &colon.= &cdq.MEMVAR&cdq.

        myname &colon.= myname + &cdq. assigned&cdq.

        // In Clipper&colon. &cdq.FIELD&cdq.&comma.  In Harbour&colon. &cdq.FIELD assigned&cdq.
        ? FIELD->myname

        // In Clipper&colon. &cdq.MEMVAR assigned&cdq.&comma. In Harbour&colon. &cdq.MEMVAR&cdq.
        ? MEMVAR->myname

        USE

      RETURN
     

     Passing an undeclared variable by the reference   
     -----------------------------------------------   
       The Clipper compiler uses the special opcode PUSHP to pass a  reference to an undeclared variable ( '@' operator ). The type of  passed variable is checked at runtime (field or memvar). However&comma.  field variables cannot be passed by reference. This means that  Clipper checks the memvar variable only and doesn't look for a field.  This is the reason why the Harbour compiler uses the usual  PUSHMEMVARREF opcode in such cases. Notice that the runtime behavior  is the same in Clipper and in Harbour - only the generated opcodes  are different.        


     Handling of object messages   
     ---------------------------   
       The HARBOUR_STRICT_CLIPPER_COMPATIBILITY setting determines  the way chained send messages are handled.        

     For example&comma. the following code&colon.   

     a&colon.b( COUNT() )&colon.c += 1   

     will be handled as&colon.   

     a&colon.b( COUNT() )&colon.c &colon.= a&colon.b( COUNT() )&colon.c + 1   

     in strict Clipper compatibility mode and   

     temp &colon.= a&colon.b( COUNT() )&comma. temp&colon.c += 1   

     in non-strict mode.   

       In practice&comma. Clipper will call the COUNT() function two times&colon.  the first time before addition and the second one after addition.  In Harbour&comma. COUNT() will be called only once&comma. before addition.        

       The Harbour (non-strict) method is&colon.   
     1) faster   
     2) it guarantees that the same instance variable of the same object  will be changed        

     (See also&colon. source/compiler/expropt.c)   

     Initialization of static variables      
     ----------------------------------      

     There is a difference in the initialization of static  variables that are initialized with a codeblock that refers to  a local variable. For example&colon.        

      
      PROCEDURE TEST()
      LOCAL MyLocalVar
      STATIC MyStaticVar &colon.= {|| MyLocalVar }

        MyLocalVar &colon.=0
        ? EVAL( MyStaticVar )

      RETURN
      

     The above code compiles fine in Clipper&comma. but it generates a  runtime error Error/BASE 1132 Bound error&colon. array access     
     Called form (b)STATICS$(0)   

     In Harbour this code generates a compile time error&colon.  Error E0009 Illegal variable (b) initializer&colon. 'MyLocalVar'        

     Both Clipper and Harbour are handling all local variables used in a  codeblock in a special way&colon. they are detached from the local stack  of function/procedure where they are declared. This allows access to  these variables after the exit from a function/procedure. However&comma.  all static variables are initialized in a separate procedure     
     ('STATICS$' in Clipper and '(_INITSTATICS)' in Harbour) before the  main procedure and before all INIT procedures. The local variables  don't exist on the eval stack when static variables are initialized&comma.  so they cannot be detached.        

:h1 res=330.CLASS
:i1 id=CLASS.CLASS
:p.CLASS
:p.:hp2.Define a Class for Object Oriented Programming
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CLASS <ClassName> [ <FROM, INHERIT> <SuperClass> ]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <ClassName>:ehp2.    Name of the class to define. By tradition, Harbour classes start with "T" to avoid collisions with user-  created classes.       

      :hp2. <SuperClass>:ehp2.   The Parent class to use for inheritance    

:p.:hp2.Description
:ehp2.
     CLASS creates a class from which you can create objects.  Each Class is defined in a separate .PRG file dedicated to that  purpose. You cannot create more than one class in a .PRG.  After the CLASS command begins the definition&comma. the DATA  elements (also known as instance variables) and METHODS of the  class are named.       

     Classes can inherit from a single <SuperClass>&comma. but the chain of  inheritance can extend to many levels.       

     A program uses a Class by calling the Class Constructor&comma. the  New() method&comma. to create an object. That object is usually assigned  to a variable&comma. which is used to access the DATA elements and  methods.     

:p.:hp2.Examples
:ehp2.

  
      CLASS TBColumn

         DATA Block      // Code block to retrieve data for the column
         DATA Cargo      // User-definable variable
         DATA ColorBlock // Code block that determines color of data items
         DATA ColSep     // Column separator character
         DATA DefColor   // Array of numeric indexes into the color table
         DATA Footing    // Column footing
         DATA FootSep    // Footing separator character
         DATA Heading    // Column heading
         DATA HeadSep    // Heading separator character
         DATA Width      // Column display width
         DATA ColPos     // Temporary column position on screen

         METHOD New()    // Constructor

      ENDCLASS
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CLASS is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=442.TClass():elink.
.br
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:link reftype=hd res=444.METHOD:elink.
.br
:h1 res=443.DATA
:i1 id=DATA.DATA
:p.DATA
:p.:hp2.Define a DATA instance variable for the objects of a class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.DATA <DataName1> [,<DataNameN>] [ AS <type> ] [ INIT <uValue> ]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <DataName1>:ehp2.    Name of the DATA      

      :hp2. <type>:ehp2.         Optional data type specification from the following: Character, Numeric, Date, Logical, Codeblock, Nil       

      :hp2. <uValue>:ehp2.       Optional initial value when creating a new object    

:p.:hp2.Description
:ehp2.
     DATA elements can also be thought of as the &cdq.properties&cdq. of an  object. They can be of any data type&comma. including codeblock.  Once an object has been created&comma. the DATA elements are referenced  with the colon (&colon.) as in  MyObject&colon.Heading &colon.= &cdq.Last name&cdq..  Usually a class also defines methods to manipulate the DATA.       

     You can use the &cdq.AS <type>&cdq. clause to enforce that the DATA is  maintained as a certain type. Otherwise it will take on the type of  whatever value is first assigned to it.       

     Use the &cdq.INIT <uValue>&cdq. clause to initialize that DATA to <uValue>  whenever a new object is created.     

:p.:hp2.Examples
:ehp2.

  
      CLASS TBColumn

         DATA Block      // Code block to retrieve data for the column
         DATA Cargo      // User-definable variable
         DATA ColorBlock // Code block that determines color of data items
         DATA ColSep     // Column separator character
         DATA DefColor   // Array of numeric indexes into the color table
         DATA Footing    // Column footing
         DATA FootSep    // Footing separator character
         DATA Heading    // Column heading
         DATA HeadSep    // Heading separator character
         DATA Width      // Column display width
         DATA ColPos     // Temporary column position on screen

         METHOD New()    // Constructor

      ENDCLASS
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     DATA is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:link reftype=hd res=444.METHOD:elink.
.br
:link reftype=hd res=445.CLASSDATA:elink.
.br
:h1 res=445.CLASSDATA
:i1 id=CLASSDATA.CLASSDATA
:p.CLASSDATA
:p.:hp2.Define a CLASSDATA variable for a class (NOT for an Object!)
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.CLASSDATA <DataName1> [,<DataNameN>] [ AS <type> ] [ INIT <uValue> ]
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <DataName1>:ehp2.    Name of the DATA      

      :hp2. <type>:ehp2.         Optional data type specification from the following: Character, Numeric, Date, Logical, Codeblock, Nil       

      :hp2. <uValue>:ehp2.       Optional initial value at program startup    

:p.:hp2.Description
:ehp2.
     CLASSDATA variables can also be thought of as the &cdq.properties&cdq. of an  entire class. Each CLASSDATA exists only once&comma. no matter how many  objects are created. A common usage is for a counter that is  incremented whenever an object is created and decremented when one  is destroyed&comma. thus monitoring the number of objects in existance  for this class.       

     You can use the &cdq.AS <type>&cdq. clause to enforce that the CLASSDATA is  maintained as a certain type. Otherwise it will take on the type of  whatever value is first assigned to it.  Use the &cdq.INIT <uValue>&cdq. clause to initialize that DATA to <uValue>  whenever the class is first used.     

:p.:hp2.Examples
:ehp2.

     
      CLASS TWindow
         DATA   hWnd&comma. nOldProc
         CLASSDATA lRegistered AS LOGICAL
      ENDCLASS
      
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     CLASSDATA is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:link reftype=hd res=444.METHOD:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:h1 res=444.METHOD
:i1 id=METHOD.METHOD
:p.METHOD
:p.:hp2.Declare a METHOD for a class in the class header
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) [ CONSTRUCTOR ]
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) INLINE <Code,...>
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) BLOCK  <CodeBlock>
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) EXTERN <FuncName>([<args,...>])
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) SETGET
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) VIRTUAL
:ehp2.
:p.:hp2.METHOD <MethodName>( [<param>] )      OPERATOR <op>
:ehp2.
:p.:hp2.METHOD <MethodName>( [<params,...>] ) CLASS <ClassName>
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <MethodName>:ehp2.    Name of the method to define      

      :hp2. <params,...>:ehp2.    Optional parameter list    

:p.:hp2.Description
:ehp2.
     Methods are &cdq.class functions&cdq. which do the work of the class.  All methods must be defined in the class header between the  CLASS and ENDCLASS commands.  If the body of a method is not fully  defined here&comma. the full body is written below the ENDCLASS command  using this syntax&colon.       

        METHOD <MethodName>( [<params&comma....>] ) CLASS <ClassName>       

     Methods can reference the current object with the keyword &cdq.Self&colon.&cdq. or  its shorthand version &cdq.&colon.&colon.&cdq..       

     CLAUSES&colon.       

     CONSTRUCTOR  Defines a special method Class Constructor method&comma.  used to create objects.  This is usually the  New() method. Constructors always return the new  object.       

     INLINE       Fast and easy to code&comma. INLINE lets you define the  code for the method immediately within the definition  of the Class. Any methods not declared INLINE or BLOCK  must be fully defined after the ENDCLASS command.  The <Code&comma....> following INLINE receives a parameter  of Self. If you need to receive more parameters&comma. use  the BLOCK clause instead.       

     BLOCK        Use this clause when you want to declare fast 'inline'  methods that need parameters. The first parameter to  <CodeBlock> must be Self&comma. as in&colon.       

         METHOD <MethodName> BLOCK {|Self&comma.<arg1>&comma.<arg2>&comma. ...&comma.<argN>|...}       

     EXTERN       If an external function does what the method needs&comma.  use this clause to make an optimized call to that  function directly.       

     SETGET       For calculated Data. The name of the method can be  manipulated like a Data element to Set or Get a value.       

     VIRTUAL      Methods that do nothing. Useful for Base classes where  the child class will define the method's behavior&comma. or  when you are first creating and testing a Class.       

     OPERATOR     Operator Overloading for classes.  See example Tests/TestOp.prg for details.       

     CLASS <ClassName>  Use this syntax only for defining a full method after  the ENDCLASS command.     

:p.:hp2.Examples
:ehp2.

      
      CLASS TWindow
         DATA   hWnd&comma. nOldProc
         METHOD New( ) CONSTRUCTOR
         METHOD Capture() INLINE  SetCapture( &colon.&colon.hWnd )
         METHOD End() BLOCK  { | Self&comma. lEnd | If( lEnd &colon.= &colon.&colon.lValid()&comma.;
                                 &colon.&colon.PostMsg( WM_CLOSE )&comma.)&comma. lEnd }
         METHOD EraseBkGnd( hDC )
         METHOD cTitle( cNewTitle ) SETGET
         METHOD Close() VIRTUAL
      ENDCLASS

      METHOD New( ) CLASS TWindow
         local nVar&comma. cStr
         ... <code> ...
         ... <code> ...
      RETURN Self
      

:p.:hp2.Tests
:ehp2.

      
      TestOp.prg
       
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     METHOD is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=442.TClass():elink.
.br
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:h1 res=446.MESSAGE
:i1 id=MESSAGE.MESSAGE
:p.MESSAGE
:p.:hp2.Route a method call to another Method
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.MESSAGE <MessageName>   METHOD <MethodName>( [<params,...>] )
:ehp2.
:p.:hp2.MESSAGE <MessageName>() METHOD <MethodName>( [<params,...>] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <MessageName>:ehp2.    The pseudo-method name to define      

      :hp2. <MethodName>:ehp2.     The method to create and call when <MessageName> is invoked.       

      :hp2. <params,...>:ehp2.     Optional parameter list for the method    

:p.:hp2.Description
:ehp2.
     The MESSAGE command is a seldom-used feature that lets you re-route  a call to a method with a different name. This can be necessary if  a method name conflicts with a public function that needs to be  called from within the class methods.       

     For example&comma. your app may have a public function called BeginPaint()  that is used in painting windows. It would also be natural to have a  Window class method called &colon.BeginPaint() that the application can  call. But within the class method you would not be able to call the  public function because internally methods are based on static  functions (which hide public functions of the same name).       

     The MESSAGE command lets you create the true method with a different  name (&colon.&colon.xBeginPaint())&comma. yet still allow the &colon.&colon.BeginPaint() syntax  to call &colon.&colon.xBeginPaint().  This is then free to call the public  function BeginPaint().     

:p.:hp2.Examples
:ehp2.

  
      CLASS TWindow
         DATA   hWnd&comma. nOldProc
         METHOD New( ) CONSTRUCTOR
         MESSAGE BeginPaint METHOD xBeginPaint()
      ENDCLASS
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     MESSAGE is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=444.METHOD:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:h1 res=447.ERROR HANDLER
:i1 id=ERROR HANDLER.ERROR HANDLER
:p.ERROR HANDLER
:p.:hp2.Designate a method as an error handler for the class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ERROR HANDLER <MethodName>( [<params,...>] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <MethodName>:ehp2.    Name of the method to define      

      :hp2. <params,...>:ehp2.    Optional parameter list    

:p.:hp2.Description
:ehp2.
     ERROR HANDLER names the method that should handle errors for the  class being defined.     

:p.:hp2.Examples
:ehp2.

  
      CLASS TWindow
         ERROR HANDLER  MyErrHandler()
      ENDCLASS
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ERROR HANDLER is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=448.ON ERROR:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:link reftype=hd res=444.METHOD:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:h1 res=448.ON ERROR
:i1 id=ON ERROR.ON ERROR
:p.ON ERROR
:p.:hp2.Designate a method as an error handler for the class
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ON ERROR <MethodName>( [<params,...>] )
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <MethodName>:ehp2.    Name of the method to define      

      :hp2. <params,...>:ehp2.    Optional parameter list    

:p.:hp2.Description
:ehp2.
     ON ERROR is a synonym for ERROR HANDLER.  It names the method that should handle errors for the  class being defined.     

:p.:hp2.Examples
:ehp2.

  
      CLASS TWindow
         ON ERROR  MyErrHandler()
      ENDCLASS
  
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ON ERROR is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=447.ERROR HANDLER:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:link reftype=hd res=444.METHOD:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:h1 res=449.ENDCLASS
:i1 id=ENDCLASS.ENDCLASS
:p.ENDCLASS
:p.:hp2.End the declaration of a class.
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.ENDCLASS
:ehp2.

:p.:hp2.Description
:ehp2.
     ENDCLASS marks the end of a class declaration.  It is usually followed by the class methods that are not INLINE.     

:p.:hp2.Examples
:ehp2.

   
      CLASS TWindow
         DATA   hWnd&comma. nOldProc
      ENDCLASS
   
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     ON ERROR is a Harbour extension.     

:p.:hp2.Platforms
:ehp2.
     All     
.br
See Also&colon.
:link reftype=hd res=329.Object Oriented Programming:elink.
.br
:link reftype=hd res=330.CLASS:elink.
.br
:link reftype=hd res=444.METHOD:elink.
.br
:link reftype=hd res=443.DATA:elink.
.br
:h1 res=450.HB_LANGSELECT()
:i1 id=HB_LANGSELECT().HB_LANGSELECT()
:p.HB_LANGSELECT()
:p.:hp2.Select a specific nation message module
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_LANGSELECT(<cNewLang>)   --> cOldLang
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <cNewLang>:ehp2.    The ID of the country language module The possible values for <cNewLang> is below as is defined in the  Lang library,sorted by language.       


:cgraphic.
 
      <cNewLang>   Language     Codepage
      EU           Basque       850
      CS852        Czech        852
      CSISO        Czech        ISO-8859-2
      CSKAM        Czech        KAM
      CA           Catalan      850
      EN           English      437
      FR           French       850
      GL           Galician     850
      HE862        Hebrew       862
      HEWIN        Hebrew       1255
      HU852        Hungarian    852
      HUCWI        Hungarian    CWI-2
      HUWIN        Hungarian    Windows-1
      IS85         Icelandic    850
      PT           Portuguese   850
      RO           Romanian     852
      SRISO        Serbian      ISO-8859-2
      SR852        Serbian      852
      ES           Spanish      850
 
:ecgraphic.


:p.:hp2.Returns
:ehp2.
      :hp2. <cOldLang>:ehp2.     The old language indentifier    

:p.:hp2.Description
:ehp2.
     This function set a default language module for date/month names&comma.  internal warnigs&comma.NatMsg messages and internal errors. When a  Lang ID is selected all messages will be output as the current lang  selected until another one is selected or the program ends.     

:p.:hp2.Examples
:ehp2.

      REQUEST HB_LANG_PT
      REQUEST HB_LANG_RO
      REQUEST HB_LANG_ES
      FUNCTION MAIN()
      HB_LANGSELECT('PT')       // Default language is now Portuguese
      ? CDOW(DATE()) //Segunda-feira
      ? 'Old language id selected is &cdq.&comma.HB_LANGSELECT()   // PT
      HB_LANGSELECT('RO')       // Default language is now Romanian
      ? CMONTH(DATE()) // Mai
      ? 'Old language id selected is &cdq.&comma.HB_LANGSELECT()   // RO
      HB_LANGSELECT('ES')       // Default language is now Romanian
      ? CMONTH(DATE()) //       Mayo
      ? CDOW(DATE()) //  Lunes

    Return nil

:p.:hp2.Tests
:ehp2.

      See tests/langapi.prg
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour Extension.     

:p.:hp2.Platforms
:ehp2.
     Dos&comma.Win32&comma.OS/2     

:p.:hp2.Files
:ehp2.
     Libraty is rtl     
.br
See Also&colon.
:link reftype=hd res=451.HB_LANGNAME():elink.
.br
:link reftype=hd res=169.NATIONMSG():elink.
.br
:h1 res=451.HB_LANGNAME()
:i1 id=HB_LANGNAME().HB_LANGNAME()
:p.HB_LANGNAME()
:p.:hp2.Return the Name of the Current Language module in USE
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.HB_LANGNAME()   --> cLangName
:ehp2.
:p.:hp2.Arguments
:ehp2.
       None.    

:p.:hp2.Returns
:ehp2.
      :hp2. <cLangName>:ehp2.    Name of the Current language in use    

:p.:hp2.Description
:ehp2.
     This function return the current name of the language module in use.     

:p.:hp2.Examples
:ehp2.

      REQUEST HB_LANG_PT
      REQUEST HB_LANG_RO
      REQUEST HB_LANG_ES
      FUNCTION MAIN()
      HB_LANGSELECT('PT')       // Default language is now Portuguese
      ? CDOW(DATE()) //Segunda-feira
      ? 'Current language is &cdq.&comma.HB_LANGNAME() //Portuguese
      ? 'Old language id selected is &cdq.&comma.HB_LANGSELECT()   // PT
      HB_LANGSELECT('RO')       // Default language is now Romanian
      ? CMONTH(DATE()) // Mai
      ? 'Old language id selected is &cdq.&comma.HB_LANGSELECT()   // RO
      HB_LANGSELECT('ES')       // Default language is now Romanian
      ? 'Current language is &cdq.&comma.HB_LANGNAME() //Spanish
      ? CMONTH(DATE()) //       Mayo
      ? CDOW(DATE()) //  Lunes

:p.:hp2.Tests
:ehp2.

      See tests/langapi.prg
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is a Harbour Extension     

:p.:hp2.Platforms
:ehp2.
     Dos&comma.Win32&comma.OS/2     

:p.:hp2.Files
:ehp2.
     Library is lang     
.br
See Also&colon.
:link reftype=hd res=450.HB_LANGSELECT():elink.
.br
:link reftype=hd res=169.NATIONMSG():elink.
.br
:h1 res=452.SETMODE()
:i1 id=SETMODE().SETMODE()
:p.SETMODE()
:p.:hp2.Change the video mode to a specified number of rows and columns
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.SETMODE( <nRows>, <nCols> ) --> lSuccess
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <nRows>:ehp2.   is the number of rows for the video mode to set.      

      :hp2. <nCols>:ehp2.   is the number of columns for the video mode to set.    

:p.:hp2.Returns
:ehp2.
      :hp2. SETMODE():ehp2.   returns true if the video mode change was successful; otherwise, it returns false.     

:p.:hp2.Description
:ehp2.
     SETMODE() is a function that change the video mode depend on the  video card and monitor combination&comma. to match the number of rows and  columns specified.  Note that there are only a real few combination or rows/cols pairs  that produce the video mode change.  The followings are availables for D.O.S&colon.       


:cgraphic.
 
      12 rows x 40 columns   12 rows x 80 columns
      25 rows x 40 columns   25 rows x 80 columns
      28 rows x 40 columns   28 rows x 80 columns
      50 rows x 40 columns   43 rows x 80 columns
      None                   50 rows x 80 columns
 
:ecgraphic.

     The follow modes are avaliable to Windows       


:cgraphic.
 

      25 rows x 40 columns
      25 rows x 80 columns
      50 rows x 40 columns
      43 rows x 80 columns
      50 rows x 80 columns
 
:ecgraphic.

     Some modes only are availables for color and/or VGA monitors.  Any change produced on the screen size is updated in the values  returned by MAXROW() and MAXCOL().     

:p.:hp2.Examples
:ehp2.

     The first example change to a 12 lines of display mode&colon.
      IF SETMODE( 12&comma. 40)
         ? &cdq.Hey man are you blind ?&cdq.
      ELSE
         ? &cdq.Mom bring me my glasses!&cdq.
      ENDIF

     Next example change to a 50 lines mode&colon.
      IF SETMODE( 50&comma. 80)
         ? &cdq.This wonderful mode was successfully set&cdq.
      ELSE
         ? &cdq.Wait. this monitor are not made in rubber !&cdq.
      ENDIF

:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     Some of these modes are not availables on Clipper     

:p.:hp2.Platforms
:ehp2.
     DOS&comma.WIN32     

:p.:hp2.Files
:ehp2.
     Source  is gtdos.c&comma.gtwin.c     
.br
See Also&colon.
:link reftype=hd res=453.MAXCOL():elink.
.br
:link reftype=hd res=454.MAXROW():elink.
.br
:h1 res=14.EVAL()
:i1 id=EVAL().EVAL()
:p.EVAL()
:p.:hp2.Evaluate a code block
:ehp2.
:p.:hp2.Syntax
:ehp2.
:p.:hp2.EVAL( <bBlock> [, <xVal> [,...]])   --> xExpression
:ehp2.
:p.:hp2.Arguments
:ehp2.
      :hp2. <bBlock>:ehp2.     Code block expression to be evaluated      

      :hp2. <xVal>:ehp2.       Argument to be passed to the code block expression      

      :hp2. <xVal...>:ehp2.    Argument list to be passed to the code block expression    

:p.:hp2.Returns
:ehp2.
      :hp2. <xExpression>:ehp2.    The result of the evaluated code block    

:p.:hp2.Description
:ehp2.
     This function evaluates the code bloc expressed as <bBlock> and  returns its evaluated value.If their are multiple expressions within  the code block&comma.the last expression will be value of this function.       

     If the code block requires parameters to be passed to it&comma.they are  specified in the parameter list <xVal> and following.Each parameter  is separated by a comma within the expression list.     

:p.:hp2.Examples
:ehp2.

      FUNC MAIN
      LOCAL    sbBlock   &colon.= {|| NIL }
      ?  Eval( 1 )
      ?  Eval( @sbBlock )

      ? Eval( {|p1| p1 }&comma.&cdq.A&cdq.&comma.&cdq.B&cdq.)
      ? Eval( {|p1&comma.p2| p1+p2 }&comma.&cdq.A&cdq.&comma.&cdq.B&cdq.)
      ? Eval( {|p1&comma.p2&comma.p3| p1 }&comma.&cdq.A&cdq.&comma.&cdq.B&cdq.)
      Return Nil

:p.:hp2.Tests
:ehp2.

      See examples
:p.:hp2.Status
:ehp2.
   Ready

:p.:hp2.Compliance
:ehp2.
     This function is Ca Clipper compliant     

:p.:hp2.Platforms
:ehp2.
     All     

:p.:hp2.Files
:ehp2.
     Library is vm     
.br
See Also&colon.
:link reftype=hd res=10.AEVAL():elink.
.br
:link reftype=hd res=15.DBEVAL():elink.
.br
:euserdoc.
